@@ -39,9 +39,9 @@ MiniView::MiniView(mdc::Layer *layer)
 
   set_cache_toplevel_contents(true);
 
-  layer->get_view()->set_event_callbacks(sigc::mem_fun(*this, &MiniView::view_button_cb), 
-    sigc::mem_fun(*this, &MiniView::view_motion_cb),
-    sigc::slot<bool, CanvasView*, KeyInfo, EventState, bool>());
+  layer->get_view()->set_event_callbacks(boost::bind(&MiniView::view_button_cb, this, _1, _2, _3, _4, _5),
+    boost::bind(&MiniView::view_motion_cb, this, _1, _2, _3),
+    boost::function<bool (CanvasView*, KeyInfo, EventState, bool)>());
 }
 
 
@@ -305,22 +305,22 @@ void MiniView::set_active_view(mdc::CanvasView *canvas_view, const model_Diagram
     _viewport_figure->set_draggable(true);
     _viewport_figure->set_needs_render();
 
-    _viewport_figure->signal_bounds_changed().connect(sigc::mem_fun(this, &MiniView::viewport_dragged));
+    scoped_connect(_viewport_figure->signal_bounds_changed(),boost::bind(&MiniView::viewport_dragged, this, _1));
   }
 
-  if (_view_repaint_connection)
+  if (_view_repaint_connection.connected())
     _view_repaint_connection.disconnect();
 
-  if (_view_viewport_change_connection)
+  if (_view_viewport_change_connection.connected())
     _view_viewport_change_connection.disconnect();
 
   if (_canvas_view)
   {
-    _view_viewport_change_connection= _canvas_view->signal_viewport_changed().
-      connect(sigc::mem_fun(this, &MiniView::viewport_changed));
+    _view_viewport_change_connection= *scoped_connect(_canvas_view->signal_viewport_changed(),
+      boost::bind(&MiniView::viewport_changed, this)).get();
     
-    _view_repaint_connection= _canvas_view->signal_repaint().connect(
-      sigc::hide(sigc::hide(sigc::hide(sigc::hide(sigc::mem_fun(this, &CanvasItem::set_needs_render))))));
+    _view_repaint_connection= *scoped_connect(_canvas_view->signal_repaint(),
+      (boost::bind(&CanvasItem::set_needs_render, this))).get();
 
 
     _viewport_figure->set_visible(true);
