@@ -50,47 +50,49 @@ static std::map<std::string, std::string> auto_save_files;
 
 
 WBContextModel::WBContextModel(WBContextUI *wbui)
-: _wbui(wbui), _auto_save_point(0), _last_auto_save_time(0), _file(0)
+: _wbui(wbui), _file(0), _auto_save_point(0), _last_auto_save_time(0), _auto_save_timer(NULL)
 
 {  
   _overview= new PhysicalOverviewBE(_wbui->get_wb());
   
-  _wbui->get_wb()->get_grt_manager()->get_clipboard()->signal_changed().connect(sigc::mem_fun(this, &WBContextModel::selection_changed));
-  _overview->signal_selection_changed().connect(sigc::mem_fun(this, &WBContextModel::selection_changed)); // make edit menu captions to update
+  scoped_connect(_wbui->get_wb()->get_grt_manager()->get_clipboard()->signal_changed(),boost::bind(&WBContextModel::selection_changed, this));
+  scoped_connect(_overview->signal_selection_changed(),boost::bind(&WBContextModel::selection_changed, this)); // make edit menu captions to update
 
   CommandUI *cmdui = wbui->get_command_ui();
-  sigc::slot<bool> validate = sigc::mem_fun(this, &WBContextModel::has_selected_schema);
+  boost::function<bool ()> validate = boost::bind(&WBContextModel::has_selected_schema, this);
   cmdui->add_builtin_command("addModelDiagram",
-                             sigc::mem_fun(this, &WBContextModel::add_model_diagram),
-                             sigc::mem_fun(this, &WBContextModel::has_selected_model));
+                             boost::bind(&WBContextModel::add_model_diagram, this),
+                             boost::bind(&WBContextModel::has_selected_model, this));
   cmdui->add_builtin_command("addModelSchema",
-                             sigc::mem_fun(this, &WBContextModel::add_model_schema),
-                             sigc::mem_fun(this, &WBContextModel::has_selected_model));
+                             boost::bind(&WBContextModel::add_model_schema, this),
+                             boost::bind(&WBContextModel::has_selected_model, this));
   cmdui->add_builtin_command("addModelTable",
-                             sigc::mem_fun(this, &WBContextModel::add_model_table),
+                             boost::bind(&WBContextModel::add_model_table, this),
                              validate);
   cmdui->add_builtin_command("addModelView",
-                             sigc::mem_fun(this, &WBContextModel::add_model_view),
+                             boost::bind(&WBContextModel::add_model_view, this),
                              validate);
   cmdui->add_builtin_command("addModelRoutine",
-                             sigc::mem_fun(this, &WBContextModel::add_model_rgroup),
+                             boost::bind(&WBContextModel::add_model_rgroup, this),
                              validate);
   
   // used to update the currentDiagram field
-  _wbui->signal_main_form_change().connect(sigc::mem_fun(this, &WBContextModel::update_current_diagram));
+  scoped_connect(_wbui->signal_main_form_change(),boost::bind(&WBContextModel::update_current_diagram, this, _1));
 
   // setup auto-save for model
   int interval = _wbui->get_wb()->get_root()->options()->options().get_int("workbench:AutoSaveModelInterval", 60);
   if (interval > 0)
-    _wbui->get_wb()->get_grt_manager()->run_every(sigc::mem_fun(this, &WBContextModel::auto_save_document), interval);
+    _auto_save_timer = _wbui->get_wb()->get_grt_manager()->run_every(boost::bind(&WBContextModel::auto_save_document, this), interval);
   _auto_save_interval = interval;
   
-  _wbui->get_wb()->get_root()->options()->signal_dict_changed().connect(sigc::mem_fun(this, &WBContextModel::option_changed));
+  _wbui->get_wb()->get_root()->options()->signal_dict_changed()->connect(boost::bind(&WBContextModel::option_changed, this, _1, _2, _3));
 }
 
 
 WBContextModel::~WBContextModel()
 {
+  if (_auto_save_timer)
+    _wbui->get_wb()->get_grt_manager()->cancel_timer(_auto_save_timer);
   CommandUI *cmdui = _wbui->get_command_ui();
   cmdui->remove_builtin_command("addModelDiagram");
   cmdui->remove_builtin_command("addModelSchema");
@@ -145,8 +147,10 @@ bool WBContextModel::auto_save_document()
   
   if (interval != _auto_save_interval)
   {
+    if (_auto_save_timer)
+        wb->get_grt_manager()->cancel_timer(_auto_save_timer);
     // schedule new interval
-    wb->get_grt_manager()->run_every(sigc::mem_fun(this, &WBContextModel::auto_save_document), interval);
+    _auto_save_timer = wb->get_grt_manager()->run_every(boost::bind(&WBContextModel::auto_save_document, this), interval);
     return false;
   }
   
@@ -255,7 +259,7 @@ void WBContextModel::model_created(ModelFile *file, workbench_DocumentRef doc)
   _wbui->get_wb()->get_component<WBComponentLogical>()->setup_logical_model(doc.get_grt(), _doc);
   _wbui->get_wb()->get_component<WBComponentPhysical>()->setup_physical_model(doc.get_grt(), _doc, "Mysql", "5.1.22");
   
-  _wbui->get_wb()->foreach_component(sigc::mem_fun(&WBComponent::reset_document));
+  _wbui->get_wb()->foreach_component(boost::bind(&WBComponent::reset_document, _1));
   
   _doc->physicalModels().get(0)->get_data()->set_delegate(this);
   
@@ -270,9 +274,9 @@ void WBContextModel::model_loaded(ModelFile *file, workbench_DocumentRef doc)
   _file= file;
   _doc= doc;
   
-  _wbui->get_wb()->foreach_component(sigc::mem_fun(&WBComponent::reset_document));
+  _wbui->get_wb()->foreach_component(boost::bind(&WBComponent::reset_document, _1));
   
-  _wbui->get_wb()->foreach_component(sigc::mem_fun(&WBComponent::document_loaded));
+  _wbui->get_wb()->foreach_component(boost::bind(&WBComponent::document_loaded, _1));
   
   _doc->physicalModels().get(0)->get_data()->set_delegate(this);
     
@@ -294,7 +298,7 @@ void WBContextModel::model_loaded(ModelFile *file, workbench_DocumentRef doc)
 
 void WBContextModel::realize()
 {
-  _page_settings_conn = _doc->pageSettings()->signal_changed().connect(sigc::mem_fun(this, &WBContextModel::page_settings_changed));
+  _page_settings_conn = _doc->pageSettings()->signal_changed()->connect(boost::bind(&WBContextModel::page_settings_changed, this, _1, _2));
   
   _doc->physicalModels()[0]->get_data()->realize();
 }
@@ -375,8 +379,7 @@ void WBContextModel::release_image(const std::string &file)
  *****************************************************************************/
 mdc::CanvasView *WBContextModel::create_diagram(const model_DiagramRef &view)
 {
-  return _wbui->get_wb()->execute_in_main_thread<mdc::CanvasView*>("create_diagram", sigc::bind
-                                                                                  (sigc::mem_fun(this, &WBContextModel::create_diagram_main), view));
+  return _wbui->get_wb()->execute_in_main_thread<mdc::CanvasView*>("create_diagram", boost::bind(&WBContextModel::create_diagram_main, this, view));
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -399,7 +402,7 @@ void WBContextModel::free_canvas_view(mdc::CanvasView *view)
       _wbui->get_wb()->destroy_view(view);
     else
       _wbui->get_wb()->execute_in_main_thread<void>("destroy view", 
-      sigc::bind<mdc::CanvasView*>(_wbui->get_wb()->destroy_view, view));
+      boost::bind(_wbui->get_wb()->destroy_view, view));
   }
 }
 
@@ -430,9 +433,9 @@ mdc::CanvasView *WBContextModel::create_diagram_main(const model_DiagramRef &dia
     return 0;
   }
   
-  diagram_reference->signal_objectActivated().connect(sigc::mem_fun(this, &WBContextModel::activate_canvas_object));
+  scoped_connect(diagram_reference->signal_objectActivated(),(boost::bind(&WBContextModel::activate_canvas_object, this, _1, _2)));
     
-  diagram_reference->signal_list_changed().connect(sigc::bind(sigc::mem_fun(this, &WBContextModel::diagram_object_list_changed), diagram));
+  diagram_reference->signal_list_changed()->connect(boost::bind(&WBContextModel::diagram_object_list_changed, this, _1, _2, _3, diagram));
   
   register_diagram_form(diagram);
   
@@ -446,7 +449,7 @@ mdc::CanvasView *WBContextModel::create_diagram_main(const model_DiagramRef &dia
     
     // use this signal instead of selection_change from canvas so that when the callback is called
     // the grt diagram object already reflects the selection changes
-    diagram_reference->get_data()->signal_selection_changed().connect(sigc::hide(sigc::mem_fun(this, &WBContextModel::selection_changed)));
+    scoped_connect(diagram_reference->get_data()->signal_selection_changed(),boost::bind(&WBContextModel::selection_changed, this));
 
     wb->request_refresh(RefreshNewDiagram, diagram_reference.id(), (NativeHandle)view->get_user_data());
   }
@@ -496,9 +499,8 @@ ModelDiagramForm *WBContextModel::get_diagram_form(mdc::CanvasView *view)
 
 void WBContextModel::notify_diagram_created(ModelDiagramForm *view)
 {
-  ChangeSignal::iterator signal_id = view->get_model_diagram()->signal_changed().
-    connect(sigc::bind(sigc::mem_fun(this, &WBContextModel::diagram_object_changed), view));
-  view->change_signal_id(signal_id);
+    scoped_connect(view->get_model_diagram()->signal_changed(),
+        boost::bind(&WBContextModel::diagram_object_changed, this, _1, _2, view));
     
   // now called from wb_component_physical.cpp:model_list_changed
   //_wbui->get_physical_overview()->send_refresh_diagram(model_DiagramRef());
@@ -528,7 +530,7 @@ void WBContextModel::update_current_diagram(bec::UIForm *form)
     if (diagram.is_valid() && diagram->owner().is_valid())
       diagram->owner()->currentDiagram(diagram);    
     
-    _wbui->get_command_ui()->signal_validate_edit_menu_items().emit();
+    (*_wbui->get_command_ui()->signal_validate_edit_menu_items())();
   }
 }
 
@@ -904,7 +906,7 @@ void WBContextModel::selection_changed()
 {
   if (!_wbui->get_wb()->get_grt_manager()->in_main_thread())
   {
-    _wbui->get_wb()->get_grt_manager()->run_when_idle(sigc::bind_return(sigc::mem_fun(this, &WBContextModel::selection_changed), false));
+    _wbui->get_wb()->get_grt_manager()->run_once_when_idle(boost::bind(&WBContextModel::selection_changed, this));
     return;
   }
     
@@ -964,7 +966,7 @@ void WBContextModel::selection_changed()
       }
     }
   }
-  _wbui->get_command_ui()->signal_validate_edit_menu_items().emit();
+  (*_wbui->get_command_ui()->signal_validate_edit_menu_items())();
 }
 
 
