@@ -31,7 +31,7 @@ namespace wb
   class PhysicalOverviewBE;
   class ModelFile;
   
-  class MYSQLWBBACKEND_PUBLIC_FUNC WBContextModel : public sigc::trackable, public ModelBridgeDelegate
+  class MYSQLWBBACKEND_PUBLIC_FUNC WBContextModel : public ModelBridgeDelegate, public base::trackable
   {    
   public:
     WBContextModel(WBContextUI *wbui);
@@ -112,11 +112,12 @@ namespace wb
     ModelFile *_file;
 
     workbench_DocumentRef _doc;
-    sigc::connection _page_settings_conn;
+    boost::signals2::connection _page_settings_conn;
 
     grt::UndoAction *_auto_save_point;
     mdc::Timestamp _last_auto_save_time;
     int _auto_save_interval;
+    bec::GRTManager::Timer *_auto_save_timer;
 
     std::map<std::string, ModelDiagramForm*> _model_forms;
   };
