@@ -43,6 +43,7 @@
 
 #include "wb_physical_model_diagram_features.h"
 #include "base/string_utilities.h"
+#include <boost/lambda/lambda.hpp>
 
 #define DEFAULT_TOOL "basic/select"
 
@@ -82,14 +83,14 @@ _toolbar(0), _tools_toolbar(0), _options_toolbar(0)
   _inline_edit_context= 0;
   _update_count = 0;
 
-  _layer_tree.set_activate_callback(sigc::mem_fun(owner->get_wb()->get_ui(), &WBContextUI::activate_figure));
+  _layer_tree.set_activate_callback(boost::bind(&WBContextUI::activate_figure, owner->get_wb()->get_ui(), _1));
 
   model_list_changed(0, true, grt::ValueRef());
   
-  view->owner()->signal_list_changed().connect(sigc::mem_fun(this, &ModelDiagramForm::model_list_changed));
+  scoped_connect(view->owner()->signal_list_changed(), boost::bind(&ModelDiagramForm::model_list_changed, this, _1, _2, _3));
 
-  _model_diagram->signal_refreshDisplay().connect(sigc::mem_fun(this, &ModelDiagramForm::diagram_changed));
-  _model_diagram->signal_list_changed().connect(sigc::mem_fun(this, &ModelDiagramForm::diagram_objects_changed));
+  scoped_connect(_model_diagram->signal_refreshDisplay(), boost::bind(&ModelDiagramForm::diagram_changed, this, _1));
+  scoped_connect(_model_diagram->signal_list_changed(), boost::bind(&ModelDiagramForm::diagram_objects_changed, this, _1, _2, _3));
 
   _current_mouse_x= -1;
   _current_mouse_y= -1;
@@ -103,7 +104,7 @@ _toolbar(0), _tools_toolbar(0), _options_toolbar(0)
   _paste_offset= 0;
   _shortcuts= owner->get_wb()->get_ui()->get_command_ui()->get_shortcuts_for_context(WB_CONTEXT_MODEL);
 
-  owner->get_wb()->get_clipboard()->signal_changed().connect(sigc::mem_fun(this, &ModelDiagramForm::clipboard_changed));
+  scoped_connect(owner->get_wb()->get_clipboard()->signal_changed(), boost::bind(&ModelDiagramForm::clipboard_changed, this));
   
   _features= new PhysicalModelDiagramFeatures(this);
   
@@ -117,7 +118,6 @@ ModelDiagramForm::~ModelDiagramForm()
   delete _toolbar;
   delete _tools_toolbar;
   delete _menu;
-  sigc::connection(_signal_id).disconnect();
   delete _mini_view;
   delete _features;
 }
@@ -160,7 +160,7 @@ mforms::ToolBar *ModelDiagramForm::get_tools_toolbar()
         
           item->set_icon(IconManager::get_instance()->get_icon_path(*titem->icon()));
           item->set_name((*titem->command()).substr(strlen("tool:")));
-          item->signal_activated().connect(sigc::bind(sigc::mem_fun(this, &ModelDiagramForm::set_tool), item->get_name()));
+          scoped_connect(item->signal_activated(),boost::bind(&ModelDiagramForm::set_tool, this, item->get_name()));
         }
         std::string shortcut;
         for (std::vector<WBShortcut>::const_iterator iter= _shortcuts.begin(); iter != _shortcuts.end(); ++iter)
@@ -199,14 +199,14 @@ mforms::MenuBar *ModelDiagramForm::get_menubar()
   if (!_menu)
   {
     _menu = _owner->get_wb()->get_ui()->get_command_ui()->create_menubar_for_context(WB_CONTEXT_MODEL);
-    _menu->signal_will_show().connect(sigc::hide(sigc::mem_fun(this, &ModelDiagramForm::revalidate_menu)));
+    scoped_connect(_menu->signal_will_show(),boost::bind(&ModelDiagramForm::revalidate_menu, this));
     
     mforms::MenuItem *item = _menu->find_item("wb.edit.editSelectedFigure");
     if (item)
-      item->set_validator(sigc::mem_fun(this, &ModelDiagramForm::has_selection));
+      item->set_validator(boost::bind(&ModelDiagramForm::has_selection, this));
     item = _menu->find_item("wb.edit.editSelectedFigureInNewWindow");
     if (item)
-      item->set_validator(sigc::mem_fun(this, &ModelDiagramForm::has_selection));
+      item->set_validator(boost::bind(&ModelDiagramForm::has_selection, this));
   }
   revalidate_menu();
   return _menu;
@@ -326,8 +326,7 @@ void ModelDiagramForm::update_options_toolbar()
         item = mforms::manage(new mforms::ToolBarItem(mforms::SelectorItem));
       item->set_selector_items(items);
       item->set_text(selected);
-      item->signal_activated().connect(sigc::bind(sigc::mem_fun(this, &ModelDiagramForm::select_dropdown_item),
-                                                  titem->command(), item));
+      scoped_connect(item->signal_activated(),boost::bind(&ModelDiagramForm::select_dropdown_item, this, titem->command(), item));
     }
     else if (type == "separator")
       item = mforms::manage(new mforms::ToolBarItem(mforms::SeparatorItem));
@@ -426,7 +425,7 @@ void ModelDiagramForm::selection_changed()
   if (get_wb()->get_grt_manager()->in_main_thread())
     revalidate_menu();
   else
-    get_wb()->get_grt_manager()->run_when_idle(sigc::bind_return(sigc::mem_fun(this, &ModelDiagramForm::revalidate_menu), false));
+    get_wb()->get_grt_manager()->run_once_when_idle(boost::bind(&ModelDiagramForm::revalidate_menu, this));
 }
 
 
@@ -465,9 +464,9 @@ void ModelDiagramForm::attach_canvas_view(mdc::CanvasView *cview)
   cview->get_background_layer()->set_grid_visible(_model_diagram->options().get_int("ShowGrid", 1)!=0);
   cview->get_background_layer()->set_paper_visible(_model_diagram->options().get_int("ShowPageGrid", 1)!=0);
 
-  cview->get_selection()->signal_begin_dragging().connect(sigc::mem_fun(this, &ModelDiagramForm::begin_selection_drag));
-  cview->get_selection()->signal_end_dragging().connect(sigc::mem_fun(this, &ModelDiagramForm::end_selection_drag));
-  _model_diagram->get_data()->signal_selection_changed().connect(sigc::hide(sigc::mem_fun(this, &ModelDiagramForm::selection_changed)));
+  scoped_connect(cview->get_selection()->signal_begin_dragging(),boost::bind(&ModelDiagramForm::begin_selection_drag, this));
+  scoped_connect(cview->get_selection()->signal_end_dragging(),boost::bind(&ModelDiagramForm::end_selection_drag, this));
+  scoped_connect(_model_diagram->get_data()->signal_selection_changed(),boost::bind(&ModelDiagramForm::selection_changed, this));
   
   _main_layer= _view->get_current_layer();
   _badge_layer= _view->new_layer("badges");
@@ -491,19 +490,19 @@ bool ModelDiagramForm::is_closed()
 }
 
 
-void ModelDiagramForm::set_button_callback(const sigc::slot<bool, ModelDiagramForm*, mdc::MouseButton, bool, Point, mdc::EventState> &cb)
+void ModelDiagramForm::set_button_callback(const boost::function<bool (ModelDiagramForm*, mdc::MouseButton, bool, Point, mdc::EventState)> &cb)
 {
   _handle_button= cb;
 }
 
 
-void ModelDiagramForm::set_motion_callback(const sigc::slot<bool, ModelDiagramForm*, Point, mdc::EventState> &cb)
+void ModelDiagramForm::set_motion_callback(const boost::function<bool (ModelDiagramForm*, Point, mdc::EventState)> &cb)
 {
   _handle_motion= cb;
 }
 
 
-void ModelDiagramForm::set_reset_tool_callback(const sigc::slot<void, ModelDiagramForm*> &cb)
+void ModelDiagramForm::set_reset_tool_callback(const boost::function<void (ModelDiagramForm*)> &cb)
 {
   _reset_tool= cb;
 }
@@ -769,8 +768,7 @@ void ModelDiagramForm::handle_mouse_button(mdc::MouseButton button, bool press,
       
       _context_menu.clear();
       _context_menu.add_items_from_list(items);
-      _context_menu.set_handler(sigc::mem_fun(get_wb()->get_ui()->get_command_ui(), 
-                                     (void (CommandUI::*)(const std::string&))&CommandUI::activate_command));
+      _context_menu.set_handler(boost::bind(&CommandUI::activate_command, get_wb()->get_ui()->get_command_ui(), _1));
       
       _context_menu.popup_at(NULL, x, y);
     }
@@ -859,7 +857,19 @@ bool ModelDiagramForm::handle_key(const mdc::KeyInfo &key, bool press, mdc::Even
     {
       if (iter->modifiers == state && iter->key == key)
       {
-        set_tool(iter->command.substr(strlen("tool:")));
+        if (iter->command.find("tool:") == 0)
+          set_tool(iter->command.substr(strlen("tool:")));
+        else
+        {
+          if (iter->command == "zoomin")
+            zoom_in();
+          else
+            if (iter->command == "zoomout")
+              zoom_out();
+            else
+              if (iter->command == "zoomdefault")
+                set_zoom(1);
+        }
         return true;
       }
     }
@@ -960,9 +970,11 @@ void ModelDiagramForm::reset_tool(bool notify)
     _reset_tool(this);
 
   _cursor= "";
-  _handle_button.disconnect();
-  _handle_motion.disconnect();
-  _reset_tool.disconnect();
+  static const bool fval = false;
+  boost::function<bool ()> f = boost::lambda::var(fval);
+  _handle_button = (boost::bind(f));
+  _handle_motion = (boost::bind(f));
+  _reset_tool = (boost::bind(f));
 
   if (notify)
     _owner->get_wb()->tool_changed(_view);
@@ -988,7 +1000,7 @@ void ModelDiagramForm::set_tool_argument(const std::string &option, const std::s
 {
   _tool_args[option]= value;
 
-  _tool_argument_changed.emit(option);
+  _tool_argument_changed(option);
 }
 
 
@@ -1059,7 +1071,7 @@ bool ModelDiagramForm::can_paste()
     else
     {
       bool result= false;
-      wb->foreach_component(sigc::bind<grt::ObjectRef,bool*>(sigc::ptr_fun(check_if_can_paste), *iter, &result));
+      wb->foreach_component(boost::bind(check_if_can_paste, _1, *iter, &result));
       if (!result)
         return false;
     }
@@ -1221,8 +1233,7 @@ void ModelDiagramForm::paste()
     {
       WBComponent *compo= 0;
       wb->foreach_component(
-        sigc::bind<grt::ObjectRef,WBComponent**>(sigc::ptr_fun(get_component_that_can_paste),
-        *iter, &compo)); 
+        boost::bind(get_component_that_can_paste, _1, *iter, &compo)); 
       if (compo)
       {
         compo->paste_non_model_object(this, *iter);
@@ -1711,7 +1722,7 @@ void ModelDiagramForm::stop_editing()
 static void forward_edit_finished(const std::string &text, EditFinishReason reason,
                                   ModelDiagramForm *form)
 {
-  form->signal_editing_done().emit(text, reason);
+  (*form->signal_editing_done())(text, reason);
 }
 
 
@@ -1719,8 +1730,8 @@ void ModelDiagramForm::set_inline_editor_context(InlineEditContext *context)
 {
   _inline_edit_context= context;
   
-  _inline_edit_context->signal_edit_finished().
-    connect(sigc::bind(sigc::ptr_fun(forward_edit_finished), this));
+  scoped_connect(_inline_edit_context->signal_edit_finished(),
+    boost::bind(forward_edit_finished, _1, _2, this));
 }
 
 
@@ -1807,16 +1818,3 @@ std::string ModelDiagramForm::get_title()
 }
 
 //--------------------------------------------------------------------------------------------------
-
-/**
- * Called by the context model when it connects itself to a diagram (to listen for changes).
- * For this task it binds this form to the callback, which requires that we disconnect that
- * when this form is destroyed.
- */
-void wb::ModelDiagramForm::change_signal_id(ChangeSignal::iterator signal_id)
-{
-  //XXX this is probably redundant, sigc::trackable will auto-disconnect the slot
-  _signal_id = signal_id;
-}
-
-//--------------------------------------------------------------------------------------------------
