@@ -43,6 +43,8 @@
 
 #include "mforms/toolbar.h"
 
+#include "base/trackable.h"
+
 /**
  * @file  wb_overview_physical.cpp
  * @brief Physical Model specific panels for the overview window
@@ -183,7 +185,7 @@ class SchemaListUpdater :
   std::vector<OverviewBE::Node*> &_nodes;
   std::set<OverviewBE::Node*> _reused_items;
   grt::ListRef<db_Schema> _schemata;
-  typedef sigc::slot<OverviewBE::Node *, db_SchemaRef> SchemaNodeInstantiationSlot;
+  typedef boost::function<OverviewBE::Node * (db_SchemaRef)> SchemaNodeInstantiationSlot;
   SchemaNodeInstantiationSlot _schema_node_instantiation_slot;
 
 public:
@@ -198,7 +200,7 @@ void PhysicalSchemataNode::refresh_children()
 {
   focused= 0;
 
-  SchemaListUpdater updater(children, db_CatalogRef::cast_from(object)->schemata(), sigc::mem_fun(this, &PhysicalSchemataNode::create_child_node));
+  SchemaListUpdater updater(children, db_CatalogRef::cast_from(object)->schemata(), boost::bind(&PhysicalSchemataNode::create_child_node, this, _1));
 
   updater.execute();
 }
@@ -206,7 +208,7 @@ void PhysicalSchemataNode::refresh_children()
 
 //------------------------------------------------------------------------
 
-class ModelObjectNode : public OverviewBE::ObjectNode, public sigc::trackable
+class ModelObjectNode : public OverviewBE::ObjectNode, public base::trackable
 {
 public:
   std::string member;
@@ -349,12 +351,11 @@ void SQLScriptsNode::refresh_children()
       node->small_icon= IconManager::get_instance()->get_icon_id(script.get_metaclass(), Icon16);
       node->large_icon= IconManager::get_instance()->get_icon_id(script.get_metaclass(), Icon48);
       
-      script->signal_changed().connect(sigc::bind(sigc::ptr_fun(script_object_changed), 
-                                                  _owner));
+      script->signal_changed()->connect(boost::bind(script_object_changed, _1, _2, _owner));
       children.push_back(node);
     }
     
-    OverviewBE::AddObjectNode *add_node= new OverviewBE::AddObjectNode(sigc::mem_fun(this, &SQLScriptsNode::add_new));
+    OverviewBE::AddObjectNode *add_node= new OverviewBE::AddObjectNode(boost::bind(&SQLScriptsNode::add_new, this, _1));
     
     add_node->label= _("Add Script");
     add_node->small_icon= IconManager::get_instance()->get_icon_id("db.Script.$.png", Icon16, "add");
@@ -428,12 +429,11 @@ void NotesNode::refresh_children()
       node->small_icon= IconManager::get_instance()->get_icon_id(note.get_metaclass(), Icon16);
       node->large_icon= IconManager::get_instance()->get_icon_id(note.get_metaclass(), Icon48);
       
-      note->signal_changed().connect(sigc::bind(sigc::ptr_fun(note_object_changed), 
-                                                _owner));
+      note->signal_changed()->connect(boost::bind(note_object_changed, _1, _2, _owner));
       children.push_back(node);
     }
     
-    OverviewBE::AddObjectNode *add_node= new OverviewBE::AddObjectNode(sigc::mem_fun(this, &NotesNode::add_new));
+    OverviewBE::AddObjectNode *add_node= new OverviewBE::AddObjectNode(boost::bind(&NotesNode::add_new, this, _1));
     add_node->label= _("Add Note");
     add_node->small_icon= IconManager::get_instance()->get_icon_id("GrtStoredNote.$.png", Icon16, "add");
     add_node->large_icon= IconManager::get_instance()->get_icon_id("GrtStoredNote.$.png", Icon48, "add");
@@ -612,10 +612,10 @@ mforms::MenuBar *PhysicalOverviewBE::get_menubar()
     
     mforms::MenuItem *item = _menu->find_item("wb.edit.editObject");
     if (item)
-      item->set_validator(sigc::bind(sigc::ptr_fun(has_selection), this));
+      item->set_validator(boost::bind(has_selection, this));
     item = _menu->find_item("wb.edit.editObjectInNewWindow");
     if (item)
-      item->set_validator(sigc::bind(sigc::ptr_fun(has_selection), this));    
+      item->set_validator(boost::bind(has_selection, this));    
   }
   return _menu;
 }
