@@ -24,13 +24,10 @@ public:
   int current_entry() { return _current_entry_index; }
   void current_entry(int index);
   std::string restore_sql_from_history(int entry_index, std::list<int> &detail_indexes);
-protected:
-  void insert_entry(const std::tm &t);
 protected:
   int _current_entry_index;
 
 public:
-  void save();
   void load();
 
 public:
@@ -47,26 +44,23 @@ public:
     DetailsModel(bec::GRTManager *grtm) : VarGridModel(grtm) { reset(); }
 
   public:
+    void add_entries(const std::list<std::string> &statements);
     virtual void refresh() { refresh_ui(); }
 
   public:
     virtual void reset();
-    void add_entries(const std::list<std::string> &statements);
-    void load_from(Ref details_model);
 
   public:
-    std::string storage_file_path() const;
     void save();
-    void load();
-    bool loaded() const { return _loaded; }
+    void load(const std::string &storage_file_path);
   protected:
     int _last_loaded_row; // required to skip duplication of existing entries when dumping contents
-    bool _loaded; // whether contents was loaded from storage file
 
   public:
     std::tm datestamp() const { return _datestamp; }
     void datestamp(const std::tm &val) { _datestamp= val; }
   protected:
+    std::string storage_file_path() const;
     std::tm _datestamp; // raw datestamp for locale independent storage file name
 
   private:
@@ -78,25 +72,33 @@ public:
   class EntriesModel : public VarGridModel
   {
   public:
+    friend class DbSqlEditorHistory;
+    
     typedef boost::shared_ptr<EntriesModel> Ref;
-    static Ref create(bec::GRTManager *grtm) { return Ref(new EntriesModel(grtm)); }
+    static Ref create(DbSqlEditorHistory *owner, bec::GRTManager *grtm) { return Ref(new EntriesModel(owner, grtm)); }
   protected:
-    EntriesModel(bec::GRTManager *grtm) : VarGridModel(grtm) { reset(); }
+    EntriesModel(DbSqlEditorHistory *owner, bec::GRTManager *grtm);
+
+//    struct Entry
+//    {
+//      std::tm date;
+//      std::string path;
+//    };
+    DbSqlEditorHistory *_owner;
+//    bec::GRTManager *_grtm;
+//    std::vector<Entry> _entries;
+
+    void delete_entries(const std::vector<int> &rows);
+    void add_statements(const std::list<std::string> &statements);
+  public:
+    bool insert_entry(const std::tm &t);
+    void delete_all_entries();
+    
+    std::string entry_path(int index);
+    std::tm entry_date(int index);
 
   public:
     virtual void reset();
-    void add_entry(const std::list<std::string> &statements);
-    void insert_entry(const std::tm &t);
-    void delete_entries(const std::vector<int> &rows);
-    void delete_all_entries();
-  public:
-    DetailsModel::Ref details_model(int index) { return _details_models.at(index); }
-    sigc::slot<void> reset_current_entry_index;
-  protected:
-    std::vector<DetailsModel::Ref> _details_models;
-
-  public:
-    void save();
     void load();
 
   public:
