@@ -63,7 +63,7 @@ RecordsetExportForm::RecordsetExportForm(Db_sql_editor *editor, Recordset::Ref r
 
   
   _type_sel.clear();
-  _type_sel.signal_changed().connect(sigc::mem_fun(this, &RecordsetExportForm::change_type));
+  scoped_connect(_type_sel.signal_changed(),boost::bind(&RecordsetExportForm::change_type, this));
   if (editor->recordset_count() > 0)
   {
     std::vector<std::string> formats_descs;
@@ -88,7 +88,7 @@ RecordsetExportForm::RecordsetExportForm(Db_sql_editor *editor, Recordset::Ref r
   _path_label.set_text(_("File Path:"));
   _table.add(&_path_label, 0, 1, 2, 3, mforms::HFillFlag);
   _path_button.set_text("...");
-  _path_button.signal_clicked().connect(sigc::mem_fun(this, &RecordsetExportForm::browse_path));
+  scoped_connect(_path_button.signal_clicked(),boost::bind(&RecordsetExportForm::browse_path, this));
   _path_box.set_spacing(4);
   _path_box.add(&_path_text, true, true);
   _path_box.add(&_path_button, false, false);
