@@ -45,7 +45,7 @@ static std::map<std::string,std::string> auto_save_sessions;
 //------------------------------------------------------------------------------------------------
 
 
-class MYSQLWBBACKEND_PUBLIC_FUNC db_query_EditorConcreteImplData : public db_query_Editor::ImplData, public sigc::trackable
+class MYSQLWBBACKEND_PUBLIC_FUNC db_query_EditorConcreteImplData : public db_query_Editor::ImplData, public base::trackable
 {
   void sql_editor_list_changed(Sql_editor::Ref editor, bool added)
   {
@@ -124,8 +124,8 @@ public:
       _self->queryBuffers().insert(qb);
     }
     
-    editor->recordset_list_changed.connect(sigc::mem_fun(this, &db_query_EditorConcreteImplData::recordset_list_changed));
-    editor->sql_editor_list_changed.connect(sigc::mem_fun(this, &db_query_EditorConcreteImplData::sql_editor_list_changed));
+    editor->recordset_list_changed.connect(boost::bind(&db_query_EditorConcreteImplData::recordset_list_changed, this, _1, _2));
+    editor->sql_editor_list_changed.connect(boost::bind(&db_query_EditorConcreteImplData::sql_editor_list_changed, this, _1, _2));
   }
   
   boost::shared_ptr<Db_sql_editor> editor_object() const { return _editor; }
@@ -406,7 +406,7 @@ static bool validate_revert(wb::WBContextSQLIDE *sqlide)
   if (editor)
   {
     int i = editor->active_sql_editor_index();
-    if (i >= 0 && !editor->sql_editor_path(i).empty())
+    if (i >= 0 && i < editor->sql_editor_count() && !editor->sql_editor_path(i).empty())
       return !editor->sql_editor_is_scratch(i);
   }
   return false;
@@ -598,7 +598,7 @@ bool WBContextSQLIDE::auto_save_workspaces()
   if (interval != _auto_save_interval)
   {
     // schedule new interval
-    wb->get_grt_manager()->run_every(sigc::mem_fun(this, &WBContextSQLIDE::auto_save_workspaces), interval);
+    wb->get_grt_manager()->run_every(boost::bind(&WBContextSQLIDE::auto_save_workspaces, this), interval);
     return false;
   }
   
@@ -653,59 +653,59 @@ void WBContextSQLIDE::init()
 {
   DbSqlEditorSnippets::setup(this, bec::make_path(get_grt_manager()->get_user_datadir(), "snippets"));
   
-  _wbui->get_wb()->signal_app_closing().connect(sigc::mem_fun(this, &WBContextSQLIDE::finalize));
+  scoped_connect(_wbui->get_wb()->signal_app_closing(),boost::bind(&WBContextSQLIDE::finalize, this));
 
   
   // register the builtin module
   /*WbSqlIdeImpl *module= */_wbui->get_wb()->get_grt()->get_native_module<WbSqlIdeImpl>();
-  _wbui->signal_main_form_change().connect(sigc::mem_fun(this, &WBContextSQLIDE::active_form_changed));
+  scoped_connect(_wbui->signal_main_form_change(),boost::bind(&WBContextSQLIDE::active_form_changed, this, _1));
   
   // setup some builtin commands handled by ourselves for the SQL IDE
-  _wbui->get_command_ui()->add_builtin_command("query.commit", sigc::bind(sigc::ptr_fun(call_commit), this));
-  _wbui->get_command_ui()->add_builtin_command("query.rollback", sigc::bind(sigc::ptr_fun(call_rollback), this)); 
-  _wbui->get_command_ui()->add_builtin_command("query.autocommit", sigc::bind(sigc::ptr_fun(call_autocommit), this));
+  _wbui->get_command_ui()->add_builtin_command("query.commit", boost::bind(call_commit, this));
+  _wbui->get_command_ui()->add_builtin_command("query.rollback", boost::bind(call_rollback, this)); 
+  _wbui->get_command_ui()->add_builtin_command("query.autocommit", boost::bind(call_autocommit, this));
 
-  _wbui->get_command_ui()->add_builtin_command("query.savesnippet", sigc::bind(sigc::ptr_fun(call_save_snippet), this));
+  _wbui->get_command_ui()->add_builtin_command("query.savesnippet", boost::bind(call_save_snippet, this));
 
-  _wbui->get_command_ui()->add_builtin_command("query.newtab", sigc::bind(sigc::ptr_fun(call_new_tab), this));
+  _wbui->get_command_ui()->add_builtin_command("query.newtab", boost::bind(call_new_tab, this));
 
-  _wbui->get_command_ui()->add_builtin_command("query.newQuery", sigc::bind(sigc::ptr_fun(call_new_query), this));
-  _wbui->get_command_ui()->add_builtin_command("query.newFile", sigc::bind(sigc::ptr_fun(call_new_file), this));
-  _wbui->get_command_ui()->add_builtin_command("query.openFile", sigc::bind(sigc::ptr_fun(call_open_file), this));
-  _wbui->get_command_ui()->add_builtin_command("query.saveFile", sigc::bind(sigc::ptr_fun(call_save_file), this));
-  _wbui->get_command_ui()->add_builtin_command("query.saveFileAs", sigc::bind(sigc::ptr_fun(call_save_file_as), this));
-  _wbui->get_command_ui()->add_builtin_command("query.revert", sigc::bind(sigc::ptr_fun(call_revert), this), 
-                                               sigc::bind(sigc::ptr_fun(validate_revert), this));
+  _wbui->get_command_ui()->add_builtin_command("query.newQuery", boost::bind(call_new_query, this));
+  _wbui->get_command_ui()->add_builtin_command("query.newFile", boost::bind(call_new_file, this));
+  _wbui->get_command_ui()->add_builtin_command("query.openFile", boost::bind(call_open_file, this));
+  _wbui->get_command_ui()->add_builtin_command("query.saveFile", boost::bind(call_save_file, this));
+  _wbui->get_command_ui()->add_builtin_command("query.saveFileAs", boost::bind(call_save_file_as, this));
+  _wbui->get_command_ui()->add_builtin_command("query.revert", boost::bind(call_revert, this), 
+                                               boost::bind(validate_revert, this));
 
-  _wbui->get_command_ui()->add_builtin_command("query.runFile", sigc::bind(sigc::ptr_fun(call_run_file), this));
+  _wbui->get_command_ui()->add_builtin_command("query.runFile", boost::bind(call_run_file, this));
 
-  _wbui->get_command_ui()->add_builtin_command("query.export", sigc::bind(sigc::ptr_fun(call_export), this), 
-                                              sigc::bind(sigc::ptr_fun(validate_export), this));
+  _wbui->get_command_ui()->add_builtin_command("query.export", boost::bind(call_export, this), 
+                                              boost::bind(validate_export, this));
   
-  _wbui->get_command_ui()->add_builtin_command("query.cancel", sigc::bind(sigc::ptr_fun(call_cancel), this));
+  _wbui->get_command_ui()->add_builtin_command("query.cancel", boost::bind(call_cancel, this));
 
-  _wbui->get_command_ui()->add_builtin_command("query.reconnect", sigc::bind(sigc::ptr_fun(call_reconnect), this));
+  _wbui->get_command_ui()->add_builtin_command("query.reconnect", boost::bind(call_reconnect, this));
 
-  _wbui->get_command_ui()->add_builtin_command("query.refresh_physical_overview", sigc::bind(sigc::ptr_fun(call_refresh_physical_overview), this));
+  _wbui->get_command_ui()->add_builtin_command("query.refresh_physical_overview", boost::bind(call_refresh_physical_overview, this));
 
-  _wbui->get_command_ui()->add_builtin_command("query.stopOnError", sigc::bind(sigc::ptr_fun(call_continue_on_error), this));
+  _wbui->get_command_ui()->add_builtin_command("query.stopOnError", boost::bind(call_continue_on_error, this));
   _wbui->get_command_ui()->add_builtin_command("query.recordsets_are_pinned_by_default",
-                                               sigc::bind(sigc::ptr_fun(call_recordsets_are_pinned_by_default), this));
+                                               boost::bind(call_recordsets_are_pinned_by_default, this));
 
-  _wbui->get_command_ui()->add_builtin_command("query.explain", sigc::bind(sigc::ptr_fun(call_explain_sql), this));
+  _wbui->get_command_ui()->add_builtin_command("query.explain", boost::bind(call_explain_sql, this));
   _wbui->get_command_ui()->add_builtin_command("query.explain_current_statement",
-                                               sigc::bind(sigc::ptr_fun(call_explain_current_statement), this));
+                                               boost::bind(call_explain_current_statement, this));
 
   // other commands declared in frontend code
 #ifdef _WIN32
   _wbui->get_command_ui()->add_builtin_command("query.execute",
-    sigc::bind(sigc::ptr_fun(call_exec_sql), this), sigc::bind(sigc::ptr_fun(validate_exec_sql), this));
+    boost::bind(call_exec_sql, this), boost::bind(validate_exec_sql, this));
   _wbui->get_command_ui()->add_builtin_command("query.execute_current_statement",
-    sigc::bind(sigc::ptr_fun(call_exec_current_sql_statement), this), sigc::bind(sigc::ptr_fun(validate_exec_current_sql_statement), this));
+    boost::bind(call_exec_current_sql_statement, this), boost::bind(validate_exec_current_sql_statement, this));
   _wbui->get_command_ui()->add_builtin_command("query.save_edits",
-    sigc::bind(sigc::ptr_fun(call_save_edits), this), sigc::bind(sigc::ptr_fun(validate_save_edits), this));
+    boost::bind(call_save_edits, this), boost::bind(validate_save_edits, this));
   _wbui->get_command_ui()->add_builtin_command("query.discard_edits",
-    sigc::bind(sigc::ptr_fun(call_discard_edits), this), sigc::bind(sigc::ptr_fun(validate_discard_edits), this));
+    boost::bind(call_discard_edits, this), boost::bind(validate_discard_edits, this));
 #endif // _WIN32
 }
 
@@ -752,8 +752,8 @@ Db_sql_editor::Ref WBContextSQLIDE::create_connected_editor(const db_mgmt_Connec
   if (!mforms::Utilities::run_cancelable_task(_("Opening SQL Editor"), 
                                               strfmt(_("An SQL editor instance for '%s' is opening and should be available in a "
                                                        "moment.\n\nPlease stand by..."), conn->name().c_str()),
-                                              sigc::bind(sigc::ptr_fun(connect_editor), editor),
-                                              sigc::ptr_fun(cancel_connect_editor),
+                                              boost::bind(connect_editor, editor),
+                                              boost::bind(cancel_connect_editor),
                                               result_ptr)
       || !result_ptr)
     throw grt::user_cancelled("canceled");
@@ -789,12 +789,12 @@ Db_sql_editor::Ref WBContextSQLIDE::create_connected_editor(const db_mgmt_Connec
     _auto_save_active= true;
     int interval = _wbui->get_wb()->get_root()->options()->options().get_int("workbench:AutoSaveSQLEditorInterval", 60);
     if (interval > 0)
-      _wbui->get_wb()->get_grt_manager()->run_every(sigc::mem_fun(this, &WBContextSQLIDE::auto_save_workspaces), interval);
+      _wbui->get_wb()->get_grt_manager()->run_every(boost::bind(&WBContextSQLIDE::auto_save_workspaces, this), interval);
     _auto_save_interval = interval;
 
     if (!_option_change_signal_connected)
     {
-      _wbui->get_wb()->get_root()->options()->signal_dict_changed().connect(sigc::mem_fun(this, &WBContextSQLIDE::option_changed));
+      _wbui->get_wb()->get_root()->options()->signal_dict_changed()->connect(boost::bind(&WBContextSQLIDE::option_changed, this, _1, _2, _3));
       _option_change_signal_connected= true;
     }
   }
@@ -892,7 +892,7 @@ static bool compare(Db_sql_editor::Ptr ptr, Db_sql_editor *editor)
 void WBContextSQLIDE::editor_will_close(Db_sql_editor* editor)
 {
   std::list<Db_sql_editor::Ptr>::iterator iter = std::find_if(_open_editors.begin(), _open_editors.end(), 
-                                                              sigc::bind(sigc::ptr_fun(compare), editor));
+                                                              boost::bind(compare, _1, editor));
   if (iter != _open_editors.end())
   {
     // delete entry from grt tree
