@@ -136,7 +136,7 @@ void LiveSchemaTree::refresh_ex(const std::list<std::string> &schema_list, bool
 {
   std::map<std::string, SchemaNode> old_schemata; // or expanded nodes, if it's a hard_refresh
   
-  pre_refresh_signal.emit();
+  pre_refresh_signal();
   
   if (!hard_refresh)
   {
@@ -395,6 +395,10 @@ void LiveSchemaTree::update_live_object_state(ObjectType type, const std::string
 {
   bool is_obj_created= old_obj_name.empty();
   bool is_obj_dropped= new_obj_name.empty();
+  
+  // Rename occurs when both names are set and they are different.
+  bool is_obj_renamed= !is_obj_created && !is_obj_dropped && (old_obj_name != new_obj_name);
+
   if (old_obj_name == new_obj_name)
   {
     is_obj_created= false;
@@ -459,8 +463,13 @@ void LiveSchemaTree::update_live_object_state(ObjectType type, const std::string
   {
     if ((*obj_nodes)[n].name == new_obj_name)
       is_new_obj_found= true;
-    if (is_obj_dropped && ((*obj_nodes)[n].name == old_obj_name))
-      obj_nodes->erase(obj_nodes->begin()+n);
+    if ((*obj_nodes)[n].name == old_obj_name)
+    {
+      if (is_obj_dropped)
+        obj_nodes->erase(obj_nodes->begin()+n);
+      else if (is_obj_renamed)
+        (*obj_nodes)[n].name = new_obj_name;
+    }
     if (!is_obj_dropped && !is_obj_created)
       (*obj_nodes)[n].details= "";
   }
@@ -577,7 +586,7 @@ bool LiveSchemaTree::expand_node(const bec::NodeId &node)
       snode.expanded= true;
       snode.fetching= true;
       fetch_slot(node, snode.name,
-        sigc::bind(sigc::mem_fun(this, &LiveSchemaTree::schema_contents_arrived),
+        boost::bind(&LiveSchemaTree::schema_contents_arrived, this, _1,
           node[0], _schemata_vector_serial));
     }
     return true;
@@ -634,7 +643,7 @@ LiveSchemaTree::ObjectNode * LiveSchemaTree::load_object_details(const NodeId &i
     return obj_node;
   obj_node->fetching= true;
   details_fetch_slot(obj_type, _schemata[index_node[0]].name, obj_node->name,
-    sigc::bind(sigc::mem_fun(this, &LiveSchemaTree::object_details_arrived),
+    boost::bind(&LiveSchemaTree::object_details_arrived, this, _1, _2, _3,
       index_node[0], index_node[2], _schemata_vector_serial));
   if (obj_node->details.empty())
     obj_node->details= " "; // means object's details are fetched
@@ -660,7 +669,7 @@ bool LiveSchemaTree::activate_node(const bec::NodeId &node)
   {
   case 1:
     {
-      activate_object_signal.emit("activate", Schema, _schemata[node[0]].name, "");      
+      activate_object_signal("activate", Schema, _schemata[node[0]].name, "");      
       return true;
     }
     break;
@@ -675,7 +684,7 @@ bool LiveSchemaTree::activate_node(const bec::NodeId &node)
       std::string obj_name= opt_quote_ident(obj_node->name);
       std::string text= strfmt("%s.%s", schema_name.c_str(), obj_name.c_str());
       sql_editor_text_insert_signal(text);
-      //!activate_object_signal.emit("activate", type, snode->name, obj_node->name);
+      //!activate_object_signal("activate", type, snode->name, obj_node->name);
       return true;
     }
     break;
@@ -1029,7 +1038,7 @@ bool LiveSchemaTree::activate_popup_item_for_nodes(const std::string &name, cons
 {
   if (name == "refresh")
   {
-    refresh_signal.emit();
+    refresh_signal();
     return true;
   }
   else if ((name == "alter") || (name == "drop"))
@@ -1040,7 +1049,7 @@ bool LiveSchemaTree::activate_popup_item_for_nodes(const std::string &name, cons
     switch (node.depth())
     {
       case 1:
-        live_object_signal.emit(Schema, "", _schemata[node[0]].name);
+        live_object_signal(Schema, "", _schemata[node[0]].name);
         break;
 
       case 3:
@@ -1050,7 +1059,7 @@ bool LiveSchemaTree::activate_popup_item_for_nodes(const std::string &name, cons
           if (!obj_node)
             return false;
           SchemaNode *snode(&_schemata[node[0]]);
-          live_object_signal.emit(type, snode->name, obj_node->name);
+          live_object_signal(type, snode->name, obj_node->name);
         }
         break;
     }
@@ -1063,7 +1072,7 @@ bool LiveSchemaTree::activate_popup_item_for_nodes(const std::string &name, cons
     switch (node.depth())
     {
     case 1:
-      activate_object_signal.emit(name, Schema, "", _schemata[node[0]].name);
+      activate_object_signal(name, Schema, "", _schemata[node[0]].name);
       break;
           
     case 3:
@@ -1073,7 +1082,7 @@ bool LiveSchemaTree::activate_popup_item_for_nodes(const std::string &name, cons
         if (!obj_node)
           return false;
         SchemaNode *snode(&_schemata[node[0]]);
-        activate_object_signal.emit(name, type, snode->name, obj_node->name);
+        activate_object_signal(name, type, snode->name, obj_node->name);
       }
       break;
     }
@@ -1083,7 +1092,7 @@ bool LiveSchemaTree::activate_popup_item_for_nodes(const std::string &name, cons
   {
     if (unsorted_nodes.size() == 0)
     {
-      create_live_object_signal.emit(Schema, "", "");
+      create_live_object_signal(Schema, "", "");
     }
     else
     {
@@ -1091,7 +1100,7 @@ bool LiveSchemaTree::activate_popup_item_for_nodes(const std::string &name, cons
       switch (node.depth())
       {
         case 1:
-          create_live_object_signal.emit(Schema, "", "");
+          create_live_object_signal(Schema, "", "");
           break;
 
         case 2:
@@ -1100,9 +1109,9 @@ bool LiveSchemaTree::activate_popup_item_for_nodes(const std::string &name, cons
           SchemaNode &snode(_schemata[node[0]]);
           switch (node[1])
           {
-            case 0: create_live_object_signal.emit(Table, snode.name, ""); break;
-            case 1: create_live_object_signal.emit(View, snode.name, ""); break;
-            case 2: create_live_object_signal.emit(Routine, snode.name, ""); break;
+            case 0: create_live_object_signal(Table, snode.name, ""); break;
+            case 1: create_live_object_signal(View, snode.name, ""); break;
+            case 2: create_live_object_signal(Routine, snode.name, ""); break;
           }
         }
         break;
@@ -1113,7 +1122,7 @@ bool LiveSchemaTree::activate_popup_item_for_nodes(const std::string &name, cons
   else if (name == "set_active_schema")
   {
     bec::NodeId node= unsorted_nodes[0];
-    active_schema_change_signal.emit(_schemata[node[0]].name);
+    active_schema_change_signal(_schemata[node[0]].name);
     return true;
   }
 
