@@ -502,32 +502,32 @@ bool LivePhysicalOverviewBE::activate_popup_item_for_nodes(const std::string &na
   {
     LiveObjectSignal &live_object_signal= (name == "drop") ? drop_live_object_signal : alter_live_object_signal;
     if (db_SchemaRef::can_wrap(object))
-      live_object_signal.emit(LiveSchemaTree::Schema, "", *db_SchemaRef::cast_from(object)->name());
+      live_object_signal(LiveSchemaTree::Schema, "", *db_SchemaRef::cast_from(object)->name());
     else if (db_TableRef::can_wrap(object))
-      live_object_signal.emit(LiveSchemaTree::Table, object->owner()->name(), *object->name());
+      live_object_signal(LiveSchemaTree::Table, object->owner()->name(), *object->name());
     else if (db_ViewRef::can_wrap(object))
-      live_object_signal.emit(LiveSchemaTree::View, object->owner()->name(), *object->name());
+      live_object_signal(LiveSchemaTree::View, object->owner()->name(), *object->name());
     else if (db_RoutineRef::can_wrap(object))
-      live_object_signal.emit(LiveSchemaTree::Routine, object->owner()->name(), *object->name());
+      live_object_signal(LiveSchemaTree::Routine, object->owner()->name(), *object->name());
     return true;
   }
   else if (name == "select_data" || name == "edit_data" || name == "copy_column_names" ||
     (0 == name.find("clipboard_")) || (0 == name.find("editor_")))
   {
     if (db_SchemaRef::can_wrap(object))
-      activate_object_signal.emit(name, LiveSchemaTree::Schema, "", *object->name());
+      activate_object_signal(name, LiveSchemaTree::Schema, "", *object->name());
     else if (db_TableRef::can_wrap(object))
-      activate_object_signal.emit(name, LiveSchemaTree::Table, object->owner()->name(), *object->name());
+      activate_object_signal(name, LiveSchemaTree::Table, object->owner()->name(), *object->name());
     else if (db_ViewRef::can_wrap(object))
-      activate_object_signal.emit(name, LiveSchemaTree::View, object->owner()->name(), *object->name());
+      activate_object_signal(name, LiveSchemaTree::View, object->owner()->name(), *object->name());
     else if (db_RoutineRef::can_wrap(object))
-      activate_object_signal.emit(name, LiveSchemaTree::Routine, object->owner()->name(), *object->name());
+      activate_object_signal(name, LiveSchemaTree::Routine, object->owner()->name(), *object->name());
     return true;
   }
   else if (name == "set_active_schema")
   {
     if (db_SchemaRef::can_wrap(object))
-      active_schema_change_signal.emit(*object->name());
+      active_schema_change_signal(*object->name());
     return true;
   }
   else if (name == "refresh")
