@@ -61,6 +61,7 @@ public:
     RefreshSnippets, // snippets list
     RefreshSnippetCollections, // snippet collections list
     RefreshOverview, // refresh the live overview
+    RefreshOverviewFully, // full refresh of the live overview
     RefreshRecordsetTitle, // refresh caption of active recordset
     RunCurrentScript, // running sql needs to be initiated by front-end
     RunCurrentStatement // run only statement under cursor position (if there any statement at all)
@@ -104,6 +105,7 @@ private:
   std::string _connection_info;
   base::LockFile *_autosave_lock;
   std::string _autosave_path;
+  bool _autosave_disabled;
   bool _loading_workspace;
   bool _close_done;
 
@@ -132,6 +134,7 @@ public:
 private:
   struct Sql_editor_info {
     std::string filename;
+    std::string autosave_filename;
     std::string orig_encoding;
     std::string caption;
     Sql_editor::Ref editor;
@@ -146,7 +149,7 @@ private:
   int _scratch_editors_serial;
   GMutex *_sql_editors_mutex;
 public:
-  sigc::signal<void, Sql_editor::Ref, bool> sql_editor_list_changed;
+  boost::signals2::signal<void (Sql_editor::Ref, bool)> sql_editor_list_changed;
 
   int add_sql_editor(bool scratch = false); // returns index of the added sql_editor
   void remove_sql_editor(int index);
@@ -259,8 +262,7 @@ private:
   bool _recordsets_are_pinned_by_default;
   Recordset::Ref _active_recordset;
 public:
-  sigc::signal<void, Recordset::Ref, bool> recordset_list_changed;
-  //delme sigc::signal<int, long long> close_recordset_ui;
+  boost::signals2::signal<void (Recordset::Ref, bool)> recordset_list_changed;
 private:
   void on_close_recordset(Recordset::Ptr rs_ptr);
   int _rs_sequence;
@@ -278,8 +280,9 @@ public:
   bool can_close_(bool interactive);
 
 public:
-  typedef sigc::signal<int, const std::string&> SqlEditorTextInsertSignal;
+  typedef boost::signals2::signal<int (const std::string&)> SqlEditorTextInsertSignal;
   SqlEditorTextInsertSignal sql_editor_text_insert_signal;
+  int call_sql_editor_text_insert_signal(const std::string& str){return *sql_editor_text_insert_signal(str);}
 
 public:
   void new_sql_script_file();
@@ -290,8 +293,7 @@ public:
   void revert_sql_script_file();
 
 public:
-  sigc::signal<int, int> sql_editor_new_ui;
-//  sigc::signal<int, std::string> sql_editor_caption_ui;
+  boost::signals2::signal<int (int)> sql_editor_new_ui;
 
 public:
   void get_schemata(std::list<std::string> &schemata);
@@ -344,9 +346,9 @@ public:
   bool expand_live_table_stub(bec::DBObjectEditorBE *table_editor, const std::string &schema_name, const std::string &obj_name);
 
 private:
-  typedef sigc::signal<int, long long, const std::string&, const std::string&> Error_cb;
-  typedef sigc::signal<int, float> Batch_exec_progress_cb;
-  typedef sigc::signal<int, long, long> Batch_exec_stat_cb;
+  typedef boost::signals2::signal<int (long long, const std::string&, const std::string&),boost::signals2::last_value<int> > Error_cb;
+  typedef boost::signals2::signal<int (float),boost::signals2::last_value<int> > Batch_exec_progress_cb;
+  typedef boost::signals2::signal<int (long, long),boost::signals2::last_value<int> > Batch_exec_stat_cb;
   Error_cb on_sql_script_run_error;
   Batch_exec_progress_cb on_sql_script_run_progress;
   Batch_exec_stat_cb on_sql_script_run_statistics;
@@ -361,10 +363,11 @@ public:
 private:
   grt::StringRef do_refresh_physical_overview(grt::GRT *grt, Ptr self_ptr, bool hard_refresh);
   void do_refresh_physical_overview(bool hard_refresh);
-  void do_refresh_physical_overview(std::list<std::string> schema_list, bool hard_refresh);
+  void do_refresh_physical_overview(const std::list<std::string>& schema_list, bool hard_refresh);
 private:
   wb::LivePhysicalOverviewBE * _live_physical_overview;
   bool _is_physical_overview_enabled;
+  bool _is_refreshing_physical_overview;
   GrtThreadedTask::Ref live_schemata_refresh_task;
 
 public:
@@ -373,7 +376,7 @@ public:
   std::string restore_sql_from_history(int entry_index, std::list<int> &detail_indexes);
   int exec_sql_error_count() { return _exec_sql_error_count; }
   
-  sigc::slot<void, std::string, bool> output_text_slot;
+  boost::function<void (const std::string&, bool)> output_text_slot;
 protected:
   DbSqlEditorLog::Ref _log;
   DbSqlEditorHistory::Ref _history;
