@@ -22,7 +22,7 @@
 
 
 #include "workbench/wb_backend_public_interface.h"
-#include "ui_form.h"
+#include "base/ui_form.h"
 #include "grt/tree_model.h"
 #include "workbench/wb_command_ui.h"
 #include "sqlide/wb_context_sqlide.h"
