@@ -130,7 +130,7 @@ WorkbenchCentral::WorkbenchCentral(HomeScreen* owner, grt::GRT* grt)
   
   _title1_hot= false;
   _starter_context_menu.add_item("Remove Starter from Home Screen", "remove_starter");
-  _starter_context_menu.set_handler(sigc::mem_fun(this, &WorkbenchCentral::handle_command));
+  _starter_context_menu.set_handler(boost::bind(&WorkbenchCentral::handle_command, this, _1));
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -992,7 +992,7 @@ void ActionLinkGroup::toggle_state()
   else
     _state = Expanded;
   
-  _toggled.emit(_title);
+  _toggled(_title);
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -1119,7 +1119,7 @@ void ActionLinkBox::add_link(ActionLink* link)
     if (link->get_type() == GroupLink)
     {
       ActionLinkGroup *link_group = dynamic_cast<ActionLinkGroup*> (link);
-      link_group->toggled().connect(sigc::mem_fun(this, &ActionLinkBox::toggle_group)); 
+      scoped_connect(link_group->toggled(),boost::bind(&ActionLinkBox::toggle_group, this, _1)); 
     }
     else
     {
@@ -1514,7 +1514,7 @@ ActionLink* ActionLinkBox::action_link_from_point(double x, double y)
 
 void ActionLinkBox::selection_changed()
 {
-  _signal_changed.emit();
+  _signal_changed();
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -1530,7 +1530,7 @@ int ActionLinkBox::find_selected_index()
 
 void ActionLinkBox::toggle_group(const std::string &group_name)
 {
-  _group_toggled.emit(group_name);
+  _group_toggled(group_name);
   set_needs_repaint();
 }
 
@@ -1615,7 +1615,7 @@ ActionList::ActionList(HomeScreen* owner, int left_spacing, int right_spacing, W
   _link_box->single_click(false);
   _link_box->set_back_color(0xeef1f5);
   _link_box->set_name("LinkBox");
-  _link_box->group_toggled().connect(sigc::mem_fun(this, &ActionList::toggle_group)); 
+  scoped_connect(_link_box->group_toggled(),boost::bind(&ActionList::toggle_group, this, _1)); 
 
 #if !defined(_WIN32) && !defined(__APPLE__)
   _link_box->set_size(-1, -1); 
@@ -1732,6 +1732,8 @@ void ActionList::toggle_group(const std::string &group_name)
         _link_box->remove_link(*link);
     }
   }
+  
+  refresh();
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -1796,6 +1798,7 @@ void ActionList::clear()
 
 void ActionList::refresh()
 {
+  _link_box->set_layout_dirty(true);
   _link_box->set_needs_repaint();
   _panel.relayout();
 }
@@ -1930,7 +1933,7 @@ Workspace::Workspace(HomeScreen* owner)
   _connections= new ActionList(_owner, COLUMN_LIST_LEFT_SPACING, COLUMN_LIST_RIGHT_SPACING, NULL,
     "db_connection_34x34.png", ActionOpenConnectionFromList, true);
   _connections->set_spacer_back_color(0xf4f7fc);
-  _connections->signal_changed().connect(sigc::mem_fun(this, &Workspace::connection_selection_changed));
+  scoped_connect(_connections->signal_changed(),boost::bind(&Workspace::connection_selection_changed, this));
   _left_column.set_back_color("#f4f7fc");
   _left_column.add(_sql_top, false, true);
   _left_column.add(_connections, true, true);
@@ -1990,7 +1993,7 @@ Workspace::Workspace(HomeScreen* owner)
   _server_instances= new ActionList(_owner, COLUMN_LIST_LEFT_SPACING, COLUMN_LIST_RIGHT_SPACING, NULL,
     "db_server_34x34.png", ActionManageInstanceFromList, true);
   _server_instances->set_spacer_back_color(0xf4f7fc);
-  _server_instances->signal_changed().connect( sigc::mem_fun(this, &Workspace::server_selection_changed) );
+  scoped_connect(_server_instances->signal_changed(),boost::bind(&Workspace::server_selection_changed, this) );
   _right_column.set_back_color("#f4f7fc");
   _right_column.add(_admin_top, false, true);
   _right_column.add(_server_instances, true, true);
@@ -2126,7 +2129,7 @@ static Menu *mforms_menu_from_menu_item_list(const bec::MenuItemList &menu_items
 void Workspace::set_context_menu_items(HomeScreenListType list, const bec::MenuItemList &menu_items, bool group_menu)
 {
   mforms::Menu* menu = mforms_menu_from_menu_item_list(menu_items);
-  menu->set_handler(sigc::bind(sigc::mem_fun(this, &Workspace::handle_command), list));
+  menu->set_handler(boost::bind(&Workspace::handle_command, this, _1, list));
   
   switch (list)
   {
@@ -2315,7 +2318,7 @@ void HomeScreen::show_autosave_warning(int model, int sqleditor)
     box->set_back_color("#eeeef7");
     add(box, false, true);
     
-    button->signal_clicked().connect(sigc::bind(sigc::mem_fun(this, &Box::remove), box));
+    UIForm::scoped_connect(button->signal_clicked(),boost::bind(&Box::remove, this, box));
   }
 }
 
