@@ -225,7 +225,7 @@ namespace wb
     virtual void mouse_click(int button, int x, int y);
     virtual void mouse_double_click(int button, int x, int y);
 
-    sigc::signal<void, std::string&> toggled() { return _toggled; }
+    boost::signals2::signal<void (std::string&)>* toggled() { return &_toggled; }
 
     std::vector<ActionLink*>* get_links() { return &_links; }
     
@@ -239,7 +239,7 @@ namespace wb
     
     std::vector<ActionLink*> _links;
     
-    sigc::signal<void, std::string&> _toggled;
+    boost::signals2::signal<void (std::string&)> _toggled;
     
     MySQL::Geometry::Rect _arrow_bounds;   // The group arrow icon bounds.
 
@@ -271,7 +271,7 @@ namespace wb
   /**
    * Container for any number of ActionLink instances.
    */
-  class ActionLinkBox : public mforms::DrawBox
+  class ActionLinkBox : public mforms::DrawBox, public base::trackable
   {
   public:
     ActionLinkBox(HomeScreen* owner, const std::string& header_image, WorkspaceGradient* gradient,
@@ -306,8 +306,8 @@ namespace wb
     virtual void mouse_click(int button, int x, int y);
     virtual void mouse_double_click(int button, int x, int y);
     virtual void get_layout_size(int* w, int* h);
-    sigc::signal<void> signal_changed() { return _signal_changed; }
-    sigc::signal<void, const std::string&> group_toggled() { return _group_toggled; }
+    boost::signals2::signal<void ()>* signal_changed() { return &_signal_changed; }
+    boost::signals2::signal<void (const std::string&)>* group_toggled() { return &_group_toggled; }
     void selection_changed();
     int  selected_index() { return _selected_index; }
     int  link_count() { return _links.size(); }
@@ -336,8 +336,8 @@ namespace wb
     bool _can_select;
     bool _single_click;
     int _selected_index;
-    sigc::signal<void> _signal_changed;
-    sigc::signal<void, const std::string&> _group_toggled;
+    boost::signals2::signal<void ()> _signal_changed;
+    boost::signals2::signal<void (const std::string&)> _group_toggled;
 
     ActionLink* _hot_link;
     ActionLink* _selected_link;
@@ -385,7 +385,7 @@ namespace wb
     void refresh();
     void set_context_menu(mforms::Menu* menu, bool group_menu = false);
     void set_context_menu_enabled(std::string action, bool enabled, bool group_menu = false);
-    sigc::signal<void> signal_changed() { return _link_box->signal_changed(); }
+    boost::signals2::signal<void ()>* signal_changed() { return _link_box->signal_changed(); }
     void selection_changed() { _link_box->selection_changed(); }
     int  selected_index() { return _link_box->selected_index(); }
     int  link_count() { return _link_box->link_count(); }
@@ -485,7 +485,7 @@ namespace wb
     
     void show_autosave_warning(int model, int sqleditor);
     
-    sigc::slot<void, HomeScreenListType, grt::ValueRef, std::string> handle_context_menu;
+    boost::function<void (HomeScreenListType, grt::ValueRef, std::string)> handle_context_menu;
     
     void set_context_menu_items(HomeScreenListType list, const bec::MenuItemList &menu_items, bool group_menu = false);
     void set_collapsed_group_data(HomeScreenListType list, std::string group_data);
