@@ -172,11 +172,11 @@ TEST_FUNCTION(5)
     tester.interactive_place_db_objects(10, 150, objects);
 
     grt::BaseListRef figures(tester.get_pview()->figures());
-    tester.flush_until(1, sigc::mem_fun(figures, &grt::BaseListRef::count), 2);
+    tester.flush_until(1, boost::bind(&grt::BaseListRef::count, figures), 2);
     ensure_equals("There must be 2 tables in the view now", tester.get_pview()->figures().count(), 2U);
 
     grt::BaseListRef connections(tester.get_pview()->connections());
-    tester.flush_until(5, sigc::mem_fun(connections, &grt::BaseListRef::count), 1);
+    tester.flush_until(5, boost::bind(&grt::BaseListRef::count, connections), 1);
 
     ensure_equals("connections created", tester.get_pview()->connections().count(), 1U);
   }
@@ -324,7 +324,7 @@ TEST_FUNCTION(8)
   int result;
 
   //TODO: Investigate what was the purpose of this and if it continues needed
-  //callbacks.confirm_action= sigc::bind<int*>(sigc::ptr_fun(delegated_confirm_action), &result);
+  //callbacks.confirm_action= boost::bind(&delegated_confirm_action, &result);
 
   WBTester tester(Size(800, 800), callbacks);
 
@@ -422,24 +422,24 @@ TEST_FUNCTION(9)
 
   grt::BaseListRef connections(tester.get_pview()->connections());
 
-  tester.flush_until(2, sigc::mem_fun(connections, &BaseListRef::count), 1);
+  tester.flush_until(2, boost::bind(&BaseListRef::count, connections), 1);
 
   ensure_equals("connection created", connections.count(), 1U);
 
   um->undo();
 
-  tester.flush_until(2, sigc::mem_fun(connections, &BaseListRef::count), 0);
+  tester.flush_until(2, boost::bind(&BaseListRef::count, connections), 0);
 
   ensure_equals("connection undone", connections.count(), 0U);
 
   um->redo();
 
-  tester.flush_until(2, sigc::mem_fun(connections, &BaseListRef::count), 1);
+  tester.flush_until(2, boost::bind(&BaseListRef::count, connections), 1);
 
   ensure_equals("connection redone", connections.count(), 1U);
 
   um->undo();
-  tester.flush_until(2, sigc::mem_fun(connections, &BaseListRef::count), 0);
+  tester.flush_until(2, boost::bind(&BaseListRef::count, connections), 0);
 
 }
 
@@ -585,7 +585,7 @@ TEST_FUNCTION(17)
   fk->referencedTable(table1);
 
   grt::BaseListRef connections(tester.get_pview()->connections());
-  tester.flush_until(2, sigc::mem_fun(connections, &grt::BaseListRef::count), 1);
+  tester.flush_until(2, boost::bind(&grt::BaseListRef::count, connections), 1);
 
   ensure_equals("rel count", tester.get_pview()->connections().count(), 1U);
 }
@@ -657,9 +657,10 @@ TEST_FUNCTION(23)
 
   wb.wb->open_document("data/workbench/selected_table.mwb");
 
+
   wb.sync_view();
 
-  wb.flush_while(3, sigc::mem_fun(wb.last_view->get_selection(), &mdc::Selection::empty));
+  wb.flush_while(3, boost::bind(&mdc::Selection::empty, wb.last_view->get_selection()));
 
   ensure("has selection in canvas", !wb.last_view->get_selection()->empty());
 }
