@@ -41,7 +41,7 @@ static void ensure_simple_contents_match(const grt::ObjectRef &copy, const grt::
 {
   grt::MetaClass *mc= copy.get_metaclass();
   
-  mc->foreach_member(sigc::bind<grt::ObjectRef,grt::ObjectRef>(sigc::ptr_fun(match_member), copy, source));
+  mc->foreach_member(boost::bind(&match_member, _1, copy, source));
 }
 
 
