@@ -110,7 +110,7 @@ TEST_FUNCTION(3)
 
   grt::ListRef<model_Connection> tmp(tester.get_pview()->connections());
   
-  tester.flush_until(3, sigc::mem_fun(tmp, &grt::ListRef<model_Connection>::count), 1);
+  tester.flush_until(3, boost::bind(&grt::ListRef<model_Connection>::count, tmp), 1);
 
   ensure_equals("connection created", tester.get_pview()->connections().count(), 1U);
 }
@@ -150,7 +150,7 @@ TEST_FUNCTION(4)
   ensure("fk created", table->foreignKeys().count()>0);
 
   grt::ListRef<model_Connection> tmp(tester.get_pview()->connections());
-  tester.flush_until(3, sigc::mem_fun(tmp, &grt::ListRef<model_Connection>::count), 1);
+  tester.flush_until(3, boost::bind(&grt::ListRef<model_Connection>::count, tmp), 1);
 
   ensure_equals("connection created", tester.get_pview()->connections().count(), 1U);
 }
