@@ -33,6 +33,7 @@
 
 #include <mforms/toolbar.h>
 #include <mforms/menubar.h>
+#include <boost/lambda/bind.hpp>
 
 #include "base/log.h"
 ENABLE_LOG("core")
@@ -186,11 +187,11 @@ bool CommandUI::validate_command_item(const app_CommandItemRef &item, const wb::
     std::list<std::string> results;
     
     /* VS2010 doesn't like this (even tho 2008 was fine)
-    _wb->foreach_component(sigc::compose(
-               sigc::mem_fun(results, &std::list<std::string>::push_back),
-               sigc::bind<std::string>(sigc::mem_fun(&WBComponent::get_command_option_value), cmd.name)));
+    //_wb->foreach_component(sigc::compose(
+               boost::bind(&std::list<std::string>::push_back, results),
+               boost::bind(&WBComponent::get_command_option_value, _1, cmd.name)));
                */
-    _wb->foreach_component(sigc::bind(sigc::ptr_fun(add_option_value_to_list), cmd.name, &results));
+    _wb->foreach_component(boost::bind(add_option_value_to_list, _1, cmd.name, &results));
     
     return true;
     for (std::list<std::string>::iterator i= results.begin(); i != results.end(); ++i)
@@ -426,10 +427,8 @@ std::vector<WBShortcut> CommandUI::get_shortcuts_for_context(const std::string &
   {
     grt::ListRef<app_ShortcutItem> model_items;
 
-    _wb->foreach_component(sigc::compose(
-      sigc::bind<std::string, std::vector<WBShortcut>* >(sigc::mem_fun(this, &CommandUI::append_shortcut_items),
-                                                        context, &shortcuts),
-      sigc::mem_fun(&WBComponent::get_shortcut_items)));
+    _wb->foreach_component(boost::bind(&CommandUI::append_shortcut_items, this, boost::bind(&WBComponent::get_shortcut_items,_1)
+        , context, &shortcuts));
   }
 
   return shortcuts;
@@ -472,7 +471,7 @@ void CommandUI::add_recent_menu(mforms::MenuItem *parent)
     
     item = mforms::manage(new mforms::MenuItem(caption));
     item->set_name(strfmt("wb.file.openRecentModel:%li", i+1));
-    item->signal_clicked().connect(sigc::bind(sigc::mem_fun(_wb, &WBContext::open_recent_document), i+1));
+    scoped_connect(item->signal_clicked(),boost::bind(&WBContext::open_recent_document, _wb, i+1));
     parent->add_item(item);
   }
 }
@@ -481,16 +480,14 @@ void CommandUI::add_recent_menu(mforms::MenuItem *parent)
 void CommandUI::add_plugins_menu_items(mforms::MenuItem *parent, const std::string &group)
 {
   std::vector<app_PluginRef> plugins(_wb->get_plugin_manager()->get_plugins_for_group(group));
-
-  sigc::slot<bool, std::string> validate_slot = sigc::mem_fun(this, &CommandUI::validate_plugin_command);
   
   for (std::vector<app_PluginRef>::const_iterator iter= plugins.begin(); iter != plugins.end(); ++iter)
   {
     mforms::MenuItem *item = mforms::manage(new mforms::MenuItem((*iter)->caption()));
     item->set_name(std::string("plugin:").append(*(*iter)->name()));
-    item->set_validator(sigc::bind(validate_slot, *(*iter)->name()));
+    item->set_validator(boost::bind(&CommandUI::validate_plugin_command, this, *(*iter)->name()));
     item->validate();
-    item->signal_clicked().connect(sigc::bind(sigc::mem_fun(this, (void(CommandUI::*)(const std::string&))&CommandUI::activate_command), item->name()));
+    scoped_connect(item->signal_clicked(),boost::bind((void(CommandUI::*)(const std::string&))&CommandUI::activate_command, this, item->name()));
     parent->add_item(item);
   }
 }
@@ -549,7 +546,7 @@ void CommandUI::add_menu_items_for_context(const std::string &context, mforms::M
     std::set<std::string> added_menu_items;
 
     grt::ListRef<app_MenuItem> plist(menu->subItems());
-    sigc::slot<void, std::string> activate_slot = sigc::mem_fun(this, (void (CommandUI::*)(const std::string&))&CommandUI::activate_command);
+    boost::function<void (std::string)> activate_slot = boost::bind(&CommandUI::activate_command, this, _1);
 
     for (size_t c= plist.count(), i= 0; i < c; i++)
     {
@@ -628,7 +625,7 @@ void CommandUI::add_menu_items_for_context(const std::string &context, mforms::M
         std::string caption = mitem->caption();
 
         bool enabled = true;
-        sigc::slot<bool> validator;
+        boost::function<bool ()> validator;
         if (cmd.type == "plugin")
         {
           app_PluginRef plugin(_wb->get_plugin_manager()->get_plugin(cmd.name));
@@ -646,7 +643,7 @@ void CommandUI::add_menu_items_for_context(const std::string &context, mforms::M
 #endif
           }
           else
-            validator = sigc::bind(sigc::mem_fun(this, &CommandUI::validate_plugin_command), cmd.name);
+            validator = boost::bind(&CommandUI::validate_plugin_command, this, cmd.name);
         }
         else if (cmd.type == "builtin")
         {
@@ -665,7 +662,7 @@ void CommandUI::add_menu_items_for_context(const std::string &context, mforms::M
         item = mforms::manage(new mforms::MenuItem(caption, type));
         item->set_name(cmd.args.empty() ? cmd.name : cmd.name+":"+cmd.args);
         item->set_shortcut(mitem->shortcut());
-        item->signal_clicked().connect(sigc::bind(activate_slot, mitem->command()));
+        scoped_connect(item->signal_clicked(),boost::bind(activate_slot, mitem->command()));
         //update_item_state(mitem, cmd, item);
         if (!enabled)
           item->set_enabled(false);
@@ -692,11 +689,11 @@ void CommandUI::add_menu_items_for_context(const std::string &context, mforms::M
 }
 
 
-static void connect_validate_to_signal(sigc::signal<void> &validate_edit_menu_items, std::vector<mforms::MenuItem*> &items)
+static void connect_validate_to_signal(boost::signals2::signal<void ()> &validate_edit_menu_items, std::vector<mforms::MenuItem*> &items)
 {
   for (std::vector<mforms::MenuItem*>::iterator i = items.begin(); i != items.end(); ++i)
   {
-    validate_edit_menu_items.connect(sigc::mem_fun(*i, &mforms::MenuItem::validate));
+    (*i)->scoped_connect(&validate_edit_menu_items,boost::bind(&mforms::MenuItem::validate, *i));
     connect_validate_to_signal(validate_edit_menu_items, (*i)->get_subitems());
   }
 }
@@ -754,11 +751,11 @@ mforms::MenuBar *CommandUI::create_menubar_for_context(const std::string &contex
 
 mforms::ToolBar *CommandUI::create_toolbar(const std::string &toolbar_file)
 {
-  return create_toolbar(toolbar_file, sigc::mem_fun(this, (void (CommandUI::*)(const std::string&))&CommandUI::activate_command));
+  return create_toolbar(toolbar_file, boost::bind(&CommandUI::activate_command, this, _1));
 }
 
 
-mforms::ToolBar *CommandUI::create_toolbar(const std::string &toolbar_file, const sigc::slot<void, std::string> &activate_slot)
+mforms::ToolBar *CommandUI::create_toolbar(const std::string &toolbar_file, const boost::function<void (std::string)> &activate_slot)
 {
   app_ToolbarRef toolbar(app_ToolbarRef::cast_from(_wb->get_grt()->unserialize(_wb->get_grt_manager()->get_data_file_path(toolbar_file))));
   
@@ -811,7 +808,7 @@ mforms::ToolBar *CommandUI::create_toolbar(const std::string &toolbar_file, cons
 #endif
       tbitem->set_icon(s);
       
-      tbitem->signal_activated().connect(sigc::bind(activate_slot, titem->command()));
+      tbitem->scoped_connect(tbitem->signal_activated(),boost::bind(activate_slot, titem->command()));
     }
     else if (titem->itemType() == "toggle")
     {
@@ -848,7 +845,7 @@ mforms::ToolBar *CommandUI::create_toolbar(const std::string &toolbar_file, cons
       }
       tbitem->set_alt_icon(s);
       
-      tbitem->signal_activated().connect(sigc::bind(activate_slot, titem->command()));
+      tbitem->scoped_connect(tbitem->signal_activated(),boost::bind(activate_slot, titem->command()));
     }
     else if (titem->itemType() == "imagebox")
     {
@@ -861,7 +858,7 @@ mforms::ToolBar *CommandUI::create_toolbar(const std::string &toolbar_file, cons
     {
       tbitem = mforms::manage(new mforms::ToolBarItem(mforms::SearchFieldItem));
 
-      tbitem->signal_activated().connect(sigc::bind(activate_slot, titem->command()));
+      tbitem->scoped_connect(tbitem->signal_activated(),boost::bind(activate_slot, titem->command()));
     }    
     else if (titem->itemType() == "expander")
     {
@@ -958,10 +955,10 @@ void CommandUI::add_frontend_commands(const std::list<std::string> &commands)
     if (iter->compare("diagram_size")==0
         || iter->compare("wb.page_setup")==0)
       add_builtin_command(*iter, 
-        sigc::bind<std::string>(_wb->perform_command, *iter),
-        sigc::bind<WBContext*>(sigc::ptr_fun(has_active_view), _wb));
+        boost::bind(_wb->perform_command, *iter),
+        boost::bind(has_active_view, _wb));
     else
-      add_builtin_command(*iter, sigc::bind<std::string>(_wb->perform_command, *iter));
+      add_builtin_command(*iter, boost::bind(_wb->perform_command, *iter));
   }
 }
 
@@ -974,8 +971,8 @@ void CommandUI::remove_builtin_command(const std::string &name)
 }
 
 void CommandUI::add_builtin_command(const std::string &name, 
-                         const sigc::slot<void> &slot,
-                         const sigc::slot<bool> &validate)
+                         const boost::function<void ()> &slot,
+                         const boost::function<bool()> &validate)
 {
   BuiltinCommand cmd;
 
@@ -1094,10 +1091,10 @@ void CommandUI::activate_command(const std::string &command)
 void CommandUI::revalidate_edit_menu_items()
 {
   if (mforms::Utilities::in_main_thread())
-    signal_validate_edit_menu_items().emit();
+    (*signal_validate_edit_menu_items())();
   else
-    _wb->get_grt_manager()->run_when_idle(sigc::bind_return<bool>(sigc::bind_return(sigc::mem_fun(this, &CommandUI::revalidate_edit_menu_items), (void*)0), false));
-    //mforms::Utilities::perform_from_main_thread(sigc::bind_return(sigc::mem_fun(this, &CommandUI::revalidate_edit_menu_items), (void*)0));
+      _wb->get_grt_manager()->run_once_when_idle(boost::bind(&CommandUI::revalidate_edit_menu_items, this));
+  //mforms::Utilities::perform_from_main_thread((boost::bind(&CommandUI::revalidate_edit_menu_items, this), (void*)0));
 
   // NOTE : using perform_from_main_thread causes a _grtm reference on the BaseEditor to to get lost in the process, 
   //        this causes the application to crash while attempting to create AutoUndoUpdate objects.
