@@ -36,14 +36,14 @@ namespace wb
   struct ParsedCommand;
 
   // Manager menus and toolbars.
-  class MYSQLWBBACKEND_PUBLIC_FUNC CommandUI
+  class MYSQLWBBACKEND_PUBLIC_FUNC CommandUI: public base::trackable
   {
     friend class WBContextUI;
     
     struct BuiltinCommand
     {
-      sigc::slot<void> execute;
-      sigc::slot<bool> validate;
+      boost::function<void ()> execute;
+      boost::function<bool ()> validate;
     };
 
     WBContext *_wb;
@@ -51,7 +51,7 @@ namespace wb
     grt::ListRef<app_ShortcutItem> _shortcuts;
 
     std::map<std::string, BuiltinCommand> _builtin_commands;
-    sigc::signal<void> _validate_edit_menu_items;
+    boost::signals2::signal<void ()> _validate_edit_menu_items;
 
     bool validate_command_item(const app_CommandItemRef &item, const ParsedCommand &cmd);
     void update_item_state(const app_ToolbarItemRef &item, const ParsedCommand &cmd, mforms::ToolBarItem *tb_item);
@@ -73,12 +73,12 @@ namespace wb
     mforms::MenuBar *create_menubar_for_context(const std::string &context);
     
     void revalidate_edit_menu_items();
-    sigc::signal<void> &signal_validate_edit_menu_items() { return _validate_edit_menu_items; }
+    boost::signals2::signal<void ()>* signal_validate_edit_menu_items() { return &_validate_edit_menu_items; }
   public:
     CommandUI(WBContext *wb);
 
     mforms::ToolBar *create_toolbar(const std::string &toolbar_file);
-    mforms::ToolBar *create_toolbar(const std::string &toolbar_file, const sigc::slot<void, std::string> &activate_slot);
+    mforms::ToolBar *create_toolbar(const std::string &toolbar_file, const boost::function<void (std::string)> &activate_slot);
     
     void load_data();
 
@@ -89,8 +89,8 @@ namespace wb
 
     void add_frontend_commands(const std::list<std::string> &commands);
     void add_builtin_command(const std::string &name, 
-                             const sigc::slot<void> &slot,
-                             const sigc::slot<bool> &validate= sigc::slot<bool>());
+                             const boost::function<void ()> &slot,
+                             const boost::function<bool ()> &validate= boost::function<bool ()>());
     void remove_builtin_command(const std::string &name);    
   };
 };
