@@ -45,13 +45,14 @@
 
 #include "mdc.h"
 #include "mforms/utilities.h"
+#include "base/trackable.h"
 
 
 #define APP_MAJOR_NUMBER 5
 #define APP_MINOR_NUMBER 2
-#define APP_RELEASE_NUMBER 34
-#define APP_REVISION_NUMBER 7780
-
+#define APP_RELEASE_NUMBER 35
+#define APP_REVISION_NUMBER 7915
+#define APP_RELEASE_TYPE ""
 
 
 #define WBContext_VERSION 5
@@ -159,50 +160,50 @@ namespace wb {
   struct MYSQLWBBACKEND_PUBLIC_FUNC WBFrontendCallbacks
   {
     // Args: type, title, file extensions
-    sigc::slot<std::string,std::string,std::string,std::string> show_file_dialog;
+    boost::function<std::string (std::string,std::string,std::string)> show_file_dialog;
 
     // Show some text in the application's status bar: must be thread-safe
-    sigc::slot<void,std::string> show_status_text;
+    boost::function<void (std::string)> show_status_text;
     // Displays a progress bar
     // Args: title, status, percentage completed
     // Must return false if the action must be cancelled
-    sigc::slot<bool,std::string,std::string,float> show_progress;
+    boost::function<bool (std::string,std::string,float)> show_progress;
 
     // ok/cancel, title, flags, returnval
-    sigc::slot<bool, std::string, int, std::string&> request_input;
+    boost::function<bool (std::string, int, std::string&)> request_input;
 
     // Open an editor
     // Args: grtmanager, module containing plugin, editor dll, editor class, edited object
-    sigc::slot<NativeHandle, bec::GRTManager*, grt::Module*, std::string, std::string, grt::BaseListRef, bec::GUIPluginFlags> open_editor;
+    boost::function<NativeHandle (bec::GRTManager*, grt::Module*, std::string, std::string, grt::BaseListRef, bec::GUIPluginFlags)> open_editor;
     // Show/Hide an editor
     // Args: editor handle (e.g: window handle)
-    sigc::slot<void, NativeHandle> show_editor;
-    sigc::slot<void, NativeHandle> hide_editor;
+    boost::function<void (NativeHandle)> show_editor;
+    boost::function<void (NativeHandle)> hide_editor;
 
     // Execute a built-in command
-    sigc::slot<void, std::string> perform_command;
+    boost::function<void (std::string)> perform_command;
 
     // Create a new diagram.
-    sigc::slot<mdc::CanvasView*, const model_DiagramRef&> create_diagram;
+    boost::function<mdc::CanvasView* (const model_DiagramRef&)> create_diagram;
     // Destroy a previously created canvas view
-    sigc::slot<void, mdc::CanvasView*> destroy_view;
+    boost::function<void (mdc::CanvasView*)> destroy_view;
     // Signals the current view has been changed
-    sigc::slot<void, mdc::CanvasView*> switched_view;
+    boost::function<void (mdc::CanvasView*)> switched_view;
 
     // Open the named type of main view tab with the given form object. ownership is passed to frontend
     // Args: type (eg query), bec::UIForm*
-    sigc::slot<void, std::string, boost::shared_ptr<bec::UIForm> > create_main_form_view;
-    sigc::slot<void, bec::UIForm*> destroy_main_form_view;
+    boost::function<void (std::string, boost::shared_ptr<bec::UIForm>) > create_main_form_view;
+    boost::function<void (bec::UIForm*)> destroy_main_form_view;
     
     // The tool for the view has been changed
-    sigc::slot<void, mdc::CanvasView*> tool_changed;
+    boost::function<void (mdc::CanvasView*)> tool_changed;
 
     // Refresh interface
-    sigc::slot<void, RefreshType, std::string, NativeHandle> refresh_gui;
-    sigc::slot<void,bool> lock_gui;
+    boost::function<void (RefreshType, std::string, NativeHandle)> refresh_gui;
+    boost::function<void (bool)> lock_gui;
 
     // Closes the application
-    sigc::slot<void> quit_application;
+    boost::function<void ()> quit_application;
   };
 
 
@@ -232,7 +233,7 @@ namespace wb {
   
 #define FOREACH_COMPONENT(list, iter) for (std::vector<WBComponent*>::iterator iter= list.begin(); iter != list.end(); ++iter)
 
-  class MYSQLWBBACKEND_PUBLIC_FUNC WBContext : public sigc::trackable
+  class MYSQLWBBACKEND_PUBLIC_FUNC WBContext : public base::trackable
   {
     friend class WorkbenchImpl;
     friend class WBComponent;
@@ -331,7 +332,7 @@ namespace wb {
 
     WBComponent *get_component_handling(const model_ObjectRef &object);
 
-    void foreach_component(const sigc::slot<void, WBComponent*> &slot);
+    void foreach_component(const boost::function<void (WBComponent*)> &slot);
 
     bec::GRTManager *get_grt_manager() const { return _manager; }
     grt::GRT *get_grt() const { return _manager->get_grt(); }
@@ -362,18 +363,18 @@ namespace wb {
         
    template<class R>
     R execute_in_main_thread(const std::string &name, 
-                             const sigc::slot<R> &function) THROW (grt::grt_runtime_error)
+                             const boost::function<R ()> &function) THROW (grt::grt_runtime_error)
     {
       return _manager->get_dispatcher()->call_from_main_thread/*<R>*/(function, true, false);
     }
     void execute_in_main_thread(const std::string &name, 
-                              const sigc::slot<void> &function, bool wait) THROW (grt::grt_runtime_error);
+                              const boost::function<void ()> &function, bool wait) THROW (grt::grt_runtime_error);
  
     grt::ValueRef execute_in_grt_thread(const std::string &name, 
-                                            const sigc::slot1<grt::ValueRef, grt::GRT*> &function) THROW (grt::grt_runtime_error);
+                                            const boost::function<grt::ValueRef (grt::GRT*)> &function) THROW (grt::grt_runtime_error);
 
     void execute_async_in_grt_thread(const std::string &name, 
-                                     const sigc::slot1<grt::ValueRef, grt::GRT*> &function) THROW (grt::grt_runtime_error);
+                                     const boost::function<grt::ValueRef (grt::GRT*)> &function) THROW (grt::grt_runtime_error);
 
     void open_object_editor(const GrtObjectRef &object, bec::GUIPluginFlags flags=bec::NoFlags);
     bool activate_live_object(const GrtObjectRef &object);
@@ -454,7 +455,7 @@ namespace wb {
     
     TunnelManager *_tunnel_manager;
     
-    sigc::signal<void> _signal_app_closing;
+    boost::signals2::signal<void ()> _signal_app_closing;
     
     void delete_canvas_item(mdc::CanvasItem *item);
 
@@ -482,7 +483,7 @@ namespace wb {
     void save_app_options();
     void add_recent_file(const std::string &file);
 
-    sigc::signal<void> &signal_app_closing() { return _signal_app_closing; }
+    boost::signals2::signal<void ()>* signal_app_closing() { return &_signal_app_closing; }
     
   protected:
     void load_app_state();
@@ -523,29 +524,29 @@ namespace wb {
     void determine_opengl_support(WBOptions* command_line_options);
 
   public: // front end callbacks
-    sigc::slot<std::string,std::string,std::string,std::string> show_file_dialog;
+    boost::function<std::string (std::string,std::string,std::string)> show_file_dialog;
 
-    sigc::slot<void,std::string> show_status_text;
+    boost::function<void (std::string)> show_status_text;
 
-    sigc::slot<bool,std::string,int,std::string&> request_input;
+    boost::function<bool (std::string,int,std::string&)> request_input;
 
-    sigc::slot<void,std::string,void*> show_gui_plugin;
+    boost::function<void (std::string,void*)> show_gui_plugin;
 
-    sigc::slot<mdc::CanvasView*, const model_DiagramRef&> create_diagram;
-    sigc::slot<void, mdc::CanvasView*> destroy_view;
-    sigc::slot<void, mdc::CanvasView*> switched_view;
+    boost::function<mdc::CanvasView* (const model_DiagramRef&)> create_diagram;
+    boost::function<void (mdc::CanvasView*)> destroy_view;
+    boost::function<void (mdc::CanvasView*)> switched_view;
 
-    sigc::slot<void, std::string, boost::shared_ptr<bec::UIForm> > create_main_form_view;
-    sigc::slot<void, bec::UIForm*> destroy_main_form_view;
+    boost::function<void (std::string, boost::shared_ptr<bec::UIForm> )> create_main_form_view;
+    boost::function<void (bec::UIForm*)> destroy_main_form_view;
 
-    sigc::slot<void, mdc::CanvasView*> tool_changed;
+    boost::function<void (mdc::CanvasView*)> tool_changed;
 
-    sigc::slot<void, RefreshType, std::string, NativeHandle> refresh_gui;
-    sigc::slot<void,bool> lock_gui;
+    boost::function<void (RefreshType, std::string, NativeHandle)> refresh_gui;
+    boost::function<void (bool)> lock_gui;
 
-    sigc::slot<void, std::string> perform_command;
+    boost::function<void (std::string)> perform_command;
     
-    sigc::slot<void> quit_application;
+    boost::function<void ()> quit_application;
   };
 
   struct GUILock
