@@ -64,10 +64,10 @@ WBContextUI::WBContextUI(bool verbose)
   _shell_window= 0;
   
   _find_dialog= new FindDialogBE(_wb);
-  _find_dialog->set_activate_slot(sigc::mem_fun(this, &WBContextUI::activate_find_result));
+  _find_dialog->set_activate_slot(boost::bind(&WBContextUI::activate_find_result, this, _1, _2, _3));
 
   _output_view= new OutputView(_wb->get_grt_manager()->get_messages_list());
-  _output_view->get_be()->signal_show().connect(sigc::mem_fun(this, &WBContextUI::show_output));
+  scoped_connect(_output_view->get_be()->signal_show(),boost::bind(&WBContextUI::show_output, this));
     
   _active_form= 0;
   _active_main_form= 0;
@@ -81,10 +81,11 @@ WBContextUI::WBContextUI(bool verbose)
   _home_screen= NULL;
 
   // to notify that the save status of the doc has changed
-  _wb->get_grt()->get_undo_manager()->signal_changed().connect(sigc::mem_fun(this, &WBContextUI::history_changed));
+  //_wb->get_grt()->get_undo_manager()->signal_changed().connect(boost::bind(&WBContextUI::history_changed, this));
+  scoped_connect(_wb->get_grt()->get_undo_manager()->signal_changed(),boost::bind(&WBContextUI::history_changed, this));
   
   // stuff to do when the active form is switched in the UI (through set_active_form)
-  _form_change_signal.connect(sigc::hide(sigc::mem_fun(this, &WBContextUI::form_changed)));
+  _form_change_signal.connect(boost::bind(&WBContextUI::form_changed, this));
 }
 
 
@@ -185,6 +186,8 @@ bool WBContextUI::request_quit()
     }
     else if (answer == mforms::ResultCancel)
       return false;
+
+    _wb->do_close_document(true);
   }
 
   if (_wb->get_sqlide_context() && !_wb->get_sqlide_context()->request_quit())
@@ -211,7 +214,7 @@ void WBContextUI::reset()
   if (!dynamic_cast<OverviewBE*>(_active_main_form))
     _active_main_form= 0;
   
-  get_physical_overview()->signal_selection_changed().connect(sigc::mem_fun(this, &WBContextUI::overview_selection_changed));
+  scoped_connect(get_physical_overview()->signal_selection_changed(),boost::bind(&WBContextUI::overview_selection_changed, this));
   
   get_physical_overview()->set_model(_wb->get_document()->physicalModels()[0]);
   
@@ -251,7 +254,7 @@ void WBContextUI::overview_selection_changed()
   if (get_active_main_form() == get_physical_overview())
   {
     _wb->request_refresh(RefreshSelection, "", (NativeHandle)get_physical_overview()->get_frontend_data());
-    _command_ui.signal_validate_edit_menu_items().emit();
+    (*_command_ui.signal_validate_edit_menu_items())();
   }
 }
 
@@ -315,46 +318,46 @@ static void add_note_file(WBContextUI *wbui)
 void WBContextUI::add_backend_builtin_commands()
 {
   _command_ui.add_builtin_command("overview.home", 
-                                  sigc::mem_fun(this, &WBContextUI::show_home_screen));
+                                  boost::bind(&WBContextUI::show_home_screen, this));
   _command_ui.add_builtin_command("show_output_form", 
-                                  sigc::mem_fun(this, &WBContextUI::show_output));
+                                  boost::bind(&WBContextUI::show_output, this));
 
   _command_ui.add_builtin_command("find_next", 
-    sigc::hide_return(sigc::mem_fun(_find_dialog, &FindDialogBE::find_next)));
+    boost::bind(&FindDialogBE::find_next, _find_dialog));
   _command_ui.add_builtin_command("find_previous", 
-    sigc::hide_return(sigc::mem_fun(_find_dialog, &FindDialogBE::find_previous)));
+    boost::bind(&FindDialogBE::find_previous, _find_dialog));
 
   _command_ui.add_builtin_command("add_script_file", 
-    sigc::bind<WBContextUI*>(sigc::ptr_fun(add_script_file), this));
+    boost::bind(add_script_file, this));
   _command_ui.add_builtin_command("add_note_file", 
-    sigc::bind<WBContextUI*>(sigc::ptr_fun(add_note_file), this));
+    boost::bind(add_note_file, this));
 
   // handle some url opening stuff ourselves through mforms
   _command_ui.add_builtin_command("community_blog",
-    sigc::bind(sigc::mem_fun(this, &WBContextUI::show_web_page), "http://wb.mysql.com/", true));
+    boost::bind(&WBContextUI::show_web_page, this, "http://wb.mysql.com/", true));
   _command_ui.add_builtin_command("community_faq",
-    sigc::bind(sigc::mem_fun(this, &WBContextUI::show_web_page), "http://wb.mysql.com/?page_id=7", true));
+    boost::bind(&WBContextUI::show_web_page, this, "http://wb.mysql.com/?page_id=7", true));
   _command_ui.add_builtin_command("community_learn",
-    sigc::bind(sigc::mem_fun(this, &WBContextUI::show_web_page), "http://wb.mysql.com/?page_id=10", true));
+    boost::bind(&WBContextUI::show_web_page, this, "http://wb.mysql.com/?page_id=10", true));
   _command_ui.add_builtin_command("community_discuss",
-    sigc::bind(sigc::mem_fun(this, &WBContextUI::show_web_page), "http://wb.mysql.com/?page_id=16", true));
+    boost::bind(&WBContextUI::show_web_page, this, "http://wb.mysql.com/?page_id=16", true));
   _command_ui.add_builtin_command("community_contribute",
-    sigc::bind(sigc::mem_fun(this, &WBContextUI::show_web_page), "http://wb.mysql.com/?page_id=17", true));
+    boost::bind(&WBContextUI::show_web_page, this, "http://wb.mysql.com/?page_id=17", true));
   _command_ui.add_builtin_command("web_mysql_home",
-    sigc::bind(sigc::mem_fun(this, &WBContextUI::show_web_page), "http://mysql.com/", true));
+    boost::bind(&WBContextUI::show_web_page, this, "http://mysql.com/", true));
   _command_ui.add_builtin_command("web_home",
-    sigc::bind(sigc::mem_fun(this, &WBContextUI::show_web_page), "http://mysql.com/products/tools/workbench/", true));
+    boost::bind(&WBContextUI::show_web_page, this, "http://mysql.com/products/tools/workbench/", true));
   _command_ui.add_builtin_command("report_a_bug",
-    sigc::bind(sigc::mem_fun(this, &WBContextUI::show_web_page), "http://bugs.mysql.com/", true));
+    boost::bind(&WBContextUI::show_web_page, this, "http://bugs.mysql.com/", true));
   _command_ui.add_builtin_command("list_bugs",
-    sigc::bind(sigc::mem_fun(this, &WBContextUI::show_web_page), "http://bugs.mysql.com/saved/WB%20bugs", true));
+    boost::bind(&WBContextUI::show_web_page, this, "http://bugs.mysql.com/saved/WB%20bugs", true));
   _command_ui.add_builtin_command("plugin_site",
-    sigc::bind(sigc::mem_fun(this, &WBContextUI::show_web_page), "http://wb.mysql.com/addons/", true));
+    boost::bind(&WBContextUI::show_web_page, this, "http://wb.mysql.com/addons/", true));
   _command_ui.add_builtin_command("check_update",
-    sigc::bind(sigc::mem_fun(this, &WBContextUI::show_web_page), 
+    boost::bind(&WBContextUI::show_web_page, this, 
                base::strfmt("http://wb.mysql.com/workbench/version-check.php?version=%i.%i.%i&revision=%i", 
                             APP_MAJOR_NUMBER, APP_MINOR_NUMBER, APP_RELEASE_NUMBER, APP_REVISION_NUMBER), false));
-  _command_ui.add_builtin_command("help_index", sigc::mem_fun(this, &WBContextUI::show_help_index));
+  _command_ui.add_builtin_command("help_index", boost::bind(&WBContextUI::show_help_index, this));
 }
 
 #ifndef ___specialforms
@@ -474,8 +477,7 @@ HistoryTreeBE *WBContextUI::get_history_tree()
   {
     _history_tree= new HistoryTreeBE(_wb, _wb->get_grt()->get_undo_manager());
     
-    _wb->get_grt()->get_undo_manager()->signal_changed().
-       connect(sigc::bind(sigc::mem_fun(_history_tree, &HistoryTreeBE::tree_changed), -1, bec::NodeId()));
+    scoped_connect(_wb->get_grt()->get_undo_manager()->signal_changed(),boost::bind(&HistoryTreeBE::tree_changed, _history_tree, -1, bec::NodeId()));
   }
   return _history_tree;
 }
@@ -1086,11 +1088,11 @@ void WBContextUI::set_active_form(bec::UIForm *form)
     if (_active_main_form != form)
     {
       _active_main_form= form;
-      _main_form_change_signal.emit(form);
+      _main_form_change_signal(form);
     }
   }
 
-  _form_change_signal.emit(form);
+  _form_change_signal(form);
 }
 
 
