@@ -25,13 +25,13 @@
 #include "wb_config.h"
 
 #include "mdc_events.h"
-#include <sigc++/sigc++.h>
 
 #include "wb_context.h"
 
 #include "wb_command_ui.h"
 #include "home_screen.h"
 #include "starter_popup.h"
+#include "base/trackable.h"
 
 #include "model/wb_user_datatypes.h"
 
@@ -61,7 +61,7 @@ namespace wb {
   // this class contains functionality that the UI needs,
   // like menu/toolbar access, special form backends etc
 
-  class MYSQLWBBACKEND_PUBLIC_FUNC WBContextUI : public sigc::trackable
+  class MYSQLWBBACKEND_PUBLIC_FUNC WBContextUI : public base::trackable
   {
   public:
     WBContextUI(bool verbose);
@@ -140,8 +140,8 @@ namespace wb {
 
     std::string get_active_context(bool main_context= true);
 
-    sigc::signal<void,bec::UIForm*> signal_main_form_change() { return _main_form_change_signal; }
-    sigc::signal<void,bec::UIForm*> signal_form_change() { return _form_change_signal; }
+    boost::signals2::signal<void (bec::UIForm*)>* signal_main_form_change() { return &_main_form_change_signal; }
+    boost::signals2::signal<void (bec::UIForm*)>* signal_form_change() { return &_form_change_signal; }
 
     // other functionality for UI
     std::string get_title();
@@ -215,8 +215,8 @@ namespace wb {
     bec::UIForm *_active_form;
     bec::UIForm *_active_main_form;
 
-    sigc::signal<void,bec::UIForm*> _main_form_change_signal;
-    sigc::signal<void,bec::UIForm*> _form_change_signal;
+    boost::signals2::signal<void (bec::UIForm*)> _main_form_change_signal;
+    boost::signals2::signal<void (bec::UIForm*)> _form_change_signal;
     
     
     bool _last_unsaved_changes_state;
