@@ -115,14 +115,14 @@ void WBContextUI::show_home_screen()
   if (_home_screen == NULL)
   {    
     _home_screen= mforms::manage(new HomeScreen(&_command_ui, _wb->get_grt()));
-    _home_screen->set_on_close(sigc::bind(sigc::ptr_fun(on_home_closing), this, _home_screen));
+    _home_screen->set_on_close(boost::bind(on_home_closing, this, _home_screen));
     _home_screen->set_callback((home_screen_action_callback)&WBContextUI::home_action_callback, this);
-    _home_screen->handle_context_menu = sigc::mem_fun(this, &WBContextUI::handle_home_context_menu);
+    _home_screen->handle_context_menu = boost::bind(&WBContextUI::handle_home_context_menu, this, _1, _2, _3);
     
 #if defined(__APPLE__) || defined(_WIN32)
     // in Linux, the Home screen is closed/deleted when the app closes, so state should be
     // saved when the home screen is closed
-    _wb->signal_app_closing().connect(sigc::bind(sigc::ptr_fun(save_state), _wb, _home_screen));
+    scoped_connect(_wb->signal_app_closing(),boost::bind(save_state, _wb, _home_screen));
 #endif
     // setup context menus
     bec::MenuItemList items, pitems;
@@ -874,6 +874,7 @@ void WBContextUI::handle_starter_action(StarterAction action, const app_StarterR
     }
       break;
       
+    /* Bug 12613922
     case StarterFindPlugin:
     {
       GUILock lock(_wb, _("Starting Plugin Search"), _("The MySQL Workbench Plugin Search web page "
@@ -881,7 +882,7 @@ void WBContextUI::handle_starter_action(StarterAction action, const app_StarterR
       show_web_page("http://wb.mysql.com/wb-plugins/", true);
     }
       break;
-      
+    */
     case StarterAuthorHome:
       show_web_page(starter->authorHome(), true);
       break;
