@@ -172,28 +172,24 @@ std::string ModelFile::create_document_dir(const std::string &dir, const std::st
   for (;;)
   {
     path= dir+"/"+prefix+s;
-    if (g_mkdir(path.c_str(), 0700) < 0)
+    
+    try 
     {
-#ifdef _WIN32
-      // errno is not reliable in windows
-      if (!g_file_test(path.c_str(), G_FILE_TEST_EXISTS))
-        throw grt::os_error("Cannot create directory for document.", errno);
-#else
-      if (errno != EEXIST)
-        throw grt::os_error("Cannot create directory for document.", errno);
-#endif
+      (void)base::create_directory(path, 0700); // return false means dir already exists
     }
-    else
+    catch (base::file_error &exc)
     {
-      try 
-      {
-        _temp_dir_lock = new base::LockFile(bec::make_path(path, lock_filename.c_str()));
-        break;
-      }
-      catch (const base::file_locked_error)
-      {
-        // continue
-      }
+      throw grt::os_error(strfmt("Cannot create directory for document: %s", exc.what()));
+    }
+    
+    try 
+    {
+      _temp_dir_lock = new base::LockFile(bec::make_path(path, lock_filename.c_str()));
+      break;
+    }
+    catch (const base::file_locked_error)
+    {
+      // continue
     }
     sprintf(s, "d%i", ++i);
   }
