@@ -316,7 +316,7 @@ ListRef<app_Plugin> WorkbenchImpl::getPluginInfo()
 int WorkbenchImpl::copyToClipboard(const std::string &astr)
 {
   _wb->get_grt_manager()->get_dispatcher()
-    ->call_from_main_thread<void>(sigc::bind(sigc::ptr_fun(mforms::Utilities::set_clipboard_text), astr), true, false);
+    ->call_from_main_thread<void>(boost::bind(mforms::Utilities::set_clipboard_text, astr), true, false);
 
   return 1;
 }
@@ -425,7 +425,7 @@ static void quit(WBContext *wb)
 int WorkbenchImpl::exit()
 {
   _wb->get_grt_manager()->get_dispatcher()->
-  call_from_main_thread<void>(sigc::bind(sigc::ptr_fun(quit), _wb), false, false);
+  call_from_main_thread<void>(boost::bind(quit, _wb), false, false);
 
   return 0;
 }
@@ -557,7 +557,7 @@ int WorkbenchImpl::editSelectedFigure(const model_DiagramRef &view)
 
     for (size_t c= list.count(), i= 0; i < c; i++)
     {
-      _wb->foreach_component(sigc::bind<model_ObjectRef,bool>(sigc::ptr_fun(activate_object), list.get(i), false));
+      _wb->foreach_component(boost::bind(activate_object, _1, list.get(i), false));
     }
   }
   return 0;
@@ -572,7 +572,7 @@ int WorkbenchImpl::editSelectedFigureInNewWindow(const model_DiagramRef &view)
 
     for (size_t c= list.count(), i= 0; i < c; i++)
     {
-      _wb->foreach_component(sigc::bind<model_ObjectRef,bool>(sigc::ptr_fun(activate_object), list.get(i), true));
+      _wb->foreach_component(boost::bind(activate_object, _1, list.get(i), true));
     }
   }
   return 0;
@@ -763,7 +763,7 @@ int WorkbenchImpl::goToMarker(const std::string &marker)
       diagram->y(mk->y());
 
       _wb->get_grt_manager()->get_dispatcher()->call_from_main_thread<void>(
-        sigc::bind<model_DiagramRef>(sigc::mem_fun(_wb, &WBContext::switch_diagram), diagram), false, false);
+        boost::bind(&WBContext::switch_diagram, _wb, diagram), false, false);
     }
   }
 
@@ -1079,7 +1079,7 @@ static int traverse_value(GRT *grt, const ObjectRef &owner, const std::string &m
       ObjectRef object(ObjectRef::cast_from(value));
       MetaClass *gstruct= object->get_metaclass();
      
-      gstruct->foreach_member(sigc::bind<ObjectRef,ObjectRef,GRT*>(sigc::ptr_fun(traverse_member), owner, object, grt));
+      gstruct->foreach_member(boost::bind(traverse_member, _1, owner, object, grt));
     }
     break;
 
@@ -1233,28 +1233,28 @@ std::string WorkbenchImpl::request_input_m(const std::string &caption)
 std::string WorkbenchImpl::input(const std::string &caption)
 {
   return _wb->get_grt_manager()->get_dispatcher()->call_from_main_thread<std::string>(
-    sigc::bind<std::string>(sigc::mem_fun(this, &WorkbenchImpl::request_input_m), caption), true, false);
+    boost::bind(&WorkbenchImpl::request_input_m, this, caption), true, false);
 }
 
 
 int WorkbenchImpl::confirm(const std::string &title, const std::string &caption)
 {
   return _wb->get_grt_manager()->get_dispatcher()->call_from_main_thread<int>(
-    sigc::bind(sigc::ptr_fun(mforms::Utilities::show_message), title, caption, _("OK"), _("Cancel"), ""), true, false);
+    boost::bind(mforms::Utilities::show_message, title, caption, _("OK"), _("Cancel"), ""), true, false);
 }
 
 
 std::string WorkbenchImpl::requestFileOpen(const std::string &caption, const std::string &extensions)
 {
   return _wb->get_grt_manager()->get_dispatcher()->
-  call_from_main_thread<std::string>(sigc::bind(_wb->show_file_dialog, "open", caption, extensions), true, false);
+  call_from_main_thread<std::string>(boost::bind(_wb->show_file_dialog, "open", caption, extensions), true, false);
 }
 
 
 std::string WorkbenchImpl::requestFileSave(const std::string &caption, const std::string &extensions)
 {
   return _wb->get_grt_manager()->get_dispatcher()->
-  call_from_main_thread<std::string>(sigc::bind(_wb->show_file_dialog, "save", caption, extensions), true, false);
+  call_from_main_thread<std::string>(boost::bind(_wb->show_file_dialog, "save", caption, extensions), true, false);
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -1264,7 +1264,7 @@ int WorkbenchImpl::showUserTypeEditor(const workbench_physical_ModelRef &model)
   if ( _current_user_type_editor == NULL)
   {
     _current_user_type_editor = new UserDefinedTypeEditor(_wb->get_ui(), model);
-    _current_user_type_editor->signal_closed().connect(sigc::mem_fun(this, &WorkbenchImpl::userTypeEditorClosed));
+    scoped_connect(_current_user_type_editor->signal_closed(),boost::bind(&WorkbenchImpl::userTypeEditorClosed, this));
   }
   _current_user_type_editor->show_modal(NULL, NULL);
   
