@@ -36,15 +36,8 @@ class GrtObject;
 namespace bec {
   struct ChangeSet;
 
-  struct WBPUBLICBACKEND_PUBLIC_FUNC RefreshCentry
-  {
-    BaseEditor &_editor;
-    RefreshCentry(BaseEditor &editor);
 
-    ~RefreshCentry();
-  };
-  
-  
+
   class WBPUBLICBACKEND_PUBLIC_FUNC UndoObjectChangeGroup : public grt::UndoGroup
   {
     std::string _object_id;
@@ -57,7 +50,7 @@ namespace bec {
   };
 
 
-  class WBPUBLICBACKEND_PUBLIC_FUNC BaseEditor : public UIForm, public RefreshUI 
+  class WBPUBLICBACKEND_PUBLIC_FUNC BaseEditor : public UIForm, public RefreshUI
   {
   public:
     BaseEditor(GRTManager *grtm, const grt::Ref<GrtObject> &object);
@@ -75,11 +68,11 @@ namespace bec {
     virtual bool is_editing_live_object() { return false; }
     virtual void apply_changes_to_live_object() {}
     virtual void refresh_live_object() {}
-    typedef sigc::slot<int, long long, const std::string&, const std::string&> Live_object_change_error_cb;
+    typedef boost::function<int (long long, const std::string&, const std::string&)> Live_object_change_error_cb;
     Live_object_change_error_cb on_live_object_change_error;
-    typedef sigc::slot<int, float> Live_object_change_progress_cb;
+    typedef boost::function<int (float)> Live_object_change_progress_cb;
     Live_object_change_progress_cb on_live_object_change_progress;
-    typedef sigc::slot<int, long, long> Live_object_change_statistics_cb;
+    typedef boost::function<int (long, long)> Live_object_change_statistics_cb;
     Live_object_change_statistics_cb on_live_object_change_statistics;
 
     grt::GRT *get_grt() { return _grtm->get_grt(); }
@@ -89,12 +82,13 @@ namespace bec {
 
   protected:
     GRTManager *_grtm;
+    boost::signals2::scoped_connection _ui_refresh_conn;
 
     std::set<std::string> _ignored_object_fields_for_ui_refresh;
 
     void add_listeners(const grt::Ref<GrtObject> &object);
 
-    void run_from_grt(const sigc::slot<void> &slot);
+    void run_from_grt(const boost::function<void ()> &slot);
 
   private:
     friend class AutoUndoEdit;
@@ -108,7 +102,6 @@ namespace bec {
   
   class WBPUBLICBACKEND_PUBLIC_FUNC AutoUndoEdit : public grt::AutoUndo
   {
-    typedef std::pair<sigc::connection, sigc::connection> SignalConnections;
     
     static void undo_applied(grt::UndoAction *applied, grt::UndoGroup *group, BaseEditor *editor)
     {
@@ -116,24 +109,6 @@ namespace bec {
         editor->undo_applied();
     }
     
-    static void *editor_destroyed(void *data)
-    {
-      SignalConnections *sigs= reinterpret_cast<SignalConnections*>(data);
-      
-      sigs->first.disconnect();
-      sigs->second.disconnect();
-      delete sigs;
-      
-      return NULL;
-    }
-    
-    void mark_for_delete_when_destroyed(BaseEditor *editor, sigc::connection &conn1, sigc::connection &conn2)
-    {
-      SignalConnections *sigs= new SignalConnections(conn1, conn2);
-  
-      editor->add_destroy_notify_callback(sigs, AutoUndoEdit::editor_destroyed);
-    }
-
   public:
     AutoUndoEdit(BaseEditor *editor)
     // if editing a live object, this should be a no-op
@@ -141,15 +116,23 @@ namespace bec {
     {
       if (group)
       {
-        sigc::connection conn1, conn2;
-          
+        /*
+        //sigc::connection conn1, conn2;
         conn1= editor->get_grt()->get_undo_manager()->
+        signal_undo().connect(sigc::bind(sigc::ptr_fun(&AutoUndoEdit::undo_applied), group, editor));
           signal_undo().connect(sigc::bind(sigc::ptr_fun(&AutoUndoEdit::undo_applied), group, editor));
+        signal_undo().connect(boost::bind(\&AutoUndoEdit::undo_applied, _1, group, editor));
 
         conn2= editor->get_grt()->get_undo_manager()->
-          signal_redo().connect(sigc::bind(sigc::ptr_fun(&AutoUndoEdit::undo_applied), group, editor));
-        
+        signal_redo().connect(boost::bind(&AutoUndoEdit::undo_applied, _1, group, editor));
+
         mark_for_delete_when_destroyed(editor, conn1, conn2);
+        */
+        editor->scoped_connect(editor->get_grt()->get_undo_manager()->
+          signal_undo(),boost::bind(&AutoUndoEdit::undo_applied, _1, group, editor));
+        editor->scoped_connect(editor->get_grt()->get_undo_manager()->
+          signal_redo(),boost::bind(&AutoUndoEdit::undo_applied,_1, group, editor));
+
       }
     }
 
@@ -158,15 +141,22 @@ namespace bec {
     {
       if (group)
       {
-        sigc::connection conn1, conn2;
-    
+        /*
+        //sigc::connection conn1, conn2;
+
         conn1= editor->get_grt()->get_undo_manager()->
-          signal_undo().connect(sigc::bind(sigc::ptr_fun(&AutoUndoEdit::undo_applied), group, editor));
+        signal_undo().connect(boost::bind(&AutoUndoEdit::undo_applied, _1, group, editor));
 
         conn2= editor->get_grt()->get_undo_manager()->
-          signal_redo().connect(sigc::bind(sigc::ptr_fun(&AutoUndoEdit::undo_applied), group, editor));
-        
+        signal_redo().connect(boost::bind(&AutoUndoEdit::undo_applied, _1, group, editor));
+
         mark_for_delete_when_destroyed(editor, conn1, conn2);
+        */
+        editor->scoped_connect((editor->get_grt()->get_undo_manager()->
+          signal_undo()),boost::bind(&AutoUndoEdit::undo_applied, _1, group, editor));
+        editor->scoped_connect((editor->get_grt()->get_undo_manager()->
+          signal_redo()),boost::bind(&AutoUndoEdit::undo_applied, _1, group, editor));
+
       }
     }
   };
