@@ -48,7 +48,7 @@ public:
 
 class GRTSimpleTask : public GRTTaskBase {
 public:
-  GRTSimpleTask(const std::string &name, GRTDispatcher *disp, const sigc::slot1<grt::ValueRef, grt::GRT*> &function)
+  GRTSimpleTask(const std::string &name, GRTDispatcher *disp, const boost::function<grt::ValueRef (grt::GRT*)> &function)
     : GRTTaskBase(name, disp), _function(function)
   {
   }
@@ -83,7 +83,7 @@ protected:
   GRTDispatcher *_dispatcher;
 
 private:
-  sigc::slot1<grt::ValueRef, grt::GRT*> _function;
+  boost::function<grt::ValueRef (grt::GRT*)> _function;
 };
 
 
@@ -136,8 +136,8 @@ void GRTTaskBase::release()
 
 void GRTTaskBase::started()
 {
-  signal_starting_task.emit();
-  _dispatcher->call_from_main_thread<void>(sigc::mem_fun(this, &GRTTaskBase::started_m), false, false);
+  signal_starting_task();
+  _dispatcher->call_from_main_thread<void>(boost::bind(&GRTTaskBase::started_m, this), false, false);
 }
 
 
@@ -149,9 +149,8 @@ void GRTTaskBase::started_m()
 void GRTTaskBase::finished(const grt::ValueRef &result)
 {
   retain();
-  signal_finishing_task.emit(); 
-  _dispatcher->call_from_main_thread<void>(sigc::bind<grt::ValueRef>(sigc::mem_fun(this, &GRTTaskBase::finished_m), result),
-                                           false, false);
+  signal_finishing_task(); 
+  _dispatcher->call_from_main_thread<void>(boost::bind(&GRTTaskBase::finished_m, this, result),false, false);
 }
 
 
@@ -173,9 +172,8 @@ void GRTTaskBase::failed(const std::exception &exc)
 
   retain();
 
-  signal_failing_task.emit();
-  _dispatcher->call_from_main_thread<void>(sigc::bind<std::exception>(sigc::mem_fun(this, &GRTTaskBase::failed_m), exc),
-                                           false, false);
+  signal_failing_task();
+  _dispatcher->call_from_main_thread<void>(boost::bind(&GRTTaskBase::failed_m, this, exc), false, false);
 }
 
 
@@ -209,15 +207,15 @@ void GRTTaskBase::process_message(const grt::Message &msg)
 {
   retain();
 
-  _dispatcher->call_from_main_thread<void>(sigc::bind<grt::Message>(sigc::mem_fun(this, &GRTTaskBase::process_message_m), msg),
-                                           false/*was true*/, false);
+  _dispatcher->call_from_main_thread<void>(boost::bind(&GRTTaskBase::process_message_m, this, msg), false/*was true*/, false);
 }
 
 
 void GRTTaskBase::process_message_m(const grt::Message &msg)
 {
   // fallback to the original handlerf
-  _default_callbacks.message_cb(msg, this);
+  if(_default_callbacks.message_cb)
+    _default_callbacks.message_cb(msg, this);
 
   release();
 }
@@ -233,7 +231,7 @@ int GRTTaskBase::perform_status_query()
 //---------------------------------------------------------------------------
 
 
-GRTTask::GRTTask(const std::string &name, GRTDispatcher *owner, const sigc::slot1<grt::ValueRef, grt::GRT*> &function)
+GRTTask::GRTTask(const std::string &name, GRTDispatcher *owner, const boost::function<grt::ValueRef (grt::GRT*)> &function)
   : GRTTaskBase(name, owner), _function(function)
 {
 }
@@ -247,13 +245,13 @@ grt::ValueRef GRTTask::execute(grt::GRT *grt)
 
 void GRTTask::started_m()
 {
-  _started.emit();
+  _started();
 }
 
 
 void GRTTask::finished_m(const grt::ValueRef &result)
 {
-  _finished.emit(result);
+  _finished(result);
 
   GRTTaskBase::finished_m(result);
 }
@@ -262,7 +260,7 @@ void GRTTask::finished_m(const grt::ValueRef &result)
 void GRTTask::failed_m(const std::exception &error)
 {
   //_failed.emit(error);
-  _failed.emit(*_exception);
+  _failed(*_exception);
   
   //GRTTaskBase::failed_m(error);
   GRTTaskBase::failed_m(*_exception);
@@ -277,7 +275,7 @@ void GRTTask::process_message_m(const grt::Message &msgs)
     return;
   }
 
-  _message.emit(msgs);
+  _message(msgs);
 
   release();
 }
@@ -303,14 +301,14 @@ grt::ValueRef GRTShellTask::execute(grt::GRT *grt)
 
 void GRTShellTask::finished_m(const grt::ValueRef &result)
 {
-  _finished_signal.emit(_result, _prompt);
+  _finished_signal(_result, _prompt);
   
   GRTTaskBase::finished_m(result);
 }
 
 void GRTShellTask::process_message_m(const grt::Message &msg)
 {
-  _message.emit(msg);
+  _message(msg);
 
   release();
 }
@@ -379,8 +377,8 @@ void GRTDispatcher::start(boost::shared_ptr<GRTDispatcher> self)
   if (_is_main_dispatcher)
   {
     DispatcherCallbacks cb;
-    cb.message_cb= _grt->set_message_handler(sigc::mem_fun(this, &GRTDispatcher::message_callback));
-    cb.status_query_cb= _grt->set_status_query_handler(sigc::mem_fun(this, &GRTDispatcher::status_query_callback));
+    cb.message_cb= _grt->set_message_handler(boost::bind(&GRTDispatcher::message_callback, this, _1, _2));
+    cb.status_query_cb= _grt->set_status_query_handler(boost::bind(&GRTDispatcher::status_query_callback, this));
     _default_callbacks= cb;
   }
 }
@@ -566,7 +564,7 @@ bool GRTDispatcher::get_busy()
  * etc. It should not handle mouse and keyboard events or anything that could
  * cause another call to the backend.
  */
-void GRTDispatcher::set_main_thread_flush_and_wait(void (*callback)())
+void GRTDispatcher::set_main_thread_flush_and_wait(FlushAndWaitCallback callback)
 {
   _flush_main_thread_and_wait= callback;
 }
@@ -677,8 +675,8 @@ void GRTDispatcher::prepare_task(GRTTaskBase *gtask)
   // directly set the task callbacks
   if (_is_main_dispatcher)
   {
-    _grt->set_message_handler(sigc::bind(sigc::ptr_fun(call_process_message), gtask));
-    _grt->set_status_query_handler(sigc::bind(sigc::ptr_fun(call_status_query), gtask));
+    _grt->set_message_handler(boost::bind(call_process_message, _1, _2, gtask));
+    _grt->set_status_query_handler(boost::bind(call_status_query, gtask));
   }
 }
 
@@ -688,8 +686,8 @@ void GRTDispatcher::restore_callbacks(GRTTaskBase *task)
   // restore originally set msg callbacks
   if (_is_main_dispatcher)
   {
-    _grt->set_message_handler(sigc::mem_fun(this, &GRTDispatcher::message_callback));
-    _grt->set_status_query_handler(sigc::mem_fun(this, &GRTDispatcher::status_query_callback));
+    _grt->set_message_handler(boost::bind(&GRTDispatcher::message_callback, this, _1, _2));
+    _grt->set_status_query_handler(boost::bind(&GRTDispatcher::status_query_callback, this));
   }
  
 //  _grt->flush_messages();
@@ -724,6 +722,8 @@ void GRTDispatcher::execute_task(GRTTaskBase *gtask)
 
 void GRTDispatcher::wait_task(GRTTaskBase *task)
 {
+  bool is_main_thread = g_thread_self() == _main_thread;
+  
   // wait for a task to be completed, making sure that
   // the task won't deadlock because of a call to 
   // call_from_main_thread()
@@ -732,7 +732,7 @@ void GRTDispatcher::wait_task(GRTTaskBase *task)
   {
     flush_pending_callbacks();
     
-    if (_flush_main_thread_and_wait)
+    if (_flush_main_thread_and_wait && is_main_thread)
       _flush_main_thread_and_wait();
   }
 }
@@ -778,7 +778,7 @@ grt::ValueRef GRTDispatcher::add_task_and_wait(GRTTaskBase *task) THROW (grt::gr
 
 
 grt::ValueRef GRTDispatcher::execute_simple_function(const std::string &name, 
-                                                         const sigc::slot1<grt::ValueRef, grt::GRT*> &function) THROW (grt::grt_runtime_error)
+                                                         const boost::function<grt::ValueRef (grt::GRT*)> &function) THROW (grt::grt_runtime_error)
 {
   GRTSimpleTask *task= new GRTSimpleTask(name, this, function);
 
@@ -795,7 +795,7 @@ grt::ValueRef GRTDispatcher::execute_simple_function(const std::string &name,
 
 
 void GRTDispatcher::execute_async_function(const std::string &name,
-                                           const sigc::slot1<grt::ValueRef, grt::GRT*> &function) THROW (grt::grt_runtime_error)
+                                           const boost::function<grt::ValueRef (grt::GRT*)> &function) THROW (grt::grt_runtime_error)
 {
   GRTSimpleTask *task= new GRTSimpleTask(name, this, function);
 
