@@ -95,19 +95,21 @@ namespace bec {
   template<class R>
     class DispatcherCallback : public DispatcherCallbackBase 
   {
-    sigc::slot<R> _slot;
+	typedef boost::function<R ()> slot_type;
+    slot_type _slot;
     
   public:
     R rvalue;
     
-    DispatcherCallback(const sigc::slot<R> &slot)
+    DispatcherCallback(const slot_type &slot)
       : DispatcherCallbackBase(), _slot(slot)
       {
       };
     
     void execute()
     {
-      rvalue= _slot();
+        if(_slot)
+            rvalue= _slot();
     }
     
     R get_result() { return rvalue; }
@@ -116,17 +118,19 @@ namespace bec {
   template<>
     class DispatcherCallback<void> : public DispatcherCallbackBase 
   {
-    sigc::slot<void> _slot;
+	typedef boost::function<void ()> slot_type;
+    slot_type _slot;
     
   public:
-    DispatcherCallback(const sigc::slot<void> &slot= sigc::slot<void>())
+    DispatcherCallback(const slot_type &slot= slot_type())
       : DispatcherCallbackBase(), _slot(slot)
       {
       };
     
     void execute()
     {
-      _slot();
+	    if (_slot)
+            _slot();
     }
   };
   
@@ -178,13 +182,13 @@ namespace bec {
     grt::grt_runtime_error *get_error() { return _exception; };
 
   public:
-    typedef sigc::signal<void> StartingTaskSignal;
+    typedef boost::signals2::signal<void ()> StartingTaskSignal;
     StartingTaskSignal signal_starting_task;
 
-    typedef sigc::signal<void> FinishingTaskSignal;
+    typedef boost::signals2::signal<void ()> FinishingTaskSignal;
     FinishingTaskSignal signal_finishing_task;
 
-    typedef sigc::signal<void> FailingTaskSignal;
+    typedef boost::signals2::signal<void ()> FailingTaskSignal;
     FailingTaskSignal signal_failing_task;
 
   protected:
@@ -211,22 +215,22 @@ namespace bec {
   
   class WBPUBLICBACKEND_PUBLIC_FUNC GRTTask : public GRTTaskBase 
   {
-    typedef sigc::signal<void> StartedSignal;
-    typedef sigc::signal<void,grt::ValueRef> FinishedSignal;
-    typedef sigc::signal<void,std::exception> FailedSignal;
-    typedef sigc::signal<void,const grt::Message&> ProcessMessageSignal; 
+    typedef boost::signals2::signal<void ()> StartedSignal;
+    typedef boost::signals2::signal<void (grt::ValueRef)> FinishedSignal;
+    typedef boost::signals2::signal<void (std::exception)> FailedSignal;
+    typedef boost::signals2::signal<void (const grt::Message&)> ProcessMessageSignal; 
 
   public:
-    GRTTask(const std::string &name, GRTDispatcher *owner, const sigc::slot1<grt::ValueRef, grt::GRT*> &function);
+    GRTTask(const std::string &name, GRTDispatcher *owner, const boost::function<grt::ValueRef (grt::GRT*)> &function);
 
     //XXX replace with direct slots?
-    StartedSignal &signal_started() { return _started; }
-    FinishedSignal &signal_finished() { return _finished; }
-    FailedSignal &signal_failed() { return _failed; }
-    ProcessMessageSignal &signal_message() { return _message; }
+    StartedSignal *signal_started() { return &_started; }
+    FinishedSignal *signal_finished() { return &_finished; }
+    FailedSignal *signal_failed() { return &_failed; }
+    ProcessMessageSignal *signal_message() { return &_message; }
     
   protected:
-    sigc::slot1<grt::ValueRef, grt::GRT*> _function;
+    boost::function<grt::ValueRef (grt::GRT*)> _function;
     
     StartedSignal _started;
     FinishedSignal _finished;
@@ -245,8 +249,8 @@ namespace bec {
   
   class GRTShellTask : public GRTTaskBase
   {
-    typedef sigc::signal<void,grt::ShellCommand,std::string> FinishedSignal;
-    typedef sigc::signal<void,const grt::Message&> ProcessMessageSignal;
+    typedef boost::signals2::signal<void (grt::ShellCommand,std::string)> FinishedSignal;
+    typedef boost::signals2::signal<void (const grt::Message&)> ProcessMessageSignal;
 
   public:
     GRTShellTask(const std::string &name, GRTDispatcher *owner, const std::string &command);
@@ -277,9 +281,12 @@ namespace bec {
 
   class WBPUBLICBACKEND_PUBLIC_FUNC GRTDispatcher 
   {
+  public:
+    typedef void (*FlushAndWaitCallback)();
+  private:
     friend class GRTTaskBase;
     GAsyncQueue *_task_queue;
-    void (*_flush_main_thread_and_wait)();
+    FlushAndWaitCallback _flush_main_thread_and_wait;
     
     bool _busy;
     bool _threading_disabled;
@@ -324,15 +331,15 @@ namespace bec {
     grt::ValueRef add_task_and_wait(GRTTaskBase *task) THROW (grt::grt_runtime_error);
 
     grt::ValueRef execute_simple_function(const std::string &name, 
-      const sigc::slot1<grt::ValueRef, grt::GRT*> &function) THROW (grt::grt_runtime_error);
+      const boost::function<grt::ValueRef (grt::GRT*)> &function) THROW (grt::grt_runtime_error);
 
     void execute_async_function(const std::string &name, 
-      const sigc::slot1<grt::ValueRef, grt::GRT*> &function) THROW (grt::grt_runtime_error);
+      const boost::function<grt::ValueRef (grt::GRT*)> &function) THROW (grt::grt_runtime_error);
 
     void wait_task(GRTTaskBase *task);
     
     template<class R>
-      R call_from_main_thread(const sigc::slot<R> &callback, bool wait, bool force_queue)
+      R call_from_main_thread(const boost::function<R ()> &callback, bool wait, bool force_queue)
       {
         DispatcherCallback<R> *cb= new DispatcherCallback<R>(callback);
         R result;
@@ -350,7 +357,8 @@ namespace bec {
     
     void call_from_main_thread(DispatcherCallbackBase *callback, bool wait, bool force_queue);
     
-    void set_main_thread_flush_and_wait(void (*callback)());
+    void set_main_thread_flush_and_wait(FlushAndWaitCallback callback);
+    FlushAndWaitCallback get_main_thread_flush_and_wait() { return _flush_main_thread_and_wait; }
     
     void start(boost::shared_ptr<GRTDispatcher> self);
     void shutdown();
@@ -366,7 +374,7 @@ namespace bec {
   
 
   template<>
-    inline void GRTDispatcher::call_from_main_thread<void>(const sigc::slot<void> &callback, bool wait, bool force_queue)
+    inline void GRTDispatcher::call_from_main_thread<void>(const boost::function<void ()> &callback, bool wait, bool force_queue)
     {
       DispatcherCallback<void> *cb= new DispatcherCallback<void>(callback);
       
