@@ -71,6 +71,7 @@ GRTManager::GRTManager(bool threaded, bool verbose)
   
   init_all();
 
+  _idle_signal = new boost::signals2::signal<void ()>();
   _idle_mutex= g_mutex_new();
   _timer_mutex= g_mutex_new();
   _disp_map_mutex= g_mutex_new();
@@ -80,7 +81,7 @@ GRTManager::GRTManager(bool threaded, bool verbose)
   
   _grt->set_verbose(verbose);
   
-  _grt->set_message_handler(sigc::mem_fun(this, &GRTManager::grt_default_msg_cb));
+  _grt->set_message_handler(boost::bind(&GRTManager::grt_default_msg_cb, this, _1, _2));
 
   _terminated= false;
   _idle_blocked= false;
@@ -212,6 +213,8 @@ bool GRTManager::in_main_thread()
 
 GRTManager::~GRTManager()
 {
+  delete _idle_signal;
+
   {
     GStaticMutexLock _lock(_instance_mutex);
     _instances.erase(_grt);
@@ -334,18 +337,18 @@ ModulesTreeBE *GRTManager::get_shared_modules_tree()
 }
 
 
-void GRTManager::set_message_callback(const sigc::slot<void,grt::Message> &cb)
+void GRTManager::set_message_callback(const boost::function<void (const grt::Message&)> &cb)
 {
   _message_cb= cb;
 }
 
-void GRTManager::set_progress_callback(const sigc::slot<bool,std::string,std::string,float> &cb)
+void GRTManager::set_progress_callback(const boost::function<bool (const std::string&,const std::string&,float)> &cb)
 {
   _progress_cb= cb;
 }
 
 
-void GRTManager::push_output_callback(const sigc::slot<bool, std::string> &slot)
+void GRTManager::push_output_callback(const boost::function<bool (const std::string&)> &slot)
 {
   GMutexLock lock(_tmp_output_cb_stack_mutex);
   _tmp_output_cb_stack.push_back(slot);
@@ -389,7 +392,7 @@ void GRTManager::task_msg_cb(const grt::Message &msg, const std::string &title,
     
     if (!_tmp_output_cb_stack.empty())
     {
-      std::list<sigc::slot<bool, std::string> >::reverse_iterator iter = _tmp_output_cb_stack.rbegin();
+      std::list<boost::function<bool (std::string)> >::reverse_iterator iter = _tmp_output_cb_stack.rbegin();
       while (iter != _tmp_output_cb_stack.rend())
       {
         if ((*iter)(msg.text))
@@ -407,14 +410,15 @@ void GRTManager::task_msg_cb(const grt::Message &msg, const std::string &title,
   case InfoMsg:
   case OutputMsg:
   case ControlMsg:
-    _message_cb(msg);
+    if (_message_cb)
+      _message_cb(msg);
     break;
   case VerboseMsg:
-    if (_verbose)
+    if (_verbose && _message_cb)
       _message_cb(msg);
     break;
   case ProgressMsg:
-    if (show_progress)
+    if (show_progress && _progress_cb)
       _progress_cb(msg.text, msg.detail, msg.progress);
     break;
   default:
@@ -440,7 +444,8 @@ void GRTManager::grt_default_msg_cb(const grt::Message &msg, void *sender)
   switch (msg.type)
   {
     case ProgressMsg:
-      _progress_cb(msg.text, msg.detail, msg.progress);
+      if (_progress_cb)
+        _progress_cb(msg.text, msg.detail, msg.progress);
       break;
       
     default:
@@ -448,32 +453,32 @@ void GRTManager::grt_default_msg_cb(const grt::Message &msg, void *sender)
     case WarningMsg:
     case InfoMsg:
     case ControlMsg:
-      _message_cb(msg);
+      if (_message_cb)
+        _message_cb(msg);
       break;
   }
 }
 
 
 void GRTManager::execute_grt_task(const std::string &title,
-                                  const sigc::slot1<grt::ValueRef, grt::GRT*> &function,
-                                  const sigc::slot<void,grt::ValueRef> &finished_cb,
+                                  const boost::function<grt::ValueRef (grt::GRT*)> &function,
+                                  const boost::function<void (grt::ValueRef)> &finished_cb,
                                   bool show_progress)
 {
   GRTTask *task= new GRTTask(title, _dispatcher.get(), function);
 
   if (show_progress)
   {
-    task->signal_started().connect(sigc::bind<std::string>(sigc::mem_fun(this,&GRTManager::task_started_cb), title));
-    task->signal_finished().connect(sigc::mem_fun(this, &GRTManager::task_finished_cb));
+    scoped_connect(task->signal_started(),boost::bind(&GRTManager::task_started_cb, this, title));
+    scoped_connect(task->signal_finished(),boost::bind(&GRTManager::task_finished_cb, this, _1));
   }
 
   // connect finished_cb provided by caller (after ours)
-  task->signal_finished().connect(finished_cb);
+  task->signal_finished()->connect(finished_cb);
 
-  task->signal_failed().connect(sigc::bind<std::string>(sigc::mem_fun(this, &GRTManager::task_error_cb), title));
+  scoped_connect(task->signal_failed(),boost::bind(&GRTManager::task_error_cb, this, _1, title));
 
-  task->signal_message().connect(sigc::bind<std::string,bool>(sigc::mem_fun(this, &GRTManager::task_msg_cb),
-    title, show_progress));
+  scoped_connect(task->signal_message(),boost::bind(&GRTManager::task_msg_cb, this, _1, title, show_progress));
 
   _dispatcher->add_task(task);
 }
@@ -481,11 +486,10 @@ void GRTManager::execute_grt_task(const std::string &title,
 
 void GRTManager::dispatch_task(GRTTask *task)
 {
-  if (!task->signal_message().empty())
+  if (!task->signal_message()->empty())
   {
     // make msgs be sent to output window as well
-    task->signal_message().connect(
-      sigc::bind<std::string, bool>(sigc::mem_fun(this, &GRTManager::task_msg_cb), "", false));
+    scoped_connect(task->signal_message(), boost::bind(&GRTManager::task_msg_cb, this, _1, "", false));
   }
 
   _dispatcher->add_task(task);
@@ -604,38 +608,24 @@ void GRTManager::perform_idle_tasks()
     _shell->flush_shell_output();
   }
 
-  std::list<sigc::slot<bool> > idle_slots;
   if (!_idle_blocked)
   {
+    boost::signals2::signal<void ()> *idle_signal = new boost::signals2::signal<void ()>();
     g_mutex_lock(_idle_mutex);
-    idle_slots= _idle_slots;
-    _idle_slots.clear();
+    std::swap(idle_signal, _idle_signal);
     g_mutex_unlock(_idle_mutex);
 
-    for (std::list<sigc::slot<bool> >::iterator iter= idle_slots.begin();
-      iter != idle_slots.end(); ++iter)
-    {
-      if (!iter->empty()) // skip if slot got disconnected
-      {
-        bool flag= (*iter)();
-        
-        if (flag)
-        {
-          g_mutex_lock(_idle_mutex);
-          _idle_slots.push_back(*iter);
-          g_mutex_unlock(_idle_mutex);
-        }
-      }
-    }
+    // emit everything
+    (*idle_signal)();
+    delete idle_signal;
   }
 }
 
 
-void GRTManager::run_when_idle(const sigc::slot<bool> &slot)
+boost::signals2::connection GRTManager::run_once_when_idle(const boost::function<void ()> &slot)
 {
-  g_mutex_lock(_idle_mutex);
-  _idle_slots.push_back(slot);
-  g_mutex_unlock(_idle_mutex);
+  GMutexLock lock(_idle_mutex);
+  return _idle_signal->connect(slot);
 }
 
 
@@ -651,7 +641,7 @@ void GRTManager::unblock_idle_tasks()
 }
 
 
-GRTManager::Timer::Timer(const sigc::slot<bool> &slot, double interval)
+GRTManager::Timer::Timer(const boost::function<bool ()> &slot, double interval)
 {
   this->slot= slot;
   this->interval= interval;
@@ -663,7 +653,7 @@ GRTManager::Timer::Timer(const sigc::slot<bool> &slot, double interval)
 
 bool GRTManager::Timer::trigger()
 {
-  bool flag= slot();
+  bool flag= slot?slot():false;
 
   g_get_current_time(&next_trigger);
   g_time_val_add(&next_trigger, (glong)(interval*G_USEC_PER_SEC));
@@ -683,7 +673,7 @@ double GRTManager::Timer::delay_for_next_trigger(const GTimeVal &now)
 }
 
 
-GRTManager::Timer *GRTManager::run_every(const sigc::slot<bool> &slot, double seconds)
+GRTManager::Timer *GRTManager::run_every(const boost::function<bool ()> &slot, double seconds)
 {
   Timer *timer= new Timer(slot, seconds);
   GTimeVal now;
@@ -824,7 +814,7 @@ double GRTManager::delay_for_next_timeout()
 }
 
 
-void GRTManager::set_timeout_request_slot(const sigc::slot<void> &slot)
+void GRTManager::set_timeout_request_slot(const boost::function<void ()> &slot)
 {
   _timeout_request= slot;
 }
@@ -957,8 +947,8 @@ bool GRTManager::init_loaders(const std::string &loader_module_path)
       PythonModuleLoader *loader = dynamic_cast<PythonModuleLoader*>(_grt->get_module_loader("python"));
       if (loader)
       {
-        loader->get_python_context()->push_output_handler = sigc::mem_fun(this, &GRTManager::push_output_callback);
-        loader->get_python_context()->pop_output_handler = sigc::mem_fun(this, &GRTManager::pop_output_callback);
+        loader->get_python_context()->push_output_handler = boost::bind(&GRTManager::push_output_callback, this, _1);
+        loader->get_python_context()->pop_output_handler = boost::bind(&GRTManager::pop_output_callback, this);
       }
     }
   }
@@ -1025,8 +1015,8 @@ void GRTManager::scan_modules_grt(grt::GRT *grt, const std::list<std::string> &e
 }
 
 
-void GRTManager::set_app_option_slots(const sigc::slot<grt::ValueRef,std::string> &slot,
-                                      const sigc::slot<void, std::string, grt::ValueRef> &set_slot)
+void GRTManager::set_app_option_slots(const boost::function<grt::ValueRef (std::string)> &slot,
+                                      const boost::function<void (std::string, grt::ValueRef)> &set_slot)
 {
   _get_app_option_slot= slot;
   _set_app_option_slot= set_slot;
@@ -1148,7 +1138,7 @@ void GRTManager::pop_status_text()
 }
 
 
-void GRTManager::set_status_slot(const sigc::slot<void, std::string> &slot)
+void GRTManager::set_status_slot(const boost::function<void (const std::string&)> &slot)
 {
   _status_text_slot= slot;
 }
@@ -1225,7 +1215,7 @@ bool GRTManager::check_plugin_runnable(const app_PluginRef &plugin, const bec::A
         _grt->send_output(base::strfmt("Debug: Plugin %s cannot execute because argument %s is not available\n",
                                        plugin->name().c_str(), searched_key.c_str()));
         _grt->send_output("Debug: Available arguments:\n");
-        argpool.dump_keys(sigc::bind(sigc::mem_fun(_grt, &grt::GRT::send_output), (void*)0));
+        argpool.dump_keys(boost::bind(&grt::GRT::send_output, _grt, _1, (void*)0));
       }
       return false;
     }
