@@ -34,7 +34,7 @@ MessageListStorage::MessageListStorage(GRTManager *grtm)
   _warning_icon= IconManager::get_instance()->get_icon_id("mini_warning.png");
   _info_icon= IconManager::get_instance()->get_icon_id("mini_notice.png");
   
-  ValidationManager::signal_notify().connect(sigc::mem_fun(*this, &MessageListStorage::validation_notify));
+  scoped_connect(ValidationManager::signal_notify(),boost::bind(&MessageListStorage::validation_notify, this, _1, _2, _3, _4));
 }
 
 
@@ -55,7 +55,7 @@ void MessageListStorage::handle_message(const grt::Message &msg)
 {
   if (msg.type == grt::OutputMsg)
   {
-    _grtm->run_when_idle(sigc::bind_return(sigc::bind(_output_handler, msg.text), false));
+    _grtm->run_once_when_idle(boost::bind(_output_handler,msg.text));
     //_output_handler(msg.text);
     return;
   }
@@ -92,11 +92,11 @@ void MessageListStorage::handle_message(const grt::Message &msg)
   entry->detail= msg.detail;
   if (entry->icon >= 0)
     _entries.push_back(entry);
-  _new_message.emit(entry);
+  _new_message(entry);
 }
 
 
-void MessageListStorage::set_output_handler(const sigc::slot<void, std::string> &handler)
+void MessageListStorage::set_output_handler(const boost::function<void (std::string)> &handler)
 {
   _output_handler = handler;
 }
@@ -125,7 +125,7 @@ MessageListBE::MessageListBE(MessageListStorage *owner)
 {
   _notified= false;
 
-  _conn = _owner->signal_new_message().connect(sigc::mem_fun(*this, &MessageListBE::add_message));
+  _conn = *scoped_connect(_owner->signal_new_message(),boost::bind(&MessageListBE::add_message, this, _1));
 }
 
 
@@ -139,14 +139,14 @@ void MessageListBE::add_message(MessageListStorage::MessageEntryRef message)
   if (message->icon == -1)
   {
     if (message->message == "show")
-      signal_show().emit();
+      (*signal_show())();
     return;
   }
   
   if (_wanted_sources.empty() || _wanted_sources.find(message->source) != _wanted_sources.end())
   {
     _entries.push_back(message);
-    signal_row_added().emit();
+    (*signal_row_added())();
   }
 }
 
