@@ -29,7 +29,7 @@ namespace bec {
   class GRTManager;
   class MessageListBE;
   
-  class WBPUBLICBACKEND_PUBLIC_FUNC MessageListStorage : public sigc::trackable
+  class WBPUBLICBACKEND_PUBLIC_FUNC MessageListStorage : public base::trackable
   {
   public:
     struct MessageEntry {
@@ -45,20 +45,20 @@ namespace bec {
     
     MessageListStorage(GRTManager *grtm);
 
-    sigc::signal<void, MessageEntryRef> &signal_new_message() { return _new_message; }
+    boost::signals2::signal<void (MessageEntryRef)>* signal_new_message() { return &_new_message; }
     
     MessageListBE *create_list(const std::string &filter_to_source="");
          
     void clear_all();
      
     void handle_message(const grt::Message &msg);
-    void set_output_handler(const sigc::slot<void, std::string> &handler);
+    void set_output_handler(const boost::function<void (std::string)> &handler);
 //    std::vector<MessageEntry*> get_messages_from_source(const std::string &source);
     
   private:
     GRTManager *_grtm;
-    sigc::signal<void, MessageEntryRef> _new_message;
-    sigc::slot<void, std::string> _output_handler;
+    boost::signals2::signal<void (MessageEntryRef)> _new_message;
+    boost::function<void (std::string)> _output_handler;
     std::vector<MessageEntryRef> _entries;
     IconId _error_icon;
     IconId _warning_icon;
@@ -93,8 +93,8 @@ namespace bec {
     
     void add_message(MessageListStorage::MessageEntryRef message);
     
-    sigc::signal<void> &signal_show() { return _list_show; }
-    sigc::signal<void> &signal_row_added() { return _list_changed; }
+    boost::signals2::signal<void ()>* signal_show() { return &_list_show; }
+    boost::signals2::signal<void ()>* signal_row_added() { return &_list_changed; }
 
     virtual ~MessageListBE();
   private:
@@ -106,10 +106,10 @@ namespace bec {
     MessageListStorage *_owner;
 
     std::vector<MessageListStorage::MessageEntryRef> _entries;
-    sigc::signal<void> _list_changed;
-    sigc::signal<void> _list_show;
+    boost::signals2::signal<void ()> _list_changed;
+    boost::signals2::signal<void ()> _list_show;
     std::set<std::string> _wanted_sources;
-    sigc::connection _conn;
+    boost::signals2::connection _conn;
     
     bool _notified;
   };
