@@ -117,9 +117,9 @@ void ShellBE::process_line_async(const std::string &line)
 {
   GRTShellTask *task= new GRTShellTask("User shell command", _dispatcher, line);
 
-  task->signal_message().connect(sigc::mem_fun(this, &ShellBE::handle_msg));
+  task->signal_message().connect(boost::bind(&ShellBE::handle_msg, this, _1));
 
-  task->signal_finished().connect(sigc::bind<std::string>(sigc::mem_fun(this, &ShellBE::shell_finished_cb), line));
+  task->signal_finished().connect(boost::bind(&ShellBE::shell_finished_cb, this, _1, _2, line));
 
 //  _dispatcher->add_task(task);
   
@@ -272,13 +272,13 @@ void ShellBE::reset_history_position()
 }
 
 
-void ShellBE::set_ready_handler(const sigc::slot<void,const std::string&> &slot)
+void ShellBE::set_ready_handler(const boost::function<void (const std::string&)> &slot)
 {
   _ready_slot= slot;
 }
 
 
-void ShellBE::set_output_handler(const sigc::slot<void, const std::string&> &slot)
+void ShellBE::set_output_handler(const boost::function<void (const std::string&)> &slot)
 {
   _output_slot= slot;
 }
@@ -363,7 +363,8 @@ void ShellBE::flush_shell_output()
     _text_queue.pop_front();
     g_static_mutex_unlock(&_text_queue_mutex);
 
-    _output_slot(line);
+    if (_output_slot)
+        _output_slot(line);
 
     g_static_mutex_lock(&_text_queue_mutex);
   }
