@@ -43,7 +43,7 @@ ValueInspectorBE::~ValueInspectorBE()
 
 void ValueInspectorBE::monitor_object_changes(const grt::ObjectRef& obj)
 {
-  _changed_conn = obj->signal_changed().connect(sigc::mem_fun(this, &ValueInspectorBE::changed_slot));
+  _changed_conn = *scoped_connect(obj->signal_changed(),boost::bind(&ValueInspectorBE::changed_slot, this, _1, _2)).get();
 }
 
 void ValueInspectorBE::changed_slot(const std::string& name, const grt::ValueRef& value)
@@ -111,7 +111,7 @@ public:
   {
     MetaClass *gstruct(object.get_metaclass());
 
-    gstruct->foreach_member(sigc::bind<ObjectRef>(sigc::mem_fun(this, &ObjectWrapper::setup_member), object));
+    gstruct->foreach_member(boost::bind(&ObjectWrapper::setup_member, this, _1, object));
   }
 
   bool setup_member(const MetaClass::Member *mem, const ObjectRef &object)
@@ -897,7 +897,7 @@ public:
 
 			MetaClass *meta= _list[i].get_metaclass();
 
-			meta->foreach_member(sigc::bind<std::map<std::string, boost::tuple<int,std::string,std::string,std::string> >*, MetaClass*>(sigc::mem_fun(this, &GRTObjectListValueInspectorBE::refresh_member), &keys, meta));
+			meta->foreach_member(boost::bind(&GRTObjectListValueInspectorBE::refresh_member, this, _1, &keys, meta));
 		}
 
 		_items.clear();
