@@ -20,7 +20,7 @@
 #define __REFRESH_UI_H__
 
 #include "wbpublic_public_interface.h"
-#include <sigc++/sigc++.h>
+#include <boost/function.hpp>
 
 namespace bec
 {
@@ -30,10 +30,11 @@ namespace bec
 class WBPUBLICBACKEND_PUBLIC_FUNC RefreshUI
 {
   public:
+    RefreshUI() {unblock_auto_refresh();}
     virtual ~RefreshUI() {}
     
-    typedef sigc::slot<void>              RefreshSlot;
-    typedef sigc::slot<void,const int>    PartialRefreshSlot;
+    typedef boost::function<void ()>              RefreshSlot;
+    typedef boost::function<void (const int)>    PartialRefreshSlot;
 
     void set_refresh_ui_slot(const RefreshSlot &slot);
     //! A way to make a refresh of part of the editor
@@ -43,11 +44,19 @@ class WBPUBLICBACKEND_PUBLIC_FUNC RefreshUI
     void do_partial_ui_refresh(const int what);
     void do_ui_refresh();
 
-    void block_auto_refresh()    { _refresh_ui.block(); _partial_refresh_ui.block(); }
-    void unblock_auto_refresh()  { _refresh_ui.unblock(); _partial_refresh_ui.unblock(); }
+    struct Blocker
+    {
+      Blocker(RefreshUI& o) : _obj(&o) {_obj->block_auto_refresh();}
+      ~Blocker() {_obj->unblock_auto_refresh();}
 
-  private:
-    sigc::slot<void>      _refresh_ui;
+      RefreshUI     *_obj;
+    };
+    void block_auto_refresh()    { _partial_refresh_blocked = true; }
+    void unblock_auto_refresh()  { _partial_refresh_blocked = false; }
+
+private:
+    bool _partial_refresh_blocked;
+    boost::function<void ()>      _refresh_ui;
     PartialRefreshSlot    _partial_refresh_ui;
 };
 
