@@ -32,6 +32,7 @@
 #include "grt/icon_manager.h"
 #include "grt/common.h"
 #include "base/ui_form.h" // for menu stuff
+#include "base/trackable.h"
 
 #include "wbpublic_public_interface.h"
 #include <boost/shared_ptr.hpp>
@@ -445,11 +446,11 @@ namespace bec
    *
    * @ingroup begrt
    */
-  class WBPUBLICBACKEND_PUBLIC_FUNC ListModel : public sigc::trackable
+  class WBPUBLICBACKEND_PUBLIC_FUNC ListModel : public base::trackable
   {
    private:
     NodeIds               _nodeid_map;
-    sigc::signal<void, bec::NodeId, int>    _tree_changed_signal;
+    boost::signals2::signal<void (bec::NodeId, int)>    _tree_changed_signal;
     
    public:
     virtual ~ListModel() {};
@@ -459,14 +460,11 @@ namespace bec
     virtual bool has_next(const NodeId &node);
     virtual NodeId get_next(const NodeId &node);
 
-    sigc::signal<void, bec::NodeId, int>& tree_changed_signal()
-    {
-      return _tree_changed_signal;
-    }
+    boost::signals2::signal<void (bec::NodeId, int)>* tree_changed_signal(){return &_tree_changed_signal;}
 
     void tree_changed(int old_child_count = -1, const bec::NodeId &parent = bec::NodeId())
     {
-      _tree_changed_signal.emit(parent, old_child_count);
+      _tree_changed_signal(parent, old_child_count);
       _nodeid_map.flush();
     }
 
