@@ -52,8 +52,8 @@ TEST_FUNCTION(1)
   grt::ValueRef result;
   bool finish_called= false;
   
-  task= new GRTTask("test", grtm.get_dispatcher(), sigc::ptr_fun(normal_test_function));
-  task->signal_finished().connect(sigc::bind<bool*>(sigc::ptr_fun(finished), &finish_called));
+  task= new GRTTask("test", grtm.get_dispatcher(), std::ptr_fun(normal_test_function));
+  task->signal_finished().connect(boost::bind(&finished, _1, &finish_called));
   
   result= grtm.get_dispatcher()->add_task_and_wait(task);
   
@@ -64,8 +64,8 @@ TEST_FUNCTION(1)
   
   
   finish_called= false;
-  task= new GRTTask("test", grtm.get_dispatcher(), sigc::ptr_fun(normal_test_function));
-  task->signal_finished().connect(sigc::bind<bool*>(sigc::ptr_fun(finished_with_wait), &finish_called));
+  task= new GRTTask("test", grtm.get_dispatcher(), std::ptr_fun(normal_test_function));
+  task->signal_finished().connect(boost::bind(&finished_with_wait, _1, &finish_called));
   
   result= grtm.get_dispatcher()->add_task_and_wait(task);
   
