@@ -61,7 +61,7 @@ DBObjectEditorBE::DBObjectEditorBE(GRTManager *grtm,
     _non_std_sql_delimiter= sql_specifics->non_std_sql_delimiter();
   }
   
-  _val_notify_conn = ValidationManager::signal_notify().connect(sigc::mem_fun(this, &DBObjectEditorBE::notify_from_validation));
+  _val_notify_conn = *scoped_connect(ValidationManager::signal_notify(),boost::bind(&DBObjectEditorBE::notify_from_validation, this, _1, _2, _3, _4)).get();
 }
 
 
@@ -156,7 +156,7 @@ void DBObjectEditorBE::set_name(const std::string &name)
 {
   if (get_dbobject()->name() != name)
   {
-    RefreshCentry __centry(*this);
+    RefreshUI::Blocker __centry(*this);
     //grt::AutoUndo undo(get_grt(), new UndoObjectChangeGroup(get_dbobject().id(), "name"));
     AutoUndoEdit undo(this, get_dbobject(), "name");
 
@@ -179,7 +179,7 @@ void DBObjectEditorBE::set_comment(const std::string &descr)
 {
   if (get_dbobject()->comment() != descr)
   {
-    RefreshCentry __centry(*this);
+    RefreshUI::Blocker __centry(*this);
 //    grt::AutoUndo undo(get_grt(), new UndoObjectChangeGroup(get_dbobject().id(), "comment"));
     AutoUndoEdit undo(this, get_dbobject(), "comment");
 
@@ -207,7 +207,7 @@ bool DBObjectEditorBE::is_sql_commented()
 
 void DBObjectEditorBE::set_sql_commented(bool flag)
 {
-  RefreshCentry __centry(*this);
+  RefreshUI::Blocker __centry(*this);
 
   //grt::AutoUndo undo(get_grt(), new UndoObjectChangeGroup(get_dbobject().id(), "commentedOut"));
   AutoUndoEdit undo(this, get_dbobject(), "commentedOut");
@@ -473,10 +473,10 @@ void DBObjectEditorBE::set_sql(const std::string &sql, bool sync, const db_Datab
 
   bec::GRTTask *task= new bec::GRTTask(task_desc,
     _grtm->get_dispatcher(),
-    sigc::bind(_sql_parser_task_cb, grt::StringRef(sql)));
+    boost::bind(_sql_parser_task_cb, _1, grt::StringRef(sql)));
 
-  task->signal_message().connect(sigc::mem_fun(this, &DBObjectEditorBE::sql_parser_msg_cb));
-  task->signal_finished().connect(sigc::mem_fun(this, &DBObjectEditorBE::sql_parser_task_finished_cb));
+  scoped_connect(task->signal_message(),boost::bind(&DBObjectEditorBE::sql_parser_msg_cb, this, _1));
+  scoped_connect(task->signal_finished(),boost::bind(&DBObjectEditorBE::sql_parser_task_finished_cb, this, _1));
 
   GRTDispatcher *dispatcher= _grtm->get_dispatcher();
   if (sync)
@@ -536,7 +536,8 @@ void DBObjectEditorBE::notify_from_validation(const grt::Validator::Tag& tag, co
 
 void DBObjectEditorBE::sql_parser_task_finished_cb(grt::ValueRef value)
 {
-  _sql_parser_log_cb(_sql_parser_log);
+  if (_sql_parser_log_cb)
+    _sql_parser_log_cb(_sql_parser_log);
   _sql_parser_log.clear();
   do_ui_refresh();
 }
@@ -568,7 +569,7 @@ void DBObjectEditorBE::check_sql()
     sql_editor->is_sql_check_enabled(true);
     // provoke database object to refresh FE control contents
     db_DatabaseObjectRef db_object= get_dbobject();
-    db_object->signal_changed().emit("", grt::ValueRef());
+    (*db_object->signal_changed())("", grt::ValueRef());
   }
 }
 
