@@ -245,7 +245,7 @@ void TableColumnsListBE::reorder(const NodeId &node, int nindex)
   
     _owner->update_change_date();
     
-    _owner->get_table()->signal_refreshDisplay().emit("column");
+    (*_owner->get_table()->signal_refreshDisplay())("column");
     undo.end(strfmt(_("Reorder Column '%s.%s'"), _owner->get_name().c_str(), _owner->get_table()->columns()[node[0]]->name().c_str()));
 
     _owner->do_partial_ui_refresh(::bec::TableEditorBE::RefreshColumnList);
@@ -288,7 +288,7 @@ void TableColumnsListBE::reorder_many(const std::vector<int> &rows, int targetIn
     update_primary_index_order();
     
     _owner->update_change_date();
-    _owner->get_table()->signal_refreshDisplay().emit("column");
+    (*_owner->get_table()->signal_refreshDisplay())("column");
     undo.end(strfmt(_("Reorder Columns in '%s'"), _owner->get_name().c_str()));
 
     _owner->do_partial_ui_refresh(::bec::TableEditorBE::RefreshColumnList);
@@ -537,7 +537,7 @@ bool TableColumnsListBE::make_unique_index(const db_ColumnRef &col, bool flag)
 
 bool TableColumnsListBE::set_field(const NodeId &node, int column, const std::string &value)
 {
-  RefreshCentry __centry(*_owner);
+  RefreshUI::Blocker __centry(*_owner);
 
   db_ColumnRef col;
   std::string old;
@@ -718,7 +718,7 @@ bool TableColumnsListBE::set_field(const NodeId &node, int column, const std::st
 
 bool TableColumnsListBE::set_field(const NodeId &node, int column, int value)
 {
-  RefreshCentry __centry(*_owner);
+  RefreshUI::Blocker __centry(*_owner);
   db_ColumnRef col;
 
   // only entering a new name can create a new column
@@ -770,7 +770,7 @@ bool TableColumnsListBE::set_field(const NodeId &node, int column, int value)
       
       TableHelper::update_foreign_keys_from_column_notnull(_owner->get_table(), col);
       _owner->update_change_date();
-      _owner->get_table()->signal_refreshDisplay().emit("column");
+      (*_owner->get_table()->signal_refreshDisplay())("column");
       undo.end(strfmt(_("Set '%s.%s' NOT NULL"), _owner->get_name().c_str(), (*col->name()).c_str()));
     }
     return true;
@@ -971,7 +971,7 @@ bool TableColumnsListBE::set_column_flag(const ::bec::NodeId &node, const std::s
 
           col_flags.remove(i);
           _owner->update_change_date();
-          _owner->get_table()->signal_refreshDisplay().emit("column");
+          (*_owner->get_table()->signal_refreshDisplay())("column");
           undo.end(strfmt(_("Unset %s of '%s.%s'"), flag_name.c_str(), _owner->get_name().c_str(), col->name().c_str()));
         }
         break;
@@ -986,7 +986,7 @@ bool TableColumnsListBE::set_column_flag(const ::bec::NodeId &node, const std::s
       col_flags.insert(grt::StringRef(flag_name));
       _owner->update_change_date();
       
-      _owner->get_table()->signal_refreshDisplay().emit("column");
+      (*_owner->get_table()->signal_refreshDisplay())("column");
       
       undo.end(strfmt(_("Set %s of '%s.%s'"), flag_name.c_str(), _owner->get_name().c_str(), col->name().c_str()));
       
@@ -1599,7 +1599,7 @@ NodeId IndexListBE::add_column(const db_ColumnRef &column, const db_IndexRef &aI
 
 void IndexListBE::remove_column(const NodeId &node)
 {
-  RefreshCentry __centry(*_owner);
+  RefreshUI::Blocker __centry(*_owner);
 
   db_IndexRef index= get_selected_index();
   if (!index_editable(index) || index_belongs_to_fk(index))
@@ -2555,7 +2555,7 @@ _fk_list(this)
 {
   if (table.class_name() == "db.Table") throw std::logic_error("table object is abstract");
   
-  table->signal_refreshDisplay().connect(sigc::hide(sigc::mem_fun(this, &BaseEditor::on_object_changed)));
+  scoped_connect(table->signal_refreshDisplay(),(boost::bind(&BaseEditor::on_object_changed, this)));
 }
 #ifdef _MSC_VER
 #pragma warning(pop)
@@ -2566,7 +2566,7 @@ void TableEditorBE::set_name(const std::string &name)
 {
   if (name != get_name())
   {
-    RefreshCentry __centry(*this);
+    RefreshUI::Blocker __centry(*this);
 
     AutoUndoEdit undo(this, get_object(), "name");
     bec::ValidationManager::validate_instance(_table, CHECK_NAME);
@@ -2682,7 +2682,7 @@ bool TableEditorBE::remove_fk(const NodeId &fk)
   std::string name= fklist[fk[0]]->name();
   // needs to execute from GRT thread so that side-effects get executed properly
   get_table()->removeForeignKey(fklist[fk[0]], false);
-//  run_from_grt(sigc::bind(sigc::mem_fun(get_table().content(), &db_Table::removeForeignKey), fklist[fk[0]], 0));
+//  run_from_grt(boost::bind(&db_Table::removeForeignKey, get_table().content(), fklist[fk[0]], 0));
   //bec::TableHelper::remove_foreign_key(get_table(), fklist[fk[0]], false, get_undo_manager());
   update_change_date();
   undo.end(strfmt(_("Remove Foreign Key '%s'.'%s'"), get_name().c_str(), name.c_str()));
@@ -2824,10 +2824,8 @@ bool TableEditorBE::parse_column_type(const std::string &str, db_ColumnRef &colu
     grt::UndoManager *um= get_grt()->get_undo_manager();
 
     // call _refresh_ui when this parse column type action is undone
-    um->signal_undo().connect(sigc::bind(sigc::mem_fun(this, &TableEditorBE::undo_called),
-                                         um->get_latest_undo_action()));
-    um->signal_redo().connect(sigc::bind(sigc::mem_fun(this, &TableEditorBE::undo_called),
-                                         um->get_latest_undo_action()));
+    scoped_connect(um->signal_undo(),boost::bind(&TableEditorBE::undo_called, this, _1, um->get_latest_undo_action()));
+    scoped_connect(um->signal_redo(),boost::bind(&TableEditorBE::undo_called, this, _1, um->get_latest_undo_action()));
   }
   return flag;
 }
@@ -2841,7 +2839,7 @@ std::string TableEditorBE::format_column_type(db_ColumnRef &column)
 
 void TableEditorBE::set_triggers_sql(const std::string &sql, bool sync)
 {
-  set_sql_parser_task_cb(sigc::mem_fun(this, &TableEditorBE::parse_triggers_sql));
+  set_sql_parser_task_cb(boost::bind(&TableEditorBE::parse_triggers_sql, this, _1, _2));
   DBObjectEditorBE::set_sql(sql, sync, _table, "triggers");
 }
 
@@ -2878,7 +2876,7 @@ Recordset::Ref TableEditorBE::get_inserts_model()
     _inserts_model= Recordset::create(_grtm);
     _inserts_model->empty_info_message_on_reset(true);
     _inserts_model->data_storage(_inserts_storage);
-    _inserts_model->export_wizard = sigc::mem_fun(this, &TableEditorBE::show_export_wizard);
+    _inserts_model->export_wizard = boost::bind(&TableEditorBE::show_export_wizard, this);
     _inserts_model->refresh();
   }
   return _inserts_model;
