@@ -132,7 +132,8 @@ void Sql_parser_base::report_sql_error(int lineno, bool calc_abs_lineno, int err
     lineno= total_line_count() - stmt_lc - sql_script_preamble_line_count + lineno;
   }
 
-  _parse_error_cb(lineno, err_tok_line_pos, err_tok_len, err_msg);
+  if (_parse_error_cb)
+    _parse_error_cb(lineno, err_tok_line_pos, err_tok_len, err_msg);
 
   std::ostringstream oss;
   if (_active_obj.is_valid())
@@ -189,5 +190,6 @@ void Sql_parser_base::do_report_sql_statement_border(int begin_lineno, int begin
     int sql_script_preamble_line_count= base::EolHelpers::count_lines(_sql_script_preamble);
     lineno_shift= total_line_count() - stmt_lc - sql_script_preamble_line_count;
   }
-  report_sql_statement_border(begin_lineno + lineno_shift, begin_line_pos, end_lineno + lineno_shift, end_line_pos);
+  if (report_sql_statement_border)
+    report_sql_statement_border(begin_lineno + lineno_shift, begin_line_pos, end_lineno + lineno_shift, end_line_pos);
 }
