@@ -88,10 +88,10 @@ public:
     _back.set_text("< Previous");
     _next.set_text("Next >");
     _last.set_text("Last >>");
-    _first.signal_clicked().connect(sigc::bind(sigc::mem_fun(this, &HexDataViewer::go), -2));
-    _back.signal_clicked().connect(sigc::bind(sigc::mem_fun(this, &HexDataViewer::go), -1));
-    _next.signal_clicked().connect(sigc::bind(sigc::mem_fun(this, &HexDataViewer::go), 1));
-    _last.signal_clicked().connect(sigc::bind(sigc::mem_fun(this, &HexDataViewer::go), 2));
+    scoped_connect(_first.signal_clicked(),boost::bind(&HexDataViewer::go, this, -2));
+    scoped_connect(_back.signal_clicked(),boost::bind(&HexDataViewer::go, this, -1));
+    scoped_connect(_next.signal_clicked(),boost::bind(&HexDataViewer::go, this, 1));
+    scoped_connect(_last.signal_clicked(),boost::bind(&HexDataViewer::go, this, 2));
     
     _tree.add_column(mforms::StringColumnType, "Offset", 100, true);
 
@@ -99,7 +99,7 @@ public:
       _tree.add_column(mforms::StringColumnType, base::strfmt("%X", i), 25, !read_only);
     _tree.end_columns();
 
-    _tree.set_cell_edit_handler(sigc::mem_fun(this, &HexDataViewer::set_cell_value));
+    _tree.set_cell_edit_handler(boost::bind(&HexDataViewer::set_cell_value, this, _1, _2, _3));
   }
 
   virtual void data_changed()
@@ -225,7 +225,7 @@ public:
     
     _text.set_read_only(read_only);
     
-    _text.signal_changed().connect(sigc::mem_fun(this, &TextDataViewer::edited));
+    scoped_connect(_text.signal_changed(),boost::bind(&TextDataViewer::edited, this));
   }
   
   virtual void data_changed()
@@ -377,12 +377,12 @@ void BinaryDataEditor::setup()
   _export.set_text("Save...");
   _import.set_text("Load...");
   
-  _tab_view.signal_tab_changed().connect(sigc::mem_fun(this, &BinaryDataEditor::tab_changed));
+  scoped_connect(_tab_view.signal_tab_changed(),boost::bind(&BinaryDataEditor::tab_changed, this));
   
-  _save.signal_clicked().connect(sigc::mem_fun(this, &BinaryDataEditor::save));
-  _close.signal_clicked().connect(sigc::mem_fun(this, &BinaryDataEditor::close));
-  _import.signal_clicked().connect(sigc::mem_fun(this, &BinaryDataEditor::import_value));
-  _export.signal_clicked().connect(sigc::mem_fun(this, &BinaryDataEditor::export_value));
+  scoped_connect(_save.signal_clicked(),boost::bind(&BinaryDataEditor::save, this));
+  scoped_connect(_close.signal_clicked(),boost::bind(&BinaryDataEditor::close, this));
+  scoped_connect(_import.signal_clicked(),boost::bind(&BinaryDataEditor::import_value, this));
+  scoped_connect(_export.signal_clicked(),boost::bind(&BinaryDataEditor::export_value, this));
 }
 
 void BinaryDataEditor::notify_edit()
@@ -424,7 +424,7 @@ void BinaryDataEditor::add_viewer(BinaryDataViewer *viewer, const std::string &t
 
 void BinaryDataEditor::save()
 {
-  signal_saved.emit();
+  signal_saved();
 }
 
 void BinaryDataEditor::import_value()
