@@ -52,7 +52,7 @@ public:
   size_t length() const { return _length; }
 
   // when user clicks Save
-  sigc::signal<void> signal_saved;
+  boost::signals2::signal<void ()> signal_saved;
   
 public:
   void add_viewer(BinaryDataViewer *viewer, const std::string &title);
