@@ -24,11 +24,11 @@
 
 #include "wbpublic_public_interface.h"
 
-class WBPUBLICBACKEND_PUBLIC_FUNC StringCheckBoxList : public mforms::ScrollPanel
+class WBPUBLICBACKEND_PUBLIC_FUNC StringCheckBoxList : public mforms::ScrollPanel, public base::trackable
 {
   std::vector<mforms::CheckBox*> _items;
   mforms::Box _box;
-  sigc::signal<void> _signal_changed;
+  boost::signals2::signal<void ()> _signal_changed;
   
   
   void toggled();
@@ -44,7 +44,7 @@ public:
   
   void set_selected(const std::string &name, bool flag);
   
-  sigc::signal<void> signal_changed() { return _signal_changed; }
+  boost::signals2::signal<void ()>* signal_changed() { return &_signal_changed; }
 };
 
 
