@@ -35,14 +35,14 @@ using namespace mforms;
 
 
 WizardForm::WizardForm(bec::GRTManager *mgr)
-  : _grtm(mgr), _cancelled(false)
+  : Wizard(Form::main_form()), _cancelled(false), _grtm(mgr)
 {
   _active_page= 0;
   
-  signal_next_clicked().connect(sigc::mem_fun(this, &WizardForm::go_to_next));
-  signal_back_clicked().connect(sigc::mem_fun(this, &WizardForm::go_to_back));
-  signal_extra_clicked().connect(sigc::mem_fun(this, &WizardForm::extra_clicked));
-  set_cancel_handler(sigc::mem_fun(this, &WizardForm::cancel));
+  scoped_connect(signal_next_clicked(),boost::bind(&WizardForm::go_to_next, this));
+  scoped_connect(signal_back_clicked(),boost::bind(&WizardForm::go_to_back, this));
+  scoped_connect(signal_extra_clicked(),boost::bind(&WizardForm::extra_clicked, this));
+  set_cancel_handler(boost::bind(&WizardForm::cancel, this));
   
   _values= grt::DictRef(mgr->get_grt());
 }
@@ -460,7 +460,7 @@ void WizardPage::enter(bool advancing)
 {
   mforms::FsObjectSelector::clear_stored_filenames();
   
-  _signal_enter.emit(advancing);
+  _signal_enter(advancing);
 }
 
 
@@ -472,6 +472,6 @@ void WizardPage::enter(bool advancing)
  */
 void WizardPage::leave(bool advancing)
 {
-  _signal_leave.emit(advancing);
+  _signal_leave(advancing);
 }
 
