@@ -117,8 +117,8 @@ namespace grtui {
 
     void validate();
 
-    sigc::signal<void, bool> signal_enter() { return _signal_enter; }
-    sigc::signal<void, bool> signal_leave() { return _signal_leave; }
+    boost::signals2::signal<void (bool)>* signal_enter() { return &_signal_enter; }
+    boost::signals2::signal<void (bool)>* signal_leave() { return &_signal_leave; }
     
   public:
 
@@ -168,8 +168,8 @@ namespace grtui {
   protected:
     WizardForm *_form;
     std::string _id;
-    sigc::signal<void, bool> _signal_enter;
-    sigc::signal<void, bool> _signal_leave;
+    boost::signals2::signal<void (bool)> _signal_enter;
+    boost::signals2::signal<void (bool)> _signal_leave;
     std::string _title;
     std::string _short_title;
     
