@@ -79,9 +79,9 @@ DbConnectPanel::DbConnectPanel(bool show_connection_combo)
   _desc3.set_style(mforms::SmallHelpTextStyle);
 
   if (show_connection_combo)
-    _stored_connection_sel.signal_changed().connect(sigc::mem_fun(this, &DbConnectPanel::change_active_stored_conn));
-  _rdbms_sel.signal_changed().connect(sigc::mem_fun(this, &DbConnectPanel::change_active_rdbms));
-  _driver_sel.signal_changed().connect(sigc::mem_fun(this, &DbConnectPanel::change_active_driver));
+    scoped_connect(_stored_connection_sel.signal_changed(),boost::bind(&DbConnectPanel::change_active_stored_conn, this));
+  scoped_connect(_rdbms_sel.signal_changed(),boost::bind(&DbConnectPanel::change_active_rdbms, this));
+  scoped_connect(_driver_sel.signal_changed(),boost::bind(&DbConnectPanel::change_active_driver, this));
   
   _table.set_row_count(2);
   _table.set_column_count(3);
@@ -152,9 +152,9 @@ void DbConnectPanel::init(DbConnection *conn, const db_mgmt_ConnectionRef &defau
   _connection= conn;
   _delete_connection_be= false;
   
-  _connection->set_control_callbacks(sigc::mem_fun(this, &DbConnectPanel::suspend_view_layout),
-                                     sigc::mem_fun(this, &DbConnectPanel::clear_param_controls),
-                                     sigc::mem_fun(this, &DbConnectPanel::create_control));
+  _connection->set_control_callbacks(boost::bind(&DbConnectPanel::suspend_view_layout, this, _1),
+                                     boost::bind(&DbConnectPanel::clear_param_controls, this),
+                                     boost::bind(&DbConnectPanel::create_control, this, _1, _2, _3, _4));
   
   if (_show_connection_combo)
     refresh_stored_connections();
@@ -201,7 +201,6 @@ db_mgmt_ConnectionRef DbConnectPanel::get_connection()
   return _connection->get_connection();
 }
 
-
 void DbConnectPanel::set_enabled(bool flag)
 {
   _name_entry.set_enabled(flag);
@@ -258,7 +257,7 @@ void DbConnectPanel::param_value_changed(mforms::View *sender)
   
   std::string error= _connection->validate_driver_params();
   if (error != _last_validation)
-    _signal_validation_state_changed.emit(error, error.empty());
+    _signal_validation_state_changed(error, error.empty());
   _last_validation= error;
 }
 
@@ -366,7 +365,7 @@ void DbConnectPanel::set_active_driver(int driver_index)
   _last_validation= _connection->validate_driver_params();
   // notify the frontend that the state has changed but don't show any error
   // even if there is one
-  _signal_validation_state_changed.emit("", _last_validation.empty());
+  _signal_validation_state_changed("", _last_validation.empty());
   show();
 }
 
@@ -689,7 +688,7 @@ void DbConnectPanel::create_control(::DbDriverParam *driver_param, const ::Contr
           ctrl->set_active(*value != "" && *value != "0" && *value != "NULL");
       }
 
-      ctrl->signal_clicked().connect(sigc::bind(sigc::mem_fun(this, &DbConnectPanel::param_value_changed), ctrl));
+      scoped_connect(ctrl->signal_clicked(),boost::bind(&DbConnectPanel::param_value_changed, this, ctrl));
 
       box->add(mforms::manage(ctrl), false, true);
       _views.push_back(ctrl);
@@ -710,7 +709,7 @@ void DbConnectPanel::create_control(::DbDriverParam *driver_param, const ::Contr
       
       box->add(mforms::manage(btn), false, true);
       _views.push_back(btn);
-      btn->signal_clicked().connect(sigc::bind(sigc::mem_fun(this, &DbConnectPanel::set_keychain_password), driver_param, false));
+      scoped_connect(btn->signal_clicked(),boost::bind(&DbConnectPanel::set_keychain_password, this, driver_param, false));
 
       btn = new Button();
       btn->set_text("Clear");
@@ -722,7 +721,7 @@ void DbConnectPanel::create_control(::DbDriverParam *driver_param, const ::Contr
 #endif
       box->add(mforms::manage(btn), false, true);
       _views.push_back(btn);
-      btn->signal_clicked().connect(sigc::bind(sigc::mem_fun(this, &DbConnectPanel::set_keychain_password), driver_param, true));
+      scoped_connect(btn->signal_clicked(),boost::bind(&DbConnectPanel::set_keychain_password, this, driver_param, true));
 
       break;
     }
@@ -742,7 +741,7 @@ void DbConnectPanel::create_control(::DbDriverParam *driver_param, const ::Contr
 
       ctrl->set_size(bounds.width, -1);
 
-      ctrl->signal_changed().connect(sigc::bind(sigc::mem_fun(this, &DbConnectPanel::param_value_changed), ctrl));
+      scoped_connect(ctrl->signal_changed(),boost::bind(&DbConnectPanel::param_value_changed, this, ctrl));
 
       box->add(mforms::manage(ctrl), true, true);
       _views.push_back(ctrl);
@@ -761,7 +760,7 @@ void DbConnectPanel::create_control(::DbDriverParam *driver_param, const ::Contr
         initial_value= *value;
       
       ctrl->initialize(initial_value, mforms::OpenFile, "", "...", true,
-        sigc::bind(sigc::mem_fun(this, &DbConnectPanel::param_value_changed), ctrl));
+        boost::bind(&DbConnectPanel::param_value_changed, this, ctrl));
       box->add(mforms::manage(ctrl), true, true);
       _views.push_back(ctrl);
       
