@@ -57,7 +57,7 @@ public:
   
   db_mgmt_ConnectionRef get_connection();
   
-  sigc::signal<void,std::string,bool> signal_validation_state_changed() { return _signal_validation_state_changed; }
+  boost::signals2::signal<void (std::string,bool)>* signal_validation_state_changed() { return &_signal_validation_state_changed; }
 
   bool test_connection();
 protected:
@@ -94,7 +94,7 @@ private:
   void save_param(const std::string& name, const grt::StringRef& param);
   std::string get_saved_param(const std::string& name);
   
-  sigc::signal<void,std::string,bool> _signal_validation_state_changed;
+  boost::signals2::signal<void (std::string,bool)> _signal_validation_state_changed;
   
   int _rdbms_index;
   int _driver_index;
