@@ -147,7 +147,7 @@ WizardProgressPage::~WizardProgressPage()
 
 
 WizardProgressPage::TaskRow *WizardProgressPage::add_async_task(const std::string &caption,
-                                                                const sigc::slot<bool> &execute,
+                                                                const boost::function<bool ()> &execute,
                                                                 const std::string &status_text)
 {
   return add_task(true, caption, execute, status_text);
@@ -156,7 +156,7 @@ WizardProgressPage::TaskRow *WizardProgressPage::add_async_task(const std::strin
 
 
 WizardProgressPage::TaskRow *WizardProgressPage::add_task(const std::string &caption,
-                                                          const sigc::slot<bool> &execute,
+                                                          const boost::function<bool ()> &execute,
                                                           const std::string &status_text)
 {
   return add_task(false, caption, execute, status_text);
@@ -165,7 +165,7 @@ WizardProgressPage::TaskRow *WizardProgressPage::add_task(const std::string &cap
 
 WizardProgressPage::TaskRow *WizardProgressPage::add_task(bool async,
                                                           const std::string &caption, 
-                                                          const sigc::slot<bool> &execute,
+                                                          const boost::function<bool ()> &execute,
                                                           const std::string &status_text)
 {
   TaskRow *row= new TaskRow;
@@ -439,13 +439,13 @@ void WizardProgressPage::extra_clicked()
 //--------------------------------------------------------------------------------
 
 
-void WizardProgressPage::execute_grt_task(const sigc::slot<grt::ValueRef,grt::GRT*> &slot, bool sync)
+void WizardProgressPage::execute_grt_task(const boost::function<grt::ValueRef (grt::GRT*)> &slot, bool sync)
 {
   bec::GRTTask *task= new bec::GRTTask("wizard task", _form->grtm()->get_dispatcher(), slot);
 
-  task->signal_message().connect(sigc::mem_fun(this, &WizardProgressPage::process_grt_task_message));
-  task->signal_failed().connect(sigc::mem_fun(this, &WizardProgressPage::process_grt_task_fail));
-  task->signal_finished().connect(sigc::mem_fun(this, &WizardProgressPage::process_grt_task_finish));
+  scoped_connect(task->signal_message(),boost::bind(&WizardProgressPage::process_grt_task_message, this, _1));
+  scoped_connect(task->signal_failed(),boost::bind(&WizardProgressPage::process_grt_task_fail, this, _1));
+  scoped_connect(task->signal_finished(),boost::bind(&WizardProgressPage::process_grt_task_finish, this, _1));
 
   if (sync)
     _form->grtm()->get_dispatcher()->add_task_and_wait(task);
