@@ -47,9 +47,9 @@ namespace grtui {
     {
       mforms::ImageBox icon;
       mforms::Label label;
-      sigc::slot<bool> execute; //! return value indicates whether an asynchronous function was actually executed
-      sigc::slot<bool> process_fail; //! return value indicates whether it can continue executing ok
-      sigc::slot<void, grt::ValueRef> process_finish;
+      boost::function<bool ()> execute; //! return value indicates whether an asynchronous function was actually executed
+      boost::function<bool ()> process_fail; //! return value indicates whether it can continue executing ok
+      boost::function<void (grt::ValueRef)> process_finish;
       std::string status_text;
       bool enabled;
       bool async;
@@ -87,11 +87,11 @@ namespace grtui {
     
 
     TaskRow *add_async_task(const std::string &caption,
-                            const sigc::slot<bool> &execute,
+                            const boost::function<bool ()> &execute,
                             const std::string &status_text);
 
     TaskRow *add_task(const std::string &caption,
-                      const sigc::slot<bool> &execute,
+                      const boost::function<bool ()> &execute,
                       const std::string &status_text);
 
     TaskRow *add_disabled_task(const std::string &caption);
@@ -115,11 +115,11 @@ namespace grtui {
   private:
     TaskRow *add_task(bool async, 
                       const std::string &caption,
-                      const sigc::slot<bool> &execute,
+                      const boost::function<bool ()> &execute,
                       const std::string &status_text);
 
   public:
-    void execute_grt_task(const sigc::slot<grt::ValueRef,grt::GRT*> &slot, bool sync);
+    void execute_grt_task(const boost::function<grt::ValueRef (grt::GRT*)> &slot, bool sync);
 
     void process_grt_task_message(const grt::Message &msg);
     void process_grt_task_fail(const std::exception &error);
