@@ -39,13 +39,14 @@ static void notify_visible_member_change(const std::string &member, const grt::V
   if (member == "name" || member == "simpleType" || member == "userType")
   {
     if (ovalue != ref->get_member(member) && ref->owner().is_valid())
-      db_TableRef::cast_from(ref->owner())->signal_refreshDisplay().emit("column");
+      (*db_TableRef::cast_from(ref->owner())->signal_refreshDisplay())("column");
   }
 }
 
 void db_Column::init()
 {
-  signal_changed().connect(sigc::bind(sigc::ptr_fun(notify_visible_member_change), this)); 
+  //No need in disconnet management since signal it part of object
+  _changed_signal.connect(boost::bind(notify_visible_member_change, _1, _2, this));
 }
 
 db_Column::~db_Column()
@@ -508,7 +509,7 @@ grt::IntegerRef db_Column::setParseType(const std::string &type, const grt::List
   }
 
   if (_owner.is_valid())
-    db_TableRef::cast_from(_owner)->signal_refreshDisplay().emit("column");
+    (*db_TableRef::cast_from(_owner)->signal_refreshDisplay())("column");
 
   undo.end(_("Change Column Type"));
 
