@@ -81,7 +81,7 @@ _pinned(false),
 task(GrtThreadedTask::create(grtm))
 {
   task->send_task_res_msg(false);
-  apply_changes= sigc::mem_fun(this, (void (Recordset::*)())&Recordset::apply_changes_);
+  apply_changes= boost::bind(&Recordset::apply_changes_, this);
   register_default_actions();
   reset();
 }
@@ -218,7 +218,7 @@ bool Recordset::can_close(bool interactive)
 bool Recordset::close()
 {
   RETVAL_IF_FAIL_TO_RETAIN_RAW_PTR (Recordset, this, false)
-  on_close.emit(weak_ptr_from(this));
+  on_close(weak_ptr_from(this));
   return true;
 }
 
@@ -247,7 +247,7 @@ void Recordset::refresh_ui_status_bar()
 {
   task->send_msg(grt::InfoMsg, "");
   if (_grtm->in_main_thread())
-    refresh_ui_status_bar_signal.emit();
+    refresh_ui_status_bar_signal();
 }
 
 
@@ -556,10 +556,9 @@ grt::StringRef Recordset::do_apply_changes(grt::GRT *grt, Ptr self_ptr, Recordse
 
 void Recordset::apply_changes_(Recordset_data_storage::Ptr data_storage_ptr)
 {
-  task->finish_cb(sigc::mem_fun(this, &Recordset::on_apply_changes_finished));
+  task->finish_cb(boost::bind(&Recordset::on_apply_changes_finished, this));
   task->exec(true,
-    sigc::bind(sigc::mem_fun(this, &Recordset::do_apply_changes),
-      weak_ptr_from(this), data_storage_ptr));
+    boost::bind(&Recordset::do_apply_changes, this, _1, weak_ptr_from(this), data_storage_ptr));
 }
 
 
@@ -833,7 +832,7 @@ void Recordset::rebuild_data_index(sqlite::connection *data_swap_db, bool do_cac
     {
       sqlide::QuoteVar qv;
       {
-        qv.escape_string= sigc::ptr_fun(sqlide::QuoteVar::escape_ansi_sql_string);
+        qv.escape_string= boost::bind(sqlide::QuoteVar::escape_ansi_sql_string, _1);
         qv.store_unknown_as_string= true;
         qv.allow_func_escaping= false;
       }
@@ -1178,7 +1177,7 @@ void Recordset::copy_rows_to_clipboard(const std::vector<int> &indeces, bool quo
 
   sqlide::QuoteVar qv;
   {
-    qv.escape_string= sigc::ptr_fun(sqlide::QuoteVar::escape_ansi_sql_string);
+    qv.escape_string= boost::bind(sqlide::QuoteVar::escape_ansi_sql_string, _1);
     qv.store_unknown_as_string= true;
     qv.allow_func_escaping= true;
   }
@@ -1210,7 +1209,7 @@ void Recordset::copy_field_to_clipboard(int row, int column, bool quoted)
 {
   sqlide::QuoteVar qv;
   {
-    qv.escape_string= sigc::ptr_fun(sqlide::QuoteVar::escape_ansi_sql_string);
+    qv.escape_string= boost::bind(sqlide::QuoteVar::escape_ansi_sql_string, _1);
     qv.store_unknown_as_string= true;
     qv.allow_func_escaping= true;
   }
@@ -1398,25 +1397,25 @@ ActionList & Recordset::action_list()
 void Recordset::register_default_actions()
 {
   _action_list.register_action("record_sort_reset",
-    sigc::bind(sigc::mem_fun(this, &Recordset::sort_by), 0, 0, false));
+    boost::bind(&Recordset::sort_by, this, 0, 0, false));
 
   _action_list.register_action("scroll_rows_frame_forward",
-    sigc::mem_fun(this, &Recordset::scroll_rows_frame_forward));
+    boost::bind(&Recordset::scroll_rows_frame_forward, this));
 
   _action_list.register_action("scroll_rows_frame_backward",
-    sigc::mem_fun(this, &Recordset::scroll_rows_frame_backward));
+    boost::bind(&Recordset::scroll_rows_frame_backward, this));
 
   _action_list.register_action("record_fetch_all",
-    sigc::mem_fun(this, &Recordset::toggle_limit_rows));
+    boost::bind(&Recordset::toggle_limit_rows, this));
 
   _action_list.register_action("record_refresh",
-    sigc::mem_fun(this, &Recordset::refresh));
+    boost::bind(&Recordset::refresh, this));
 
   _action_list.register_action("record_export",
-    sigc::mem_fun(this, &Recordset::invoke_export));
+    boost::bind(&Recordset::invoke_export, this));
 
   _action_list.register_action("pin",
-    sigc::mem_fun(this, &Recordset::toggle_pinned));
+    boost::bind(&Recordset::toggle_pinned, this));
 }
 
 
@@ -1487,8 +1486,7 @@ void Recordset::open_field_data_editor(RowId row, ColumnId column)
       return;
     data_editor->set_title(base::strfmt("Edit Data for %s", _column_names[column].c_str()));
     data_editor->set_release_on_close(true);
-    data_editor->signal_saved.connect(sigc::bind(sigc::mem_fun(this, &Recordset::set_field_value),
-      row, column, data_editor));
+    data_editor->signal_saved.connect(boost::bind(&Recordset::set_field_value,this, row, column, data_editor));
     data_editor->show(true);
   }
   CATCH_AND_DISPATCH_EXCEPTION(false, res)
