@@ -50,7 +50,7 @@ public:
   bool can_close();
   bool can_close(bool interactive);
   bool close();
-  sigc::signal<void, Ptr> on_close;
+  boost::signals2::signal<void (Ptr)> on_close;
 
 public:
   typedef boost::shared_ptr<Recordset_data_storage> Recordset_data_storage_Ref;
@@ -64,7 +64,7 @@ public:
   bool reset(bool rethrow);
   virtual void reset();
   virtual void refresh();
-  sigc::signal<void> refresh_ui_status_bar_signal;
+  boost::signals2::signal<void ()> refresh_ui_status_bar_signal;
 private:
   bool reset(Recordset_data_storage_Ptr data_storage_ptr, bool rethrow);
 protected:
@@ -114,7 +114,7 @@ protected:
   Recordset_data_storage_Ref _data_storage;
 
 public:
-  sigc::slot<void> apply_changes;
+  boost::function<void ()> apply_changes;
 public:
   void apply_changes_();
   grt::StringRef do_apply_changes(grt::GRT *grt, Ptr self_ptr, Recordset_data_storage_Ptr data_storage_ptr);
@@ -139,15 +139,15 @@ public:
   virtual bec::MenuItemList get_popup_menu_items(const std::vector<int> &rows, int clicked_column);
   virtual bool activate_popup_menu_item(const std::string &action, const std::vector<int> &rows, int clicked_column);
 
-  sigc::slot<bec::MenuItemList, std::vector<int>, int> popup_menu_items_slot;
-  sigc::slot<bool, std::string, std::vector<int>, int> call_popup_menu_item_slot;
+  boost::function<bec::MenuItemList (std::vector<int>, int)> popup_menu_items_slot;
+  boost::function<bool (const std::string&, const std::vector<int>&, int)> call_popup_menu_item_slot;
   
 public:
   void copy_rows_to_clipboard(const std::vector<int> &indeces, bool quoted=true);
   void copy_field_to_clipboard(int row, int column, bool quoted=true);
 
 public:
-  sigc::slot<void> export_wizard;
+  boost::function<void ()> export_wizard;
   
   void data_storages_for_export(std::vector<std::string> &formats_names, std::vector<std::string> &formats_desc);
   Recordset_data_storage_Ref data_storage_for_export(const std::string &format);
