@@ -480,7 +480,7 @@ std::string Recordset_cdbc_storage::decorated_sql_query()
   {
     SqlFacade::Ref sql_facade= SqlFacade::instance_for_rdbms(_rdbms);
     Sql_specifics::Ref sql_specifics= sql_facade->sqlSpecifics();
-    sql_query= sql_specifics->limit_select_query(sql_query, _limit_rows_count, _limit_rows_offset);
+    sql_query= sql_specifics->limit_select_query(sql_query, &_limit_rows_count, &_limit_rows_offset);
   }
 
   return sql_query;
