@@ -107,12 +107,12 @@ void Recordset_sql_storage::init_variant_quoter(sqlide::QuoteVar &qv) const
   }
   else
   {
-    qv.escape_string= sigc::ptr_fun(sqlide::QuoteVar::escape_ansi_sql_string);
+    qv.escape_string= boost::bind(sqlide::QuoteVar::escape_ansi_sql_string, _1);
     // swap db (sqlite) stores unknown values as quoted strings
     qv.store_unknown_as_string= true;
     qv.allow_func_escaping= false;
   }
-  qv.blob_to_string= (_binding_blobs) ? sqlide::QuoteVar::Blob_to_string() : sigc::ptr_fun(sqlide::QuoteVar::blob_to_hex_string);
+  qv.blob_to_string= (_binding_blobs) ? sqlide::QuoteVar::Blob_to_string() : boost::bind(sqlide::QuoteVar::blob_to_hex_string, _1, _2);
 }
 
 
@@ -131,11 +131,7 @@ void Recordset_sql_storage::do_unserialize(Recordset *recordset, sqlite::connect
     Var_list var_list;
     SqlFacade::Ref sql_facade= SqlFacade::instance_for_rdbms_name(_grtm->get_grt(), "Mysql"); //!
     Sql_inserts_loader::Ref loader= sql_facade->sqlInsertsLoader();
-    loader->process_insert_cb(
-      sigc::bind(
-        sigc::mem_fun(this, &Recordset_sql_storage::load_insert_statement),
-        &column_names,
-        &var_list));
+    loader->process_insert_cb(boost::bind(&Recordset_sql_storage::load_insert_statement, this, _1, _2, _3, _4, _5, &column_names, &var_list));
     loader->load(sql_script(), schema_name());
 
     // column types
