@@ -193,11 +193,11 @@ void Recordset_text_storage::do_serialize(const Recordset *recordset, sqlite::co
   ColumnId visible_col_count= recordset->get_column_count();
   sqlide::QuoteVar qv;
   {
-    qv.escape_string= sigc::ptr_fun(sqlide::QuoteVar::escape_ansi_sql_string);
+    qv.escape_string= std::ptr_fun(sqlide::QuoteVar::escape_ansi_sql_string);
     // swap db (sqlite) stores unknown values as quoted strings
     qv.store_unknown_as_string= true;
     qv.allow_func_escaping= false;
-    qv.blob_to_string= (true) ? sqlide::QuoteVar::Blob_to_string() : sigc::ptr_fun(sqlide::QuoteVar::blob_to_hex_string);
+    qv.blob_to_string= (true) ? sqlide::QuoteVar::Blob_to_string() : std::ptr_fun(sqlide::QuoteVar::blob_to_hex_string);
   }
 
   // misc subst variables
