@@ -122,7 +122,7 @@ void Sql_editor::sql(const std::string &sql)
   {
     _sql= sql;
     eol(EolHelpers::eol(EolHelpers::detect(sql)));
-    text_change_signal.emit();
+    text_change_signal();
   }
 }
 
@@ -133,7 +133,7 @@ void Sql_editor::eol(const std::string &value)
     return;
   _eol= value;
   _sql_checker->eol(_eol);
-  eol_change_signal.emit();
+  eol_change_signal();
 }
 
 
@@ -171,9 +171,7 @@ void Sql_editor::check_sql(bool sync)
     _sql_errors.clear();
   }
 
-  _sql_checker_task->exec(sync,
-    sigc::bind(sigc::mem_fun(this, &Sql_editor::do_check_sql),
-      weak_ptr_from(this)));
+  _sql_checker_task->exec(sync, boost::bind(&Sql_editor::do_check_sql, this, _1, weak_ptr_from(this)));
 }
 
 
@@ -183,10 +181,10 @@ grt::StringRef Sql_editor::do_check_sql(grt::GRT *grt, Ptr self_ptr)
 
   GMutexLock sql_checker_mutex(_sql_checker_mutex);
 
-  _sql_checker->report_sql_statement_border= sigc::bind(sigc::mem_fun(this, &Sql_editor::on_report_sql_statement_border), _sql_checker_tag);
-  _sql_checker->parse_error_cb(sigc::bind(sigc::mem_fun(this, &Sql_editor::on_sql_error), _sql_checker_tag));
-  _sql_checker_task->progress_cb(sigc::bind(sigc::mem_fun(this, &Sql_editor::on_sql_check_progress), _sql_checker_tag));
-  _sql_checker_task->finish_cb(sigc::mem_fun(this, &Sql_editor::on_sql_check_finished));
+  _sql_checker->report_sql_statement_border= boost::bind(&Sql_editor::on_report_sql_statement_border, this, _1, _2, _3, _4, _sql_checker_tag);
+  _sql_checker->parse_error_cb(boost::bind(&Sql_editor::on_sql_error, this, _1, _2, _3, _4, _sql_checker_tag));
+  _sql_checker_task->progress_cb(boost::bind(&Sql_editor::on_sql_check_progress, this, _1, _2, _sql_checker_tag));
+  _sql_checker_task->finish_cb(boost::bind(&Sql_editor::on_sql_check_finished, this));
 
   _last_sql_check_progress_msg_timestamp= timestamp();
 
@@ -250,7 +248,7 @@ int Sql_editor::on_sql_check_progress(float progress, const std::string &msg, in
       sql_statement_borders.swap(_sql_statement_borders_cache);
     }
     BOOST_FOREACH (const SqlStatementBorder &sql_statement_border, sql_statement_borders)
-      if (sql_statement_border.tag == _sql_checker_tag)
+      if (sql_statement_border.tag == _sql_checker_tag && report_sql_statement_border)
         report_sql_statement_border(sql_statement_border.begin_lineno, sql_statement_border.begin_line_pos,
           sql_statement_border.end_lineno, sql_statement_border.end_line_pos);
     {
@@ -267,7 +265,7 @@ int Sql_editor::on_sql_check_progress(float progress, const std::string &msg, in
       _sql_errors.swap(sql_errors);
     }
     BOOST_FOREACH (const SqlError &sql_error, sql_errors)
-      if (sql_error.tag == _sql_checker_tag)
+      if (sql_error.tag == _sql_checker_tag && _sql_parser_err_cb)
         _sql_parser_err_cb(sql_error.tok_lineno, sql_error.tok_line_pos, sql_error.tok_len, sql_error.msg);
   }
 
@@ -279,7 +277,7 @@ int Sql_editor::on_sql_check_finished()
 {
   // usage of this signal is a temporary workaround for scintilla control rendering problem in osx version
   // it's needed to determine the moment when parsing (syntax check) is complete
-  sql_check_finish_signal.emit();
+  sql_check_finish_signal();
 
   return 0;
 }
@@ -354,7 +352,7 @@ void Sql_editor::set_selected_range(int start, int end)
 {
   _selection_start= start;
   _selection_end= end;
-  text_selection_change_signal.emit();
+  text_selection_change_signal();
 }
 
 
@@ -381,7 +379,7 @@ void Sql_editor::set_cursor_pos(int pos)
 
 std::string Sql_editor::current_statement()
 {
-  return current_statement_slot();
+  return current_statement_slot ? current_statement_slot() : "";
 }
 
 
