@@ -22,6 +22,7 @@
 #define _SQL_EDITOR_BE_H_
 
 #include <memory>
+#include "base/trackable.h"
 #include "wbpublic_public_interface.h"
 #include "grt/grt_threaded_task.h"
 #include "grtsqlparser/sql_semantic_check.h"
@@ -36,7 +37,7 @@
 /** Base class for SQL Editor Backend classes.
  Subclassed by specific RDBMS support modules.
  */
-class WBPUBLICBACKEND_PUBLIC_FUNC Sql_editor : public sigc::trackable, public boost::enable_shared_from_this<Sql_editor>
+class WBPUBLICBACKEND_PUBLIC_FUNC Sql_editor : public boost::enable_shared_from_this<Sql_editor>, public base::trackable
 {
 public:
   typedef boost::shared_ptr<Sql_editor> Ref;
@@ -71,7 +72,7 @@ public:
 protected:
   std::string _eol;
 public:
-  sigc::signal<void> eol_change_signal;
+  boost::signals2::signal<void ()> eol_change_signal;
 
 public:
   int int_option(std::string name);
@@ -104,13 +105,13 @@ public:
   void insert_text(const std::string &new_text);
   std::string current_statement();
 public:
-  sigc::signal<void> text_selection_change_signal;
-  sigc::signal<void> text_change_signal;
-  sigc::slot<int, const std::string&> replace_selected_text_slot;
-  sigc::slot<void, int, int> change_selected_range_slot;
-  sigc::slot<void, int> change_cursor_pos_slot;
-  sigc::slot<int, const std::string&> insert_text_slot;
-  sigc::slot<std::string> current_statement_slot;
+  boost::signals2::signal<void ()> text_selection_change_signal;
+  boost::signals2::signal<void ()> text_change_signal;
+  boost::function<int (const std::string&)> replace_selected_text_slot;
+  boost::function<void (int, int)> change_selected_range_slot;
+  boost::function<void (int)> change_cursor_pos_slot;
+  boost::function<int (const std::string&)> insert_text_slot;
+  boost::function<std::string ()> current_statement_slot;
 protected:
   int _selection_start;
   int _selection_end;
@@ -153,7 +154,7 @@ protected:
   bool _has_sql_errors;
 
 public:
-  sigc::signal<void> sql_check_finish_signal;
+  boost::signals2::signal<void ()> sql_check_finish_signal;
 
 public:
   typedef Sql_parser_base::Report_sql_statement_border Report_sql_statement_border;
