@@ -54,7 +54,7 @@ public:
   int on_error(long long err_code, const std::string& err_msg, const std::string& err_sql);
   int on_exec_progress(float progress);
   int on_exec_stat(long success_count, long err_count);
-  sigc::slot<void, std::string &> apply_sql_script;
+  boost::function<void (std::string &)> apply_sql_script;
   bool execute_sql_script();
   virtual std::string next_button_caption();
   virtual bool allow_back();
