@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -26,6 +26,9 @@
 
 using namespace std;
 using namespace wbfig;
+using namespace mdc;
+using namespace MySQL::Geometry;
+using namespace MySQL::Drawing;
 
 #define SPLIT_LINE_LENGTH 30
 
@@ -48,7 +51,7 @@ std::vector<mdc::ItemHandle*> ConnectionLineLayouter::create_handles(mdc::Line *
 
 
 bool ConnectionLineLayouter::handle_dragged(mdc::Line *line, mdc::ItemHandle *handle, 
-                                            const mdc::Point &pos, bool dragging)
+                                            const Point &pos, bool dragging)
 {
   /*
   if (handle->get_tag() == 1)
@@ -123,27 +126,27 @@ bool ConnectionLineLayouter::update_end_point()
 }
 
 
-std::vector<mdc::Point> ConnectionLineLayouter::get_points_for_subline(int subline)
+std::vector<Point> ConnectionLineLayouter::get_points_for_subline(int subline)
 {
   if (_type == ZLine)
   {
     if (subline == _linfo.start_subline())
     {
-      std::vector<mdc::Point> points;
-      mdc::Point p;
+      std::vector<Point> points;
+      Point p;
 
       p= _linfo.subline_start_point(subline).round();
       points.push_back(p);
       if (_linfo.subline_start_angle(subline) == 0)
-        points.push_back(mdc::Point(p.x+15, p.y));
+        points.push_back(Point(p.x+15, p.y));
       else
-        points.push_back(mdc::Point(p.x-15, p.y));
+        points.push_back(Point(p.x-15, p.y));
 
       p= _linfo.subline_end_point(subline).round();
       if (_linfo.subline_end_angle(subline) == 0)
-        points.push_back(mdc::Point(p.x+15, p.y));
+        points.push_back(Point(p.x+15, p.y));
       else
-        points.push_back(mdc::Point(p.x-15, p.y));
+        points.push_back(Point(p.x-15, p.y));
       points.push_back(p);
 
       return points;
@@ -270,15 +273,15 @@ void Connection::set_segment_offset(int subline, double offset)
 }
 
 
-bool Connection::contains_point(const mdc::Point &point) const
+bool Connection::contains_point(const Point &point) const
 {
   if (!super::contains_point(point))
     return false;
 
   if (_split)
   {
-    mdc::Point v1, v2;
-    mdc::Rect bounds;
+    Point v1, v2;
+    Rect bounds;
 
     v1= convert_point_to(_segments[0].pos, get_parent());
     v2= convert_point_to(_segments[1].pos, get_parent());
@@ -292,7 +295,7 @@ bool Connection::contains_point(const mdc::Point &point) const
         v2.x= v1.x + 20;
       else
         v2.x= v1.x - 20;
-      bounds= mdc::Rect(v1, v2);
+      bounds= Rect(v1, v2);
     }
     else
     {
@@ -302,7 +305,7 @@ bool Connection::contains_point(const mdc::Point &point) const
         v2.y= v1.y + 20;
       else
         v2.y= v1.y - 20;
-      bounds= mdc::Rect(v1, v2);
+      bounds= Rect(v1, v2);
     }
 
     if (bounds_contain_point(bounds, point.x, point.y))
@@ -320,7 +323,7 @@ bool Connection::contains_point(const mdc::Point &point) const
         v2.x= v1.x + 20;
       else
         v2.x= v1.x - 20;
-      bounds= mdc::Rect(v1, v2);
+      bounds= Rect(v1, v2);
     }
     else
     {
@@ -330,7 +333,7 @@ bool Connection::contains_point(const mdc::Point &point) const
         v2.y= v1.y + 20;
       else
         v2.y= v1.y - 20;
-      bounds= mdc::Rect(v1, v2);
+      bounds= Rect(v1, v2);
     }
 
     if (bounds_contain_point(bounds, point.x, point.y))
@@ -348,7 +351,7 @@ void Connection::stroke_outline(mdc::CairoCtx *cr, float offset) const
     mdc::Line::stroke_outline(cr, offset);
   else // Draw a split connection (only show start and end).
   {
-    mdc::Point v1, v2;
+    Point v1, v2;
     {
       v1= _segments[0].pos;
       v2= _segments[1].pos;
@@ -407,7 +410,7 @@ void Connection::stroke_outline_gl(float offset)
     glTranslated(offset, offset, 0);
     glBegin(GL_LINES);
 
-    mdc::Point v1, v2;
+    Point v1, v2;
 
     // Begin of the connection.
     v1= _segments[0].pos;
@@ -457,12 +460,12 @@ void Connection::stroke_outline_gl(float offset)
 
 //--------------------------------------------------------------------------------------------------
 
-mdc::Point Connection::get_middle_caption_pos(const mdc::Size &size, CaptionPos pos)
+Point Connection::get_middle_caption_pos(const Size &size, CaptionPos pos)
 {
   if (_segments.size() >= 2)
   {
-    mdc::Point midpoint;
-    mdc::Point p1, p2;
+    Point midpoint;
+    Point p1, p2;
 
     if (_segments.size() == 2)
     {
@@ -583,7 +586,7 @@ double Connection::get_middle_segment_angle()
     while (--i > 0)
       ++iter;
 
-    mdc::Point pos= iter->pos;
+    Point pos= iter->pos;
     ++iter;
 
     return mdc::angle_of_line(pos, iter->pos);
@@ -592,10 +595,10 @@ double Connection::get_middle_segment_angle()
 }
 
 
-mdc::Point Connection::get_start_caption_pos(const mdc::Size &size)
+Point Connection::get_start_caption_pos(const Size &size)
 {
-  mdc::Point p= _segments.front().pos;
-  mdc::Point next_point= (++_segments.begin())->pos;
+  Point p= _segments.front().pos;
+  Point next_point= (++_segments.begin())->pos;
   
   if (fabs(next_point.x-p.x) <= fabs(next_point.y-p.y))
   {
@@ -618,10 +621,10 @@ mdc::Point Connection::get_start_caption_pos(const mdc::Size &size)
 }
 
 
-mdc::Point Connection::get_end_caption_pos(const mdc::Size &size)
+Point Connection::get_end_caption_pos(const Size &size)
 {
-  mdc::Point p= _segments.back().pos;
-  mdc::Point next_point= (++_segments.rbegin())->pos;
+  Point p= _segments.back().pos;
+  Point next_point= (++_segments.rbegin())->pos;
 
   if (fabs(next_point.x-p.x) <= fabs(next_point.y-p.y))
   {
@@ -710,7 +713,7 @@ void Connection::render(mdc::CairoCtx *cr)
   draw_line_ends(cr);
 
   cr->save();
-  cr->translate(get_middle_caption_pos(mdc::Size(1,1), Middle) - get_position());
+  cr->translate(get_middle_caption_pos(Size(1,1), Middle) - get_position());
 
   double angle= get_middle_segment_angle();
 
@@ -731,7 +734,7 @@ void Connection::render(mdc::CairoCtx *cr)
     cr->line_to(-10, 0);
     cr->line_to(0, -10);
     cr->close_path();
-    cr->set_color(mdc::Color::Black());
+    cr->set_color(Color::Black());
     cr->fill();
     break;
   case LeftEmpty:
@@ -742,9 +745,9 @@ void Connection::render(mdc::CairoCtx *cr)
     cr->line_to(-10, 0);
     cr->line_to(0, -10);
     cr->close_path();
-    cr->set_color(mdc::Color::White());
+    cr->set_color(Color::White());
     cr->fill_preserve();
-    cr->set_color(mdc::Color::Black());
+    cr->set_color(Color::Black());
     cr->stroke();
     cr->new_path();
     cr->move_to(0, -10);
@@ -762,9 +765,9 @@ void Connection::render(mdc::CairoCtx *cr)
     cr->line_to(-10, 0);
     cr->line_to(0, -10);
     cr->close_path();
-    cr->set_color(mdc::Color::White());
+    cr->set_color(Color::White());
     cr->fill_preserve();
-    cr->set_color(mdc::Color::Black());
+    cr->set_color(Color::Black());
     cr->stroke();
     cr->new_path();
     cr->move_to(0, -10);
@@ -782,9 +785,9 @@ void Connection::render(mdc::CairoCtx *cr)
     cr->line_to(-10, 0);
     cr->line_to(0, -10);
     cr->close_path();
-    cr->set_color(mdc::Color::White());
+    cr->set_color(Color::White());
     cr->fill_preserve();
-    cr->set_color(mdc::Color::Black());
+    cr->set_color(Color::Black());
     cr->stroke();
     break;
   }
@@ -824,7 +827,7 @@ void Connection::render_gl(mdc::CairoCtx *cr)
   glDisable(GL_LINE_STIPPLE);
   draw_line_ends_gl();
 
-  mdc::Point effective_position= get_middle_caption_pos(mdc::Size(1, 1), Middle) - get_position();
+  Point effective_position= get_middle_caption_pos(Size(1, 1), Middle) - get_position();
   glTranslated(effective_position.x, effective_position.y, 0);
 
   double angle= get_middle_segment_angle();
@@ -840,82 +843,82 @@ void Connection::render_gl(mdc::CairoCtx *cr)
     break;
   case Filled:
     {
-      mdc::Point vertices[]=
+      Point vertices[]=
       {
-        mdc::Point(0, -10),
-        mdc::Point(10, 0),
-        mdc::Point(0, 10),
-        mdc::Point(-10, 0),
-        mdc::Point(0, -10),
+        Point(0, -10),
+        Point(10, 0),
+        Point(0, 10),
+        Point(-10, 0),
+        Point(0, -10),
       };
-      gl_setcolor(mdc::Color::Black());
+      gl_setcolor(Color::Black());
       gl_polygon(vertices, 5, true);
       break;
     }
 
   case LeftEmpty:
     {
-      mdc::Point vertices[]=
+      Point vertices[]=
       {
-        mdc::Point(0, -10),
-        mdc::Point(10, 0),
-        mdc::Point(0, 10),
-        mdc::Point(-10, 0),
-        mdc::Point(0, -10),
+        Point(0, -10),
+        Point(10, 0),
+        Point(0, 10),
+        Point(-10, 0),
+        Point(0, -10),
       };
-      gl_setcolor(mdc::Color::Black());
-      gl_polygon(vertices, 5, mdc::Color::Black(), mdc::Color::White());
+      gl_setcolor(Color::Black());
+      gl_polygon(vertices, 5, Color::Black(), Color::White());
     }
 
     {
-      mdc::Point vertices[]=
+      Point vertices[]=
       {
-        mdc::Point(0, -10),
-        mdc::Point(10, 0),
-        mdc::Point(0, 10),
-        mdc::Point(0, -10),
+        Point(0, -10),
+        Point(10, 0),
+        Point(0, 10),
+        Point(0, -10),
       };
-      gl_polygon(vertices, 4, mdc::Color::Black(), mdc::Color::White());
+      gl_polygon(vertices, 4, Color::Black(), Color::White());
     }
     break;
 
   case RightEmpty:
     {
-      mdc::Point vertices[]=
+      Point vertices[]=
       {
-        mdc::Point(0, -10),
-        mdc::Point(10, 0),
-        mdc::Point(0, 10),
-        mdc::Point(-10, 0),
-        mdc::Point(0, -10),
+        Point(0, -10),
+        Point(10, 0),
+        Point(0, 10),
+        Point(-10, 0),
+        Point(0, -10),
       };
-      gl_polygon(vertices, 5, mdc::Color::Black(), mdc::Color::White());
+      gl_polygon(vertices, 5, Color::Black(), Color::White());
     }
 
     {
-      mdc::Point vertices[]=
+      Point vertices[]=
       {
-        mdc::Point(0, -10),
-        mdc::Point(10, 0),
-        mdc::Point(0, 10),
-        mdc::Point(0, -10),
+        Point(0, -10),
+        Point(10, 0),
+        Point(0, 10),
+        Point(0, -10),
       };
-      gl_setcolor(mdc::Color::Black());
+      gl_setcolor(Color::Black());
       gl_polygon(vertices, 4, true);
     }
 
     break;
   case Empty:
     {
-      mdc::Point vertices[]=
+      Point vertices[]=
       {
-        mdc::Point(0, -10),
-        mdc::Point(10, 0),
-        mdc::Point(0, 10),
-        mdc::Point(-10, 0),
-        mdc::Point(0, -10),
+        Point(0, -10),
+        Point(10, 0),
+        Point(0, 10),
+        Point(-10, 0),
+        Point(0, -10),
       };
-      gl_polygon(vertices, 5, mdc::Color::Black(), mdc::Color::White());
+      gl_polygon(vertices, 5, Color::Black(), Color::White());
     }
     break;
   }
@@ -925,7 +928,7 @@ void Connection::render_gl(mdc::CairoCtx *cr)
 
 //--------------------------------------------------------------------------------------------------
 
-bool Connection::on_click(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button,
+bool Connection::on_click(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button,
                           mdc::EventState state)
 {
   if (!_hub->figure_click(_represented_object, target, point, button, state))
@@ -935,7 +938,7 @@ bool Connection::on_click(mdc::CanvasItem *target, const mdc::Point &point, mdc:
 
 //--------------------------------------------------------------------------------------------------
 
-bool Connection::on_double_click(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button,
+bool Connection::on_double_click(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button,
                           mdc::EventState state)
 {
   if (!_hub->figure_double_click(_represented_object, target, point, button, state))
@@ -945,7 +948,7 @@ bool Connection::on_double_click(mdc::CanvasItem *target, const mdc::Point &poin
 
 //--------------------------------------------------------------------------------------------------
 
-bool Connection::on_enter(mdc::CanvasItem *target, const mdc::Point &point)
+bool Connection::on_enter(mdc::CanvasItem *target, const Point &point)
 {
   if (!_hub->figure_enter(_represented_object, target, point))
     return super::on_enter(target, point);
@@ -953,7 +956,7 @@ bool Connection::on_enter(mdc::CanvasItem *target, const mdc::Point &point)
 }
 
 
-bool Connection::on_leave(mdc::CanvasItem *target, const mdc::Point &point)
+bool Connection::on_leave(mdc::CanvasItem *target, const Point &point)
 {
   if (!_hub->figure_leave(_represented_object, target, point))
     return super::on_leave(target, point);
@@ -961,7 +964,7 @@ bool Connection::on_leave(mdc::CanvasItem *target, const mdc::Point &point)
 }
 
 
-bool Connection::on_button_press(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool Connection::on_button_press(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   if (!_hub->figure_button_press(_represented_object, target, point, button, state))
     return super::on_button_press(target, point, button, state);
@@ -969,7 +972,7 @@ bool Connection::on_button_press(mdc::CanvasItem *target, const mdc::Point &poin
 }
 
 
-bool Connection::on_button_release(mdc::CanvasItem *target, const mdc::Point &point, mdc::MouseButton button, mdc::EventState state)
+bool Connection::on_button_release(mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
   if (!_hub->figure_button_release(_represented_object, target, point, button, state))
     return super::on_button_release(target, point, button, state);
