@@ -32,7 +32,7 @@ model_Connection::ImplData::ImplData(model_Connection *self)
   : model_Object::ImplData(self), _line(0),
   _above_caption(0), _below_caption(0), _start_caption(0), _end_caption(0)
 {
-  self->signal_changed().connect(sigc::mem_fun(this, &ImplData::member_changed));
+  scoped_connect(self->signal_changed(),boost::bind(&ImplData::member_changed, this, _1, _2));
 }
 
 
@@ -89,9 +89,9 @@ void model_Connection::ImplData::member_changed(const std::string &name, const g
     } */
     else if (name == "owner")
     {
-      if (!_object_realized && self()->owner().is_valid())
-        _object_realized= self()->owner()->get_data()->signal_object_realized().
-          connect(sigc::mem_fun(this, &ImplData::object_realized));
+      if (!_object_realized.connected() && self()->owner().is_valid())
+        _object_realized= *scoped_connect(self()->owner()->get_data()->signal_object_realized(),
+        boost::bind(&ImplData::object_realized, this, _1)).get();
     }
   }
 }
@@ -195,8 +195,8 @@ void model_Connection::ImplData::set_above_caption(const std::string &text)
     _above_caption->set_draggable(true);
     _above_caption->set_accepts_selection(true);
     _above_caption->set_visible(*self()->_visible != 0);
-    _above_caption->signal_bounds_changed().
-      connect(sigc::bind<mdc::TextFigure*>(sigc::mem_fun(this, &model_Connection::ImplData::caption_bounds_changed), _above_caption));
+    scoped_connect(_above_caption->signal_bounds_changed(),
+      boost::bind(&model_Connection::ImplData::caption_bounds_changed, this, _1, _above_caption));
   }
   _above_caption->set_text(text);
 
@@ -230,8 +230,8 @@ void model_Connection::ImplData::set_below_caption(const std::string &text)
     _below_caption->set_draggable(true);
     _below_caption->set_accepts_selection(true);
     _below_caption->set_visible(*self()->_visible != 0);
-    _below_caption->signal_bounds_changed().
-      connect(sigc::bind<mdc::TextFigure*>(sigc::mem_fun(this, &model_Connection::ImplData::caption_bounds_changed), _below_caption));
+    scoped_connect(_below_caption->signal_bounds_changed(),
+      boost::bind(&model_Connection::ImplData::caption_bounds_changed, this, _1, _below_caption));
   }
   _below_caption->set_text(text);
 
@@ -259,8 +259,8 @@ void model_Connection::ImplData::set_start_caption(const std::string &text)
     _start_caption->set_draggable(true);
     _start_caption->set_accepts_selection(true);
     _start_caption->set_visible(*self()->_visible != 0);
-    _start_caption->signal_bounds_changed().
-      connect(sigc::bind<mdc::TextFigure*>(sigc::mem_fun(this, &model_Connection::ImplData::caption_bounds_changed), _start_caption));
+    scoped_connect(_start_caption->signal_bounds_changed(),
+      boost::bind(&model_Connection::ImplData::caption_bounds_changed, this, _1, _start_caption));
   }
   _start_caption->set_text(text);
 
@@ -288,8 +288,8 @@ void model_Connection::ImplData::set_end_caption(const std::string &text)
     _end_caption->set_draggable(true);
     _end_caption->set_accepts_selection(true);
     _end_caption->set_visible(*self()->_visible != 0);
-    _end_caption->signal_bounds_changed().
-      connect(sigc::bind<mdc::TextFigure*>(sigc::mem_fun(this, &model_Connection::ImplData::caption_bounds_changed), _end_caption));
+    scoped_connect(_end_caption->signal_bounds_changed(),
+      boost::bind(&model_Connection::ImplData::caption_bounds_changed, this, _1, _end_caption));
   }
   _end_caption->set_text(text);
 
@@ -384,7 +384,7 @@ void model_Connection::ImplData::finish_realize()
   if (!font.empty())
     _caption_font= parse_font_spec(font);
 
-  _line->signal_layout_changed().connect(sigc::mem_fun(this, &model_Connection::ImplData::layout_changed));
+  scoped_connect(_line->signal_layout_changed(),boost::bind(&model_Connection::ImplData::layout_changed, this));
 
   self()->owner()->get_data()->stack_connection(model_ConnectionRef(self()), _line);
 
