@@ -50,7 +50,7 @@ protected:
   
   mdc::FontSpec _caption_font;
 
-  sigc::connection _object_realized;
+  boost::signals2::connection _object_realized;
     
   bool _destroying;
   
