@@ -110,8 +110,8 @@ model_Diagram::ImplData::ImplData(model_Diagram *self)
   _updating_selection= 0;
   _connected_update= false;
   
-  self->signal_changed().connect(sigc::mem_fun(this, &model_Diagram::ImplData::member_changed));
-  self->signal_list_changed().connect(sigc::mem_fun(this, &model_Diagram::ImplData::member_list_changed));
+  scoped_connect(self->signal_changed(),boost::bind(&model_Diagram::ImplData::member_changed, this, _1 ,_2));
+  scoped_connect(self->signal_list_changed(),boost::bind(&model_Diagram::ImplData::member_list_changed, this, _1, _2, _3));
 }
 
 
@@ -190,13 +190,13 @@ void model_Diagram::ImplData::block_updates(bool flag)
 
 void model_Diagram::ImplData::notify_object_realize(const model_ObjectRef &object)
 {
-  _realize_object_signal.emit(object);
+  _realize_object_signal(object);
 }
 
 
 void model_Diagram::ImplData::notify_object_will_unrealize(const model_ObjectRef &object)
 {
-  _will_unrealize_object_signal.emit(object);
+  _will_unrealize_object_signal(object);
 }
 
 
@@ -226,7 +226,7 @@ void model_Diagram::ImplData::update_size()
     Size pageSize(get_size_for_page(_self->owner()->get_data()->get_page_settings()));
 
     if (!is_main_thread())
-      run_later(sigc::bind(sigc::mem_fun(_canvas_view, &mdc::CanvasView::set_page_size), pageSize));
+      run_later(boost::bind(&mdc::CanvasView::set_page_size, _canvas_view, pageSize));
     else
       _canvas_view->set_page_size(pageSize);
 
@@ -239,7 +239,7 @@ void model_Diagram::ImplData::update_size()
     if (yc < 1) yc= 1;
 
     if (!is_main_thread())
-      run_later(sigc::bind(sigc::mem_fun(_canvas_view, &mdc::CanvasView::set_page_layout), xc, yc));
+      run_later(boost::bind(&mdc::CanvasView::set_page_layout, _canvas_view, xc, yc));
     else
       _canvas_view->set_page_layout(xc, yc);
   }
@@ -339,7 +339,7 @@ bool model_Diagram::ImplData::realize()
   
   if (!is_main_thread())
   {
-    run_later(sigc::hide_return(sigc::mem_fun(this, &model_Diagram::ImplData::realize)));
+    run_later(boost::bind(&model_Diagram::ImplData::realize, this));
     return true;
   }
 
@@ -348,7 +348,7 @@ bool model_Diagram::ImplData::realize()
     model_Model::ImplData *model= _self->owner()->get_data();
     
     if (!_connected_update)
-      model->signal_options_changed().connect(sigc::mem_fun(this, &model_Diagram::ImplData::update_options));
+      scoped_connect(model->signal_options_changed(),boost::bind(&model_Diagram::ImplData::update_options, this, _1));
     _connected_update= true;
 
     _canvas_view= model->get_delegate()->create_diagram(model_DiagramRef(_self));
@@ -357,8 +357,8 @@ bool model_Diagram::ImplData::realize()
 
     update_options("");
 
-    _selection_signal_conn= _canvas_view->get_selection()->signal_changed().
-      connect(sigc::mem_fun(this, &model_Diagram::ImplData::canvas_selection_changed));
+    _selection_signal_conn= *scoped_connect(_canvas_view->get_selection()->signal_changed(),
+      boost::bind(&model_Diagram::ImplData::canvas_selection_changed, this, _1, _2)).get();
 
     update_size();
 
@@ -369,7 +369,7 @@ bool model_Diagram::ImplData::realize()
     
     realize_contents();
 
-    run_later(sigc::mem_fun(this, &model_Diagram::ImplData::realize_selection));
+    run_later(boost::bind(&model_Diagram::ImplData::realize_selection, this));
   }
   if (!_canvas_view)
   {
@@ -384,7 +384,7 @@ bool model_Diagram::ImplData::realize()
 
 void model_Diagram::ImplData::unrealize()
 {
-  if (_selection_signal_conn)
+  if (_selection_signal_conn.connected())
     _selection_signal_conn.disconnect();
 
   for (size_t c= _self->_figures.count(), i= 0; i < c; i++)
@@ -406,8 +406,7 @@ void model_Diagram::ImplData::unrealize()
   {
     _canvas_view->pre_destroy();
 //    run_later(
-//      sigc::bind<mdc::CanvasView*>(sigc::mem_fun(_self->owner()->get_data()->get_delegate(),
-//        &ModelBridgeDelegate::free_canvas_view), _canvas_view));
+//      boost::bind(&ModelBridgeDelegate::free_canvas_view), _self->owner()->get_data()->get_delegate(), _canvas_view));
     _self->owner()->get_data()->get_delegate()->free_canvas_view(_canvas_view);
 
     _canvas_view= 0;
@@ -654,7 +653,7 @@ void model_Diagram::ImplData::end_selection_update()
 {
   _updating_selection--;
   if (_updating_selection == 0)
-    _selection_changed_signal.emit(model_DiagramRef(_self));
+    _selection_changed_signal(model_DiagramRef(_self));
 }
 
 void model_Diagram::ImplData::canvas_selection_changed(bool added, mdc::CanvasItem *item)
@@ -910,7 +909,7 @@ bool model_Diagram::ImplData::figure_click(const model_ObjectRef &owner, mdc::Ca
                                            const Point &point, mdc::MouseButton button,
                                            mdc::EventState state)
 {
-  _item_click_signal.emit(owner, target, point, button, state);
+  _item_click_signal(owner, target, point, button, state);
   
   return false;
 }
@@ -921,7 +920,7 @@ bool model_Diagram::ImplData::figure_double_click(const model_ObjectRef &owner,
                                                   const Point &point, mdc::MouseButton button,
                                                   mdc::EventState state)
 {
-  _item_double_click_signal.emit(owner, target, point, button, state);
+  _item_double_click_signal(owner, target, point, button, state);
 
   return false;
 }
@@ -930,7 +929,7 @@ bool model_Diagram::ImplData::figure_double_click(const model_ObjectRef &owner,
 
 bool model_Diagram::ImplData::figure_button_press(const model_ObjectRef &owner, mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
-  _item_mouse_button_signal.emit(owner, target, true, point, button, state);
+  _item_mouse_button_signal(owner, target, true, point, button, state);
   
   return false;
 }
@@ -938,7 +937,7 @@ bool model_Diagram::ImplData::figure_button_press(const model_ObjectRef &owner,
 
 bool model_Diagram::ImplData::figure_button_release(const model_ObjectRef &owner, mdc::CanvasItem *target, const Point &point, mdc::MouseButton button, mdc::EventState state)
 {
-  _item_mouse_button_signal.emit(owner, target, false, point, button, state);
+  _item_mouse_button_signal(owner, target, false, point, button, state);
   
   return false;
 }
@@ -946,7 +945,7 @@ bool model_Diagram::ImplData::figure_button_release(const model_ObjectRef &owner
 
 bool model_Diagram::ImplData::figure_enter(const model_ObjectRef &owner, mdc::CanvasItem *target, const Point &point)
 {
-  _item_crossed_signal.emit(owner, target, true, point);
+  _item_crossed_signal(owner, target, true, point);
   
   return false;
 }
@@ -954,7 +953,7 @@ bool model_Diagram::ImplData::figure_enter(const model_ObjectRef &owner, mdc::Ca
 
 bool model_Diagram::ImplData::figure_leave(const model_ObjectRef &owner, mdc::CanvasItem *target, const Point &point)
 {
-  _item_crossed_signal.emit(owner, target, false, point);
+  _item_crossed_signal(owner, target, false, point);
   
   return false;
 }
@@ -982,8 +981,7 @@ void model_Diagram::ImplData::add_tag_badge_to_figure(const model_FigureRef &fig
   badge->set_gradient_from_color(Color::parse(*tag->color()));
   badge->set_text_color(Color::parse("#ffffff"));
 
-  badge->updater_connection=
-    tag->signal_changed().connect(sigc::bind(sigc::ptr_fun(&update_badge), tag, badge));
+  badge->updater_connection= *scoped_connect(tag->signal_changed(),boost::bind(&update_badge, _1, _2, tag, badge)).get();
 
   get_canvas_view()->get_current_layer()->add_item(badge,
                                                    get_canvas_view()->get_current_layer()->get_root_area_group());
