@@ -38,20 +38,20 @@ protected:
   model_Diagram *_self;
 
   mdc::CanvasView *_canvas_view;
-  sigc::connection _selection_signal_conn;
+  boost::signals2::connection _selection_signal_conn;
 
-  sigc::signal<void, model_DiagramRef> _selection_changed_signal;
+  boost::signals2::signal<void (model_DiagramRef)> _selection_changed_signal;
 
-  sigc::signal<void, model_ObjectRef> _realize_object_signal;
-  sigc::signal<void, model_ObjectRef> _will_unrealize_object_signal;
+  boost::signals2::signal<void (model_ObjectRef)> _realize_object_signal;
+  boost::signals2::signal<void (model_ObjectRef)> _will_unrealize_object_signal;
   
-  sigc::signal<void, model_ObjectRef, mdc::CanvasItem*, bool, MySQL::Geometry::Point> _item_crossed_signal;
-  sigc::signal<void, model_ObjectRef, mdc::CanvasItem*, MySQL::Geometry::Point, mdc::MouseButton,
-    mdc::EventState> _item_click_signal;
-  sigc::signal<void, model_ObjectRef, mdc::CanvasItem*, MySQL::Geometry::Point, mdc::MouseButton,
-    mdc::EventState> _item_double_click_signal;
-  sigc::signal<void, model_ObjectRef, mdc::CanvasItem*, bool, MySQL::Geometry::Point, mdc::MouseButton,
-    mdc::EventState> _item_mouse_button_signal;
+  boost::signals2::signal<void (model_ObjectRef, mdc::CanvasItem*, bool, MySQL::Geometry::Point)> _item_crossed_signal;
+  boost::signals2::signal<void (model_ObjectRef, mdc::CanvasItem*, MySQL::Geometry::Point, mdc::MouseButton,
+    mdc::EventState)> _item_click_signal;
+  boost::signals2::signal<void (model_ObjectRef, mdc::CanvasItem*, MySQL::Geometry::Point, mdc::MouseButton,
+    mdc::EventState)> _item_double_click_signal;
+  boost::signals2::signal<void (model_ObjectRef, mdc::CanvasItem*, bool, MySQL::Geometry::Point, mdc::MouseButton,
+    mdc::EventState)> _item_mouse_button_signal;
   
   int _updating_selection;
   bool _connected_update;
@@ -123,17 +123,17 @@ public:
   void stack_connection(const model_ConnectionRef &conn, mdc::CanvasItem *item);
   void stack_figure(const model_FigureRef &figure, mdc::CanvasItem *item);
 
-  sigc::signal<void, model_DiagramRef> signal_selection_changed() { return _selection_changed_signal; }
+  boost::signals2::signal<void (model_DiagramRef)>* signal_selection_changed() { return &_selection_changed_signal; }
   
-  sigc::signal<void, model_ObjectRef, mdc::CanvasItem*, bool, MySQL::Geometry::Point> signal_item_crossed() { return _item_crossed_signal; }
-  sigc::signal<void, model_ObjectRef, mdc::CanvasItem*, MySQL::Geometry::Point, mdc::MouseButton, mdc::EventState> signal_item_click() { return _item_click_signal; }
-  sigc::signal<void, model_ObjectRef, mdc::CanvasItem*, MySQL::Geometry::Point, mdc::MouseButton, mdc::EventState> signal_item_double_click() { return _item_double_click_signal; }
-  sigc::signal<void, model_ObjectRef, mdc::CanvasItem*, bool, MySQL::Geometry::Point, mdc::MouseButton, mdc::EventState> signal_item_mouse_button() { return _item_mouse_button_signal; }
+  boost::signals2::signal<void (model_ObjectRef, mdc::CanvasItem*, bool, MySQL::Geometry::Point)>* signal_item_crossed() { return &_item_crossed_signal; }
+  boost::signals2::signal<void (model_ObjectRef, mdc::CanvasItem*, MySQL::Geometry::Point, mdc::MouseButton, mdc::EventState)>* signal_item_click() { return &_item_click_signal; }
+  boost::signals2::signal<void (model_ObjectRef, mdc::CanvasItem*, MySQL::Geometry::Point, mdc::MouseButton, mdc::EventState)>* signal_item_double_click() { return &_item_double_click_signal; }
+  boost::signals2::signal<void (model_ObjectRef, mdc::CanvasItem*, bool, MySQL::Geometry::Point, mdc::MouseButton, mdc::EventState)>* signal_item_mouse_button() { return &_item_mouse_button_signal; }
   
-  sigc::signal<void, model_ObjectRef> signal_object_realized() { return _realize_object_signal; }
+  boost::signals2::signal<void (model_ObjectRef)>* signal_object_realized() { return &_realize_object_signal; }
   void notify_object_realize(const model_ObjectRef &object);
 
-  sigc::signal<void, model_ObjectRef> signal_object_will_unrealize() { return _will_unrealize_object_signal; }
+  boost::signals2::signal<void (model_ObjectRef)>* signal_object_will_unrealize() { return &_will_unrealize_object_signal; }
   void notify_object_will_unrealize(const model_ObjectRef &object);
 
   void update_size();
