@@ -60,7 +60,7 @@ private:
   PhysicalRelationshipNotation _relationship_notation;
   PhysicalFigureNotation _figure_notation;
 
-  std::map<std::string, sigc::connection> _tag_connections;
+  std::map<std::string, boost::signals2::connection> _tag_connections;
   
   void tag_list_changed(grt::internal::OwnedList *list, bool added, const grt::ValueRef &value,
                         const meta_TagRef &tag);
