@@ -44,7 +44,7 @@ class WBPUBLICBACKEND_PUBLIC_FUNC workbench_physical_RoutineGroupFigure::ImplDat
 
 protected:
   wbfig::RoutineGroup *_figure;
-  sigc::connection _figure_conn;
+  boost::signals2::connection _figure_conn;
   
   virtual bool realize();
 
