@@ -44,7 +44,7 @@ workbench_physical_TableFigure::ImplData::ImplData(workbench_physical_TableFigur
   _pending_index_sync= false;
   _pending_trigger_sync= false;
 
-  self->signal_changed().connect(sigc::mem_fun(this, &ImplData::member_changed));
+  scoped_connect(self->signal_changed(),boost::bind(&ImplData::member_changed, this, _1, _2));
 }
 
 
@@ -115,9 +115,9 @@ void workbench_physical_TableFigure::ImplData::set_table(const db_TableRef &tabl
     if (self()->_owner.is_valid())
       workbench_physical_DiagramRef::cast_from(self()->_owner)->get_data()->add_mapping(table, self());
     
-    _table_fk_conn= table->signal_foreignKeyChanged().connect(sigc::mem_fun(this, &ImplData::fk_changed));
-    _refresh_conn= table->signal_refreshDisplay().connect(sigc::mem_fun(this, &ImplData::content_changed));
-    _changed_conn= table->signal_changed().connect(sigc::mem_fun(this, &ImplData::table_member_changed));
+    _table_fk_conn= *scoped_connect(table->signal_foreignKeyChanged(),boost::bind(&ImplData::fk_changed, this, _1)).get();
+    _refresh_conn = *scoped_connect(table->signal_refreshDisplay(),boost::bind(&ImplData::content_changed, this, _1)).get();
+    _changed_conn = *scoped_connect(table->signal_changed(),boost::bind(&ImplData::table_member_changed, this, _1, _2)).get();
 
     self()->_name= self()->_table->name();
 
@@ -125,15 +125,15 @@ void workbench_physical_TableFigure::ImplData::set_table(const db_TableRef &tabl
     {
       // Refresh everything because table has been replaced.
       _figure->get_title()->set_title(*self()->_table->name());
-      run_later(sigc::mem_fun(this, &workbench_physical_TableFigure::ImplData::sync_columns));
-      run_later(sigc::mem_fun(this, &workbench_physical_TableFigure::ImplData::sync_indexes));
-      run_later(sigc::mem_fun(this, &workbench_physical_TableFigure::ImplData::sync_triggers));
+      run_later(boost::bind(&workbench_physical_TableFigure::ImplData::sync_columns, this));
+      run_later(boost::bind(&workbench_physical_TableFigure::ImplData::sync_indexes, this));
+      run_later(boost::bind(&workbench_physical_TableFigure::ImplData::sync_triggers, this));
     }
     else
     {
-      _table_fk_conn.block();
-      _changed_conn.block();
-      _refresh_conn.block();
+      _table_fk_conn_block = boost::shared_ptr<boost::signals2::shared_connection_block>(new boost::signals2::shared_connection_block(_table_fk_conn));
+      _changed_conn_block = boost::shared_ptr<boost::signals2::shared_connection_block>(new boost::signals2::shared_connection_block(_changed_conn));
+      _refresh_conn_block = boost::shared_ptr<boost::signals2::shared_connection_block>(new boost::signals2::shared_connection_block(_refresh_conn));
       try_realize();
     }
   }
@@ -158,7 +158,7 @@ void workbench_physical_TableFigure::ImplData::table_member_changed(const std::s
       if (!_pending_columns_sync)
       {
         _pending_columns_sync= true;
-        run_later(sigc::mem_fun(this, &workbench_physical_TableFigure::ImplData::sync_columns));
+        run_later(boost::bind(&workbench_physical_TableFigure::ImplData::sync_columns, this));
       }
     }
   }
@@ -173,7 +173,7 @@ void workbench_physical_TableFigure::ImplData::fk_changed(const db_ForeignKeyRef
     if (!_pending_columns_sync)
     {
       _pending_columns_sync= true;
-      run_later(sigc::mem_fun(this, &workbench_physical_TableFigure::ImplData::sync_columns));
+      run_later(boost::bind(&workbench_physical_TableFigure::ImplData::sync_columns, this));
     }
   }  
 }
@@ -185,19 +185,19 @@ void workbench_physical_TableFigure::ImplData::content_changed(const std::string
       _figure && !_pending_columns_sync)
   {
     _pending_columns_sync= true;
-    run_later(sigc::mem_fun(this, &workbench_physical_TableFigure::ImplData::sync_columns));
+    run_later(boost::bind(&workbench_physical_TableFigure::ImplData::sync_columns, this));
   }
 
   if (where == "index" && _figure && !_pending_index_sync)
   {
     _pending_index_sync= true;
-    run_later(sigc::mem_fun(this, &workbench_physical_TableFigure::ImplData::sync_indexes));
+    run_later(boost::bind(&workbench_physical_TableFigure::ImplData::sync_indexes, this));
   }
 
   if (where == "trigger" && _figure && !_pending_trigger_sync)
   {
     _pending_trigger_sync= true;
-    run_later(sigc::mem_fun(this, &workbench_physical_TableFigure::ImplData::sync_triggers));
+    run_later(boost::bind(&workbench_physical_TableFigure::ImplData::sync_triggers, this));
   }  
 }
 
@@ -441,7 +441,7 @@ bool workbench_physical_TableFigure::ImplData::realize()
   
   if (!is_main_thread())
   {
-    run_later(sigc::hide_return(sigc::mem_fun(this, &ImplData::realize)));
+    run_later(boost::bind(&ImplData::realize, this));
     return true;
   }
   
@@ -465,17 +465,17 @@ bool workbench_physical_TableFigure::ImplData::realize()
     
     _figure->get_title()->set_title(*self()->_table->name());
 
-    _figure->get_title()->signal_expand_toggle().connect(
-      sigc::bind<wbfig::Titlebar*>(sigc::mem_fun(this, &workbench_physical_TableFigure::ImplData::toggle_title), _figure->get_title()));
+    scoped_connect(_figure->get_title()->signal_expand_toggle(),
+      boost::bind(&workbench_physical_TableFigure::ImplData::toggle_title, this, _1, _figure->get_title()));
     if (_figure->get_index_title())
     {
-      _figure->get_index_title()->signal_expand_toggle().connect(
-        sigc::bind<wbfig::Titlebar*>(sigc::mem_fun(this, &workbench_physical_TableFigure::ImplData::toggle_title), _figure->get_index_title()));
+      scoped_connect(_figure->get_index_title()->signal_expand_toggle(),
+        boost::bind(&workbench_physical_TableFigure::ImplData::toggle_title, this, _1, _figure->get_index_title()));
     }
     if (_figure->get_trigger_title())
     {
-      _figure->get_trigger_title()->signal_expand_toggle().connect(
-        sigc::bind<wbfig::Titlebar*>(sigc::mem_fun(this, &workbench_physical_TableFigure::ImplData::toggle_title), _figure->get_trigger_title()));
+      scoped_connect(_figure->get_trigger_title()->signal_expand_toggle(),
+        boost::bind(&workbench_physical_TableFigure::ImplData::toggle_title, this, _1, _figure->get_trigger_title()));
     }
 
     _figure->set_dependant(self()->_table->isDependantTable() != 0);
@@ -510,9 +510,12 @@ bool workbench_physical_TableFigure::ImplData::realize()
     }
     
     // unblock refresh signals
-    _table_fk_conn.unblock();
-    _changed_conn.unblock();
-    _refresh_conn.unblock();    
+    if (_table_fk_conn_block.get())
+      _table_fk_conn_block->unblock();    
+    if (_changed_conn_block.get())
+      _changed_conn_block->unblock();    
+    if (_refresh_conn_block.get())
+      _refresh_conn_block->unblock();    
   }
   return true;
 }
