@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -27,6 +27,12 @@
 #include "Overview.h"
 
 namespace MySQL {
+namespace Grt {
+
+long long nativeToManaged(::Recordset::Ref rs);
+
+};
+
 namespace GUI {
 namespace Workbench {
 
@@ -64,20 +70,19 @@ public:
   int active_sql_editor_index() { return (*_ref)->active_sql_editor_index(); }
   void active_sql_editor_index(int val) { (*_ref)->active_sql_editor_index(val); }
   bool sql_editor_will_close(int index) { return (*_ref)->sql_editor_will_close(index); }
+  long long active_recordset_for_sql_editor(int index);
 
   void active_recordset(Recordset ^val);
 
   String ^ caption() { return CppStringToNative((*_ref)->caption()); }
   int exec_sql_error_count() { return (*_ref)->exec_sql_error_count(); };
 
-  String ^ connection_info() { return CppStringToNative((*_ref)->connection_info()); }
-
   void connect() { (*_ref)->connect(); }
   bool connected() { return (*_ref)->connected(); }
   void cancel_query() { (*_ref)->cancel_query(); }
 
   void reset() { (*_ref)->reset(); }
-  void exec_sql(String ^sql, bool wrap_with_non_std_delimiter) { (*_ref)->exec_sql(NativeToCppString(sql), false, wrap_with_non_std_delimiter); }
+  void exec_sql(String ^sql, bool active_editor, bool wrap_with_non_std_delimiter) { (*_ref)->exec_sql(NativeToCppString(sql), !active_editor ? ::Sql_editor::Ref() : (*_ref)->sql_editor(), false, wrap_with_non_std_delimiter); }
   void commit() { (*_ref)->commit(); }
   void rollback() { (*_ref)->rollback(); }
   int recordset_count() { return (*_ref)->recordset_count(); }
@@ -124,8 +129,6 @@ public:
   enum class PartialRefreshType
   {
     RefreshSidebar= ::Db_sql_editor::RefreshSidebar, // update the sidebar
-    RefreshActiveSchemaSelector= ::Db_sql_editor::RefreshActiveSchemaSelector,
-    RefreshSchemaTree= ::Db_sql_editor::RefreshSchemaTree, // refresh live schema tree
     RefreshEditor= ::Db_sql_editor::RefreshEditor, // refresh the text editor using data from backend
     RefreshSnippets= ::Db_sql_editor::RefreshSnippets,
     RefreshSnippetCollections= ::Db_sql_editor::RefreshSnippetCollections,
@@ -135,14 +138,14 @@ public:
   };
 
 public:
-  TreeModel ^ schema_tree() { return gcnew TreeModel((*_ref)->get_schema_tree()); }
+  Windows::Forms::Control^ get_sidebar_control();
 
 public:
-  typedef DelegateSlot1<int, int,
-    long long, long long> Close_recordset_ui_cb;
-  void close_recordset_ui_cb(Close_recordset_ui_cb::ManagedDelegate ^cb);
+  typedef DelegateSlot2<void, void,
+    ::Recordset::Ref, long long, bool, bool> Recordset_list_changed_cb;
+  void recordset_list_changed_cb(Recordset_list_changed_cb::ManagedDelegate ^cb);
 private:
-  Close_recordset_ui_cb ^_close_recordset_ui_cb;
+  Recordset_list_changed_cb ^_recordset_list_changed_cb;
 
 public:
   typedef DelegateSlot2<void, void, std::string, String^, bool, bool> Output_text_ui_cb;
