@@ -65,10 +65,10 @@ void Sql_editor::reset_fe_callbacks()
 {
   if ((void*)~_ref)
   {
-    _ref->replace_selected_text_slot.disconnect();
-    _ref->insert_text_slot.disconnect();
-    _ref->current_statement_slot.disconnect();
-    _ref->report_sql_statement_border.disconnect();
+    _ref->replace_selected_text_slot.clear();
+    _ref->insert_text_slot.clear();
+    _ref->current_statement_slot.clear();
+    _ref->report_sql_statement_border.clear();
     _ref->sql_parser_err_cb(::Sql_parser_base::Parse_error_cb());
   }
 
