@@ -65,7 +65,7 @@ void VarGridModel::refresh_ui_cb(Refresh_ui_cb::ManagedDelegate ^cb)
   else
   {
     _refresh_ui_cb= nullptr;
-    _ref->refresh_ui_cb= sigc::slot<int>();
+    _ref->refresh_ui_cb= boost::function<int ()>();
   }
 }
 
