@@ -22,7 +22,7 @@
 
 #include "workbench/wb_overview.h"
 #include "GrtTemplates.h"
-#include "string_utilities.h"
+#include "base/string_utilities.h"
 
 #ifdef _MSC_VER
 #include  <vcclr.h> // .net interop helpers
@@ -103,9 +103,9 @@ namespace MySQL {
       String^ get_title()
       {
         std::string title= get_unmanaged_object()->get_title();
-	      if (title.empty())
+        if (title.empty())
           return nullptr;
-	      return CppStringToNative(title);
+        return CppStringToNative(title);
       }
 
       //NodeId get_child(const NodeId &parent, int index);
@@ -122,9 +122,9 @@ namespace MySQL {
 
       String^ get_node_unique_id(::MySQL::Grt::NodeId^ node)
       {
-	      std::string id= get_unmanaged_object()->get_node_unique_id(*node->get_unmanaged_object());
-	      if (id.empty()) return nullptr;
-	      return CppStringToNative(id);
+        std::string id= get_unmanaged_object()->get_node_unique_id(*node->get_unmanaged_object());
+        if (id.empty()) return nullptr;
+        return CppStringToNative(id);
       }
 
 
