@@ -352,7 +352,7 @@ public:
   // ----- Edit menu handling
   void validate_edit_menu()
   {
-    inner->get_command_ui()->signal_validate_edit_menu_items().emit();
+    (*inner->get_command_ui()->signal_validate_edit_menu_items())();
   }
 
   void edit_undo()
@@ -762,7 +762,7 @@ public:
     inner= new wb::DiagramOptionsBE(view->get_unmanaged_object(), 
       wbContext->get_unmanaged_object()->get_wb()->get_model_context()->get_active_model_diagram(true), wbContext->get_unmanaged_object()->get_wb());
 
-    inner->signal_changed().connect(_delegate->get_slot());
+    inner->scoped_connect(inner->signal_changed(),_delegate->get_slot());
   }
 
   ~DiagramOptionsBE()
