@@ -104,7 +104,7 @@ void BaseWindowsCanvasView::set_on_queue_repaint(Void4IntDelegate^ dt)
     gcnew Void4IntWrapperDelegate(this, &BaseWindowsCanvasView::on_queue_repaint_wrapper);
   IntPtr ip = Marshal::GetFunctionPointerForDelegate(on_queue_repaint_wrapper_delegate);
   VOID_4INT_CB cb = static_cast<VOID_4INT_CB>(ip.ToPointer());
-  inner->signal_repaint().connect(sigc::ptr_fun(cb));
+  inner->signal_repaint()->connect(boost::bind(cb, _1, _2, _3, _4));
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -116,7 +116,7 @@ void BaseWindowsCanvasView::set_on_viewport_changed(VoidVoidDelegate^ dt)
     gcnew VoidVoidWrapperDelegate(this, &BaseWindowsCanvasView::on_viewport_changed_wrapper);
   IntPtr ip = Marshal::GetFunctionPointerForDelegate(on_viewport_changed_wrapper_delegate);
   VOID_VOID_CB cb = static_cast<VOID_VOID_CB>(ip.ToPointer());
-  inner->signal_viewport_changed().connect(sigc::ptr_fun(cb));
+  inner->signal_viewport_changed()->connect(boost::bind(cb));
 }
 
 //--------------------------------------------------------------------------------------------------
