@@ -146,7 +146,7 @@ String^ NodeId::repr()
 ListModel::ListModel(::bec::ListModel *inn)
   : inner(inn)
 {
-  native_connections = new std::vector<sigc::connection>();
+  native_connections = new std::vector<boost::signals2::connection>();
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -370,7 +370,7 @@ bool ListModel::is_editable(NodeId^ node)
 void ListModel::add_tree_refresh_handler(TreeRefreshSlot::ManagedDelegate^ slot)
 {
   TreeRefreshSlot ^tree_refresh_handler= gcnew TreeRefreshSlot(slot);
-  sigc::connection connection = sigc::connection(inner->tree_changed_signal().connect(tree_refresh_handler->get_slot()));
+  boost::signals2::connection connection = *inner->scoped_connect(inner->tree_changed_signal(),tree_refresh_handler->get_slot()).get();
   tree_refresh_handlers.Add(tree_refresh_handler);
   native_connections->push_back(connection);
 }
@@ -386,7 +386,7 @@ void ListModel::remove_tree_refresh_handler(TreeRefreshSlot::ManagedDelegate^ sl
     {
       tree_refresh_handlers.Remove(handler);
 
-      std::vector<sigc::connection>::iterator iterator = native_connections->begin() + i;
+      std::vector<boost::signals2::connection>::iterator iterator = native_connections->begin() + i;
       iterator->disconnect();
       native_connections->erase(iterator);
       break;
