@@ -20,6 +20,8 @@
 #ifndef __SIGCSLOT_H__
 #define __SIGCSLOT_H__
 
+#include <boost/function.hpp>
+
 using namespace System;
 using namespace System::Collections::Generic;
 using namespace System::Runtime::InteropServices;
@@ -237,16 +239,13 @@ namespace Grt {
         wrapped_delegate= gcnew WD(run_wrapped_delegate, &DR::native_callback);
       IntPtr ip= Marshal::GetFunctionPointerForDelegate(wrapped_delegate);
       NCB cb= static_cast<NCB>(ip.ToPointer());
-      native_slot= new NS(sigc::ptr_fun(cb));
+      native_slot= new NS(cb);
       return native_slot;
     }
     void destroy_slot()
     {
       if (!native_slot)
         return;
-      native_slot->disconnect();
-      if (native_slot->rep_)
-        native_slot->rep_->destroy();
       delete native_slot;
       native_slot= NULL;
     }
@@ -272,14 +271,14 @@ namespace Grt {
     delegate RM ManagedDelegate();
     delegate RN WrapperDelegate();
     typedef RN (*NativeCBType)();
-    typedef sigc::slot<RN> NativeSlot;
+    typedef boost::function<RN ()> NativeSlot;
     typedef RunWrappedDelegate0<RN, RM, ManagedDelegate> RunWrappedDelegate;
     typedef DelegateSlotWrapper_<ManagedDelegate, WrapperDelegate, NativeCBType, NativeSlot, RunWrappedDelegate> DelegateSlotWrapper;
   private:
     DelegateSlotWrapper ^delegate_slot_wrapper;
   public:
     DelegateSlot0(ManagedDelegate ^deleg) : delegate_slot_wrapper(gcnew DelegateSlotWrapper(deleg)) {}
-    const sigc::slot<RN> & get_slot() { return *delegate_slot_wrapper->get_slot(); }
+    const boost::function<RN ()> & get_slot() { return *delegate_slot_wrapper->get_slot(); }
     bool wraps_delegate(ManagedDelegate ^deleg) { return delegate_slot_wrapper->wraps_delegate(deleg); }
   private:
     ~DelegateSlot0() { reset(); }
@@ -296,7 +295,7 @@ namespace Grt {
   public:
     delegate RM ManagedDelegate(A1M);
     delegate RN WrapperDelegate(const A1N &);
-    typedef sigc::slot<RN, const A1N &> NativeSlot;
+    typedef boost::function<RN (const A1N &)> NativeSlot;
     typedef RN (*NativeCBType)(const A1N &);
     typedef RunWrappedDelegate1<RN, RM, A1N, A1M, ManagedDelegate> RunWrappedDelegate;
     typedef DelegateSlotWrapper_<ManagedDelegate, WrapperDelegate, NativeCBType, NativeSlot, RunWrappedDelegate> DelegateSlotWrapper;
@@ -322,7 +321,7 @@ namespace Grt {
     delegate RM ManagedDelegate(A1M, A2M);
     delegate RN WrapperDelegate(const A1N &, const A2N &);
     typedef RN (*NativeCBType)(const A1N &, const A2N &);
-    typedef sigc::slot<RN, const A1N &, const A2N &> NativeSlot;
+    typedef boost::function<RN (const A1N &, const A2N &)> NativeSlot;
     typedef RunWrappedDelegate2<RN, RM, A1N, A1M, A2N, A2M, ManagedDelegate> RunWrappedDelegate;
     typedef DelegateSlotWrapper_<ManagedDelegate, WrapperDelegate, NativeCBType, NativeSlot, RunWrappedDelegate> DelegateSlotWrapper;
   private:
@@ -347,7 +346,7 @@ namespace Grt {
     delegate RM ManagedDelegate(A1M, A2M, A3M);
     delegate RN WrapperDelegate(const A1N &, const A2N &, const A3N &);
     typedef RN (*NativeCBType)(const A1N &, const A2N &, const A3N &);
-    typedef sigc::slot<RN, const A1N &, const A2N &, const A3N &> NativeSlot;
+    typedef boost::function<RN (const A1N &, const A2N &, const A3N &)> NativeSlot;
     typedef RunWrappedDelegate3<RN, RM, A1N, A1M, A2N, A2M, A3N, A3M, ManagedDelegate> RunWrappedDelegate;
     typedef DelegateSlotWrapper_<ManagedDelegate, WrapperDelegate, NativeCBType, NativeSlot, RunWrappedDelegate> DelegateSlotWrapper;
   private:
@@ -372,7 +371,7 @@ namespace Grt {
     delegate RM ManagedDelegate(A1M, A2M, A3M, A4M);
     delegate RN WrapperDelegate(const A1N &, const A2N &, const A3N &, const A4N &);
     typedef RN (*NativeCBType)(const A1N &, const A2N &, const A3N &, const A4N &);
-    typedef sigc::slot<RN, const A1N &, const A2N &, const A3N &, const A4N &> NativeSlot;
+    typedef boost::function<RN (const A1N &, const A2N &, const A3N &, const A4N &)> NativeSlot;
     typedef RunWrappedDelegate4<RN, RM, A1N, A1M, A2N, A2M, A3N, A3M, A4N, A4M, ManagedDelegate> RunWrappedDelegate;
     typedef DelegateSlotWrapper_<ManagedDelegate, WrapperDelegate, NativeCBType, NativeSlot, RunWrappedDelegate> DelegateSlotWrapper;
   private:
