@@ -12,7 +12,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 #
 
 """
@@ -24,7 +24,7 @@ import datetime
 import os
 import re
 import mysql.connector
-from mysql.utilities.exception import MySQLUtilError
+from mysql.utilities.exception import UtilError, UtilDBError
 
 # List of database objects for enumeration
 _DATABASE, _TABLE, _VIEW, _TRIG, _PROC, _FUNC, _EVENT, _GRANT = "DATABASE", \
@@ -60,8 +60,8 @@ _OBJTYPE_QUERY = """
 
 class Database(object):
     """
-    The Table class encapsulates a database. The class
-    has the following capabilities:
+    The Database class encapsulates a database. The class has the following
+    capabilities:
 
         - Check to see if the database exists
         - Drop the database
@@ -99,6 +99,9 @@ class Database(object):
         self.init_called = False
         self.destination = None # Used for copy mode
         self.cloning = False    # Used for clone mode
+        self.query_options = {  # Used for skipping fetch of rows
+            'fetch' : False
+        }
 
         self.objects = []
         self.new_objects = []
@@ -153,12 +156,12 @@ class Database(object):
         if quiet:
             try:
                 res = server.exec_query("DROP DATABASE %s" % (db),
-                                        (), False, False)
+                                        self.query_options)
             except:
                 pass
         else:
             res = server.exec_query("DROP DATABASE %s" % (db),
-                                    (), False, False)
+                                    self.query_options)
             op_ok = True
 
 
@@ -180,7 +183,7 @@ class Database(object):
             db = self.db_name
         op_ok = False
         res = server.exec_query("CREATE DATABASE %s" % (db),
-                                (), False, False)
+                                self.query_options)
         op_ok = True
         return op_ok
 
@@ -304,18 +307,18 @@ class Database(object):
         # Suppress the error on drop
         if self.cloning:
             try:
-                self.source.exec_query(drop_str, (), False, False)
+                self.source.exec_query(drop_str, self.query_options)
             except:
                 pass
         else:
             try:
-                self.destination.exec_query(drop_str, (), False, False)
+                self.destination.exec_query(drop_str, self.query_options)
             except:
                 pass
 
 
     def __create_object(self, obj_type, obj, show_grant_msg,
-                        quiet=False):
+                        quiet=False, new_engine=None, def_engine=None):
         """Create a database object.
 
         obj_type[in]       Object type (string) e.g. DATABASE
@@ -323,6 +326,9 @@ class Database(object):
                            that contains the elements of the object
         show_grant_msg[in] If true, display diagnostic information
         quiet[in]          do not print informational messages
+        new_engine[in]     Use this engine if not None for object
+        def_engine[in]     If target storage engine doesn't exist, use
+                           this engine.
 
         Note: will handle exception and print error if query fails
         """
@@ -333,6 +339,13 @@ class Database(object):
                          (self.new_db, obj[0], self.db_name, obj[0])
         else:
             create_str = self.__make_create_statement(obj_type, obj)
+        if obj_type == _TABLE:
+            tbl_name = "%s.%s" % (self.new_db, obj[0])
+            create_str = self.destination.substitute_engine(tbl_name,
+                                                            create_str,
+                                                            new_engine,
+                                                            def_engine,
+                                                            quiet)
         str = "# Copying"
         if not quiet:
             if obj_type == _GRANT:
@@ -346,14 +359,14 @@ class Database(object):
         res = None
         try:
             res = self.destination.exec_query("USE %s" % self.new_db,
-                                              (), False, False)
+                                              self.query_options)
         except:
             pass
         try:
-            res = self.destination.exec_query(create_str, (), False, False)
+            res = self.destination.exec_query(create_str, self.query_options)
         except Exception, e:
-            raise MySQLUtilError("Cannot operate on %s object. Error: %s" %
-                                 (obj_type, e.errmsg))
+            raise UtilDBError("Cannot operate on %s object. Error: %s" %
+                              (obj_type, e.errmsg), -1, self.db_name)
 
     def __copy_table_data(self, name, quiet=False):
         """Clone table data.
@@ -389,7 +402,7 @@ class Database(object):
         The method can also be used to copy a database to another server
         by providing the new server object (new_server). Copy to the same
         name by setting new_db = old_db or as a new database.
-
+        
         new_db[in]         Name of the new database
         input_file[in]     Full path of input file (or None)
         options[in]        Options for copy e.g. force, copy_dir, etc.
@@ -399,6 +412,7 @@ class Database(object):
         """
 
         from mysql.utilities.common.table import Table
+        from mysql.utilities.common.options import check_engine_options
 
         # Must call init() first!
         # Guard for init() prerequisite
@@ -424,6 +438,12 @@ class Database(object):
         else:
             self.destination = self.source
 
+        # Check storage engines
+        check_engine_options(self.destination,
+                             options.get("new_engine", None),
+                             options.get("def_engine", None),
+                             False, options.get("quiet", False))
+
         res = self.destination.show_server_variable("foreign_key_checks")
         fkey = (res is not None) and (res[0][1] == "ON")
 
@@ -432,7 +452,7 @@ class Database(object):
         # First, turn off foreign keys if turned on
         if fkey:
             res = self.destination.exec_query(fkey_query % "OFF",
-                                              (), False, False)
+                                              self.query_options)
 
         # Check to see if database exists
         exists = False
@@ -447,9 +467,9 @@ class Database(object):
             if options.get("force", False):
                 self.drop(drop_server, True, new_db)
             elif not self.skip_create:
-                raise MySQLUtilError("destination database exists. Use "
-                                      "--force to overwrite existing "
-                                      "database.")
+                raise UtilDBError("destination database exists. Use "
+                                  "--force to overwrite existing "
+                                  "database.", -1, new_db)
 
         # Create new database first
         if not self.skip_create:
@@ -468,7 +488,9 @@ class Database(object):
 
             # Create the object
             self.__create_object(obj[0], obj[1], not grant_msg_displayed,
-                                 options.get("quiet", False))
+                                 options.get("quiet", False),
+                                 options.get("new_engine", None),
+                                 options.get("def_engine", None))
 
             if obj[0] == _GRANT and not grant_msg_displayed:
                 grant_msg_displayed = True
@@ -484,12 +506,17 @@ class Database(object):
                         if not options.get("quiet", False):
                             print "# Copying data for TABLE %s.%s" % \
                                    (self.db_name, tblname)
+                        tbl_options = {
+                            'verbose'  : self.verbose,
+                            'get_cols' : True,
+                            'quiet'    : options.get('quiet', False)
+                        }
                         tbl = Table(self.source,
                                     "%s.%s" % (self.db_name, tblname),
-                                    self.verbose, True)
+                                    tbl_options)
                         if tbl is None:
-                            raise MySQLUtilError("Cannot create table "
-                                                 "object before copy.")
+                            raise UtilDBError("Cannot create table object "
+                                              "before copy.", -1, self.db_name)
 
                         tbl.copy_data(self.destination, new_db, connections)
 
@@ -501,7 +528,7 @@ class Database(object):
         # Now, turn on foreign keys if they were on at the start
         if fkey:
             res = self.destination.exec_query(fkey_query % "ON",
-                                              (), False, False)
+                                              self.query_options)
 
 
     def get_create_statement(self, db, name, obj_type):
@@ -800,10 +827,13 @@ class Database(object):
         else:
             return None
 
+        col_options = {
+            'columns' : get_columns
+        }
         if obj_type == _GRANT:
             query = _OBJECT_QUERY % (self.db_name, self.db_name,
                                      self.db_name, self.db_name)
-            return self.source.exec_query(query, None, get_columns)
+            return self.source.exec_query(query, col_options)
         else:
             if columns == "NAMES":
                 prefix = _NAMES
@@ -818,12 +848,12 @@ class Database(object):
             if self.exclude_patterns is not None:
                 exclude_str += self.__build_exclude_patterns(exclude_param)
             query = prefix + _OBJECT_QUERY % (self.db_name, exclude_str)
-            res = self.source.exec_query(query, None, get_columns)
+            res = self.source.exec_query(query, col_options)
             return res
 
 
     def _check_user_permissions(self, uname, host, access):
-        """ Check user permissions for a given privilege
+        """Check user permissions for a given privilege
 
         uname[in]          user name to check
         host[in]           host name of connection
@@ -839,26 +869,25 @@ class Database(object):
         return result
 
 
-    def check_read_access(self, user, host, skip_views,
-                          skip_proc, skip_func, skip_grants,
-                          skip_events):
-        """ Check access levels for reading database objects
+    def check_read_access(self, user, host, options):
+        """Check access levels for reading database objects
 
         This method will check the user's permission levels for copying a
         database from this server.
 
         It will also skip specific checks if certain objects are not being
         copied (i.e., views, procs, funcs, grants).
-
+    
         user[in]           user name to check
         host[in]           host name to check
-        skip_views[in]     True = no views processed
-        skup_proc[in]      True = no procedures processed
-        skip_func[in]      True = no functions processed
-        skip_grants[in]    True = no grants processed
-        skip_events[in]    True = no events processed
+        options[in]        dictionary of values to include:
+            skip_views     True = no views processed
+            skip_proc      True = no procedures processed
+            skip_func      True = no functions processed
+            skip_grants    True = no grants processed
+            skip_events    True = no events processed
 
-        Returns True if user has permissions and raises a MySQLUtilError if the
+        Returns True if user has permissions and raises a UtilDBError if the
                      user does not have permission with a message that includes
                      the server context.
         """
@@ -868,33 +897,33 @@ class Database(object):
         priv_tuple = (self.db_name, "SELECT")
         source_privs.append(priv_tuple)
         # if views are included, we need SHOW VIEW
-        if not skip_views:
+        if not options.get('skip_views', False):
             priv_tuple = (self.db_name, "SHOW VIEW")
             source_privs.append(priv_tuple)
         # if procs or funcs are included, we need read on mysql db
-        if not skip_proc or not skip_func:
+        if not options.get('skip_proc', False) or \
+           not options.get('skip_func', False):
             priv_tuple = ("mysql", "SELECT")
             source_privs.append(priv_tuple)
         # if events, we need event
-        if not skip_events:
+        if not options.get('skip_events', False):
             priv_tuple = (self.db_name, "EVENT")
             source_privs.append(priv_tuple)
 
         # Check permissions on source
         for priv in source_privs:
             if not self._check_user_permissions(user, host, priv):
-                raise MySQLUtilError("User %s on the %s server does not have "
-                                     "permissions to read all objects in %s. " %
-                                     (user, self.source.role, self.db_name) +
-                                     "User needs %s privilege on %s." %
-                                     (priv[1], priv[0]))
+                raise UtilDBError("User %s on the %s server does not have "
+                                  "permissions to read all objects in %s. " %
+                                   (user, self.source.role, self.db_name) +
+                                   "User needs %s privilege on %s." %
+                                   (priv[1], priv[0]), -1, priv[0])
 
         return True
 
 
-    def check_write_access(self, user, host, skip_views,
-                           skip_proc, skip_func, skip_grants):
-        """ Check access levels for creating and writing database objects
+    def check_write_access(self, user, host, options):
+        """Check access levels for creating and writing database objects
 
         This method will check the user's permission levels for copying a
         database to this server.
@@ -904,12 +933,15 @@ class Database(object):
 
         user[in]           user name to check
         host[in]           host name to check
-        skip_views[in]     True = no views processed
-        skup_proc[in]      True = no procedures processed
-        skip_func[in]      True = no functions processed
-        skip_grants[in]    True = no grants processed
+        options[in]        dictionary of values to include:
+            skip_views     True = no views processed
+            skip_proc      True = no procedures processed
+            skip_func      True = no functions processed
+            skip_grants    True = no grants processed
+            skip_events    True = no events processed
 
-        Returns True if user has permissions and raises a MySQLUtilError if the
+
+        Returns True if user has permissions and raises a UtilDBError if the
                      user does not have permission with a message that includes
                      the server context.
         """
@@ -917,17 +949,17 @@ class Database(object):
         dest_privs = [(self.db_name, "CREATE"),
                       (self.db_name, "SUPER"),
                       ("*", "SUPER")]
-        if not skip_grants:
+        if not options.get('skip_grants', False):
             priv_tuple = (self.db_name, "WITH GRANT OPTION")
             dest_privs.append(priv_tuple)
 
         # Check privileges on destination
         for priv in dest_privs:
             if not self._check_user_permissions(user, host, priv):
-                raise MySQLUtilError("User %s on the %s server does not "
-                                     "have permissions to create all objects "
-                                     "in %s. User needs %s privilege on %s." %
-                                     (user, self.source.role, priv[0],
-                                      priv[1], priv[0]))
+                raise UtilDBError("User %s on the %s server does not "
+                                  "have permissions to create all objects "
+                                  "in %s. User needs %s privilege on %s." %
+                                  (user, self.source.role, priv[0], priv[1],
+                                   priv[0]), -1, priv[0])
 
         return True
