@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2010, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2010, 2011 Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 #
 
 """
@@ -25,13 +25,54 @@ import os
 import re
 import sys
 import mysql.connector
-from mysql.utilities.exception import MySQLUtilError
+from mysql.utilities.exception import UtilError, UtilDBError
+from mysql.utilities.common.options import parse_connection
 
-def _print_connection(prefix, conn_val):
-    """ Print connection information
+def get_connection_dictionary(conn_info):
+    """Get the connection dictionary.
+
+    The method accepts one of the following types for conn_info:
+    
+        - dictionary containing connection information including:
+          (user, passwd, host, port, socket)
+        - connection string in the form: user:pass@host:port:socket
+        - an instance of the Server class
+        
+    conn_info[in]          Connection information
+
+    Returns dict - dictionary for connection (user, passwd, host, port, socket)
     """
-    conn_str = None
-    sys.stdout.write("# %s on %s: ... " % (prefix, conn_val["host"]))
+    if conn_info is None:
+        return conn_info
+    conn_val = {}
+    if isinstance(conn_info, dict):
+        conn_val = conn_info
+    elif isinstance(conn_info, Server):
+        # get server's dictionary
+        conn_val = conn_info.get_connection_values()
+    elif isinstance(conn_info, basestring):
+        # parse the string
+        conn_val = parse_connection(conn_info)
+    else:
+        raise UtilError("Cannot determine connection information type.")
+
+    return conn_val
+
+
+def _print_connection(prefix, conn_info):
+    """Print connection information
+    
+    The method accepts one of the following types for conn_info:
+    
+        - dictionary containing connection information including:
+          (user, passwd, host, port, socket)
+        - connection string in the form: user:pass@host:port:socket
+        - an instance of the Server class
+        
+    conn_info[in]          Connection information
+    """
+    conn_val = get_connection_dictionary(conn_info)
+    print "# %s on %s: ..." % (prefix, conn_val["host"]),
 
 
 def find_running_servers(all=False, start=3306, end=3333, datadir_prefix=None):
@@ -128,30 +169,35 @@ def find_running_servers(all=False, start=3306, end=3333, datadir_prefix=None):
     return processes
 
 
-def connect_servers(src_val, dest_val, quiet=False, version=None,
-                    src_name="Source", dest_name="Destination"):
-    """ Connect to a source and destination server.
+def connect_servers(src_val, dest_val, options={}):
+    """Connect to a source and destination server.
 
     This method takes two groups of --server=user:password@host:port:socket
     values and attempts to connect one as a source connection and the other
     as the destination connection. If the source and destination are the
-    same server, destination is set to None.
+    same server and the unique parameter is False, destination is set to None.
+     
+    The method accepts one of the following types for the src_val and dest_val:
+    
+        - dictionary containing connection information including:
+          (user, passwd, host, port, socket)
+        - connection string in the form: user:pass@host:port:socket
+        - an instance of the Server class
 
-    src_val[in]        a dictionary containing connection information for the
-                       source including:
-                       (user, passwd, host, port, socket)
-    dest_val[in]       a dictionary containing connection information for the
-                       destination including:
-                       (user, passwd, host, port, socket)
-    quiet[in]          do not print any information during the operation
+    src_val[in]        source connection information
+    dest_val[in]       destination connection information
+    options[in]        options to control behavior:
+        quiet          do not print any information during the operation
                        (default is False)
-    version[in]        if specified (default is None), perform version
+        version        if specified (default is None), perform version
                        checking and fail if server version is < version
                        specified - an exception is raised
-    src_name[in]       name to use for source server
+        src_name       name to use for source server
                        (default is "Source")
-    dest_name[in]      name to use for destination server
+        dest_name      name to use for destination server
                        (default is "Destination")
+        unique         if True, servers must be different when dest_val is
+                       not None (default is False)
 
     Returns tuple (source, destination) where
             source = connection to source server
@@ -160,70 +206,111 @@ def connect_servers(src_val, dest_val, quiet=False, version=None,
             if error, returns (None, None)
     """
     
-    def _connect_server(name, values, version, quiet):
+    quiet = options.get("quiet", False)
+    src_name = options.get("src_name", "Source")
+    dest_name = options.get("dest_name", "Destination")
+    version = options.get("version", None)
+
+    def _connect_server(name, values, version, quiet):        
+
         server_conn = None
-        if not quiet:
-            _print_connection(name, values)
     
         # Try to connect to the MySQL database server.
-        server_conn = Server(values, name)
-        server_conn.connect()
-        if version is not None:
-            if not server_conn.check_version_compat(major, minor, rel):
-                raise MySQLUtilError("The %s version is incompatible. Utility "
-                                     "requires version %s or higher." %
-                                     (name, version))
-    
         if not quiet:
-            sys.stdout.write("connected.\n")
+            _print_connection(name, values)
 
+        server_options = {
+            'conn_info' : values,
+            'role'      : name,
+        }
+        server_conn = Server(server_options)
+        server_conn.connect()
+    
         return server_conn
-
+     
+    def _check_version(conn, name, version):    
+        if version is not None:
+            major, minor, rel = version.split(".")
+            if not conn.check_version_compat(major, minor, rel):
+                raise UtilError("The %s version is incompatible. Utility "
+                                "requires version %s or higher." %
+                                (name, version))
+        
     source = None
     destination = None
-    cloning = (src_val == dest_val) or dest_val is None
-    if version is not None:
-        major, minor, rel = version.split(".")
 
-    if type(src_val) == type({}): 
-        # If we're cloning so use same server for faster copy
-        if not cloning and dest_val is None:
-            dest_val = src_val
-    
-        source = _connect_server(src_name, src_val, version, quiet)
-    
-        if not cloning:
-            destination = _connect_server(dest_name, dest_val, version, quiet)
-        elif not quiet and dest_val is not None:
-            _print_connection(dest_name, src_val)
-            sys.stdout.write("connected.\n")
-    elif type(src_val) != Server:
-        raise MySQLUtilError("Cannot determine type of parameter.")
-    else:
+    # Fail if not the same types
+    if not dest_val is None and not isinstance(src_val, type(dest_val)):
+        raise UtilError("Connection paramters are not the same type.")
+
+    # Get connection dictionaries if src_val,dest_val are not Server instances.
+    if isinstance(src_val, Server):
         source = src_val
         destination = dest_val
+    src_val = get_connection_dictionary(src_val)
+    dest_val = get_connection_dictionary(dest_val)
+
+    # Check for uniqueness - dictionary 
+    if options.get("unique", False) and dest_val is not None:
+        dupes = False
+        if "unix_socket" in src_val and "unix_socket" in dest_val:
+            dupes = (src_val["unix_socket"] == dest_val["unix_socket"])
+        else:
+            dupes = (src_val["port"] == dest_val["port"]) and \
+                    (src_val["host"] == dest_val["host"])
+        if dupes:
+            raise UtilError("You must specify two different servers "
+                                 "for the operation.")
+
+    cloning = (src_val == dest_val) or dest_val is None
+    # If we're cloning so use same server for faster copy
+    if not cloning and dest_val is None:
+        dest_val = src_val
+
+    if source is None:
+        source = _connect_server(src_name, src_val, version, quiet)
+        if not quiet:
+            print "connected."
+    _check_version(source, src_name, version)
+
+    if not cloning:
+        if destination is None:
+            destination = _connect_server(dest_name, dest_val, version, quiet)
+            if not quiet:
+                print "connected."
+        _check_version(destination, dest_name, version)
+    elif not quiet and dest_val is not None:
+        _print_connection(dest_name, src_val)
+        print "connected."
 
     servers = (source, destination)
     return servers
 
 
-def test_connect(server_dict):
+def test_connect(conn_info):
     """Test connection to a server.
     
-    server_dict[in]    a dictionary containing connection information for the
-                       source including:
-                       (user, passwd, host, port, socket)
+    The method accepts one of the following types for conn_info:
+    
+        - dictionary containing connection information including:
+          (user, passwd, host, port, socket)
+        - connection string in the form: user:pass@host:port:socket
+        - an instance of the Server class
+        
+    conn_info[in]          Connection information
 
     Returns True if connection success, False if error
     """
-    from mysql.utilities.common.options import parse_connection
-    from mysql.utilities.exception import FormatError
-    
     # Parse source connection values
-    src_val = parse_connection(server_dict)
+    src_val = get_connection_dictionary(conn_info)
     try:
-        s = connect_servers(src_val, None, True, None, "test", None)
-    except MySQLUtilError, e:
+        conn_options = {
+            'quiet'     : True,
+            'src_name'  : "test",
+            'dest_name' : None,
+        }
+        s = connect_servers(src_val, None, conn_options)
+    except UtilError, e:
         return False
     return True
 
@@ -242,29 +329,67 @@ class Server(object):
         - Read SQL statements from a file and execute
     """
 
-    def __init__(self, conn_val, role="Server", verbose=False):
+    def __init__(self, options={}):
         """Constructor
 
-        dest_val[in]       a dictionary containing connection information
+        The method accepts one of the following types for options['conn_info']:
+        
+            - dictionary containing connection information including:
+              (user, passwd, host, port, socket)
+            - connection string in the form: user:pass@host:port:socket
+            - an instance of the Server class
+             
+        options[in]        options for controlling behavior:
+            conn_info      a dictionary containing connection information
                            (user, passwd, host, port, socket)
-        role[in]           Name or role of server (e.g., server, master)
-        verbose[in]        print extra data during operations (optional)
+            role           Name or role of server (e.g., server, master)
+            verbose        print extra data during operations (optional)
                            default value = False
+            charset        Default character set for the connection.
+                           (default latin1)
         """
-        self.verbose = verbose
+        
+        assert not options.get("conn_info") == None
+        
+        self.verbose = options.get("verbose", False)
         self.db_conn = None
-        self.role = role
-        self.host = conn_val["host"]
-        self.user = conn_val["user"]
-        self.passwd = conn_val["passwd"]
-        self.socket = conn_val["unix_socket"] if "unix_socket" in conn_val else None
-        self.port = 3306
-        if conn_val["port"] is not None:
-            self.port = int(conn_val["port"])
+        self.charset = options.get("charset", "latin1")
+        self.role = options.get("role", "Server")
+        conn_values = get_connection_dictionary(options.get("conn_info"))
+        try:
+            self.host = conn_values["host"]
+            self.user = conn_values["user"]
+            self.passwd = conn_values["passwd"]
+            self.socket = conn_values["unix_socket"] \
+                          if "unix_socket" in conn_values else None
+            self.port = 3306
+            if conn_values["port"] is not None:
+                self.port = int(conn_values["port"])
+        except KeyError:
+            raise UtilError("Dictionary format not recognized.")
         self.connect_error = None
 
 
-    def connect(self, charset="latin1"):
+    def get_connection_values(self):
+        """Return a dictionary of connection values for the server.
+        
+        Returns dictionary
+        """
+        conn_vals = {
+            "user"   : self.user,
+            "host"   : self.host
+        }
+        if self.passwd:
+            conn_vals["passwd"] = self.passwd
+        if self.socket:
+            conn_vals["socket"] = self.socket
+        if self.port:
+            conn_vals["port"] = self.port
+
+        return conn_vals
+
+
+    def connect(self):
         """Connect to server
 
         Attempts to connect to the server as specified by the connection
@@ -272,10 +397,8 @@ class Server(object):
 
         Note: This method must be called before executing queries.
 
-        charset[in]        Default character set for the connection.
-                           (default latin1)
 
-        Raises MySQLUtilError if error during connect
+        Raises UtilError if error during connect
         """
         try:
             parameters = {
@@ -287,17 +410,17 @@ class Server(object):
                 parameters['unix_socket'] = self.socket
             if self.passwd and self.passwd != "":
                 parameters['passwd'] = self.passwd
-            parameters['charset'] = charset
+            parameters['charset'] = self.charset
             self.db_conn = mysql.connector.connect(**parameters)
         except mysql.connector.Error, e:
-            raise MySQLUtilError("Cannot connect to the %s server.\n"
-                                 "Error %s" % (self.role, e.msg))
+            raise UtilDBError("Cannot connect to the %s server.\n"
+                              "Error %s" % (self.role, e.msg), e.errno)
             return False
         self.connect_error = None
 
 
     def check_version_compat(self, t_major, t_minor, t_rel):
-        """ Checks version of the server against requested version.
+        """Checks version of the server against requested version.
 
         This method can be used to check for version compatibility.
 
@@ -331,7 +454,7 @@ class Server(object):
 
 
     def toggle_fkeys(self, turn_on=True):
-        """ Turn foreign key checks on or off
+        """Turn foreign key checks on or off
 
         turn_on[in]        if True, turns on fkey check
                            if False, turns off fkey check
@@ -339,18 +462,20 @@ class Server(object):
         Returns original value = True == ON, False == OFF
         """
 
+        query_options = {
+            'fetch' : False
+        }
         fkey_query = "SET foreign_key_checks = %s"
         res = self.show_server_variable("foreign_key_checks")
         fkey = (res[0][1] == "ON")
         if not fkey and turn_on:
-            res = self.exec_query(fkey_query % "ON", (), False, False)
+            res = self.exec_query(fkey_query % "ON", query_options)
         elif fkey and not turn_on:
-            res = self.exec_query(fkey_query % "OFF", (), False, False)
+            res = self.exec_query(fkey_query % "OFF", query_options)
         return fkey
 
 
-    def exec_query(self, query_str, params=(),
-                   columns=False, fetch=True, raw=True):
+    def exec_query(self, query_str, options={}):
         """Execute a query and return result set
 
         This is the singular method to execute queries. It should be the only
@@ -362,17 +487,22 @@ class Server(object):
         Note: if fetchall is False, the method returns the cursor instance
 
         query_str[in]      The query to execute
-        params[in]         Parameters for query
-        columns[in]        Add column headings as first row
+        options[in]        Options to control behavior:
+            params         Parameters for query
+            columns        Add column headings as first row
                            (default is False)
-        fetch[in]          Execute the fetch as part of the operation and
+            fetch          Execute the fetch as part of the operation and
                            use a buffered cursor
                            (default is True)
-        raw[in]            If True, use a buffered raw cursor
+            raw            If True, use a buffered raw cursor
                            (default is True)
 
         Returns result set or cursor
         """
+        params = options.get('params', ())
+        columns = options.get('columns', False)
+        fetch = options.get('fetch', True)
+        raw = options.get('raw', True)
 
         # Guard for connect() prerequisite
         assert self.db_conn, "You must call connect before executing a query."
@@ -381,17 +511,13 @@ class Server(object):
         # If we are fetching all, we need to use a buffered
         if fetch:
             if raw:
-                #print "USING: buffered raw!"
                 cur = self.db_conn.cursor(
                     cursor_class=mysql.connector.cursor.MySQLCursorBufferedRaw)
             else:
-                #print "USING: buffered only"
                 cur = self.db_conn.cursor(buffered)
         else:
-            #print "USING: default cursor!"
             cur = self.db_conn.cursor(raw=True)
 
-        #print "query_str:", query_str, "\nparams:", params
         try:
             if params == ():
                 res = cur.execute(query_str)
@@ -399,10 +525,10 @@ class Server(object):
                 res = cur.execute(query_str, params)
         except mysql.connector.Error, e:
             cur.close()
-            raise MySQLUtilError("Query failed. " + e.__str__())
+            raise UtilDBError("Query failed. " + e.__str__())
         except Exception, e:
             cursor.close()
-            raise MySQLUtilError("Unknown error. Command: %s" % query_str)
+            raise UtilError("Unknown error. Command: %s" % query_str, e.errno)
         if fetch or columns:
             try:
                 results = cur.fetchall()
@@ -510,6 +636,100 @@ class Server(object):
         return (master_extra, slave_extra)
 
 
+    def has_storage_engine(self, target):
+        """Check to see if an engine exists and is supported.
+        
+        target[in]     name of engine to find
+        
+        Returns bool True - engine exists and is active, false = does not
+                     exist or is not supported/not active/disabled
+        """
+        if len(target) == 0:
+            return True # This says we will use default engine on the server.
+        if target is not None:
+            engines = self.get_storage_engines()
+            for engine in engines:
+                if engine[0].upper() == target.upper() and \
+                   engine[1].upper() in ['YES', 'DEFAULT']:
+                    return True
+        return False
+
+
+    def substitute_engine(self, tbl_name, create_str,
+                          new_engine, def_engine, quiet=False):
+        """Replace storage engine in CREATE TABLE
+        
+        This method will replace the storage engine in the CREATE statement
+        under the following conditions:
+            - If new_engine is specified and it exists on destination, use it.
+            - Else if existing engine does not exist and def_engine is specfied
+              and it exists on destination, use it. Also, don't substitute if
+              the existing engine will not be changed.
+              
+        tbl_name[in]       table name
+        create_str[in]     CREATE statement
+        new_engine[in]     name of storage engine to substitute (convert to)
+        def_engine[in]     name of storage engine to use if existing engines
+                           does not exist
+                           
+        Returns string CREATE string with replacements if found, else return
+                       original string
+        """
+
+        exist_engine = ''
+        replace_msg = "# Replacing ENGINE=%s with ENGINE=%s for table %s."
+        add_msg = "# Adding missing ENGINE=%s clause for table %s."
+        if new_engine is not None or def_engine is not None:
+            i = create_str.find("ENGINE=")
+            if i > 0:
+                j = create_str.find(" ", i)
+                exist_engine = create_str[i+7:j]
+
+        # Set default engine
+        #
+        # If a default engine is specified and is not the same as the
+        # engine specified in the table CREATE statement (existing engine) if
+        # specified, and both engines exist on the server, replace the existing
+        # engine with the default engine.
+        #
+        if def_engine is not None and \
+             exist_engine.upper() != def_engine.upper() and \
+             self.has_storage_engine(def_engine) and \
+             self.has_storage_engine(exist_engine):
+            # If no ENGINE= clause present, add it
+            if len(exist_engine) == 0:
+                i = create_str.find(";")
+                create_str = create_str[0:i] + " ENGINE=%s;"  % def_engine
+            # replace the existing storage engine
+            else:
+                create_str.replace("ENGINE=%s" % exist_engine,
+                                   "ENGINE=%s" % def_engine)
+            if not quiet:
+                if len(exist_engine) > 0:
+                    print replace_msg % (exist_engine, def_engine, tbl_name)
+                else:
+                    print add_msg % (def_engine, tbl_name)
+            exist_engine = def_engine
+
+        # Use new engine
+        if new_engine is not None and \
+           exist_engine.upper() != new_engine.upper() and \
+           self.has_storage_engine(new_engine):
+            if len(exist_engine) == 0:
+                i = create_str.find(";")
+                create_str = create_str[0:i] + " ENGINE=%s;"  % new_engine
+            else:                
+                create_str = create_str.replace("ENGINE=%s" % exist_engine,
+                                                "ENGINE=%s" % new_engine)
+            if not quiet:
+                if len(exist_engine) > 0:
+                    print replace_msg % (exist_engine, new_engine, tbl_name)
+                else:
+                    print add_msg % (new_engine, tbl_name)
+        
+        return create_str
+
+
     def get_innodb_stats(self):
         """Return type of InnoDB engine and its version information.
 
@@ -559,7 +779,8 @@ class Server(object):
             version.append(None)
 
         results = self.show_server_variable("have_innodb")
-        if results is not None and results[0][1].lower() == "yes":
+        if results is not None and results != [] and \
+           results[0][1].lower() == "yes":
             have_innodb = True
         else:
             have_innodb = False
@@ -591,6 +812,39 @@ class Server(object):
                 if cmd[0] != '#':
                     if verbose:
                         print cmd
-                    res = self.exec_query(cmd, (), False, False)
+                    query_options = {
+                        'fetch' : False
+                    }
+                    res = self.exec_query(cmd, query_options)
         file.close()
         return res
+
+
+    def binlog_enabled(self):
+        """Check binary logging status for the client.
+        
+        Returns bool - True - binary logging is ON, False = OFF
+        """
+        res = self.show_server_variable("sql_log_bin")
+        if not res:
+            raise UtilDBError("Cannot retrieve status of sql_log_bin variable.")
+        if res[0][1] == "OFF" or res[0][1] == "0":
+            return False
+        return True
+
+
+    def toggle_binlog(self, action="disable"):
+        """Enable or disable binary logging for the client.
+        
+        Note: user must have SUPER privilege
+        
+        action[in]         if 'disable', turn off the binary log
+                           elif 'enable' turn binary log on
+                           do nothing if action != 'enable' or 'disable'
+        """
+        
+        if action.lower() == 'disable':
+            self.exec_query("SET SQL_LOG_BIN=0")
+        elif action.lower() == 'enable':
+            self.exec_query("SET SQL_LOG_BIN=1")
+
