@@ -183,7 +183,7 @@ void SidebarSection::set_selected(SidebarEntry* entry)
     _selected_entry= entry;
     set_needs_repaint();
     if (entry)
-      _owner->on_section_command().emit(entry->command());
+      (*_owner->on_section_command())(entry->command());
   }
 }
 
@@ -272,7 +272,7 @@ void SidebarSection::toggle_expand()
   set_needs_repaint();
   relayout();
 
-  _expanded_changed.emit(this);
+  _expanded_changed(this);
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -518,7 +518,7 @@ void SidebarSection::mouse_click(int button, int x, int y)
       {
         SidebarEntry* entry = entry_from_point(x, y);
         if (entry && ((entry == _hot_entry) || (entry == _selected_entry)))
-          _owner->on_section_command().emit(entry->command());
+          (*_owner->on_section_command())(entry->command());
       }
     }
     break;
@@ -626,12 +626,12 @@ void AdvancedSidebar::setup_schema_tree()
   _schema_tree.set_back_color("#d9e2ef");
   set_back_color("#d9e2ef");
   _schema_tree.set_context_menu(&_tree_context_menu);
-  _tree_context_menu.signal_will_show().connect(sigc::mem_fun(this, &AdvancedSidebar::on_show_menu));
-  _tree_context_menu.set_handler(sigc::mem_fun(this, &AdvancedSidebar::handle_menu_command));
+  scoped_connect(_tree_context_menu.signal_will_show(),boost::bind(&AdvancedSidebar::on_show_menu, this));
+  _tree_context_menu.set_handler(boost::bind(&AdvancedSidebar::handle_menu_command, this, _1));
 
   // Add the tree itself and its section caption to the container.
   _schema_tree_heading = new SidebarSection(this, _("SCHEMAS"), true, true);
-  _schema_tree_heading->expanded_changed().connect(sigc::mem_fun(this, &AdvancedSidebar::on_expand_changed));
+  scoped_connect(_schema_tree_heading->expanded_changed(),boost::bind(&AdvancedSidebar::on_expand_changed, this, _1));
   _sections.push_back(_schema_tree_heading);
   _schema_box.set_back_color("#d9e2ef");
   _schema_box.add(_schema_tree_heading, false, true);
@@ -694,7 +694,7 @@ void AdvancedSidebar::set_schema_model(LiveSchemaTree* model)
   _schema_tree.set_model(model);
   _changed_conn.disconnect();
   if (model)
-    _changed_conn = model->tree_changed_signal().connect(sigc::mem_fun(_schema_tree, &GRTTreeView::row_count_changed));
+    _changed_conn = *scoped_connect(model->tree_changed_signal(),boost::bind(&GRTTreeView::row_count_changed, &_schema_tree, _1, _2)).get();
   
   if (_is_model_owner)
   {
@@ -706,7 +706,7 @@ void AdvancedSidebar::set_schema_model(LiveSchemaTree* model)
   
   _activate_conn.disconnect();
   if (_schema_model)
-    _activate_conn = _schema_tree.signal_row_activate().connect(sigc::hide_return(sigc::hide(sigc::mem_fun(_schema_model, &wb::LiveSchemaTree::activate_node))));
+    _activate_conn = *scoped_connect(_schema_tree.signal_row_activate(),boost::bind(&wb::LiveSchemaTree::activate_node, _schema_model, _1)).get();
 }
 
 //--------------------------------------------------------------------------------------------------
