@@ -77,7 +77,7 @@ namespace wb {
 
     SidebarEntry* _selected_entry;
     SidebarEntry* _hot_entry;
-    sigc::signal<void, SidebarSection*> _expanded_changed;
+    boost::signals2::signal<void (SidebarSection*)> _expanded_changed;
 
     AdvancedSidebar* _owner;
   protected:
@@ -115,7 +115,7 @@ namespace wb {
 
     void clear_selection();
 
-    sigc::signal<void, SidebarSection*> &expanded_changed() { return _expanded_changed; }
+    boost::signals2::signal<void (SidebarSection*)>* expanded_changed() { return &_expanded_changed; }
   };
 
   class AdvancedSidebar : public mforms::TaskSidebar
@@ -128,8 +128,8 @@ namespace wb {
     mforms::GRTTreeView _schema_tree;
     mforms::Menu _tree_context_menu;
     wb::LiveSchemaTree* _schema_model;
-    sigc::connection _activate_conn;
-    sigc::connection _changed_conn;
+    boost::signals2::connection _activate_conn;
+    boost::signals2::connection _changed_conn;
     bool _is_model_owner;                   // True if the sidebar is the owner of the model.
 
     mforms::Box _schema_box; // Container for schema section and tree so we can hide it as a block.
