@@ -48,8 +48,8 @@ SqlScriptSelectionPage::SqlScriptSelectionPage(WizardForm* wizard)
   _table.add(&_caption, 0, 1, 0, 1, mforms::HFillFlag);
 
   _file_selector.initialize("", mforms::OpenFile, "SQL Files (*.sql)|*.sql", _("Browse..."),
-    false, sigc::mem_fun(this, &WizardPage::validate));
-  _file_selector.signal_changed().connect(sigc::mem_fun(this, &SqlScriptSelectionPage::file_changed)); 
+    false, boost::bind(&WizardPage::validate, this));
+  scoped_connect(_file_selector.signal_changed(),boost::bind(&SqlScriptSelectionPage::file_changed, this)); 
 
   _table.add(&_file_selector, 1, 2, 0, 1, mforms::HExpandFlag | mforms::HFillFlag);
 
