@@ -140,10 +140,10 @@ public:
     table->add(manage(newDescr(_("Python modules containing functions exported to be used by other scripts, modules or plugins in Workbench."))),
                1, 2, 3, 4, HExpandFlag|HFillFlag);
     
-    _lua_script.signal_clicked().connect(sigc::mem_fun(this, &NewPluginDialog::changed_type));
-    _python_script.signal_clicked().connect(sigc::mem_fun(this, &NewPluginDialog::changed_type));
-    _python_module.signal_clicked().connect(sigc::mem_fun(this, &NewPluginDialog::changed_type));
-    _python_plugin.signal_clicked().connect(sigc::mem_fun(this, &NewPluginDialog::changed_type));
+    scoped_connect(_lua_script.signal_clicked(),boost::bind(&NewPluginDialog::changed_type, this));
+    scoped_connect(_python_script.signal_clicked(),boost::bind(&NewPluginDialog::changed_type, this));
+    scoped_connect(_python_module.signal_clicked(),boost::bind(&NewPluginDialog::changed_type, this));
+    scoped_connect(_python_plugin.signal_clicked(),boost::bind(&NewPluginDialog::changed_type, this));
     
     for (std::vector<PluginTemplate>::const_iterator tpl= _plugin_template_list.begin();
          tpl != _plugin_template_list.end(); ++tpl)
@@ -163,7 +163,7 @@ public:
     _script_args.set_column_spacing(8);
     _script_args.add(manage(new Label(_("Script File Name:"))), 0, 1, 0, 1, HFillFlag);
     _script_args.add(&_filename, 1, 2, 0, 1, HExpandFlag|HFillFlag);
-    _filename.signal_changed().connect(sigc::mem_fun(this, &NewPluginDialog::validate));
+    scoped_connect(_filename.signal_changed(),boost::bind(&NewPluginDialog::validate, this));
     _script_args.add(manage(newDescr(_("The default location for scripts is in the scripts folder\nof your Workbench configuration folder."))), 
                      2, 3, 0, 1, HFillFlag);
     _tab.add_page(&_script_args, "");
@@ -181,13 +181,13 @@ public:
 
     _plugin_args.add(manage(new Label(_("Plugin Name:"))), 0, 1, 1, 2, HFillFlag);
     _plugin_args.add(&_plugin_name, 1, 2, 1, 2, HFillFlag|HExpandFlag);
-    _plugin_name.signal_changed().connect(sigc::bind(sigc::mem_fun(this, &NewPluginDialog::name_changed), &_plugin_name));
+    scoped_connect(_plugin_name.signal_changed(),boost::bind(&NewPluginDialog::name_changed, this, &_plugin_name));
     _plugin_args.add(manage(newDescr(_("Provide a unique name for the plugin. Use alphanumeric\ncharacters and _ only."))), 
                      2, 3, 1, 2, HFillFlag);
 
     _plugin_args.add(manage(new Label(_("File Name:"))), 0, 1, 2, 3, HFillFlag);
     _plugin_args.add(&_plugin_file, 1, 2, 2, 3, HExpandFlag|HFillFlag);
-    _plugin_file.signal_changed().connect(sigc::mem_fun(this, &NewPluginDialog::validate));
+    scoped_connect(_plugin_file.signal_changed(),boost::bind(&NewPluginDialog::validate, this));
     _plugin_args.add(manage(newDescr(_("Name of the plugin file, must be unique and contain only\nalphanumeric chars and _. Specify name only, without a path."))), 
                      2, 3, 2, 3, HFillFlag);
 
@@ -205,18 +205,18 @@ public:
     _module_args.add(&_module_name, 1, 2, 0, 1, HFillFlag|HExpandFlag);
     _module_args.add(manage(newDescr(_("Provide a name for the module. Use alphanumeric\ncharacters and _ only."))), 
                      2, 3, 0, 1, HFillFlag);
-    _module_name.signal_changed().connect(sigc::bind(sigc::mem_fun(this, &NewPluginDialog::name_changed), &_module_name));
+    scoped_connect(_module_name.signal_changed(),boost::bind(&NewPluginDialog::name_changed, this, &_module_name));
     _module_args.add(manage(new Label(_("Function Name:"))), 0, 1, 1, 2, HFillFlag);
     _module_args.add(&_function_name, 1, 2, 1, 2, HFillFlag|HExpandFlag);    
     _module_args.add(manage(newDescr(_("Provide a name for the module function. Use alphanumeric\ncharacters and _ only."))), 
                      2, 3, 1, 2, HFillFlag);
-    _function_name.signal_changed().connect(sigc::mem_fun(this, &NewPluginDialog::validate));
+    scoped_connect(_function_name.signal_changed(),boost::bind(&NewPluginDialog::validate, this));
     
     _module_args.add(manage(new Label(_("File Name:"))), 0, 1, 2, 3, HFillFlag);
     _module_args.add(&_module_file, 1, 2, 2, 3, HExpandFlag|HFillFlag);
     _module_args.add(manage(newDescr(_("Name of the module file, must be unique and contain only\nalphanumeric chars and _. Specify name only, without a path."))), 
                      2, 3, 2, 3, HFillFlag);
-    _module_file.signal_changed().connect(sigc::mem_fun(this, &NewPluginDialog::validate));
+    scoped_connect(_module_file.signal_changed(),boost::bind(&NewPluginDialog::validate, this));
 
     _module_name.set_value("mymodule");
     name_changed(&_module_name);
