@@ -244,7 +244,7 @@ PythonDebugger::PythonDebugger(GRTShellWindow *shell, mforms::TabView *tabview)
   _breakpoint_list->add_column(StringColumnType, "Location", 200, false);
   _breakpoint_list->add_column(StringColumnType, "Condition", 200, true);
   _breakpoint_list->end_columns();
-  _breakpoint_list->set_cell_edit_handler(sigc::mem_fun(this, &PythonDebugger::edit_breakpoint));
+  _breakpoint_list->set_cell_edit_handler(boost::bind(&PythonDebugger::edit_breakpoint, this, _1, _2, _3));
   _lower_tabs->add_page(_breakpoint_list, _("Breakpoints"));
 
   mforms::Splitter *spl = manage(new Splitter(true));
@@ -257,7 +257,7 @@ PythonDebugger::PythonDebugger(GRTShellWindow *shell, mforms::TabView *tabview)
   _stack_list->add_column(StringColumnType, "File", 300, false);
   _stack_list->end_columns();
   spl->add(_stack_list);
-  _stack_list->signal_changed().connect(sigc::mem_fun(this, &PythonDebugger::stack_selected));
+  scoped_connect(_stack_list->signal_changed(),boost::bind(&PythonDebugger::stack_selected, this));
   //_stack_list->signal_row_activated().connect();
   
   _variable_list= manage(new TreeView(TreeDefault));
@@ -309,8 +309,8 @@ void PythonDebugger::init_pdb()
 
 void PythonDebugger::editor_added(GRTCodeEditor *editor)
 {
-  editor->get_editor()->signal_gutter_clicked().connect(sigc::bind(sigc::mem_fun(this, &PythonDebugger::line_gutter_clicked), editor));
-  editor->get_editor()->signal_changed().connect(sigc::bind(sigc::mem_fun(this, &PythonDebugger::editor_text_changed), editor));
+  scoped_connect(editor->get_editor()->signal_gutter_clicked(),boost::bind(&PythonDebugger::line_gutter_clicked, this, _1, _2, _3, editor));
+  scoped_connect(editor->get_editor()->signal_changed(),boost::bind(&PythonDebugger::editor_text_changed, this, _1, _2, editor));
 }
 
 
