@@ -62,7 +62,7 @@ GRTShellWindow::GRTShellWindow(wb::WBContext* context)
 {
   set_title(("Workbench Scripting Shell"));
   set_content(&_content);
-  signal_closed().connect(sigc::mem_fun(this, &GRTShellWindow::shell_closed));
+  scoped_connect(signal_closed(),boost::bind(&GRTShellWindow::shell_closed, this));
   
   _content.add(&_toolbar, false, true);
 
@@ -81,7 +81,7 @@ GRTShellWindow::GRTShellWindow(wb::WBContext* context)
   _hsplitter.add(&_side_tab);
 #endif
 
-  _side_tab.signal_tab_changed().connect(sigc::mem_fun(this, &GRTShellWindow::side_tab_changed));
+  scoped_connect(_side_tab.signal_tab_changed(),boost::bind(&GRTShellWindow::side_tab_changed, this));
 
   _hsplitter.add(&_right_splitter);
 
@@ -97,38 +97,38 @@ GRTShellWindow::GRTShellWindow(wb::WBContext* context)
   _toolbar.set_padding(2);
   _toolbar.set_spacing(4);
 
-  add_tool_button("tiny_new_doc.png", sigc::mem_fun(this, &GRTShellWindow::add_new_script),
+  add_tool_button("tiny_new_doc.png", boost::bind(&GRTShellWindow::add_new_script, this),
     _("Create a new file from a template"));
-  add_tool_button("tiny_load.png", sigc::mem_fun(this, &GRTShellWindow::open_script_file),
+  add_tool_button("tiny_load.png", boost::bind(&GRTShellWindow::open_script_file, this),
     _("Open a script file"));
 
   add_tool_separator();
-  _save_button = add_tool_button("tiny_save.png", sigc::bind(sigc::mem_fun(this, &GRTShellWindow::save_file), false),
+  _save_button = add_tool_button("tiny_save.png", boost::bind(&GRTShellWindow::save_file, this, false),
     _("Save file"));
-  _save_as_button = add_tool_button("tiny_saveas.png", sigc::bind(sigc::mem_fun(this, &GRTShellWindow::save_file), true),
+  _save_as_button = add_tool_button("tiny_saveas.png", boost::bind(&GRTShellWindow::save_file, this, true),
     _("Save file with a new name"));
 
   add_tool_separator();
   //  if (_editing_module)
   {
-    //   add_tool_button("tiny_refresh.png", sigc::mem_fun(this, &GRTCodeEditor::execute),
+    //   add_tool_button("tiny_refresh.png", boost::bind(&GRTCodeEditor::execute, this),
     //                   "Refresh the module");
   }
   //  else
   {
-    _run_button = add_tool_button("tiny_execute.png", sigc::mem_fun(this, &GRTShellWindow::execute_file),
+    _run_button = add_tool_button("tiny_execute.png", boost::bind(&GRTShellWindow::execute_file, this),
       _("Execute script"));
-    _continue_button = add_tool_button("debug_continue.png", sigc::mem_fun(this, &GRTShellWindow::debug_continue), 
+    _continue_button = add_tool_button("debug_continue.png", boost::bind(&GRTShellWindow::debug_continue, this), 
       _("Continue execution until next breakpoint"));
-    _pause_button = add_tool_button("debug_pause.png", sigc::mem_fun(this, &GRTShellWindow::debug_pause),
+    _pause_button = add_tool_button("debug_pause.png", boost::bind(&GRTShellWindow::debug_pause, this),
                                     "Pause script execution");
-    _step_button = add_tool_button("debug_step.png", sigc::mem_fun(this, &GRTShellWindow::debug_step), 
+    _step_button = add_tool_button("debug_step.png", boost::bind(&GRTShellWindow::debug_step, this), 
       _("Step to next statement"));
-    _step_into_button = add_tool_button("debug_step_into.png", sigc::mem_fun(this, &GRTShellWindow::debug_step_into), 
+    _step_into_button = add_tool_button("debug_step_into.png", boost::bind(&GRTShellWindow::debug_step_into, this), 
       _("Step into next function"));
-    _step_out_button = add_tool_button("debug_step_out.png", sigc::mem_fun(this, &GRTShellWindow::debug_step_out),
+    _step_out_button = add_tool_button("debug_step_out.png", boost::bind(&GRTShellWindow::debug_step_out, this),
       _("Finish execution of current function"));
-    _stop_button = add_tool_button("debug_stop.png", sigc::mem_fun(this, &GRTShellWindow::debug_stop),
+    _stop_button = add_tool_button("debug_stop.png", boost::bind(&GRTShellWindow::debug_stop, this),
       _("Stop executing script"));
 
     _continue_button->show(false);
@@ -142,19 +142,19 @@ GRTShellWindow::GRTShellWindow(wb::WBContext* context)
 
 #ifndef _WIN32
   // TODO: remove as soon as all platforms support closable tabs.
-  add_tool_button("Discard.png", sigc::mem_fun(this, &GRTShellWindow::close_tab),
+  add_tool_button("Discard.png", boost::bind(&GRTShellWindow::close_tab, this),
     _("Close this script tab"), false);
 #endif
   add_tool_separator();
 
-  add_tool_button("clear_output.png", sigc::bind(sigc::mem_fun(_output_text, &mforms::TextBox::set_value), ""), 
+  add_tool_button("clear_output.png", boost::bind(&mforms::TextBox::set_value, &_output_text, ""), 
     _("Clear script output"), false);
 
-  add_tool_button("snippet_add.png", sigc::mem_fun(this, &GRTShellWindow::add_snippet), 
+  add_tool_button("snippet_add.png", boost::bind(&GRTShellWindow::add_snippet, this), 
     _("Add a new snippet"));
-  _snippet_delete_button = add_tool_button("snippet_del.png", sigc::mem_fun(this, &GRTShellWindow::del_snippet), 
+  _snippet_delete_button = add_tool_button("snippet_del.png", boost::bind(&GRTShellWindow::del_snippet, this), 
     _("Delete the selected snippet"));
-  _snippet_copy_button = add_tool_button("snippet_clipboard.png", sigc::mem_fun(this, &GRTShellWindow::copy_snippet), 
+  _snippet_copy_button = add_tool_button("snippet_clipboard.png", boost::bind(&GRTShellWindow::copy_snippet, this), 
     _("Copy snippet text to the clipboard"));
   add_tool_separator();
 
@@ -172,14 +172,14 @@ GRTShellWindow::GRTShellWindow(wb::WBContext* context)
   _files_menu.add_separator();
   _files_menu.add_item("Delete Script", "delete-script");
 
-  _files_menu.set_handler(sigc::mem_fun(this, &GRTShellWindow::file_menu_activate));
+  _files_menu.set_handler(boost::bind(&GRTShellWindow::file_menu_activate, this, _1));
 
   _files_tree->set_context_menu(&_files_menu);
 
   _files_tree->add_column(StringColumnType, "", 400, false);
   _files_tree->end_columns();
 
-  _files_tree->signal_row_activated().connect(sigc::mem_fun(this, &GRTShellWindow::file_list_activated));
+  scoped_connect(_files_tree->signal_row_activated(),boost::bind(&GRTShellWindow::file_list_activated, this, _1, _2));
   
   files_box->add(_files_tree, true, true);
 #ifdef _WIN32
@@ -216,14 +216,14 @@ GRTShellWindow::GRTShellWindow(wb::WBContext* context)
   _global_list.set_column_width(1, 100);
   _global_tree.add_column(mforms::IconStringGRTColumnType, 0, "GRT Globals");
   _global_tree.set_column_width(0, 220);
-  _global_tree.signal_changed().connect(sigc::mem_fun(this, &GRTShellWindow::global_selected));
-  _global_combo.signal_changed().connect(sigc::mem_fun(this, &GRTShellWindow::change_global_path));
+  scoped_connect(_global_tree.signal_changed(),boost::bind(&GRTShellWindow::global_selected, this));
+  scoped_connect(_global_combo.signal_changed(),boost::bind(&GRTShellWindow::change_global_path, this));
   _inspector= 0;
 
   _global_menu.add_item(_("Copy Value"), "copy_value");
   _global_menu.add_item(_("Copy Path"), "copy_path");
   _global_menu.add_item(_("Copy Path for Python"), "copy_path_py");
-  _global_menu.set_handler(sigc::mem_fun(this, &GRTShellWindow::handle_global_menu));
+  _global_menu.set_handler(boost::bind(&GRTShellWindow::handle_global_menu, this, _1));
   
   _global_tree.set_context_menu(&_global_menu);
   // 2) Classes tree
@@ -243,11 +243,11 @@ GRTShellWindow::GRTShellWindow(wb::WBContext* context)
   _classes_tree.add_column(mforms::IconStringGRTColumnType, bec::StructsTreeBE::Name, "Name");
   _classes_tree.add_column(mforms::StringGRTColumnType, bec::StructsTreeBE::Type, "Type");
   _classes_tree.set_column_width(0, 150);
-  _classes_tree.signal_changed().connect(sigc::mem_fun(this, &GRTShellWindow::class_selected));
+  scoped_connect(_classes_tree.signal_changed(),boost::bind(&GRTShellWindow::class_selected, this));
   _classes_sorting.add_item("Group by Name");
   _classes_sorting.add_item("Group by Hierarchy");
   _classes_sorting.add_item("Group by Package");
-  _classes_sorting.signal_changed().connect(sigc::mem_fun(this, &GRTShellWindow::change_class_sorting));
+  scoped_connect(_classes_sorting.signal_changed(),boost::bind(&GRTShellWindow::change_class_sorting, this));
   
   // 3) Modules tree
 #ifdef _WIN32
@@ -261,7 +261,7 @@ GRTShellWindow::GRTShellWindow(wb::WBContext* context)
   _modules_text.set_back_color("#FFFFFF");
   _modules_tree.add_column(mforms::IconStringGRTColumnType, 0, "GRT Modules");
   _modules_tree.set_column_width(0, 220);
-  _modules_tree.signal_changed().connect(sigc::mem_fun(this, &GRTShellWindow::module_selected));
+  scoped_connect(_modules_tree.signal_changed(),boost::bind(&GRTShellWindow::module_selected, this));
   
   _right_splitter.add(&_main_tab);
 
@@ -293,7 +293,7 @@ GRTShellWindow::GRTShellWindow(wb::WBContext* context)
   _shell_hbox.add(&_shell_entry, true, true);
   _main_tab.add_page(&_shell_box, "Shell");
   
-  _shell_entry.signal_action().connect(sigc::mem_fun(this, &GRTShellWindow::shell_action));
+  scoped_connect(_shell_entry.signal_action(),boost::bind(&GRTShellWindow::shell_action, this, _1));
 
   // snippets tab
 #ifdef _WIN32
@@ -317,22 +317,22 @@ GRTShellWindow::GRTShellWindow(wb::WBContext* context)
   _snippet_menu.add_separator();
   _snippet_menu.add_item("Delete Snippet", "delete");
 
-  _snippet_menu.set_handler(sigc::mem_fun(this, &GRTShellWindow::snippet_menu_activate));
+  _snippet_menu.set_handler(boost::bind(&GRTShellWindow::snippet_menu_activate, this, _1));
 
   _snippet_list->set_context_menu(&_snippet_menu);
 
-  _snippet_list->signal_changed().connect(sigc::mem_fun(this, &GRTShellWindow::snippet_selected));
+  scoped_connect(_snippet_list->signal_changed(),boost::bind(&GRTShellWindow::snippet_selected, this));
   _snippet_text.set_language(LanguagePython);
 
-  _snippet_text.signal_changed().connect(sigc::mem_fun(this, &GRTShellWindow::snippet_changed));
+  scoped_connect(_snippet_text.signal_changed(),boost::bind(&GRTShellWindow::snippet_changed, this, _1, _2));
 
   _snippet_list->add_column(mforms::StringColumnType, "Snippet", 500, false);
   _snippet_list->end_columns();
   _main_tab.add_page(&_snippet_page, "Snippets");
 
-  _main_tab.signal_tab_closing().connect(sigc::mem_fun(this, &GRTShellWindow::on_tab_closing));
-  _main_tab.signal_tab_closed().connect(sigc::mem_fun(this, &GRTShellWindow::on_tab_closed));
-  _main_tab.signal_tab_changed().connect(sigc::mem_fun(this, &GRTShellWindow::on_tab_changed));
+  scoped_connect(_main_tab.signal_tab_closing(),boost::bind(&GRTShellWindow::on_tab_closing, this, _1));
+  scoped_connect(_main_tab.signal_tab_closed(),boost::bind(&GRTShellWindow::on_tab_closed, this, _1));
+  scoped_connect(_main_tab.signal_tab_changed(),boost::bind(&GRTShellWindow::on_tab_changed, this));
 
   //
   
@@ -361,8 +361,8 @@ GRTShellWindow::GRTShellWindow(wb::WBContext* context)
   _modules_splitter.set_position(400);
   _classes_splitter.set_position(400);
   
-  grtm()->get_shell()->set_ready_handler(sigc::mem_fun(this, &GRTShellWindow::handle_prompt));
-  grtm()->get_shell()->set_output_handler(sigc::mem_fun(this, &GRTShellWindow::handle_output));
+  grtm()->get_shell()->set_ready_handler(boost::bind(&GRTShellWindow::handle_prompt, this, _1));
+  grtm()->get_shell()->set_output_handler(boost::bind(&GRTShellWindow::handle_output, this, _1));
 
   on_tab_changed();
   snippet_selected();
@@ -475,7 +475,7 @@ void GRTShellWindow::execute_file()
   GRTCodeEditor *editor = get_active_editor();
   if (!editor) return;
 
-  grtm()->push_output_callback(sigc::mem_fun(this, &GRTShellWindow::add_output));
+  grtm()->push_output_callback(boost::bind(&GRTShellWindow::add_output, this, _1));
 
   if (_debugger && g_str_has_suffix(editor->get_path().c_str(), ".py"))
   {
@@ -513,7 +513,7 @@ void GRTShellWindow::debug_step()
     else 
     {
       // start the program stopping at the 1st line
-      grtm()->push_output_callback(sigc::mem_fun(this, &GRTShellWindow::add_output));
+      grtm()->push_output_callback(boost::bind(&GRTShellWindow::add_output, this, _1));
     
       _run_button->show(false);
       _continue_button->show(true);
@@ -913,6 +913,11 @@ void GRTShellWindow::scriptize_snippet()
   }
 }
 
+bool run_return_true(boost::function<void (const std::string&)> f, const std::string& param)
+{
+  f(param);
+  return true;
+}
 
 void GRTShellWindow::run_snippet()
 {
@@ -926,7 +931,10 @@ void GRTShellWindow::run_snippet()
 
     handle_output("Running snippet...\n");
     // redirect snippet output to the shell
-    grtm()->push_output_callback(sigc::bind_return(sigc::mem_fun(this, &GRTShellWindow::handle_output), true));
+    //static const bool trueval = true;
+    boost::function<void (const std::string&)> f = boost::bind(&GRTShellWindow::handle_output,this,_1);
+    boost::function<bool (const std::string&)> task = boost::bind(run_return_true,f, _1);
+    grtm()->push_output_callback(task);
     
     try
     {
@@ -1275,7 +1283,7 @@ void GRTShellWindow::delete_selected_file()
 //--------------------------------------------------------------------------------------------------
 
 mforms::Button *GRTShellWindow::add_tool_button(const std::string &image,
-                                    const sigc::slot<void> &action,
+                                    const boost::function<void ()> &action,
                                     const std::string &tooltip,
                                     bool left)
 {
@@ -1283,7 +1291,7 @@ mforms::Button *GRTShellWindow::add_tool_button(const std::string &image,
   Button *b = manage(new Button(ToolButton));
   b->set_icon(app->get_resource_path(image));
   b->set_tooltip(tooltip);
-  b->signal_clicked().connect(action);
+  scoped_connect(b->signal_clicked(),action);
   if (left)
     _toolbar.add(b, false, true);
   else
@@ -1394,7 +1402,7 @@ void GRTShellWindow::on_tab_changed()
     _save_as_button->set_enabled(true);
     _run_button->set_enabled(exec_enabled);
     _step_button->set_enabled(exec_enabled);
-    
+
     _right_splitter.set_expanded(false, true);
   }
   else 
@@ -1403,6 +1411,7 @@ void GRTShellWindow::on_tab_changed()
     _save_as_button->set_enabled(false);
     _run_button->set_enabled(false);
     _step_button->set_enabled(false);
+
     _right_splitter.set_expanded(false, false);
   }
 
