@@ -87,11 +87,11 @@ HostMachinePage::HostMachinePage(WizardForm* host, wb::WBContext *wb)
   _top_box.add(&_host_description, false, true);
 
   _localhost_button.set_text(_("localhost"));
-  _localhost_button.signal_toggled().connect(sigc::mem_fun(this, &HostMachinePage::host_selection_changed));
+  scoped_connect(_localhost_button.signal_toggled(),boost::bind(&HostMachinePage::host_selection_changed, this));
   _top_box.add(&_localhost_button, false, true);
   _networkhost_button.set_text(_("Remote Host"));
   _networkhost_button.set_active(true);
-  _networkhost_button.signal_toggled().connect(sigc::mem_fun(this, &HostMachinePage::host_selection_changed));
+  scoped_connect(_networkhost_button.signal_toggled(),boost::bind(&HostMachinePage::host_selection_changed, this));
   _top_box.add(&_networkhost_button, false, true);
   
   Label *indent;
@@ -119,7 +119,7 @@ HostMachinePage::HostMachinePage(WizardForm* host, wb::WBContext *wb)
   
   _dbhost_button.set_text(_("Take Parameters from Existing Database Connection"));
   _dbhost_button.set_active(true);
-  _dbhost_button.signal_toggled().connect(sigc::mem_fun(this, &HostMachinePage::host_selection_changed));
+  scoped_connect(_dbhost_button.signal_toggled(),boost::bind(&HostMachinePage::host_selection_changed, this));
   _top_box.add(&_dbhost_button, false, true);
   _top_box.add(&_dbhost_block, false, true);
   
@@ -329,20 +329,20 @@ TestDatabaseSettingsPage::TestDatabaseSettingsPage(WizardForm* host)
   grtui::WizardProgressPage::TaskRow *task;
   
   task = add_task(_("Open Database Connection"),
-                  sigc::mem_fun(this, &TestDatabaseSettingsPage::open_connection),
+                  boost::bind(&TestDatabaseSettingsPage::open_connection, this),
                   _("Connecting to database server..."));
   
   add_task(_("Get Server Version"),
-           sigc::mem_fun(this, &TestDatabaseSettingsPage::get_server_version),
+           boost::bind(&TestDatabaseSettingsPage::get_server_version, this),
            _("Querying server version..."));
   
   add_task(_("Get Server OS"),
-           sigc::mem_fun(this, &TestDatabaseSettingsPage::get_server_platform),
+           boost::bind(&TestDatabaseSettingsPage::get_server_platform, this),
            _("Querying server OS type..."));
 
 /*XXX TODO
   add_task(_("Check Account Privileges"),
-           sigc::mem_fun(this, &TestDatabaseSettingsPage::get_server_platform),
+           boost::bind(&TestDatabaseSettingsPage::get_server_platform, this),
            _("Checking if account being used has enough privileges..."));
 - check the privs the account has and warn if it can't do something:
 - creating and modifying user accts
@@ -505,14 +505,14 @@ HostAndRemoteTypePage::HostAndRemoteTypePage(WizardForm* host)
   _management_type_panel.add(&_management_type_box);
 
   _no_remote_admin.set_text(_("Do not use remote management"));
-  _no_remote_admin.signal_toggled().connect(sigc::mem_fun(this, &HostAndRemoteTypePage::toggle_remote_admin));
+  scoped_connect(_no_remote_admin.signal_toggled(),boost::bind(&HostAndRemoteTypePage::toggle_remote_admin, this));
   _win_remote_admin.set_text(_("Native Windows remote management (only available on Windows)"));
-  _win_remote_admin.signal_toggled().connect(sigc::mem_fun(this, &HostAndRemoteTypePage::toggle_remote_admin));
+  scoped_connect(_win_remote_admin.signal_toggled(),boost::bind(&HostAndRemoteTypePage::toggle_remote_admin, this));
 #ifndef _WIN32
   _win_remote_admin.set_enabled(false);
 #endif
   _ssh_remote_admin.set_text(_("SSH login based management"));
-  _ssh_remote_admin.signal_toggled().connect(sigc::mem_fun(this, &HostAndRemoteTypePage::toggle_remote_admin));
+  scoped_connect(_ssh_remote_admin.signal_toggled(),boost::bind(&HostAndRemoteTypePage::toggle_remote_admin, this));
 
   _management_type_box.add(&_no_remote_admin, false, true);
   _management_type_box.add(&_win_remote_admin, false, true);
@@ -545,7 +545,7 @@ HostAndRemoteTypePage::HostAndRemoteTypePage(WizardForm* host)
   _os_label.set_text(_("Operating System:"));
   _params.add(&_os_label, 0, 1, 0, 1, mforms::HFillFlag);
   _params.add(&_os_selector, 1, 2, 0, 1, mforms::HFillFlag|mforms::HExpandFlag);
-  _os_selector.signal_changed().connect(sigc::mem_fun(this, &HostAndRemoteTypePage::refresh_profile_list));
+  scoped_connect(_os_selector.signal_changed(),boost::bind(&HostAndRemoteTypePage::refresh_profile_list, this));
 
   _type_label.set_text_align(mforms::MiddleRight);
   _type_label.set_text(_("MySQL Installation Type:"));
@@ -846,7 +846,7 @@ SSHConfigurationPage::SSHConfigurationPage(WizardForm* host)
   _ssh_settings_table.add(&_username, 2, 3, 1, 2, HFillFlag | HExpandFlag);
 
   _use_ssh_key.set_text(_("Authenticate Using SSH Key"));
-  _use_ssh_key.signal_clicked().connect(sigc::mem_fun(this, &SSHConfigurationPage::use_ssh_key_changed));
+  scoped_connect(_use_ssh_key.signal_clicked(),boost::bind(&SSHConfigurationPage::use_ssh_key_changed, this));
   _ssh_settings_table.add(&_use_ssh_key, 1, 5, 4, 5, HFillFlag);
   
   _ssh_path_label.set_text(_("SSH Public Key Path:"));
@@ -862,7 +862,7 @@ SSHConfigurationPage::SSHConfigurationPage(WizardForm* host)
     "~";
 #endif
   _file_selector->initialize(homedir + "/.ssh/id_rsa", mforms::OpenFile, "", "...", true,
-    sigc::mem_fun(this, &WizardPage::validate));
+    boost::bind(&WizardPage::validate, this));
   use_ssh_key_changed();
   
   add(&_ssh_settings_table, false, true);
@@ -978,7 +978,7 @@ WindowsManagementPage::WindowsManagementPage(WizardForm* host, wb::WBContext* co
     "find the configuration file."));
   _layout_table.add(&_service_label, 0, 4, 3, 4, HFillFlag | VFillFlag);
 
-  _service_selector.signal_changed().connect(sigc::mem_fun(this, &WindowsManagementPage::refresh_config_path));
+  scoped_connect(_service_selector.signal_changed(),boost::bind(&WindowsManagementPage::refresh_config_path, this));
   _layout_table.add(&_service_selector, 1, 4, 4, 5, HFillFlag);
 
   _config_path_label.set_text(_("Path to Configuration File:"));
@@ -989,7 +989,7 @@ WindowsManagementPage::WindowsManagementPage(WizardForm* host, wb::WBContext* co
 
   // Setup for configuration file browsing.
   _file_selector= mforms::manage(new FsObjectSelector(&_browse_button, &_config_path));
-  _file_selector->initialize("", mforms::OpenFile, "", "...", true, sigc::mem_fun(this, &WizardPage::validate));
+  _file_selector->initialize("", mforms::OpenFile, "", "...", true, boost::bind(&WizardPage::validate, this));
 
   add(&_layout_table, false, true);
 }
@@ -1195,15 +1195,15 @@ TestHostMachineSettingsPage::TestHostMachineSettingsPage(WizardForm* host)
   set_heading(_("The connection to the host machine is being tested. This might take a few "
     "moments depending on your network connection."));
   _connect_task= add_task(_("Connect to host machine"),
-    sigc::mem_fun(this, &TestHostMachineSettingsPage::connect_to_host),
+    boost::bind(&TestHostMachineSettingsPage::connect_to_host, this),
     _("Trying to find host machine and connecting to it..."));
 
   _commands_task = add_async_task(_("Check location of start/stop commands"),
-    sigc::mem_fun(this, &TestHostMachineSettingsPage::check_admin_commands),
+    boost::bind(&TestHostMachineSettingsPage::check_admin_commands, this),
     _("Checking if commands to start and stop server are in the expected location..."));
 
   add_async_task(_("Check MySQL configuration file"),
-    sigc::mem_fun(this, &TestHostMachineSettingsPage::find_config_file),
+    boost::bind(&TestHostMachineSettingsPage::find_config_file, this),
     _("Looking for the configuration file of the database server..."));
 
   end_adding_tasks(true, _("Testing host machine settings is done."));
@@ -1240,7 +1240,7 @@ bool TestHostMachineSettingsPage::find_config_file()
 {
   // Native remote Windows management uses a direct URI for the files.
   bool use_local = wizard()->is_local() || values().get_int("windowsAdmin", 0) == 1;
-  execute_grt_task(sigc::bind(sigc::mem_fun(wizard(), &NewServerInstanceWizard::test_setting_grt),
+  execute_grt_task(boost::bind(&NewServerInstanceWizard::test_setting_grt, wizard(), _1,
                               use_local ? "find_config_file/local" : "find_config_file"), false);
   return true;
 }
@@ -1250,7 +1250,7 @@ bool TestHostMachineSettingsPage::find_config_file()
 bool TestHostMachineSettingsPage::find_error_files()
 {
   bool use_local = wizard()->is_local() || values().get_int("windowsAdmin", 0) == 1;
-  execute_grt_task(sigc::bind(sigc::mem_fun(wizard(), &NewServerInstanceWizard::test_setting_grt),
+  execute_grt_task(boost::bind(&NewServerInstanceWizard::test_setting_grt, wizard(), _1,
                               use_local ? "find_error_files/local" : "find_error_files"), false);
   return true;
 }
@@ -1259,7 +1259,7 @@ bool TestHostMachineSettingsPage::find_error_files()
 
 bool TestHostMachineSettingsPage::check_admin_commands()
 {
-  execute_grt_task(sigc::bind(sigc::mem_fun(wizard(), &NewServerInstanceWizard::test_setting_grt),
+  execute_grt_task(boost::bind(&NewServerInstanceWizard::test_setting_grt, wizard(), _1, 
                               wizard()->is_local() ? "check_admin_commands/local" : "check_admin_commands"), false);
   return true;
 }
@@ -1452,10 +1452,10 @@ PathsPage::PathsPage(WizardForm* host, wb::WBContext* context)
   
   // Setup for local config file browsing. This will be adjusted if we are at a remote location.
   _file_selector= mforms::manage(new FsObjectSelector(&_browse_button, &_config_path));
-  _file_selector->initialize("", mforms::OpenFile, "", "...", true, sigc::mem_fun(this, &WizardPage::validate));
+  _file_selector->initialize("", mforms::OpenFile, "", "...", true, boost::bind(&WizardPage::validate, this));
 
   _test_config_path_button.set_text(_("Check Path"));
-  _test_config_path_button.signal_clicked().connect(sigc::mem_fun(this, &PathsPage::test_path));
+  scoped_connect(_test_config_path_button.signal_clicked(),boost::bind(&PathsPage::test_path, this));
   _content.add(&_test_config_path_button, 1, 2, 2, 3, HFillFlag);
   _test_config_path_description.set_text(_("Click to test if your path is correct."));
   _content.add(&_test_config_path_description, 2, 3, 2, 3, HFillFlag | HExpandFlag);
@@ -1466,7 +1466,7 @@ PathsPage::PathsPage(WizardForm* host, wb::WBContext* context)
   _content.add(&_section_name, 1, 3, 3, 4, HFillFlag);
   
   _test_section_button.set_text(_("Check Name"));
-  _test_section_button.signal_clicked().connect(sigc::mem_fun(this, &PathsPage::test_section));
+  scoped_connect(_test_section_button.signal_clicked(),boost::bind(&PathsPage::test_section, this));
   _content.add(&_test_section_button, 1, 2, 4, 5, HFillFlag);
   _test_section_description.set_text(_("Click to test if your instance name is correct."));
   _content.add(&_test_section_description, 2, 3, 4, 5, HFillFlag | HExpandFlag);
@@ -1502,7 +1502,7 @@ void PathsPage::enter(bool advancing)
   if (ssh_management)
   {
     // Setup for remote browsing.
-    _file_selector->set_browse_callback(sigc::mem_fun(this, &PathsPage::browse_remote_config_file));
+    _file_selector->set_browse_callback(boost::bind(&PathsPage::browse_remote_config_file, this));
   }
   
 }
