@@ -18,6 +18,7 @@
  */
 
 #include "stdafx.h"
+
 #include "preferences_form.h"
 #include "mforms/mforms.h"
 #include "mforms/widgets.h"
@@ -163,8 +164,8 @@ PreferencesForm::PreferencesForm(wb::WBContextUI *wbui, const std::string &model
   _button_box.set_spacing(8);
   _button_box.set_homogeneous(true);
 
-  _ok_button.signal_clicked().connect(sigc::mem_fun(this, &PreferencesForm::ok_clicked));
-  _cancel_button.signal_clicked().connect(sigc::mem_fun(this, &PreferencesForm::cancel_clicked));
+  scoped_connect(_ok_button.signal_clicked(),boost::bind(&PreferencesForm::ok_clicked, this));
+  scoped_connect(_cancel_button.signal_clicked(),boost::bind(&PreferencesForm::cancel_clicked, this));
 
   _cancel_button.set_text(_("Cancel"));
   _cancel_button.enable_internal_padding(true);
@@ -181,7 +182,7 @@ PreferencesForm::PreferencesForm(wb::WBContextUI *wbui, const std::string &model
     _use_global.set_front_color("#FFFFFF");
 #endif
     _bottom_box.add(&_use_global, true, true);
-    _use_global.signal_clicked().connect(sigc::mem_fun(this, &PreferencesForm::toggle_use_global));
+    scoped_connect(_use_global.signal_clicked(),boost::bind(&PreferencesForm::toggle_use_global, this));
   }
 
   if (model_id.empty())
@@ -368,8 +369,8 @@ mforms::TextEntry *PreferencesForm::new_entry_option(const std::string &option_n
   mforms::TextEntry *entry= new mforms::TextEntry();
 
   option->view= mforms::manage(entry);
-  option->show_value= sigc::bind(sigc::mem_fun(this, &PreferencesForm::show_entry_option), option_name, entry, numeric);
-  option->update_value= sigc::bind(sigc::mem_fun(this, &PreferencesForm::update_entry_option), option_name, entry, numeric);
+  option->show_value= boost::bind(&PreferencesForm::show_entry_option, this, option_name, entry, numeric);
+  option->update_value= boost::bind(&PreferencesForm::update_entry_option, this, option_name, entry, numeric);
   _options.push_back(option);
 
   return entry;
@@ -384,8 +385,8 @@ mforms::FsObjectSelector *PreferencesForm::new_path_option(const std::string &op
   entry->initialize("", file ? mforms::OpenFile : mforms::OpenDirectory, "");
   
   option->view= mforms::manage(entry);
-  option->show_value= sigc::bind(sigc::mem_fun(this, &PreferencesForm::show_path_option), option_name, entry);
-  option->update_value= sigc::bind(sigc::mem_fun(this, &PreferencesForm::update_path_option), option_name, entry);
+  option->show_value= boost::bind(&PreferencesForm::show_path_option, this, option_name, entry);
+  option->update_value= boost::bind(&PreferencesForm::update_path_option, this, option_name, entry);
   _options.push_back(option);
   
   return entry;
@@ -398,8 +399,8 @@ mforms::TextEntry *PreferencesForm::new_numeric_entry_option(const std::string &
   mforms::TextEntry *entry= new mforms::TextEntry();
   
   option->view= mforms::manage(entry);
-  option->show_value= sigc::bind(sigc::mem_fun(this, &PreferencesForm::show_entry_option), option_name, entry, true);
-  option->update_value= sigc::bind(sigc::mem_fun(this, &PreferencesForm::update_entry_option_numeric), option_name, entry, minrange, maxrange);
+  option->show_value= boost::bind(&PreferencesForm::show_entry_option, this, option_name, entry, true);
+  option->update_value= boost::bind(&PreferencesForm::update_entry_option_numeric, this, option_name, entry, minrange, maxrange);
   _options.push_back(option);
   
   return entry;  
@@ -412,8 +413,8 @@ mforms::CheckBox *PreferencesForm::new_checkbox_option(const std::string &option
   mforms::CheckBox *checkbox= new mforms::CheckBox();
 
   option->view= mforms::manage(checkbox);
-  option->show_value= sigc::bind(sigc::mem_fun(this, &PreferencesForm::show_checkbox_option), option_name, checkbox);
-  option->update_value= sigc::bind(sigc::mem_fun(this, &PreferencesForm::update_checkbox_option), option_name, checkbox);
+  option->show_value= boost::bind(&PreferencesForm::show_checkbox_option, this, option_name, checkbox);
+  option->update_value= boost::bind(&PreferencesForm::update_checkbox_option, this, option_name, checkbox);
   _options.push_back(option);
 
   return checkbox;
@@ -447,8 +448,8 @@ mforms::Selector *PreferencesForm::new_selector_option(const std::string &option
   }
 
   option->view= mforms::manage(selector);
-  option->show_value= sigc::bind(sigc::mem_fun(this, &PreferencesForm::show_selector_option), option_name, selector, choices);
-  option->update_value= sigc::bind(sigc::mem_fun(this, &PreferencesForm::update_selector_option), option_name, selector, choices, choices.empty() ? "" : choices[0], as_number);
+  option->show_value= boost::bind(&PreferencesForm::show_selector_option, this, option_name, selector, choices);
+  option->update_value= boost::bind(&PreferencesForm::update_selector_option, this, option_name, selector, choices, choices.empty() ? "" : choices[0], as_number);
   _options.push_back(option);
 
   return selector;
@@ -862,9 +863,11 @@ void PreferencesForm::create_general_page()
                                _("Whether to place sidebar on the left or right side in module windows.\n"
                                  "Clear this checbox to place sidebar on the left side."));
     
+#ifdef _WIN32
     table->add_checkbox_option("SingleInstance", _("Only allow one instance of MySQL Workbench to run"), 
       _("Determines if only one or multiple instances of MySQL Workbench can run at the same time for "
-      "a single user."));
+      "a single user.\nThis option requires a restart."));
+#endif
 
     mforms::Selector *combo= new_selector_option("grtshell:ShellLanguage");
     table->add_option(combo, _("Interactive GRT Shell language:"), 
@@ -1015,7 +1018,7 @@ void PreferencesForm::create_mysql_page()
 
   {
     mforms::Panel *frame= mforms::manage(new mforms::Panel(mforms::TitledBoxPanel));
-    frame->set_title(_("Table Defaults"));
+    frame->set_title(_("Model Table Defaults"));
 
     mforms::Box *tbox= mforms::manage(new mforms::Box(true));
 
@@ -1029,7 +1032,7 @@ void PreferencesForm::create_mysql_page()
     box->add(frame, false);
   }
 
-  _tabview.add_page(box, _("MySQL"));
+  _tabview.add_page(box, _("Model: MySQL"));
 }
 
 
@@ -1232,8 +1235,8 @@ void PreferencesForm::create_appearance_page()
     Option *option= new Option();
     _options.push_back(option);
     option->view= text;
-    option->show_value= sigc::bind(sigc::ptr_fun(show_text_option), get_options(), "workbench.model.ObjectFigure:ColorList", text);
-    option->update_value= sigc::bind(sigc::ptr_fun(update_text_option), get_options(), "workbench.model.ObjectFigure:ColorList", text);
+    option->show_value= boost::bind(show_text_option, get_options(), "workbench.model.ObjectFigure:ColorList", text);
+    option->update_value= boost::bind(update_text_option, get_options(), "workbench.model.ObjectFigure:ColorList", text);
     
     table->add(new_label(_("Colors available for layers, notes etc")), 1, 2, 0, 1, mforms::HFillFlag);
     text= new mforms::TextBox(mforms::VerticalScrollBar);
@@ -1243,8 +1246,8 @@ void PreferencesForm::create_appearance_page()
     option= new Option();
     _options.push_back(option);
     option->view= text;
-    option->show_value= sigc::bind(sigc::ptr_fun(show_text_option), get_options(), "workbench.model.Figure:ColorList", text);
-    option->update_value= sigc::bind(sigc::ptr_fun(update_text_option), get_options(), "workbench.model.Figure:ColorList", text);
+    option->show_value= boost::bind(&show_text_option, get_options(), "workbench.model.Figure:ColorList", text);
+    option->update_value= boost::bind(&update_text_option, get_options(), "workbench.model.Figure:ColorList", text);
 
 
     box->add(frame, false);
@@ -1297,16 +1300,16 @@ void PreferencesForm::create_test_page()
   Button* file_btn = manage(new Button());
   file_btn->set_text("...");
   file_btn->enable_internal_padding(false);
-  file_btn->signal_clicked().connect(sigc::mem_fun(this, &PreferencesForm::test_clicked));
+ // file_btn->signal_clicked().connect(boost::bind(&PreferencesForm::test_clicked, this));
   file_path->add(file_btn, false, false);
   
   content->add(file_path, false, true);
   _tabview.add_page(content, _("Test page"));
 }
 
-void PreferencesForm::test_clicked()
+void PreferencesForm::test_clicked(const std::string& url)
 {
-  //Utilities::move_to_trash("D:\\New Text Document.txt");
+  Utilities::show_message("Link clicked", url, "OK");
 }
 
 #endif
