@@ -33,8 +33,8 @@ public:
   struct Option
   {
     mforms::View *view;
-    sigc::slot<void> show_value;
-    sigc::slot<void> update_value;
+    boost::function<void ()> show_value;
+    boost::function<void ()> update_value;
   };
   
 private:
@@ -57,7 +57,7 @@ private:
   std::string _model_id; // "" unless we're showing model specific options
   wb::WBContextUI *_wbui;
 
-  sigc::slot<std::string,std::string,std::string> _edit_font;
+  boost::function<std::string (std::string,std::string)> _edit_font;
   
   mforms::TextEntry *new_entry_option(const std::string &option, bool numeric);
   mforms::FsObjectSelector *new_path_option(const std::string &option, bool file);  
@@ -67,7 +67,7 @@ private:
 
   void ok_clicked();
   void cancel_clicked();
-  void test_clicked();
+  void test_clicked(const std::string&);
   
   void show_values();
   void update_values();
@@ -109,7 +109,7 @@ public:
   virtual ~PreferencesForm();
   
   // returned font, title, current font
-  void set_font_panel_function(const sigc::slot<std::string,std::string,std::string> &edit_font);
+  void set_font_panel_function(const boost::function<std::string (std::string,std::string)> &edit_font);
 
   void show();
 };
