@@ -216,7 +216,7 @@ ServerInstanceEditor::ServerInstanceEditor(bec::GRTManager *grtm, const db_mgmt_
     hbox->add(&_name_entry, true, true);
     hbox->set_padding(12);
     hbox->set_spacing(MF_TABLE_COLUMN_SPACING);
-    _name_entry.signal_changed().connect(sigc::bind(sigc::mem_fun(this, &ServerInstanceEditor::entry_changed),
+    scoped_connect(_name_entry.signal_changed(),boost::bind(&ServerInstanceEditor::entry_changed, this, 
                                                     &_name_entry));
     
     _content_box.add(hbox, false, true);
@@ -224,7 +224,7 @@ ServerInstanceEditor::ServerInstanceEditor(bec::GRTManager *grtm, const db_mgmt_
     _top_hbox.add(&_content_box, true, true);
   }
   
-  _stored_instance_list.signal_changed().connect(sigc::mem_fun(this, &ServerInstanceEditor::instance_changed));  
+  scoped_connect(_stored_instance_list.signal_changed(),boost::bind(&ServerInstanceEditor::instance_changed, this));  
   
   _conn_box.set_padding(MF_PANEL_PADDING);
   _remote_param_box.set_padding(MF_PANEL_PADDING);
@@ -263,11 +263,11 @@ ServerInstanceEditor::ServerInstanceEditor(bec::GRTManager *grtm, const db_mgmt_
     _conn_box.add(bbox, false, true);
     Button *b = manage(new Button());
     b->set_text("Manage Connections...");
-    b->signal_clicked().connect(sigc::bind(sigc::mem_fun(this, &ServerInstanceEditor::open_editor), false));
+    scoped_connect(b->signal_clicked(),boost::bind(&ServerInstanceEditor::open_editor, this, false));
     bbox->add_end(b, false, true);
     b = manage(new Button());
     b->set_text("Edit Selected...");
-    b->signal_clicked().connect(sigc::bind(sigc::mem_fun(this, &ServerInstanceEditor::open_editor), true));
+    scoped_connect(b->signal_clicked(),boost::bind(&ServerInstanceEditor::open_editor, this, true));
     bbox->add_end(b, false, true);
     
     Box *verbox = manage(new Box(true));
@@ -276,14 +276,13 @@ ServerInstanceEditor::ServerInstanceEditor(bec::GRTManager *grtm, const db_mgmt_
     
     verbox->add(manage(new Label(_("MySQL Server Version:"))), false, true);
     verbox->add(&_server_version, true, true);
-    _server_version.signal_changed().connect(sigc::bind(sigc::mem_fun(this, &ServerInstanceEditor::entry_changed),
-                                                        &_server_version));
+    scoped_connect(_server_version.signal_changed(),boost::bind(&ServerInstanceEditor::entry_changed, this, &_server_version));
     b = manage(new Button());
     b->set_text("Connect and Check...");
-    b->signal_clicked().connect(sigc::mem_fun(this, &ServerInstanceEditor::check_version));
+    scoped_connect(b->signal_clicked(),boost::bind(&ServerInstanceEditor::check_version, this));
     verbox->add(b, false, true);
     
-    _connection_selector.signal_changed().connect(sigc::mem_fun(this, &ServerInstanceEditor::connection_changed));
+    scoped_connect(_connection_selector.signal_changed(),boost::bind(&ServerInstanceEditor::connection_changed, this));
     panel->add(&_conn_box);
     vbox->add(panel, false, true);
   }
@@ -299,14 +298,14 @@ ServerInstanceEditor::ServerInstanceEditor(bec::GRTManager *grtm, const db_mgmt_
     mforms::Table* remote_param_table = NewTable(6, 2);
     
     _no_remote_admin.set_text(_("Do not use remote management"));
-    _no_remote_admin.signal_toggled().connect(sigc::mem_fun(this, &ServerInstanceEditor::toggle_administration));
+    scoped_connect(_no_remote_admin.signal_toggled(),boost::bind(&ServerInstanceEditor::toggle_administration, this));
     _win_remote_admin.set_text(_("Native Windows remote management (only available on Windows)"));
-    _win_remote_admin.signal_toggled().connect(sigc::mem_fun(this, &ServerInstanceEditor::toggle_administration));
+    scoped_connect(_win_remote_admin.signal_toggled(),boost::bind(&ServerInstanceEditor::toggle_administration, this));
 #ifndef _WIN32
     _win_remote_admin.set_enabled(false);
 #endif
     _ssh_remote_admin.set_text(_("SSH login based management"));
-    _ssh_remote_admin.signal_toggled().connect(sigc::mem_fun(this, &ServerInstanceEditor::toggle_administration));
+    scoped_connect(_ssh_remote_admin.signal_toggled(),boost::bind(&ServerInstanceEditor::toggle_administration, this));
 
     remote_admin_box->add(&_no_remote_admin, false, true);
     remote_admin_box->add(&_win_remote_admin, false, true);
@@ -321,20 +320,20 @@ ServerInstanceEditor::ServerInstanceEditor(bec::GRTManager *grtm, const db_mgmt_
 
     _remote_host.set_size(200, -1);
     box->add(&_remote_host, true, true);
-    _remote_host.signal_changed().connect(
-      sigc::bind(sigc::mem_fun(this, &ServerInstanceEditor::entry_changed), &_remote_host));
+    scoped_connect(_remote_host.signal_changed(),
+      boost::bind(&ServerInstanceEditor::entry_changed, this, &_remote_host));
     
     box->add(manage(RLabel(_("Port:"))), false, true);
     _ssh_port.set_size(50, -1);
     box->add(&_ssh_port, true, true);
-    _ssh_port.signal_changed().connect(
-      sigc::bind(sigc::mem_fun(this, &ServerInstanceEditor::entry_changed), &_ssh_port));
+    scoped_connect(_ssh_port.signal_changed(),
+      boost::bind(&ServerInstanceEditor::entry_changed, this, &_ssh_port));
     remote_param_table->add(box, 1, 2, 0, 1, HFillFlag | HExpandFlag);
     
     remote_param_table->add(manage(RLabel(_("Username:"))), 0, 1, 1, 2, HFillFlag);
     remote_param_table->add(&_remote_user, 1, 2, 1, 2, HExpandFlag|HFillFlag);
-    _remote_user.signal_changed().connect(
-      sigc::bind(sigc::mem_fun(this, &ServerInstanceEditor::entry_changed), &_remote_user));
+    scoped_connect(_remote_user.signal_changed(),
+      boost::bind(&ServerInstanceEditor::entry_changed, this,  &_remote_user));
     remote_param_table->add(manage(RLabel(_("Password:"))), 0, 1, 2, 3, HFillFlag);
     remote_param_table->add(&_password_box, 1, 2, 2, 3, HExpandFlag|HFillFlag);
 
@@ -350,28 +349,35 @@ ServerInstanceEditor::ServerInstanceEditor(bec::GRTManager *grtm, const db_mgmt_
     _password_clear.set_tooltip(_("Remove previously stored password from the system's keychain"));
 #endif
 
-    _password_set.signal_clicked().connect(sigc::bind(sigc::mem_fun(this, &ServerInstanceEditor::set_password), false));
-    _password_clear.signal_clicked().connect(sigc::bind(sigc::mem_fun(this, &ServerInstanceEditor::set_password), true));
+    scoped_connect(_password_set.signal_clicked(),boost::bind(&ServerInstanceEditor::set_password, this, false));
+    scoped_connect(_password_clear.signal_clicked(),boost::bind(&ServerInstanceEditor::set_password, this, true));
     
     _password_box.set_spacing(8);
     _password_box.add(&_password_set, true, true);
     _password_box.add(&_password_clear, true, true);
     
     _ssh_usekey.set_text(_("Authenticate Using SSH Key"));
-    _ssh_usekey.signal_clicked().connect(
-      sigc::bind(sigc::mem_fun(this, &ServerInstanceEditor::check_changed), &_ssh_usekey));
+    scoped_connect(_ssh_usekey.signal_clicked(),
+      boost::bind(&ServerInstanceEditor::check_changed, this, &_ssh_usekey));
     remote_param_table->add(&_ssh_usekey, 1, 2, 3, 4, HFillFlag);
 
-    remote_param_table->add(RLabel(_("SSH Key Path:")), 0, 1, 4, 5, HFillFlag);
+    mforms::Label *l;
+    remote_param_table->add(l = RLabel(_("SSH Key Path:")), 0, 1, 4, 5, HFillFlag);
     box= manage(new Box(true));
     box->set_spacing(MF_TABLE_COLUMN_SPACING);
     box->add(&_ssh_keypath, true, true);
-    _ssh_keypath.signal_changed().connect(sigc::bind(sigc::mem_fun(this, &ServerInstanceEditor::entry_changed), 
+    l->set_tooltip(_("Path to the SSH private key to use for connecting to the remote SSH server.\n"
+                     "The key must be in the format used by OpenSSH. If you do not use OpenSSH to\n"
+                     "generate the key (ssh-keygen), you may need to convert your key to that format."));
+    _ssh_keypath.set_tooltip(_("Path to the SSH private key to use for connecting to the remote SSH server.\n"
+                               "The key must be in the format used by OpenSSH. If you do not use OpenSSH to\n"
+                               "generate the key (ssh-keygen), you may need to convert your key to that format."));
+    scoped_connect(_ssh_keypath.signal_changed(),boost::bind(&ServerInstanceEditor::entry_changed, this,  
                                                   &_ssh_keypath));
     Button *b = manage(new Button());
     b->set_text(_("Browse"));
     box->add(b, false, true);
-    b->signal_clicked().connect(sigc::mem_fun(this, &ServerInstanceEditor::browse_file));
+    scoped_connect(b->signal_clicked(),boost::bind(&ServerInstanceEditor::browse_file, this));
     remote_param_table->add(box, 1, 2, 4, 5, HFillFlag);
 
     remote_admin_box->add(&_remote_param_box, true, true);
@@ -389,7 +395,7 @@ ServerInstanceEditor::ServerInstanceEditor(bec::GRTManager *grtm, const db_mgmt_
                                      "such as operating system type, path to configuration file, how to start/stop MySQL etc"));
     
     box->add(&_autodetect_button, true, false);
-    _autodetect_button.signal_clicked().connect(sigc::mem_fun(this, &ServerInstanceEditor::autodetect_system));
+    scoped_connect(_autodetect_button.signal_clicked(),boost::bind(&ServerInstanceEditor::autodetect_system, this));
   }
   
   
@@ -410,13 +416,13 @@ ServerInstanceEditor::ServerInstanceEditor(bec::GRTManager *grtm, const db_mgmt_
     {
       table->add(manage(RLabel(_("System Type:"))), 0, 1, 0, 1, HFillFlag);
       table->add(&_os_type, 1, 2, 0, 1, HFillFlag | HExpandFlag);
-      _os_type.signal_changed().connect(sigc::mem_fun(this, &ServerInstanceEditor::system_type_changed));
+      scoped_connect(_os_type.signal_changed(),boost::bind(&ServerInstanceEditor::system_type_changed, this));
     }
     {
       label= manage(RLabel(_("Installation Type:")));
       table->add(label, 0, 1, 1, 2, HFillFlag);
 
-      _sys_profile_type.signal_changed().connect(sigc::mem_fun(this, &ServerInstanceEditor::profile_changed));
+      scoped_connect(_sys_profile_type.signal_changed(),boost::bind(&ServerInstanceEditor::profile_changed, this));
       table->add(&_sys_profile_type, 1, 2, 1, 2, HFillFlag | HExpandFlag);
     }
 
@@ -429,20 +435,20 @@ ServerInstanceEditor::ServerInstanceEditor(bec::GRTManager *grtm, const db_mgmt_
       _sys_config_path_browse.enable_internal_padding(false);
       _sys_config_path_browse.set_text("...");
       box->add(&_sys_config_path_browse, false, true);
-      _sys_config_path_browse.signal_clicked().connect(sigc::bind(sigc::mem_fun(this, &ServerInstanceEditor::run_filechooser_wrapper), &_sys_config_path));
+      scoped_connect(_sys_config_path_browse.signal_clicked(),boost::bind(&ServerInstanceEditor::run_filechooser_wrapper, this, &_sys_config_path));
       table->add(box, 1, 2, 2, 3, HFillFlag | HExpandFlag);
     }
 
-    _sys_config_path.signal_changed().connect(sigc::bind(sigc::mem_fun(this, &ServerInstanceEditor::entry_changed), 
+    scoped_connect(_sys_config_path.signal_changed(),boost::bind(&ServerInstanceEditor::entry_changed, this,  
                                                   &_sys_config_path));
     table->add(manage(RLabel(_("Configuration File Section:"))), 0, 1, 3, 4, HFillFlag);
     table->add(&_sys_myini_section, 1, 2, 3, 4, HFillFlag | HExpandFlag);
-    _sys_myini_section.signal_changed().connect(sigc::bind(sigc::mem_fun(this, &ServerInstanceEditor::entry_changed), 
+    scoped_connect(_sys_myini_section.signal_changed(),boost::bind(&ServerInstanceEditor::entry_changed, this,  
                                                   &_sys_myini_section));
 
     table->add(_sys_win_service_name_label = manage(RLabel(_("Windows Service Name:"))), 0, 1, 4, 5, HFillFlag);
     table->add(&_sys_win_service_name, 1, 2, 4, 5, HFillFlag | HExpandFlag);
-    _sys_win_service_name.signal_changed().connect(sigc::bind(sigc::mem_fun(this, &ServerInstanceEditor::entry_changed), 
+    scoped_connect(_sys_win_service_name.signal_changed(),boost::bind(&ServerInstanceEditor::entry_changed, this,  
                                                   &_sys_win_service_name));
 
     _sys_win_hint_label.set_text(WINDOWS_CONFIG_HINT_TEXT);
@@ -462,11 +468,11 @@ ServerInstanceEditor::ServerInstanceEditor(bec::GRTManager *grtm, const db_mgmt_
     
     table->add(manage(RLabel(_("Start MySQL:"))), 0, 1, 0, 1, HFillFlag);
     table->add(&_start_cmd, 1, 2, 0, 1, HFillFlag | HExpandFlag);
-    _start_cmd.signal_changed().connect(sigc::bind(sigc::mem_fun(this, &ServerInstanceEditor::entry_changed), 
+    scoped_connect(_start_cmd.signal_changed(),boost::bind(&ServerInstanceEditor::entry_changed, this,  
                                                   &_start_cmd));
     table->add(manage(RLabel(_("Stop MySQL:"))), 0, 1, 1, 2, HFillFlag);
     table->add(&_stop_cmd, 1, 2, 1, 2, HFillFlag | HExpandFlag);    
-    _stop_cmd.signal_changed().connect(sigc::bind(sigc::mem_fun(this, &ServerInstanceEditor::entry_changed), 
+    scoped_connect(_stop_cmd.signal_changed(),boost::bind(&ServerInstanceEditor::entry_changed, this,  
                                                   &_stop_cmd));
 
     table->add(&_sudo_check, 1, 2, 2, 3, HFillFlag | HExpandFlag);
@@ -475,13 +481,13 @@ ServerInstanceEditor::ServerInstanceEditor(bec::GRTManager *grtm, const db_mgmt_
 #else
     _sudo_check.set_text(_("Acquire administrator rights to execute start/stop commands\nand write configuration data"));
 #endif
-    _sudo_check.signal_clicked().connect(sigc::bind(sigc::mem_fun(this, &ServerInstanceEditor::check_changed), 
+    scoped_connect(_sudo_check.signal_clicked(),boost::bind(&ServerInstanceEditor::check_changed, this, 
                                                   &_sudo_check));
 
 
     table->add(manage(RLabel(_("Check MySQL Status:"))), 0, 1, 3, 4, HFillFlag);
     table->add(&_status_cmd, 1, 2, 3, 4, HFillFlag | HExpandFlag);
-    _status_cmd.signal_changed().connect(sigc::bind(sigc::mem_fun(this, &ServerInstanceEditor::entry_changed), 
+    scoped_connect(_status_cmd.signal_changed(),boost::bind(&ServerInstanceEditor::entry_changed, this,  
                                                   &_status_cmd));
 
 
@@ -491,7 +497,7 @@ ServerInstanceEditor::ServerInstanceEditor(bec::GRTManager *grtm, const db_mgmt_
 #else
     _sudo_status_check.set_text(_("Acquire administrator rights to execute status commands"));
 #endif
-    _sudo_status_check.signal_clicked().connect(sigc::bind(sigc::mem_fun(this, &ServerInstanceEditor::check_changed), 
+    scoped_connect(_sudo_status_check.signal_clicked(),boost::bind(&ServerInstanceEditor::check_changed, this, 
                                                   &_sudo_status_check));
 
     table->add(manage(RLabel(_("Sudo command:"))), 0, 1, 5, 6, HFillFlag|VExpandFlag);
@@ -500,14 +506,14 @@ ServerInstanceEditor::ServerInstanceEditor(bec::GRTManager *grtm, const db_mgmt_
       box->add(&_sudo_cmd, true, true);
 
       table->add(box, 1, 2, 5, 6, HFillFlag | HExpandFlag);    
-      _sudo_cmd.signal_changed().connect(sigc::bind(sigc::mem_fun(this, &ServerInstanceEditor::selector_changed), 
+      scoped_connect(_sudo_cmd.signal_changed(),boost::bind(&ServerInstanceEditor::selector_changed, this,
                                                     &_sudo_cmd));
     }
 
     {
       Box *stats_box = manage(new Box(false));
       _details_tabview.add_page(stats_box, _("Server Stats"));    
-      _script_text.signal_changed().connect(sigc::bind(sigc::mem_fun(this, &ServerInstanceEditor::text_changed), 
+      scoped_connect(_script_text.signal_changed(),boost::bind(&ServerInstanceEditor::text_changed, this, 
                                                   &_script_text));
 
       stats_box->add(&_script_text, true, true);
@@ -518,12 +524,12 @@ ServerInstanceEditor::ServerInstanceEditor(bec::GRTManager *grtm, const db_mgmt_
       Button* help_filters_button  = manage(new Button());
       help_filters_button->set_text(_("Filters Help"));
       box->add_end(help_filters_button, false, true);
-      help_filters_button->signal_clicked().connect(sigc::mem_fun(this, &ServerInstanceEditor::show_filter_help));
+      scoped_connect(help_filters_button->signal_clicked(),boost::bind(&ServerInstanceEditor::show_filter_help, this));
       
       Button* test_filters_button  = manage(new Button());
       test_filters_button->set_text(_("Filters Debugger"));
       box->add_end(test_filters_button, false, true);
-      test_filters_button->signal_clicked().connect(sigc::mem_fun(this, &ServerInstanceEditor::run_filters_debugger));
+      scoped_connect(test_filters_button->signal_clicked(),boost::bind(&ServerInstanceEditor::run_filters_debugger, this));
 
       stats_box->add(box, false, false);
     }
@@ -531,17 +537,17 @@ ServerInstanceEditor::ServerInstanceEditor(bec::GRTManager *grtm, const db_mgmt_
   
 
   _dup_inst_button.set_text(_("Duplicate"));
-  _dup_inst_button.signal_clicked().connect(sigc::mem_fun(this, &ServerInstanceEditor::duplicate_instance));
+  scoped_connect(_dup_inst_button.signal_clicked(),boost::bind(&ServerInstanceEditor::duplicate_instance, this));
 
   _del_inst_button.set_text(_("Delete"));
-  _del_inst_button.signal_clicked().connect(sigc::mem_fun(this, &ServerInstanceEditor::delete_instance));
+  scoped_connect(_del_inst_button.signal_clicked(),boost::bind(&ServerInstanceEditor::delete_instance, this));
   _add_inst_button.set_text(_("New"));
-  _add_inst_button.signal_clicked().connect(sigc::mem_fun(this, &ServerInstanceEditor::add_instance));
+  scoped_connect(_add_inst_button.signal_clicked(),boost::bind(&ServerInstanceEditor::add_instance, this));
   
   _move_up_button.set_text(_("Move Up"));
-  _move_up_button.signal_clicked().connect(sigc::bind(sigc::mem_fun(this, &ServerInstanceEditor::reorder_instance), true));
+  scoped_connect(_move_up_button.signal_clicked(),boost::bind(&ServerInstanceEditor::reorder_instance, this, true));
   _move_down_button.set_text(_("Move Down"));
-  _move_down_button.signal_clicked().connect(sigc::bind(sigc::mem_fun(this, &ServerInstanceEditor::reorder_instance), false));
+  scoped_connect(_move_down_button.signal_clicked(),boost::bind(&ServerInstanceEditor::reorder_instance, this, false));
   
   _bottom_hbox.add(&_add_inst_button, false, true);
   _bottom_hbox.add(&_del_inst_button, false, true);
@@ -557,7 +563,7 @@ ServerInstanceEditor::ServerInstanceEditor(bec::GRTManager *grtm, const db_mgmt_
 
   _test_button.set_text(_("Test Settings"));
   _test_button.set_enabled(_grtm->get_grt()->get_module("WbAdmin")!=0);
-  _test_button.signal_clicked().connect(sigc::mem_fun(this, &ServerInstanceEditor::test_settings));
+  scoped_connect(_test_button.signal_clicked(),boost::bind(&ServerInstanceEditor::test_settings, this));
   
   _add_inst_button.enable_internal_padding(true);
   _del_inst_button.enable_internal_padding(true);
@@ -808,7 +814,7 @@ void ServerInstanceEditor::run_filechooser(mforms::TextEntry* entry)
     const std::string path = fc.get_path();
     if (!path.empty() || path != "")
       entry->set_value(path);
-    entry->signal_changed().emit();
+    (*entry->signal_changed())();
   }
 }
 
