@@ -14,10 +14,6 @@
 #include <gtkmm/paned.h>
 #include "text_list_columns_model.h"
 
-#ifdef HAVE_LIBGNOME
-#include <libgnome/libgnome.h>
-#endif
-
 #include "treemodel_wrapper.h"
 
 // This list_model is used for all functions which operate on GTKListStore
@@ -50,15 +46,6 @@ Gtk::HBox &create_icon_label(const std::string &icon, const std::string &text)
   return *hbox;
 }
 
-//------------------------------------------------------------------------------
-void open_url(const std::string &url)
-{
-#ifdef HAVE_LIBGNOME
-  gnome_url_show(url.c_str(), NULL);
-#else
-  g_message("Open URL %s (no url handler)", url.c_str());
-#endif
-}
 
 //------------------------------------------------------------------------------
 Glib::RefPtr<Gtk::ListStore> model_from_string_list(const std::vector<std::string>& list, TextListColumnsModel* columns)
@@ -135,6 +122,26 @@ std::string get_selected_combo_item(Gtk::ComboBox *combo)
   return "";
 }
 
+//------------------------------------------------------------------------------
+
+bool set_selected_combo_item(Gtk::ComboBox *combo, const std::string &value)
+{
+  Glib::RefPtr<Gtk::TreeModel> store(combo->get_model());
+
+  for (Gtk::TreeIter end = store->children().end(), iter = store->children().begin();
+      iter != end; ++iter)
+  {
+    Gtk::TreeRow row= *iter;
+    std::string item = row[_wb_list_model.item];
+    if (item == value)
+    {
+      combo->set_active(iter);
+      return true;
+    }
+  }
+  return false;
+}
+
 //------------------------------------------------------------------------------
 void set_glib_string(Glib::ValueBase& value, const std::string& str, bool escape_nuls)
 {
@@ -149,7 +156,7 @@ void set_glib_string(Glib::ValueBase& value, const std::string& str, bool escape
     // skip the \0 bytes so that data is displayed as in OSX
     while (p < length)
     {
-       e = str.find(p, '\0');
+       e = str.find('\0', p);
        if (e == std::string::npos)
          break;
        tmp.append(str.data()+p, e-p);
@@ -191,13 +198,18 @@ void set_glib_double(Glib::ValueBase& value, const double d)
 }
 
 //------------------------------------------------------------------------------
-void fill_combo_from_string_list(Gtk::ComboBoxText* combo, const std::vector<std::string>& list)
+void fill_combo_from_string_list(Gtk::ComboBox* combo, const std::vector<std::string>& list)
 {
   std::vector<std::string>::const_iterator it   = list.begin();
   std::vector<std::string>::const_iterator last = list.end();
 
+  Glib::RefPtr<Gtk::ListStore> store(Glib::RefPtr<Gtk::ListStore>::cast_dynamic(combo->get_model()));
   for (; last != it; ++it )
-    combo->append_text(*it);
+  {
+    Gtk::TreeIter iter = store->append();
+    Gtk::TreeRow row= *iter;
+    row.set_value(0, *it);
+  }
 }
 
 //------------------------------------------------------------------------------
@@ -305,7 +317,7 @@ void expand_tree_nodes_as_in_be(const Glib::RefPtr<TreeModelWrapper> &model, Gtk
     
     for (; last != row; ++row)
     {
-      if (!tv->expand_row(Gtk::TreeModel::Path(*row), true))
+      if (!tv->expand_row(Gtk::TreeModel::Path(*row), false))
         invalid_rows.push_back(*row);
     }
     
@@ -413,7 +425,7 @@ void run_popup_menu(const bec::MenuItemList &items, const int time,
         Gtk::CheckMenuItem* citem = Gtk::manage(new Gtk::CheckMenuItem(cur_item->caption, true));
         item = citem;
         citem->set_active(cur_item->checked);
-        citem->signal_toggle().connect(sigc::bind(activate_slot, cur_item->name));
+        citem->signal_activate().connect(sigc::bind(activate_slot, cur_item->name));
         break;
       }
       case bec::MenuSeparator:
