@@ -519,7 +519,7 @@ ListModelWrapper::ListModelWrapper(bec::ListModel* tm, Gtk::TreeView *treeview,
                     , _self_ref(new ListModelWrapper*(this))
                     , _name(name)
 {
-  tm->tree_changed_signal().connect(sigc::mem_fun(*this, &::ListModelWrapper::model_changed));
+  tm->tree_changed_signal()->connect(sigc::mem_fun(*this, &::ListModelWrapper::model_changed));
   tm->add_destroy_notify_callback(_self_ref, &ListModelWrapper::on_bec_model_destroyed);
   #ifndef NO_MENU_MANAGER
   if (_treeview)
