@@ -675,29 +675,65 @@ void SqlEditorFE::select_all()
   send_editor(SCI_SELECTALL);
 }
 
-void SqlEditorFE::find_text(const std::string &text, bool match_case, bool match_whole_word)
+bool SqlEditorFE::find_text(const std::string &text, bool match_case, bool match_whole_word)
 {
-  TextToFind ttf;
-  int flags = 0;
-  
+  bool wrap= true;
+  bool backwards = false;
+  int searchFlags= 0;
   if (match_case)
-    flags |= SCFIND_MATCHCASE;
+    searchFlags |= SCFIND_MATCHCASE;
   if (match_whole_word)
-    flags |= SCFIND_WHOLEWORD;
+    searchFlags |= SCFIND_WHOLEWORD;
+
+  int selectionStart = send_editor(SCI_GETSELECTIONSTART);
+  int selectionEnd = send_editor(SCI_GETSELECTIONEND);
   
-  ttf.chrg.cpMin = send_editor(SCI_GETSELECTIONEND);
-  ttf.chrg.cpMax = send_editor(SCI_GETLENGTH);
-  ttf.lpstrText = (char*)text.c_str();
-  ttf.chrgText.cpMin = 0;
-  ttf.chrgText.cpMax = text.size();
-  
-  int r = send_editor(SCI_FINDTEXT, flags, (sptr_t)&ttf);
-  if (r >= 0)
+  // Sets the start point for the comming search to the begin of the current selection.
+  // For forward searches we have therefore to set the selection start to the current selection end
+  // for proper incremental search. This does not harm as we either get a new selection if something
+  // is found or the previous selection is restored.
+  if (!backwards)
+    send_editor(SCI_SETSELECTIONSTART, selectionEnd);
+  send_editor(SCI_SEARCHANCHOR, 0);
+  sptr_t result;
+
+  // The following call will also set the selection if something was found.
+  if (backwards)
   {
-    send_editor(SCI_GOTOLINE, send_editor(SCI_LINEFROMPOSITION, ttf.chrgText.cpMin));
-    send_editor(SCI_SETSELECTIONSTART, ttf.chrgText.cpMin);
-    send_editor(SCI_SETSELECTIONEND, ttf.chrgText.cpMax);
+    result = send_editor(SCI_SEARCHPREV, searchFlags, (sptr_t)text.c_str());
+    if (result < 0 && wrap)
+    {
+      // Try again from the end of the document if nothing could be found so far and
+      // wrapped search is set.
+      send_editor(SCI_SETSELECTIONSTART, send_editor(SCI_GETTEXTLENGTH));
+      send_editor(SCI_SEARCHANCHOR, 0);
+      result = send_editor(SCI_SEARCHNEXT, searchFlags, (sptr_t)text.c_str());
+    }
   }
+  else
+  {
+    result = send_editor(SCI_SEARCHNEXT, searchFlags, (sptr_t)text.c_str());
+    if (result < 0 && wrap)
+    {
+      // Try again from the start of the document if nothing could be found so far and
+      // wrapped search is set.
+      send_editor(SCI_SETSELECTIONSTART, 0);
+      send_editor(SCI_SEARCHANCHOR, 0);
+      result = send_editor(SCI_SEARCHNEXT, searchFlags, (sptr_t)text.c_str());
+    }
+  }
+
+  if (result >= 0)
+  {
+      send_editor(SCI_SCROLLCARET);
+  }
+  else
+  {
+    // Restore the former selection if we did not found anything.
+    send_editor(SCI_SETSELECTIONSTART, selectionStart);
+    send_editor(SCI_SETSELECTIONEND, selectionEnd);
+  }
+  return (result >= 0);
 }
 
 
@@ -726,6 +762,13 @@ void SqlEditorFE::redo()
 }
 
 
+void SqlEditorFE::toggle_wrap_lines()
+{
+  const int wrap = (int)send_editor(SCI_GETWRAPMODE);
+  send_editor(SCI_SETWRAPMODE, wrap == 0 ? 1 : 0);
+}
+
+
 bool SqlEditorFE::on_button_press_event(GdkEventButton *event)
 {
   if (event->button == 3 && _be) // right button
@@ -746,6 +789,9 @@ bool SqlEditorFE::on_button_press_event(GdkEventButton *event)
           enabled= has_selection();
         else if (iter->name == "paste")
           enabled= is_editable();
+        else if (iter->name == "toggle_wrap_lines")
+          iter->checked = (bool)send_editor(SCI_GETWRAPMODE);
+
         iter->enabled= enabled;
       }
 
@@ -779,6 +825,8 @@ void SqlEditorFE::activate_menu_action(const std::string &action)
     delete_();
   else if (action == "select_all")
     select_all();
+  else if (action == "toggle_wrap_lines")
+    toggle_wrap_lines();
   else
   {
     try
