@@ -10,8 +10,9 @@
 #include <gtkmm/treeview.h>
 #include "treemodel_wrapper.h"
 #include "workbench/wb_context_ui.h"
+#include "base/trackable.h"
 
-class CatalogTree : public Gtk::ScrolledWindow
+class CatalogTree : public Gtk::ScrolledWindow, public base::trackable
 {
   wb::WBContextUI *_wbui;
   Gtk::TreeView _tree;
