@@ -35,6 +35,7 @@
 #include "base/string_utilities.h"
 #include "mforms/../gtk/lf_menubar.h"
 #include "mforms/../gtk/lf_toolbar.h"
+#include "mforms/../gtk/lf_form.h"
 
 #include <base/log.h>
 ENABLE_LOG("linux.ui")
@@ -125,13 +126,19 @@ MainForm::MainForm(wb::WBContextUI* ctx)
   _gui_locked= false;
 
   //  switch_page(0, 0);
+  mforms::gtk::FormImpl::init_main_form(this->get_mainwindow());
 }
 
 //------------------------------------------------------------------------------
 MainForm::~MainForm()
 {
+  const size_t n_slots = _slots.size();
+  for (size_t i = 0; i < n_slots; ++i)
+    _slots[i].disconnect();
+  _slots.clear();
+
   notify_callbacks(); // disconnect all signals
-  
+
   delete _model_panel;
 }
 
@@ -184,7 +191,7 @@ void MainForm::on_focus_widget(Gtk::Widget *w)
       _wbui_context->set_active_form(form);
   }
 
-  _wbui_context->get_command_ui()->signal_validate_edit_menu_items().emit();
+  (*_wbui_context->get_command_ui()->signal_validate_edit_menu_items())();
 
   // for updating the Edit menu
  //!!! Gtk::Alignment* menu_holder;
@@ -824,7 +831,6 @@ bool MainForm::validate_find_replace()
   return false;
 }
 
-
 void MainForm::register_commands()
 {
   std::list<std::string> commands;
@@ -852,36 +858,35 @@ void MainForm::register_commands()
   _wbui_context->get_command_ui()->add_frontend_commands(commands);
 
   _wbui_context->get_command_ui()->add_builtin_command("search_replace",
-                                               sigc::mem_fun(this, &MainForm::call_find_replace),
-                                               sigc::mem_fun(this, &MainForm::validate_find_replace));
-
+                                               make_slot(&MainForm::call_find_replace),
+                                               make_slot(&MainForm::validate_find_replace));
   _wbui_context->get_command_ui()->add_builtin_command("find",
-                                               sigc::mem_fun(this, &MainForm::call_find),
-                                               sigc::mem_fun(this, &MainForm::validate_find));
+                                               make_slot(&MainForm::call_find),
+                                               make_slot(&MainForm::validate_find));
   _wbui_context->get_command_ui()->add_builtin_command("undo",
-                                               sigc::mem_fun(this, &MainForm::call_undo),
-                                               sigc::mem_fun(this, &MainForm::validate_undo));
+                                               make_slot(&MainForm::call_undo),
+                                               make_slot(&MainForm::validate_undo));
   _wbui_context->get_command_ui()->add_builtin_command("redo",
-                                               sigc::mem_fun(this, &MainForm::call_redo),
-                                               sigc::mem_fun(this, &MainForm::validate_redo));
+                                               make_slot(&MainForm::call_redo),
+                                               make_slot(&MainForm::validate_redo));
   _wbui_context->get_command_ui()->add_builtin_command("copy",
-                                               sigc::mem_fun(this, &MainForm::call_copy),
-                                               sigc::mem_fun(this, &MainForm::validate_copy));
+                                               make_slot(&MainForm::call_copy),
+                                               make_slot(&MainForm::validate_copy));
   _wbui_context->get_command_ui()->add_builtin_command("cut",
-                                               sigc::mem_fun(this, &MainForm::call_cut),
-                                               sigc::mem_fun(this, &MainForm::validate_cut));
+                                               make_slot(&MainForm::call_cut),
+                                               make_slot(&MainForm::validate_cut));
   _wbui_context->get_command_ui()->add_builtin_command("paste",
-                                               sigc::mem_fun(this, &MainForm::call_paste),
-                                               sigc::mem_fun(this, &MainForm::validate_paste));
+                                               make_slot(&MainForm::call_paste),
+                                               make_slot(&MainForm::validate_paste));
   _wbui_context->get_command_ui()->add_builtin_command("delete",
-                                               sigc::mem_fun(this, &MainForm::call_delete),
-                                               sigc::mem_fun(this, &MainForm::validate_delete));
+                                               make_slot(&MainForm::call_delete),
+                                               make_slot(&MainForm::validate_delete));
   _wbui_context->get_command_ui()->add_builtin_command("selectAll",
-                                               sigc::mem_fun(this, &MainForm::call_select_all),
-                                               sigc::mem_fun(this, &MainForm::validate_select_all));
+                                               make_slot(&MainForm::call_select_all),
+                                               make_slot(&MainForm::validate_select_all));
   _wbui_context->get_command_ui()->add_builtin_command("searchbox",
-                                               sigc::mem_fun(this, &MainForm::call_search),
-                                               sigc::mem_fun(this, &MainForm::validate_search));
+                                               make_slot(&MainForm::call_search),
+                                               make_slot(&MainForm::validate_search));
 
 }
 
@@ -1045,8 +1050,7 @@ void MainForm::refresh_gui_becb(wb::RefreshType type, const std::string& arg_id,
 {
   if (_exiting)
     return;
-    
-//  g_message("%s: %i %s: arg=%s, arg_ptr=%p", __FUNCTION__, type, RefreshTypeStr[type], arg_id.c_str(), arg_ptr);
+
   // _overview is OverviewPanel
   switch (type)
   {
@@ -1057,17 +1061,18 @@ void MainForm::refresh_gui_becb(wb::RefreshType type, const std::string& arg_id,
     }
 
   case wb::RefreshCloseDocument:
-    prepare_close_document();
+    {
+      prepare_close_document();
 
-    _wbui_context->get_wb()->flush_idle_tasks();
+      _wbui_context->get_wb()->flush_idle_tasks();
 
-    _wbui_context->get_wb()->close_document_finish();
+      _wbui_context->get_wb()->close_document_finish();
 
-    handle_model_closed();
-    
-    get_mainwindow()->set_title(_wbui_context->get_title());
-    break;
+      handle_model_closed();
 
+      get_mainwindow()->set_title(_wbui_context->get_title());
+      break;
+    }
   case wb::RefreshNothing:
     break;
 
@@ -1285,7 +1290,7 @@ void MainForm::switch_page(GtkNotebookPage*, guint pagenum)
     bec::UIForm* uiform = static_cast<bec::UIForm*>(page->get_data("uiform"));
     _wbui_context->set_active_form(uiform);
   }
-  _wbui_context->get_command_ui()->signal_validate_edit_menu_items().emit();
+  (*_wbui_context->get_command_ui()->signal_validate_edit_menu_items())();
 }
 
 
@@ -1903,7 +1908,15 @@ void MainForm::dock_view(mforms::App *app, mforms::AppView *view, const std::str
       view->get_menubar()->release();
     }
 
-    Gtk::Widget *decorated = self->decorate_widget(w, view);
+    Gtk::Widget *decorated = reinterpret_cast<Gtk::Widget*>(w->get_data("DockDecoration"));
+    if (!decorated)
+    {
+      decorated = self->decorate_widget(w, view);
+      w->set_data("DockDecoration", decorated);
+
+      if (g_object_is_floating(decorated->gobj()))
+        g_object_ref_sink(decorated->gobj()); // turn the floating ref to a normal one
+    }
 
     decorated->set_data("AppView", view);
     decorated->add_destroy_notify_callback(view, (gpointer(*)(gpointer))delete_appview);
