@@ -187,6 +187,16 @@ private:
   Gtk::ProgressBar             _progress_bar;
  
   sigc::signal<void, std::string> _signal_close_editor;
+  typedef std::vector<sigc::slot_base> Slots;
+  Slots     _slots;
+
+  template <typename R, typename T>
+  sigc::slot<R> make_slot(R (T::*t)())
+  {
+    const sigc::slot<R> slot = sigc::mem_fun(this, t);
+    _slots.push_back(slot);
+    return slot;
+  }
 };
 
 #endif
