@@ -166,7 +166,7 @@ private:
     _tree->set_model(_store);
 
     if (_store)
-    expand_tree_nodes_as_in_be(_store, _tree);
+      expand_tree_nodes_as_in_be(_store, _tree);
   }
 
   static bool create(GRTTreeView *self, mforms::TreeOptions options)
@@ -213,14 +213,14 @@ private:
   static bool get_selected_node(GRTTreeView *self, bec::NodeId &node)
   {
     GRTTreeViewImpl* tree = self->get_data<GRTTreeViewImpl>();
-    Gtk::TreeIter iter= tree->_tree->get_selection()->get_selected();
-    if (iter)
-    {
-      node= tree->_store->get_node_for_path(tree->_store->get_path(iter));
-      return true;
-    }
-    return false;
-  }   
+    std::list<Gtk::TreePath> selection= tree->_tree->get_selection()->get_selected_rows();
+    const bool has_items = !selection.empty();
+
+    if (has_items)
+      node = tree->_store->get_node_for_path(*selection.begin());
+
+    return has_items;
+  }
 
 
   static int get_selection(GRTTreeView *self, std::vector<bec::NodeId> &nodes)
