@@ -319,7 +319,7 @@ void ModelDiagramPanel::view_realized()
   _canvas->get_canvas()->set_user_data(dynamic_cast<FormViewBase*>(this));
 
   // changing zoom or scrolling should cancel any editing in place
-  _canvas->get_canvas()->signal_viewport_changed().connect(sigc::mem_fun(_be, &wb::ModelDiagramForm::stop_editing));
+  _be->scoped_connect(_canvas->get_canvas()->signal_viewport_changed(),sigc::mem_fun(_be, &wb::ModelDiagramForm::stop_editing));
 }
 
 
