@@ -11,6 +11,7 @@
 #include <gtkmm/paned.h>
 #include <gtkmm/box.h>
 #include <gtkmm/notebook.h>
+#include <gtkmm/builder.h>
 #include "model/wb_model_diagram_form.h"
 #include "gtk/mdc_gtk_canvas_view.h"
 #include "gtk/mdc_gtk_canvas_scroller.h"
@@ -21,8 +22,6 @@ namespace Gtk
   class Entry;
 };
 
-class MGGladeXML;
-
 class CatalogTree;
 class LayerTree;
 class HistoryTree;
@@ -85,18 +84,19 @@ class ModelDiagramPanel : public Gtk::HPaned, public FormViewBase
 
   void view_realized();
 
-  ModelDiagramPanel(MGGladeXML *xml, GtkHPaned *paned, wb::WBContextUI *wb);
+  void post_construct(wb::WBContextUI *wb, Glib::RefPtr<Gtk::Builder> xml);
 
 public:
   static ModelDiagramPanel *create(wb::WBContextUI *wb);
 
+  ModelDiagramPanel(GtkHPaned *paned, Glib::RefPtr<Gtk::Builder> xml);
   ~ModelDiagramPanel();
 
   void init(const std::string &view_id);
   virtual bec::UIForm *get_form() const { return _be; }
   virtual std::string get_title() { return _be->get_title(); }
   virtual Gtk::Widget *get_panel() { return &_top_box; }
-  virtual bool will_close();
+  virtual bool on_close();
   virtual void toggle_sidebar();
   
   void set_title(const std::string &title);
