@@ -1,11 +1,8 @@
 #include "workbench/wb_overview.h"
 #include "overview_panel.h"
-#include "menu_manager.h"
 #include "treemodel_wrapper.h"
 #include "multi_view.h"
 
-#include "MGGladeXML.h"
-
 #include "grtdb/db_object_helpers.h"
 #include "workbench/wb_model_file.h"
 
