@@ -33,7 +33,18 @@ using base::strfmt;
 Program* Program::_instance = 0;
 
 
-
+static void flush_main_thread()
+{
+  while (Gtk::Main::events_pending())
+  {
+    if (Gtk::Main::iteration(false))
+    {
+      // return value of true means quit() was called 
+      Gtk::Main::quit();
+      break;
+    }
+  }
+}
 
 //------------------------------------------------------------------------------
 Program::Program(wb::WBOptions wboptions)
@@ -120,6 +131,8 @@ Program::Program(wb::WBOptions wboptions)
 
   _wb_context_ui->init(&wbcallbacks, &wboptions);
 
+  _wb_context_ui->get_wb()->get_grt_manager()->get_dispatcher()->set_main_thread_flush_and_wait(flush_main_thread);
+
   {
     std::string form_name;
     sigc::slot<FormViewBase*, boost::shared_ptr<bec::UIForm> > form_creator;
