@@ -734,7 +734,7 @@ bool DbSqlEditorView::on_sql_editor_key_press_event(GdkEventKey *event)
 
 void DbSqlEditorView::on_sql_editor_selection_change()
 {
-  _be->wbsql()->get_wbui()->get_command_ui()->signal_validate_edit_menu_items().emit();
+  (*_be->wbsql()->get_wbui()->get_command_ui()->signal_validate_edit_menu_items())();
 }
 
 int DbSqlEditorView::on_sql_editor_text_insert(const std::string &text)
