@@ -37,7 +37,7 @@
   mforms::Menu *menu = mOwner->get_context_menu();
   if (menu)
   {
-    menu->signal_will_show().emit();
+    (*menu->signal_will_show())();
     return menu->get_data();
   }
   return nil;
