@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,7 +17,6 @@
  * 02110-1301  USA
  */
 
-#import "sigobjc++.h"
 #import "MResultsetViewer.h"
 #include "sqlide/recordset_be.h"
 #import "MQResultSetCell.h"
@@ -71,9 +70,9 @@ static NSImage *descendingSortIndicator= nil;
 
 - (void)dealloc
 {
-  (*mData)->refresh_ui_cb.disconnect();
+  (*mData)->refresh_ui_cb.clear();
   
-  std::for_each(mSigConns.begin(), mSigConns.end(), sigc::mem_fun(&sigc::connection::disconnect));
+  std::for_each(mSigConns.begin(), mSigConns.end(), boost::bind(&boost::signals2::connection::disconnect, _1));
   delete mData;
   [mView release];
   [super dealloc];
@@ -169,9 +168,9 @@ static int processTaskMessage(int msgType, const std::string &message, const std
     
     [mTableView setRecordset: mData->get()];
     
-    (*mData)->refresh_ui_cb= sigc::bind(sigc::ptr_fun(onRefresh), self);
-    mSigConns.push_back((*mData)->refresh_ui_status_bar_signal.connect(sigc::bind(sigc::ptr_fun(updateToolbar), self)));
-    (*mData)->task->msg_cb(sigc::bind(sigc::ptr_fun(processTaskMessage), self));
+    (*mData)->refresh_ui_cb= boost::bind(onRefresh, self);
+    mSigConns.push_back((*mData)->refresh_ui_status_bar_signal.connect(boost::bind(updateToolbar, self)));
+    (*mData)->task->msg_cb(boost::bind(processTaskMessage, _1, _2, _3, self));
     
     [mTableView selectionChangedActionTarget:self];
     [mTableView setSelectionChangedAction:@selector(handleNSTableViewSelectionIsChangingNotification:)];
