@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2011 Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,7 +17,6 @@
  * 02110-1301  USA
  */
 
-#import "sigobjc++.h"
 #import "MSQLEditorController.h"
 
 #import "MScintillaView.h"
@@ -117,7 +116,7 @@ static int replace_selected_text(const std::string &text, MSQLEditorController *
   [WBPluginEditorBase setupCodeEditor: mScintillaView backend: mBackEnd withStatus: YES];  
   [mScintillaView setStatusText: @""/*"No errors found"*/];
   
-  mBackEnd->replace_selected_text_slot= sigc::bind(sigc::ptr_fun(replace_selected_text), self);
+  mBackEnd->replace_selected_text_slot= boost::bind(replace_selected_text, _1, self);
   
   std::string font = grt::StringRef::cast_from(mBackEnd->grtm()->get_app_option("workbench.general.Editor:Font"));
   
@@ -206,12 +205,12 @@ static void change_cursor_pos(int, MSQLEditorController *self);
   mBackEnd= be;
   [self setupEditor];
   
-  mBackEnd->report_sql_statement_border= sigc::bind(sigc::ptr_fun(process_sql_statement_border), self);
-  mBackEnd->sql_parser_err_cb(sigc::bind(sigc::ptr_fun(process_sql_error), self));
-  mBackEnd->insert_text_slot= sigc::bind(sigc::ptr_fun(insert_text), self);
-  mBackEnd->sql_check_finish_signal.connect(sigc::bind(sigc::ptr_fun(process_sql_done), self));
-  mBackEnd->change_cursor_pos_slot= sigc::bind(sigc::ptr_fun(change_cursor_pos), self);
-  mBackEnd->change_selected_range_slot= sigc::bind(sigc::ptr_fun(change_selection), self);
+  mBackEnd->report_sql_statement_border= boost::bind(process_sql_statement_border, _1, _2, _3, _4, self);
+  mBackEnd->sql_parser_err_cb(boost::bind(process_sql_error, _1, _2, _3, _4, self));
+  mBackEnd->insert_text_slot= boost::bind(insert_text, _1, self);
+  mBackEnd->sql_check_finish_signal.connect(boost::bind(process_sql_done, self));
+  mBackEnd->change_cursor_pos_slot= boost::bind(change_cursor_pos, _1, self);
+  mBackEnd->change_selected_range_slot= boost::bind(change_selection, _1, _2, self);
   
   [mScintillaView setString: [NSString stringWithCPPString: mBackEnd->sql()]];
 }
