@@ -370,13 +370,28 @@ static int processTaskProgress(float progress, const std::string &message, WBSQL
   return 0;
 }
 
-static int reloadTable(NSTableView *table)
+
+- (void)refreshTable:(NSTableView*)table
 {
   [table reloadData];
   [[table delegate] tableViewSelectionDidChange:[NSNotification notificationWithName:NSTableViewSelectionDidChangeNotification
                                                                               object: table]];
   [table scrollRowToVisible: [table numberOfRows]-1];
-                                                 
+}
+
+
+static int reloadTable(NSTableView *table, WBSQLQueryPanel *self)
+{
+  if ([NSThread mainThread] == [NSThread currentThread])
+  {
+    [self refreshTable: table];
+  }
+  else
+  {
+    [self performSelectorOnMainThread: @selector(refreshTable:)
+                           withObject: table
+                        waitUntilDone: NO];
+  }
   return 0;
 }
 
@@ -725,7 +740,15 @@ static void refreshUIPartial(const int what, WBSQLQueryPanel *panel)
       if (i != NSNotFound)
       {
         bec::NodeId node(bec::NodeId(0).append(i));
-        panel->mBackEnd->live_physical_overview()->focus_node(node); // refocus the node
+        try 
+        {
+          panel->mBackEnd->live_physical_overview()->focus_node(node); // refocus the node          
+        }
+        catch (const std::exception &exc) 
+        {
+          NSLog(@"Ignoring exception focusing overview node: %s", exc.what());
+        }
+        
         for (int j= 0; j < 3; j++)
         {
           // this might not be the node that needs to be refreshed. this callback needs an extra argument
@@ -737,6 +760,9 @@ static void refreshUIPartial(const int what, WBSQLQueryPanel *panel)
         [panel->mOverview rebuildAll];
       break;
     }
+    case Db_sql_editor::RefreshOverviewFully:
+      [panel->mOverview rebuildAll];
+      break;
   }
 }
 
@@ -769,20 +795,20 @@ static int editorCreated(int editor_index, WBSQLQueryPanel *panel)
                      owner: self];
     
     mBackEnd= be;
-    mBackEnd->log()->refresh_ui_cb= sigc::bind(sigc::ptr_fun(reloadTable), mMessagesTable);
-    mBackEnd->history()->entries_model()->refresh_ui_cb= sigc::bind(sigc::ptr_fun(reloadTable), mHistoryTable);
-    mBackEnd->history()->details_model()->refresh_ui_cb= sigc::bind(sigc::ptr_fun(reloadTable), mHistoryDetailsTable);
+    mBackEnd->log()->refresh_ui_cb= boost::bind(reloadTable, mMessagesTable, self);
+    mBackEnd->history()->entries_model()->refresh_ui_cb= boost::bind(reloadTable, mHistoryTable, self);
+    mBackEnd->history()->details_model()->refresh_ui_cb= boost::bind(reloadTable, mHistoryDetailsTable, self);
 
-    mBackEnd->sql_editor_text_insert_signal.connect(sigc::bind(sigc::ptr_fun(insertText), self));
+    mBackEnd->sql_editor_text_insert_signal.connect(boost::bind(insertText, _1, self));
     
-    mBackEnd->set_partial_refresh_ui_slot(sigc::bind(sigc::ptr_fun(refreshUIPartial), self));
-    mBackEnd->output_text_slot= sigc::bind(sigc::ptr_fun(addTextToOutput), self);
+    mBackEnd->set_partial_refresh_ui_slot(boost::bind(refreshUIPartial, _1, self));
+    mBackEnd->output_text_slot= boost::bind(addTextToOutput, _1, _2, self);
     
-    mBackEnd->exec_sql_task->progress_cb(sigc::bind(sigc::ptr_fun(processTaskProgress), self));
-    mBackEnd->exec_sql_task->finish_cb(sigc::bind(sigc::ptr_fun(processTaskFinish), self));
-    mBackEnd->recordset_list_changed.connect(sigc::bind(sigc::ptr_fun(recordsetListChanged), self));
+    mBackEnd->exec_sql_task->progress_cb(boost::bind(processTaskProgress, _1, _2, self));
+    mBackEnd->exec_sql_task->finish_cb(boost::bind(processTaskFinish, self));
+    mBackEnd->recordset_list_changed.connect(boost::bind(recordsetListChanged, _1, _2, self));
     
-    mBackEnd->sql_editor_new_ui.connect(sigc::bind(sigc::ptr_fun(editorCreated), self));
+    mBackEnd->sql_editor_new_ui.connect(boost::bind(editorCreated, _1, self));
     
     mBackEnd->set_frontend_data(self);
     
