@@ -31,7 +31,6 @@
 #import "WBModelDiagramPanel.h"
 
 #include "workbench/wb_context_ui.h"
-#import "sigobjc++.h"
 
 #include "grtui/gui_plugin_base.h"
 
@@ -608,7 +607,7 @@ static void call_find_replace(wb::WBContextUI *wbui, bool no_replace)
     
     mforms::SearchReplace dialog;
     
-    dialog.set_callback(sigc::bind(sigc::ptr_fun(search_callback), firstResponder));
+    dialog.set_callback(boost::bind(search_callback, _1, _2, _3, firstResponder));
     dialog.show(false,
                 (mforms::SearchFlags)(mforms::SearchNone),
                 !no_replace);
@@ -711,7 +710,7 @@ static bool validate_redo(WBMainWindow *mainWindow)
   { 
     // refresh edit menu
     wb::WBContextUI *wbui = [mainWindow context];
-    wbui->get_command_ui()->signal_validate_edit_menu_items().emit();
+    (*wbui->get_command_ui()->signal_validate_edit_menu_items())();
   }
 }
 
@@ -743,31 +742,31 @@ static bool validate_redo(WBMainWindow *mainWindow)
   
   _wbui->get_command_ui()->add_frontend_commands(commands);
 
-  _wbui->get_command_ui()->add_builtin_command("closetab", sigc::bind(sigc::ptr_fun(call_closetab), mainWindow), 
-                                               sigc::bind(sigc::ptr_fun(validate_closetab), mainWindow));
+  _wbui->get_command_ui()->add_builtin_command("closetab", boost::bind(call_closetab, mainWindow), 
+                                               boost::bind(validate_closetab, mainWindow));
   
-  _wbui->get_command_ui()->add_builtin_command("searchbox", sigc::bind(sigc::ptr_fun(call_search), mainWindow));
-                                               //sigc::bind(sigc::ptr_fun(validate_closetab), mainWindow));
+  _wbui->get_command_ui()->add_builtin_command("searchbox", boost::bind(call_search, mainWindow));
+                                               //boost::bind(validate_closetab), mainWindow));
  
-  _wbui->get_command_ui()->add_builtin_command("search_replace", sigc::bind(sigc::ptr_fun(call_find_replace), _wbui, false),
-                                               sigc::bind(sigc::ptr_fun(validate_find_replace), _wbui));
+  _wbui->get_command_ui()->add_builtin_command("search_replace", boost::bind(call_find_replace, _wbui, false),
+                                               boost::bind(validate_find_replace, _wbui));
 
-  _wbui->get_command_ui()->add_builtin_command("undo", sigc::bind(sigc::ptr_fun(call_undo), mainWindow),
-                                               sigc::bind(sigc::ptr_fun(validate_undo), mainWindow));
-  _wbui->get_command_ui()->add_builtin_command("redo", sigc::bind(sigc::ptr_fun(call_redo), mainWindow),
-                                               sigc::bind(sigc::ptr_fun(validate_redo), mainWindow));
-  _wbui->get_command_ui()->add_builtin_command("find", sigc::bind(sigc::ptr_fun(call_find), mainWindow), 
-                                               sigc::bind(sigc::ptr_fun(validate_find), mainWindow));
-  _wbui->get_command_ui()->add_builtin_command("copy", sigc::bind(sigc::ptr_fun(call_copy), _wbui), 
-                                               sigc::bind(sigc::ptr_fun(validate_copy), _wbui));
-  _wbui->get_command_ui()->add_builtin_command("cut", sigc::bind(sigc::ptr_fun(call_cut), _wbui), 
-                                               sigc::bind(sigc::ptr_fun(validate_cut), _wbui));
-  _wbui->get_command_ui()->add_builtin_command("paste", sigc::bind(sigc::ptr_fun(call_paste), _wbui), 
-                                               sigc::bind(sigc::ptr_fun(validate_paste), _wbui));
-  _wbui->get_command_ui()->add_builtin_command("delete", sigc::bind(sigc::ptr_fun(call_delete), _wbui),
-                                               sigc::bind(sigc::ptr_fun(validate_delete), _wbui));
-  _wbui->get_command_ui()->add_builtin_command("selectAll", sigc::bind(sigc::ptr_fun(call_select_all), _wbui), 
-                                               sigc::bind(sigc::ptr_fun(validate_select_all), _wbui));
+  _wbui->get_command_ui()->add_builtin_command("undo", boost::bind(call_undo, mainWindow),
+                                               boost::bind(validate_undo, mainWindow));
+  _wbui->get_command_ui()->add_builtin_command("redo", boost::bind(call_redo, mainWindow),
+                                               boost::bind(validate_redo, mainWindow));
+  _wbui->get_command_ui()->add_builtin_command("find", boost::bind(call_find, mainWindow), 
+                                               boost::bind(validate_find, mainWindow));
+  _wbui->get_command_ui()->add_builtin_command("copy", boost::bind(call_copy, _wbui), 
+                                               boost::bind(validate_copy, _wbui));
+  _wbui->get_command_ui()->add_builtin_command("cut", boost::bind(call_cut, _wbui), 
+                                               boost::bind(validate_cut, _wbui));
+  _wbui->get_command_ui()->add_builtin_command("paste", boost::bind(call_paste, _wbui), 
+                                               boost::bind(validate_paste, _wbui));
+  _wbui->get_command_ui()->add_builtin_command("delete", boost::bind(call_delete, _wbui),
+                                               boost::bind(validate_delete, _wbui));
+  _wbui->get_command_ui()->add_builtin_command("selectAll", boost::bind(call_select_all, _wbui), 
+                                               boost::bind(validate_select_all, _wbui));
 }
 
 
@@ -840,7 +839,7 @@ static void flush_main_thread()
   else
   {
     cf_unswap_edit_menu();
-    _wb->get_ui()->get_command_ui()->signal_validate_edit_menu_items().emit();
+    (*_wb->get_ui()->get_command_ui()->signal_validate_edit_menu_items())();
   }
 }
 
@@ -877,23 +876,23 @@ static NSString *applicationSupportFolder()
     wb::WBFrontendCallbacks wbcallbacks;
     
     // Assign those callback methods
-    wbcallbacks.show_file_dialog= sigc::ptr_fun(showFileDialog);
-    wbcallbacks.show_status_text= sigc::bind(sigc::ptr_fun(windowShowStatusText), mainWindow);
-    wbcallbacks.show_progress= sigc::bind(sigc::ptr_fun(windowShowProgress), mainWindow);
-    wbcallbacks.request_input= sigc::bind(sigc::ptr_fun(requestInput), self);
-    wbcallbacks.open_editor= sigc::bind(sigc::ptr_fun(windowOpenPlugin), mainWindow);
-    wbcallbacks.show_editor= sigc::bind(sigc::ptr_fun(windowShowPlugin), mainWindow);
-    wbcallbacks.hide_editor= sigc::bind(sigc::ptr_fun(windowHidePlugin), mainWindow);
-    wbcallbacks.perform_command= sigc::bind(sigc::ptr_fun(windowPerformCommand), mainWindow, self);
-    wbcallbacks.create_diagram= sigc::bind(sigc::ptr_fun(windowCreateView), mainWindow);
-    wbcallbacks.destroy_view= sigc::bind(sigc::ptr_fun(windowDestroyView), mainWindow);
-    wbcallbacks.switched_view= sigc::bind(sigc::ptr_fun(windowSwitchedView), mainWindow);
-    wbcallbacks.create_main_form_view= sigc::bind(sigc::ptr_fun(windowCreateMainFormView), self, mainWindow);
-    wbcallbacks.destroy_main_form_view= sigc::bind(sigc::ptr_fun(windowDestroyMainFormView), mainWindow);
-    wbcallbacks.tool_changed= sigc::bind(sigc::ptr_fun(windowToolChanged), mainWindow);
-    wbcallbacks.refresh_gui= sigc::bind(sigc::ptr_fun(windowRefreshGui), mainWindow);
-    wbcallbacks.lock_gui= sigc::bind(sigc::ptr_fun(windowLockGui), mainWindow);
-    wbcallbacks.quit_application= sigc::ptr_fun(quitApplication);
+    wbcallbacks.show_file_dialog= boost::bind(showFileDialog, _1, _2, _3);
+    wbcallbacks.show_status_text= boost::bind(windowShowStatusText, _1, mainWindow);
+    wbcallbacks.show_progress= boost::bind(windowShowProgress, _1, _2, _3, mainWindow);
+    wbcallbacks.request_input= boost::bind(requestInput, _1, _2, _3, self);
+    wbcallbacks.open_editor= boost::bind(windowOpenPlugin, _1, _2, _3, _4, _5, _6, mainWindow);
+    wbcallbacks.show_editor= boost::bind(windowShowPlugin, _1, mainWindow);
+    wbcallbacks.hide_editor= boost::bind(windowHidePlugin, _1, mainWindow);
+    wbcallbacks.perform_command= boost::bind(windowPerformCommand, _1, mainWindow, self);
+    wbcallbacks.create_diagram= boost::bind(windowCreateView, _1, mainWindow);
+    wbcallbacks.destroy_view= boost::bind(windowDestroyView, _1, mainWindow);
+    wbcallbacks.switched_view= boost::bind(windowSwitchedView, _1, mainWindow);
+    wbcallbacks.create_main_form_view= boost::bind(windowCreateMainFormView, _1, _2, self, mainWindow);
+    wbcallbacks.destroy_main_form_view= boost::bind(windowDestroyMainFormView, _1, mainWindow);
+    wbcallbacks.tool_changed= boost::bind(windowToolChanged, _1, mainWindow);
+    wbcallbacks.refresh_gui= boost::bind(windowRefreshGui, _1, _2, _3, mainWindow);
+    wbcallbacks.lock_gui= boost::bind(windowLockGui, _1, mainWindow);
+    wbcallbacks.quit_application= boost::bind(quitApplication);
       
     _options= new wb::WBOptions();
     _options->basedir = [[[NSBundle mainBundle] resourcePath] fileSystemRepresentation];
@@ -976,10 +975,14 @@ static NSString *applicationSupportFolder()
         }
         else if (strcmp(argv[i], "--version") == 0)
         {
+          std::string release_type = APP_RELEASE_TYPE;
+          if (!release_type.empty())
+            release_type = " " + release_type;
+          
 #ifdef EDITION_SE
-          NSLog(@"MySQL Workbench SE %i.%i.%i rev %i", APP_MAJOR_NUMBER, APP_MINOR_NUMBER, APP_RELEASE_NUMBER, APP_REVISION_NUMBER);
+          NSLog(@"MySQL Workbench SE %i.%i.%i%s rev %i", APP_MAJOR_NUMBER, APP_MINOR_NUMBER, APP_RELEASE_NUMBER, release_type.c_str(), APP_REVISION_NUMBER);
 #else
-          NSLog(@"MySQL Workbench CE %i.%i.%i rev %i", APP_MAJOR_NUMBER, APP_MINOR_NUMBER, APP_RELEASE_NUMBER, APP_REVISION_NUMBER);
+          NSLog(@"MySQL Workbench CE %i.%i.%i%s rev %i", APP_MAJOR_NUMBER, APP_MINOR_NUMBER, APP_RELEASE_NUMBER, release_type.c_str(), APP_REVISION_NUMBER);
 #endif
           exit(0);
         }
@@ -1216,8 +1219,9 @@ static void init_mforms()
     [[[aboutWindow contentView] viewWithTag: 1] setImage:[NSImage imageNamed:@"wb_splashscreen_se.png"]];
 #endif
     
-    [[[aboutWindow contentView] viewWithTag: 2] setStringValue: [NSString stringWithFormat:@"%i.%i.%i", 
-                                                                 APP_MAJOR_NUMBER, APP_MINOR_NUMBER, APP_RELEASE_NUMBER]];
+    [[[aboutWindow contentView] viewWithTag: 2] setStringValue: [NSString stringWithFormat:@"%i.%i.%i%s%s",
+                                                                 APP_MAJOR_NUMBER, APP_MINOR_NUMBER, APP_RELEASE_NUMBER, 
+                                                                 strlen(APP_RELEASE_TYPE)>0 ? " " : "", APP_RELEASE_TYPE]];
     
     [[[aboutWindow contentView] viewWithTag: 3] setStringValue: [NSString stringWithFormat:@"Revision %i", 
                                                                  APP_REVISION_NUMBER]];
