@@ -926,7 +926,7 @@ void setup_mforms_app(WBMainWindow *mwin);
     NSLog(@"restore edit menu");
   }
   else if (!changedActivePanel)
-    _wbui->get_command_ui()->signal_validate_edit_menu_items().emit();
+    (*_wbui->get_command_ui()->signal_validate_edit_menu_items())();
 }
 
 //--------------------------------------------------------------------------------------------------
