@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2011, Oracle and/or its affiliates. All rights reserved.
  * 
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,7 +14,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
 
-#import "sigobjc++.h"
 #include "model/wb_model_diagram_form.h"
 #include "model/wb_layer_tree.h"
 
@@ -80,10 +79,10 @@ sharedSidebarController:(WBModelSidebarController*) controller
      
     // setup layer tree
     [layerDS setTreeModel: _formBE->get_layer_tree()];
-    _formBE->get_layer_tree()->tree_changed_signal().connect(sigc::bind(sigc::ptr_fun(refresh_layer_tree), self));
+    _formBE->get_layer_tree()->tree_changed_signal()->connect(boost::bind(refresh_layer_tree, _1, _2, self));
 
     // when the layer tree changes, we should redisplay the catalog tree in case a new object was dropped (redisplay only is relatively cheap)
-    _formBE->get_layer_tree()->tree_changed_signal().connect(sigc::bind(sigc::ptr_fun(redisplay_catalog_tree), self));
+    _formBE->get_layer_tree()->tree_changed_signal()->connect(boost::bind(redisplay_catalog_tree, _1, _2, self));
     [layerOutline setDoubleAction:@selector(activateLayerItem:)];
     [layerOutline setTarget:self];
     [layerDS setHidesRootNode:YES];
