@@ -1,20 +1,22 @@
 /* 
- * Copyright © 2008, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2011, Oracle and/or its affiliates. All rights reserved.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 of the License.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; version 2 of the
+ * License.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301  USA
+ */
 
-#import "sigobjc++.h"
 #import "WBModelSidebarController.h"
 #import "GRTTreeDataSource.h"
 #import "GRTListDataSource.h"
@@ -65,14 +67,14 @@ static void refresh_user_types(const bec::NodeId &parent, int orow, WBModelSideb
   if (userTypeDS)
   {
     [userTypeDS setListModel: _wbui->get_usertypes_tree()];
-    _userTypesRefresh = new sigc::connection(_wbui->get_usertypes_tree()->tree_changed_signal().connect(sigc::bind(sigc::ptr_fun(refresh_user_types), self)));
+    _userTypesRefresh = _wbui->get_usertypes_tree()->tree_changed_signal()->connect(boost::bind(refresh_user_types, _1, _2, self));
   }
 
   // set backend model for history DS
   if (historyDS)
   {
     [historyDS setListModel:_wbui->get_history_tree()];
-    _historyRefresh = new sigc::connection(_wbui->get_history_tree()->tree_changed_signal().connect(sigc::bind(sigc::ptr_fun(refresh_history), self)));
+    _historyRefresh = _wbui->get_history_tree()->tree_changed_signal()->connect(boost::bind(refresh_history, _1, _2, self));
   }
   
   [self refresh];  
@@ -109,12 +111,8 @@ static void refresh_user_types(const bec::NodeId &parent, int orow, WBModelSideb
 { 
   _wbui= 0;
   
-  if (_historyRefresh)
-    _historyRefresh->disconnect();
-  delete _historyRefresh;
-  if (_userTypesRefresh)
-    _userTypesRefresh->disconnect();
-  delete _userTypesRefresh;
+  _historyRefresh.disconnect();
+  _userTypesRefresh.disconnect();
   [[NSNotificationCenter defaultCenter] removeObserver: self];
   [super dealloc];
 }
