@@ -103,15 +103,15 @@ static WBBasePanel *createQueryPanel(WBMainWindow *mainwin, boost::shared_ptr<be
 
 void setupSQLQueryUI(WBMainController *main, WBMainWindow *mainwin, wb::WBContextUI *wbui)
 {  
-  wbui->get_command_ui()->add_builtin_command("query.execute", sigc::bind(sigc::ptr_fun(call_execute), wbui), 
-                                              sigc::bind(sigc::ptr_fun(validate_query_panel_active), wbui));
-  wbui->get_command_ui()->add_builtin_command("query.execute_current_statement", sigc::bind(sigc::ptr_fun(call_execute_current_statement), wbui), 
-                                              sigc::bind(sigc::ptr_fun(validate_execute_current_statement), wbui));
+  wbui->get_command_ui()->add_builtin_command("query.execute", boost::bind(call_execute, wbui), 
+                                              boost::bind(validate_query_panel_active, wbui));
+  wbui->get_command_ui()->add_builtin_command("query.execute_current_statement", boost::bind(call_execute_current_statement, wbui), 
+                                              boost::bind(validate_execute_current_statement, wbui));
 
-  wbui->get_command_ui()->add_builtin_command("query.save_edits", sigc::bind(sigc::ptr_fun(call_save_edits), wbui), 
-                                              sigc::bind(sigc::ptr_fun(validate_save_edits), wbui));
-  wbui->get_command_ui()->add_builtin_command("query.discard_edits", sigc::bind(sigc::ptr_fun(call_discard_edits), wbui), 
-                                              sigc::bind(sigc::ptr_fun(validate_discard_edits), wbui));
+  wbui->get_command_ui()->add_builtin_command("query.save_edits", boost::bind(call_save_edits, wbui), 
+                                              boost::bind(validate_save_edits, wbui));
+  wbui->get_command_ui()->add_builtin_command("query.discard_edits", boost::bind(call_discard_edits, wbui), 
+                                              boost::bind(validate_discard_edits, wbui));
   
   // other commands in wb_context_sqlide.cpp
 
