@@ -1,27 +1,24 @@
 using System;
-using System.Collections.Generic;
-using System.ComponentModel;
-using System.Data;
-using System.Drawing;
-using System.Text;
 using System.Windows.Forms;
 
 namespace MySQL.GUI.Workbench
 {
   public partial class ExceptionDialog : Form
   {
+    private static ExceptionDialog singleton = new ExceptionDialog();
+
     private String errorInfo;
 
-    public ExceptionDialog()
+    protected ExceptionDialog()
     {
       InitializeComponent();
     }
 
-    public ExceptionDialog(String message, String info)
-      : this()
+    public static void Show(String message, String info)
     {
-      messageLabel.Text = message;
-      errorInfo = info;
+      singleton.messageLabel.Text = message;
+      singleton.errorInfo = info;
+      singleton.ShowDialog();
     }
 
     private void reportBugButton_Click(object sender, EventArgs e)
@@ -39,6 +36,5 @@ namespace MySQL.GUI.Workbench
       Clipboard.SetText(errorInfo);
     }
 
-
   }
 }
