@@ -450,7 +450,7 @@ namespace MySQL.GUI.Workbench
           }
           catch (Exception e)
           {
-            HandleException(e);
+            Program.HandleException(e);
           }
           break;
 
@@ -590,7 +590,7 @@ namespace MySQL.GUI.Workbench
               }
               catch (Exception e)
               {
-                HandleException(e);
+                Program.HandleException(e);
               }
             }
           }
@@ -598,7 +598,7 @@ namespace MySQL.GUI.Workbench
       }
       catch (Exception e)
       {
-        HandleException(e);
+        Program.HandleException(e);
       }
 
       return ptr;
@@ -623,7 +623,7 @@ namespace MySQL.GUI.Workbench
       }
       catch (Exception e)
       {
-        HandleException(e);
+        Program.HandleException(e);
       }
     }
 
@@ -1395,58 +1395,6 @@ namespace MySQL.GUI.Workbench
       //wbContext.handle_key_event(true, e);
     }
 
-    // CLR unhandled exception.
-    private static void OnUnhandledException(Object sender, UnhandledExceptionEventArgs e)
-    {
-      HandleException(e.ExceptionObject);
-    }
-
-    // Windows Forms unhandled exception.
-    private static void OnGuiUnhandledException(Object sender, ThreadExceptionEventArgs e)
-    {
-      HandleException(e.Exception);
-    }
-
-    public static void HandleException(Object o)
-    {
-      Exception e = o as Exception;
-      String message;
-      String info;
-
-      if (e != null)
-      { // Report System.Exception info
-        message = e.Message;
-        info = "Exception = " + e.GetType() + "\n";
-        info += "Message = " + e.Message + "\n";
-        info += "FullText = " + e.ToString();
-      }
-      else
-      { // Report exception Object info
-        message = "Exception = " + o.GetType();
-        info = "Exception = " + o.GetType() + "\n";
-        info += "FullText = " + o.ToString();
-      }
-
-      // Check for blocked files (Windows "security" feature).
-      if (info.Contains("0x80131515"))
-      {
-        MessageBox.Show("A blocked library could not be loaded. You probably downloaded MySQL Workbench " +
-          "as no-installation zip package. Windows has locked this preventing so its full operation.\n\n" +
-          "When you click \"OK\" MySQL Workbench will try to automatically unblock all its files. Restart the application " +
-          "for this change to take effect!\n\nThis operation might fail " +
-          "e.g. on read-only volumes or for other reasons. If that is the case then manually unblock the zip package " +
-          "(see its Properties in Explorer) and unzip it again.",
-          "Blocked DLL Detected", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
-
-        Win32Api.UnblockWorkbenchFiles(System.IO.Directory.GetCurrentDirectory());
-      }
-      else
-      {
-          ExceptionDialog dialog = new ExceptionDialog(message, info);
-          dialog.ShowDialog();
-      }
-    }
-
     private void MainForm_FormClosing(object sender, FormClosingEventArgs e)
     {
       shuttingDown = true;
@@ -1588,12 +1536,6 @@ namespace MySQL.GUI.Workbench
 
     private void MainForm_Load(object sender, EventArgs e)
     {
-      AppDomain currentDomain = AppDomain.CurrentDomain; // CLR
-      currentDomain.UnhandledException += new UnhandledExceptionEventHandler(MainForm.OnUnhandledException);
-
-      Application.ThreadException += // Windows Forms
-         new System.Threading.ThreadExceptionEventHandler(OnGuiUnhandledException);
-
       LoadFormState();
       InstallFocusChangeHandlers(this);
 
