@@ -373,7 +373,7 @@ namespace MySQL.GUI.Workbench
         if (document is MySQL.Forms.AppViewDockContent)
         {
           MySQL.Forms.AppViewDockContent content = document as MySQL.Forms.AppViewDockContent;
-          content.GetAppView().DocumentClosing(sender, e);
+          e.canClose = content.GetAppView().DocumentClosing();
         }
     }
 
