@@ -39,7 +39,7 @@ namespace MySQL.GUI.Workbench
     #region Static Variables and Enums
 
     // The types of application metadata information
-    public enum ApplicationMetaInfo { Company, Copyright, Version, Revision, Configuration };
+    public enum ApplicationMetaInfo { Company, Copyright, Version, Revision, Configuration, ReleaseType };
 
     // The Workbench Context
     private static WbContext wbContext = null;
@@ -72,16 +72,29 @@ namespace MySQL.GUI.Workbench
       Application.EnableVisualStyles();
       Application.SetCompatibleTextRenderingDefault(false);
 
-      // First check if this is the first instance of Workbench (if enabled).
-      // The setting for single-instance is stored in the registry as it is Windows-only
-      // and loading of the application settings happens later.
-      bool singleInstance = true;
+      // Hook into the exception handling to establish our own handling.
+      AppDomain currentDomain = AppDomain.CurrentDomain; // CLR
+      currentDomain.UnhandledException += new UnhandledExceptionEventHandler(OnUnhandledException);
+
+      Application.ThreadException += // Windows Forms
+         new System.Threading.ThreadExceptionEventHandler(OnGuiUnhandledException);
+
+      // Read some early values which cannot be stored in the preferences (since they are loaded
+      // later) from registry.
+      bool singleInstance = false;
+      string lastVersion = "";
+      string currentVersion = GetApplicationMetaInfo(ApplicationMetaInfo.Version);
       RegistryKey wbKey = Registry.CurrentUser;
       try
       {
         wbKey = wbKey.OpenSubKey(@"Software\Oracle\MySQL Workbench", false);
         if (wbKey != null)
+        {
           singleInstance = wbKey.GetValue("SingleInstance", 0).ToString() == "1";
+          lastVersion = wbKey.GetValue("LastStartedAs", "").ToString();
+        }
+        else
+          Registry.CurrentUser.CreateSubKey(@"Software\Oracle\MySQL Workbench");
       }
       catch (Exception)
       {
@@ -93,6 +106,9 @@ namespace MySQL.GUI.Workbench
           wbKey.Close();
       }
 
+      // First check if this is the first instance of Workbench (if enabled).
+      // The setting for single-instance is stored in the registry as it is Windows-only
+      // and loading of the application settings happens later.
       if (singleInstance)
       {
         if (!ApplicationInstanceManager.CreateSingleInstance(
@@ -111,6 +127,12 @@ namespace MySQL.GUI.Workbench
       string workdir = System.IO.Directory.GetCurrentDirectory();
       System.IO.Directory.SetCurrentDirectory(baseDir);
 
+      // Next check if this is the first start of a new version of WB. In this case remove all
+      // compiled python files. They will be automatically recreated and can produce problems
+      // under certain circumstances.
+      if (currentVersion != lastVersion)
+        RemoveCompiledPythonFiles(baseDir);
+
       // Some people don't have c:\windows\system32 in PATH, so we need to set it here
       // for WBA to find the needed commands
       String systemdir = Environment.GetFolderPath(Environment.SpecialFolder.System);
@@ -241,7 +263,7 @@ namespace MySQL.GUI.Workbench
       }
       catch (Exception ex)
       {
-        MainForm.HandleException(ex);
+        HandleException(ex);
       }
 
       #endregion
@@ -389,6 +411,24 @@ namespace MySQL.GUI.Workbench
         // and opens the overview form for it.
         wbContext.finished_loading(wbOptions);
 
+        // Right before we go to work and everything was loaded write the current version to registry
+        // to allow us later to find out if we ran a new version the first time.
+        try
+        {
+          wbKey = Registry.CurrentUser.OpenSubKey(@"Software\Oracle\MySQL Workbench", true);
+          if (wbKey != null)
+            wbKey.SetValue("LastStartedAs", currentVersion);
+        }
+        catch (Exception)
+        {
+          // Ignore errors.
+        }
+        finally
+        {
+          if (wbKey != null)
+            wbKey.Close();
+        }
+
         // Start the Application if we are not already shutting down.
         if (!wbContext.is_quitting())
         {
@@ -398,7 +438,7 @@ namespace MySQL.GUI.Workbench
           }
           catch (Exception e)
           {
-            MainForm.HandleException(e);
+            HandleException(e);
           }
         }
         
@@ -438,7 +478,7 @@ namespace MySQL.GUI.Workbench
         {
           // temporarily stop the timer so that we don't get into a loop from showing the msgbox
           timer.Stop();
-          MainForm.HandleException(exception);
+          HandleException(exception);
           timer.Start();
         }
       }
@@ -524,6 +564,18 @@ namespace MySQL.GUI.Workbench
       mainForm.Invoke(d, true);
     }
 
+    // CLR unhandled exception.
+    private static void OnUnhandledException(Object sender, UnhandledExceptionEventArgs e)
+    {
+      HandleException(e.ExceptionObject);
+    }
+
+    // Windows Forms unhandled exception.
+    private static void OnGuiUnhandledException(Object sender, ThreadExceptionEventArgs e)
+    {
+      HandleException(e.Exception);
+    }
+
     #endregion
 
     #region Message Callbacks
@@ -587,6 +639,11 @@ namespace MySQL.GUI.Workbench
           version = new Version(Application.ProductVersion);
           value = string.Format("{0}", version.MinorRevision);
           break;
+        case ApplicationMetaInfo.ReleaseType:
+          attributes = assembly.GetCustomAttributes(typeof(AssemblyReleaseTypeAttribute), false);
+          if (attributes.Length > 0)
+            value = (attributes[0] as AssemblyReleaseTypeAttribute).ReleaseType;
+          break;
       }
 
       return value;
@@ -679,6 +736,55 @@ namespace MySQL.GUI.Workbench
       return true;
     }
 
+    public static void HandleException(Object o)
+    {
+      Exception e = o as Exception;
+      String message;
+      String info;
+
+      if (e != null)
+      { // Report System.Exception info
+        message = e.Message;
+        info = "Exception = " + e.GetType() + "\n";
+        info += "Message = " + e.Message + "\n";
+        info += "FullText = " + e.ToString();
+      }
+      else
+      { // Report exception Object info
+        message = "Exception = " + o.GetType();
+        info = "Exception = " + o.GetType() + "\n";
+        info += "FullText = " + o.ToString();
+      }
+
+      // Check for blocked files (Windows "security" feature).
+      if (info.Contains("0x80131515"))
+      {
+        MessageBox.Show("A blocked library could not be loaded. You probably downloaded MySQL Workbench " +
+          "as no-installation zip package. Windows has locked this, preventing so its full operation.\n\n" +
+          "When you click \"OK\" MySQL Workbench will try to automatically unblock all its files. Restart the application " +
+          "for this change to take effect!\n\nThis operation might fail " +
+          "e.g. on read-only volumes or for other reasons. If that is the case then manually unblock the zip package " +
+          "(see its Properties in Explorer) and unzip it again.",
+          "Blocked DLL Detected", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
+
+        Win32Api.UnblockWorkbenchFiles(System.IO.Directory.GetCurrentDirectory());
+      }
+      else
+        ExceptionDialog.Show(message, info);
+    }
+
+    /// <summary>
+    /// Removes all pyc files from the given dir and its sub dirs.
+    /// </summary>
+    private static void RemoveCompiledPythonFiles(string folder)
+    {
+      foreach (string file in Directory.GetFiles(folder, "*.pyc"))
+        File.Delete(file);
+
+      foreach (string subfolder in Directory.GetDirectories(folder))
+        RemoveCompiledPythonFiles(subfolder);
+    }
+
     #endregion
 
   }
