@@ -1,6 +1,7 @@
 ﻿using System.Reflection;
 using System.Runtime.CompilerServices;
 using System.Runtime.InteropServices;
+using MySQL.GUI.Workbench;
 
 // General Information about an assembly is controlled through the following 
 // set of attributes. Change these attribute values to modify the information
@@ -35,5 +36,6 @@ using System.Runtime.InteropServices;
 //      Build Number
 //      Revision
 //
-[assembly: AssemblyVersion("5.2.34.7780")]
-[assembly: AssemblyFileVersion("5.2.34.7780")]
+[assembly: AssemblyVersion("5.2.35.7915")]
+[assembly: AssemblyFileVersion("5.2.35.7915")]
+[assembly: AssemblyReleaseType("")]
