@@ -84,7 +84,7 @@ namespace MySQL.GUI.Workbench
       historyEntriesView.MultiSelect = false;
       historyEntriesView.RowHeadersVisible = false;
       historyEntriesView.Parent = historySplitContainer.Panel1;
-      dbSqlEditorBE.history().entries_model().refresh_ui_cb(historyEntriesView.ProcessModelRowsChange);
+      dbSqlEditorBE.history().entries_model().refresh_ui_cb(ProcessModelHistoryEntryRowsChange);
       historyEntriesView.ProcessModelChange();
       historyEntriesView.AutoSizeColumnsMode = DataGridViewAutoSizeColumnsMode.Fill;
       historyEntriesView.SelectionMode = DataGridViewSelectionMode.FullRowSelect;
@@ -105,9 +105,11 @@ namespace MySQL.GUI.Workbench
       dbSqlEditorBE.history().details_model().refresh_ui_cb(historyDetailsView.ProcessModelRowsChange); 
       historyDetailsView.ProcessModelChange();
       historyDetailsView.AutoSizeColumnsMode = DataGridViewAutoSizeColumnsMode.Fill;
+      historyDetailsView.Columns[0].AutoSizeMode = DataGridViewAutoSizeColumnMode.DisplayedCells;
       historyDetailsView.SelectionMode = DataGridViewSelectionMode.FullRowSelect;
       historyDetailsView.CellDoubleClick += new DataGridViewCellEventHandler(historyDetailsView_CellDoubleClick);
       wrapButton.Checked = historyDetailsView.WrapMode;
+      historyContextMenuStrip.Opening += OnMenuOpening;
 
       dbSqlEditorBE.exec_sql_task.finish_cb(AfterExecSql);
       dbSqlEditorBE.exec_sql_task.progress_cb(OnExecSqlProgress);
@@ -341,14 +343,13 @@ namespace MySQL.GUI.Workbench
       logView.AutoResizeColumn(2);
       logView.AutoResizeColumn(5);
 
-      historyEntriesView.ProcessModelRowsChange();
-      historyDetailsView.ProcessModelRowsChange();
 
       if (logView.Rows.Count > 0)
         logView.SetRowSelected(logView.Rows.Count - 1);
 
       sqlEditors[dbSqlEditorBE.active_sql_editor_index()].Focus();
 
+
       return 0;
     }
 
@@ -795,6 +796,17 @@ namespace MySQL.GUI.Workbench
       loadSelectedHistoryItems(true);
     }
 
+    private int ProcessModelHistoryEntryRowsChange()
+    {
+      int ret_val = historyEntriesView.ProcessModelRowsChange();
+      int selected_entry = dbSqlEditorBE.history().current_entry();
+
+      if (selected_entry != -1)
+        historyEntriesView.SetRowSelected(selected_entry);
+
+      return ret_val;
+    }
+
     #endregion
 
     #region Sidebar
@@ -926,6 +938,12 @@ namespace MySQL.GUI.Workbench
       resultSetTextBox.Clear();
     }
 
+    private void OnMenuOpening(object sender, CancelEventArgs e)
+    {
+      this.appendToCurrentSqlMenuItem.Enabled = (historyDetailsView.SelectedRows.Count > 0);
+      this.replaceCurrentSqlMenuItemMenuItem.Enabled = (historyDetailsView.SelectedRows.Count > 0);
+    }
+
     #endregion
   }
 }
