@@ -2,7 +2,7 @@ using System;
 using System.Windows.Forms;
 
 using MySQL.Grt;
-using MySQL.Workbench;
+using MySQL.Forms;
 
 namespace MySQL.GUI.Workbench.Plugins
 {
