@@ -42,9 +42,12 @@ namespace base
   // TODO: move Windows specific code to base.windows library.
   BASELIBRARY_PUBLIC_FUNC std::wstring string_to_wstring(const std::string &s);
   BASELIBRARY_PUBLIC_FUNC std::string wstring_to_string(const std::wstring &s);
+  BASELIBRARY_PUBLIC_FUNC std::wstring path_from_utf8(const std::string &s);
+#else
+  BASELIBRARY_PUBLIC_FUNC std::string path_from_utf8(const std::string &s);
 #endif
   // use this to convert a utf8 std::string to a std::string that can be used to open files in windows (noop elsewhere)
-  BASELIBRARY_PUBLIC_FUNC std::string string_to_path(const std::string &s);
+  BASELIBRARY_PUBLIC_FUNC std::string string_to_path_for_open(const std::string &s);
 
   // turns a UTF8 string into something that can be used as a file name (ie, strips out special chars)
   BASELIBRARY_PUBLIC_FUNC std::string sanitize_file_name(const std::string &s);
