@@ -36,11 +36,12 @@ struct base::Logger::LoggerImpl
     for (int i = 0; i < base::Logger::NumOfLevels + 1; ++i)
       _levels[i] = true;
     _levels[0] = false; // Disable None level
-
+#ifndef DEBUG
     // Disable debug levels for production
     _levels[LogDebug]  = false;
     _levels[LogDebug2] = false;
     _levels[LogDebug3] = false;
+#endif
   }
 
   bool level_is_enabled(const base::Logger::LogLevel level) const
@@ -102,6 +103,14 @@ void base::Logger::log(const base::Logger::LogLevel level, const char* const dom
       vfprintf(fp, format, args);
       va_end(args);
       fputs("\n", fp);
+      
+#ifdef DEBUG
+      fprintf(stderr, "%02u:%02u:%02u [%7s][%15s]: ", tm.tm_hour, tm.tm_min, tm.tm_sec, LevelText[lvl], domain);
+      va_start(args, format);
+      vfprintf(stderr, format, args);
+      va_end(args);
+      fprintf(stderr, "\n");
+#endif
     }
   }
 }
