@@ -19,7 +19,6 @@
 
 #include "base/string_utilities.h"
 #include "base/file_functions.h"
-#include <sigc++/sigc++.h>
 #include <stdexcept>
 #include <functional>
 #include <locale>
@@ -27,6 +26,8 @@
 #include <math.h>
 #include <errno.h>
 #include <string.h>
+#include <boost/function.hpp>
+#include <boost/bind.hpp>
 
 using namespace std;
 
@@ -72,11 +73,22 @@ std::string wstring_to_string(const std::wstring &s)
 
   return result;
 }
+
+std::wstring path_from_utf8(const std::string &s)
+{
+  return string_to_wstring(s);
+}
+#else
+std::string path_from_utf8(const std::string &s)
+{
+  return s;
+}
+
 #endif
 
 //--------------------------------------------------------------------------------------------------
 
-std::string string_to_path(const std::string &s)
+std::string string_to_path_for_open(const std::string &s)
 {
 #ifdef _WIN32
   std::wstring ws = string_to_wstring(s);
@@ -463,17 +475,15 @@ BASELIBRARY_PUBLIC_FUNC std::string sizefmt(int64_t s, bool metric)
  * Helper routine to strip a string into an STL string using the printf parameter syntax.
  */
 std::string strip_text(const std::string &text, bool left, bool right)
-{
+{//TODO sigc rewrite it in std/boost way
   std::locale loc;
-  std::logical_not<bool> nott;
-  sigc::slot<bool, bool> not_slot= sigc::mem_fun(nott, &std::logical_not<bool>::operator());
-  sigc::slot<bool, std::string::value_type> is_space=
-    sigc::bind(sigc::ptr_fun(&std::isspace<std::string::value_type>), sigc::ref(loc));
+  boost::function<bool (std::string::value_type)> is_space=
+    boost::bind(&std::isspace<std::string::value_type>, _1, loc);
 
   std::string::const_iterator l_edge= !left ? text.begin() :
-    std::find_if(text.begin(), text.end(), sigc::compose(not_slot, is_space));
+    std::find_if(text.begin(), text.end(), boost::bind(std::logical_not<bool>(), boost::bind(is_space,_1)));
   std::string::const_reverse_iterator r_edge= !right ? text.rbegin() :
-    std::find_if(text.rbegin(), text.rend(), sigc::compose(not_slot, is_space));
+    std::find_if(text.rbegin(), text.rend(), boost::bind(std::logical_not<bool>(), boost::bind(is_space,_1)));
 
   return std::string(l_edge, r_edge.base());
 }
