@@ -85,9 +85,9 @@ CanvasItem::CanvasItem(Layer *layer)
   _fixed_min_size= Size(-1, -1);
   _fixed_size= Size(-1, -1);
 
-  _bounds_changed_signal.connect(sigc::hide(sigc::mem_fun(this, &CanvasItem::update_handles)));
+  _bounds_changed_signal.connect(boost::bind(&CanvasItem::update_handles, this));
 
-  layer->get_view()->signal_zoom_changed().connect(sigc::mem_fun(this, &CanvasItem::invalidate_cache));
+  scoped_connect(layer->get_view()->signal_zoom_changed(),boost::bind(&CanvasItem::invalidate_cache, this));
 }
 
 
@@ -157,7 +157,7 @@ void CanvasItem::set_position(const Point &pos)
   
     _pos= pos.round();
   
-    _bounds_changed_signal.emit(obounds);
+    _bounds_changed_signal(obounds);
   
     update_handles();
   }
@@ -172,7 +172,7 @@ void CanvasItem::set_size(const Size &size)
  
     _size= size;
 
-    _bounds_changed_signal.emit(obounds);
+    _bounds_changed_signal(obounds);
   
     update_handles();
   }
@@ -306,7 +306,7 @@ void CanvasItem::set_fixed_size(const Size &size)
   _min_size_invalid= true;
   _fixed_size= size;
   _size= size;
-  _bounds_changed_signal.emit(obounds);
+  _bounds_changed_signal(obounds);
   set_needs_relayout();
 }
 
@@ -314,7 +314,7 @@ void CanvasItem::set_fixed_size(const Size &size)
 
 void CanvasItem::parent_bounds_changed(const Rect &obounds, CanvasItem *item)
 {
-  _parent_bounds_changed_signal.emit(item, obounds);
+  _parent_bounds_changed_signal(item, obounds);
   
   update_handles();
 }
@@ -322,7 +322,7 @@ void CanvasItem::parent_bounds_changed(const Rect &obounds, CanvasItem *item)
 
 void CanvasItem::grand_parent_bounds_changed(CanvasItem *item, const Rect &obounds)
 {
-  _parent_bounds_changed_signal.emit(item, obounds);
+  _parent_bounds_changed_signal(item, obounds);
   
   update_handles();
 }
@@ -343,15 +343,13 @@ void CanvasItem::set_parent(CanvasItem *parent)
 
   if (parent)
   {
-    _reparent_signal.emit();
+    _reparent_signal();
 
-    _parent_bounds_con= 
-      parent->signal_bounds_changed().connect(sigc::bind<CanvasItem*>(sigc::mem_fun(this, 
-                                                                                  &CanvasItem::parent_bounds_changed), 
-                                                                    parent));
+    _parent_bounds_con= *scoped_connect(
+      parent->signal_bounds_changed(),boost::bind(&CanvasItem::parent_bounds_changed, this, _1, parent)).get();
 
     _grand_parent_bounds_con= 
-      parent->signal_parent_bounds_changed().connect(sigc::mem_fun(this, &CanvasItem::grand_parent_bounds_changed));      
+      *scoped_connect(parent->signal_parent_bounds_changed(),boost::bind(&CanvasItem::grand_parent_bounds_changed, this, _1, _2)).get();
   }
 }
 
@@ -437,7 +435,7 @@ void CanvasItem::set_focused(bool flag)
     _focused= flag;
     set_needs_render();
     
-    _focus_changed_signal.emit(flag);
+    _focus_changed_signal(flag);
   }
 }
 
@@ -1222,7 +1220,7 @@ mdc::Magnet *CanvasItem::get_closest_magnet(const Point &point)
 }
 
 
-void CanvasItem::set_drag_handle_constrainer(const sigc::slot<void,ItemHandle*,Size&> &slot)
+void CanvasItem::set_drag_handle_constrainer(const boost::function<void (ItemHandle*,Size&)> &slot)
 {
   _drag_handle_constrainer= slot;
 }
