@@ -290,7 +290,7 @@ void CanvasView::set_offset(const Point &offs)
     update_offsets();
     queue_repaint();
 
-    _viewport_changed_signal.emit();
+    _viewport_changed_signal();
   }
 }
 
@@ -311,8 +311,8 @@ void CanvasView::set_zoom(float zoom)
 
     // Zoom notification is potentially slow, so do the viewport update first
     // to get the display (e.g. scrollbars, paper etc.) looking ok asap.
-    _viewport_changed_signal.emit();
-    _zoom_changed_signal.emit();
+    _viewport_changed_signal();
+    _zoom_changed_signal();
   }
 }
 
@@ -329,9 +329,9 @@ void CanvasView::set_page_size(const Size &size)
     for (LayerList::iterator iter= _layers.begin(); iter != _layers.end(); ++iter)
       (*iter)->get_root_area_group()->resize_to(get_total_view_size());
 
-    _resized_signal.emit();
+    _resized_signal();
 
-    _viewport_changed_signal.emit();
+    _viewport_changed_signal();
   }
 }
 
@@ -343,9 +343,9 @@ void CanvasView::set_page_layout(Count xpages, Count ypages)
   update_offsets();
   queue_repaint();
 
-  _resized_signal.emit();
+  _resized_signal();
 
-  _viewport_changed_signal.emit();
+  _viewport_changed_signal();
 }
 
 
@@ -605,7 +605,7 @@ void CanvasView::update_line_crossings(Line *line)
   // get the lines in the same bounding box
 
   std::list<CanvasItem*> items= get_items_bounded_by(line->get_root_bounds(),
-                                                     sigc::ptr_fun(is_line));
+                                                     std::ptr_fun(is_line));
 
   std::list<CanvasItem*>::iterator iter= items.begin();
 
@@ -882,7 +882,7 @@ void CanvasView::queue_repaint()
 //  _needs_repaint= true;
 
   lock();
-  _need_repaint_signal.emit(0, 0, _view_width, _view_height);
+  _need_repaint_signal(0, 0, _view_width, _view_height);
   unlock();
 }
 
@@ -905,7 +905,7 @@ void CanvasView::queue_repaint(const Rect &bounds)
 
     canvas_to_window(bounds, x, y, width, height);
 
-    _need_repaint_signal.emit(std::max(0, x-1), std::max(0, y-1), width+2, height+2);
+    _need_repaint_signal(std::max(0, x-1), std::max(0, y-1), width+2, height+2);
 
     //_needs_repaint= flag;
   }
@@ -1260,9 +1260,9 @@ std::list<CanvasItem*> CanvasView::get_items_bounded_by(const Rect &rect,
 // Base Event Handling
 
 
-void CanvasView::set_event_callbacks(const sigc::slot<bool, CanvasView*, MouseButton, bool, Point, EventState> &button_handler,
-                                     const sigc::slot<bool, CanvasView*, Point, EventState> &motion_handler,
-                                     const sigc::slot<bool, CanvasView*, KeyInfo, EventState, bool> &key_handler)
+void CanvasView::set_event_callbacks(const boost::function<bool (CanvasView*, MouseButton, bool, Point, EventState)> &button_handler,
+                                     const boost::function<bool (CanvasView*, Point, EventState)> &motion_handler,
+                                     const boost::function<bool (CanvasView*, KeyInfo, EventState, bool)> &key_handler)
 {
   _button_event_relay= button_handler;
   _motion_event_relay= motion_handler;
@@ -1271,7 +1271,7 @@ void CanvasView::set_event_callbacks(const sigc::slot<bool, CanvasView*, MouseBu
 
 
 static bool propagate_event(mdc::CanvasItem *item, 
-                            const sigc::mem_functor2<bool, mdc::CanvasItem, mdc::CanvasItem*, const Point&> &functor,
+  const boost::function<bool (mdc::CanvasItem*, mdc::CanvasItem*, const Point&)> &functor,
                             const Point &pos)
 {
   mdc::CanvasItem *target= item;
@@ -1297,10 +1297,9 @@ static bool propagate_event(mdc::CanvasItem *item,
 }
 
 
-template<class T_arg1>
 static bool propagate_event(mdc::CanvasItem *item, 
-                            const sigc::mem_functor3<bool, mdc::CanvasItem, mdc::CanvasItem*, const Point&, T_arg1> &functor,
-                            const Point &pos, T_arg1 arg1)
+  const boost::function<bool (mdc::CanvasItem*, mdc::CanvasItem*, const Point&, mdc::EventState)> &functor,
+                            const Point &pos, mdc::EventState arg1)
 {
   mdc::CanvasItem *target= item;
   
@@ -1324,10 +1323,9 @@ static bool propagate_event(mdc::CanvasItem *item,
   return false;  
 }
 
-template<class T_arg1, class T_arg2>
 static bool propagate_event(mdc::CanvasItem *item, 
-                            const sigc::mem_functor4<bool, mdc::CanvasItem, mdc::CanvasItem*, const Point&, T_arg1, T_arg2> &functor,
-                            const Point &pos, T_arg1 arg1, T_arg2 arg2)
+  const boost::function<bool (mdc::CanvasItem*, mdc::CanvasItem*, const Point&, mdc::MouseButton, mdc::EventState)> &functor,
+                            const Point &pos, mdc::MouseButton arg1, mdc::EventState arg2)
 {
   mdc::CanvasItem *target= item;
   
@@ -1428,7 +1426,7 @@ void CanvasView::handle_mouse_move(int x, int y, EventState state)
     // that was under the cursor when the press happened (not the current item)
 
     handled= propagate_event(_last_click_item, 
-                             sigc::mem_fun(&CanvasItem::on_drag),
+                             boost::bind(&CanvasItem::on_drag, _1, _2, _3, _4),
                              point, state);
 
     return; // if dragging, then don't process boundary crossings (?)
@@ -1474,7 +1472,7 @@ void CanvasView::handle_mouse_move(int x, int y, EventState state)
     for (it= _last_over_item; it != ancestor; it= it->get_parent())
     {
       propagate_event(it, 
-                      sigc::mem_fun(&CanvasItem::on_leave),
+        boost::bind(&CanvasItem::on_leave, _1, _2, _3),
                       point);
     }
 
@@ -1490,7 +1488,7 @@ void CanvasView::handle_mouse_move(int x, int y, EventState state)
     {
       it= *i;
       propagate_event(it,
-                      sigc::mem_fun(&CanvasItem::on_enter),
+        boost::bind(&CanvasItem::on_enter, _1, _2, _3),
                       point);
     }
 
@@ -1537,7 +1535,7 @@ void CanvasView::handle_mouse_button(MouseButton button, bool press, int x, int
   {
     // if it's a button press, send the press event to the item at the point
     handled= propagate_event(item,
-                             sigc::mem_fun(&CanvasItem::on_button_press),
+      boost::bind(&CanvasItem::on_button_press, _1, _2, _3, _4, _5),
                              point, button, state);
   }
   else if (_last_click_item && !press)
@@ -1546,7 +1544,7 @@ void CanvasView::handle_mouse_button(MouseButton button, bool press, int x, int
     // was originally pressed (not the item we're over now)
   
     handled= propagate_event(_last_click_item, 
-                             sigc::mem_fun(&CanvasItem::on_button_release), 
+      boost::bind(&CanvasItem::on_button_release, _1, _2, _3, _4, _5),
                              point, button, state);
   }
 
@@ -1554,7 +1552,7 @@ void CanvasView::handle_mouse_button(MouseButton button, bool press, int x, int
   {
     // send click if the button was released over the same item it was pressed
     handled= propagate_event(item,
-                             sigc::mem_fun(&CanvasItem::on_click),
+                             boost::bind(&CanvasItem::on_click, _1, _2, _3, _4, _5),
                              point, button, state);
   }
 
@@ -1583,7 +1581,7 @@ void CanvasView::handle_mouse_double_click(MouseButton button, int x, int y, Eve
 
   // send click if the button was released over the same item it was pressed
   handled= propagate_event(item,
-                           sigc::mem_fun(&CanvasItem::on_double_click),
+    boost::bind(&CanvasItem::on_double_click, _1, _2, _3, _4, _5),
                            point, button, state);
 
   set_last_click_item(item);
@@ -1611,7 +1609,9 @@ bool CanvasView::handle_key(const KeyInfo &key, bool press, EventState state)
   if (_ui_lock > 0)
     return false;
 
-  return _key_event_relay(this, key, state, press);
+  if (_key_event_relay)
+    return _key_event_relay(this, key, state, press);
+  return false;
 }
 
 
