@@ -45,7 +45,7 @@ enum SelectType
   SelectToggle
 };
 
-class MYSQLCANVAS_PUBLIC_FUNC CanvasView : public sigc::trackable
+class MYSQLCANVAS_PUBLIC_FUNC CanvasView
 {
   friend class BackLayer;
   friend class CanvasViewExtras;
@@ -143,7 +143,7 @@ public:
   CanvasItem *get_leaf_item_at(int x, int y);
   CanvasItem *get_leaf_item_at(const MySQL::Geometry::Point &point);
   
-  typedef sigc::slot<bool,CanvasItem*> ItemCheckFunc;
+  typedef boost::function<bool (CanvasItem*)> ItemCheckFunc;
   std::list<CanvasItem*> get_items_bounded_by(const MySQL::Geometry::Rect &rect, 
                                               const ItemCheckFunc &pred= ItemCheckFunc());
 
@@ -192,15 +192,15 @@ public:
   void export_ps(const std::string &filename, const MySQL::Geometry::Size &size_in_pt);
   void export_svg(const std::string &filename, const MySQL::Geometry::Size &size_in_pt);
 
-  void set_event_callbacks(const sigc::slot<bool, CanvasView*, MouseButton, bool, MySQL::Geometry::Point, EventState> &button_handler,
-                           const sigc::slot<bool, CanvasView*, MySQL::Geometry::Point, EventState> &motion_handler,
-                           const sigc::slot<bool, CanvasView*, KeyInfo, EventState, bool> &key_handler);
+  void set_event_callbacks(const boost::function<bool (CanvasView*, MouseButton, bool, MySQL::Geometry::Point, EventState)> &button_handler,
+                           const boost::function<bool (CanvasView*, MySQL::Geometry::Point, EventState)> &motion_handler,
+                           const boost::function<bool (CanvasView*, KeyInfo, EventState, bool)> &key_handler);
 
 
-  sigc::signal<void> signal_resized() { return _resized_signal; }
-  sigc::signal<void,int,int,int,int> signal_repaint() { return _need_repaint_signal; }
-  sigc::signal<void> signal_viewport_changed() { return _viewport_changed_signal; }
-  sigc::signal<void> signal_zoom_changed() { return _zoom_changed_signal; }
+  boost::signals2::signal<void ()>* signal_resized() { return &_resized_signal; }
+  boost::signals2::signal<void (int,int,int,int)>* signal_repaint() { return &_need_repaint_signal; }
+  boost::signals2::signal<void ()>* signal_viewport_changed() { return &_viewport_changed_signal; }
+  boost::signals2::signal<void ()>* signal_zoom_changed() { return &_zoom_changed_signal; }
 
   void enable_debug(bool flag) { _debug= flag; }
   inline bool debug_enabled() { return _debug; }
@@ -255,14 +255,14 @@ protected:
 
   size_t _total_item_cache_mem;
   
-  sigc::signal<void> _resized_signal;
-  sigc::signal<void,int,int,int,int> _need_repaint_signal;
-  sigc::signal<void> _viewport_changed_signal;
-  sigc::signal<void> _zoom_changed_signal;
+  boost::signals2::signal<void ()> _resized_signal;
+  boost::signals2::signal<void (int,int,int,int)> _need_repaint_signal;
+  boost::signals2::signal<void ()> _viewport_changed_signal;
+  boost::signals2::signal<void ()> _zoom_changed_signal;
   
-  sigc::slot<bool, CanvasView*, MouseButton, bool, MySQL::Geometry::Point, EventState> _button_event_relay;
-  sigc::slot<bool, CanvasView*, MySQL::Geometry::Point, EventState> _motion_event_relay;
-  sigc::slot<bool, CanvasView*, KeyInfo, EventState, bool> _key_event_relay;
+  boost::function<bool (CanvasView*, MouseButton, bool, MySQL::Geometry::Point, EventState)> _button_event_relay;
+  boost::function<bool (CanvasView*, MySQL::Geometry::Point, EventState)> _motion_event_relay;
+  boost::function<bool (CanvasView*, KeyInfo, EventState, bool)> _key_event_relay;
 
   CanvasView(int width, int height);
 
