@@ -44,8 +44,7 @@ Group::Group(Layer *layer)
   set_accepts_focus(true);
   set_accepts_selection(true);  
 
-  signal_focus_change().connect(sigc::bind<CanvasItem*>(sigc::mem_fun(this, &Group::focus_changed),
-                                                        this));
+  scoped_connect(signal_focus_change(),boost::bind(&Group::focus_changed,this, _1, this));
 }
 
 
@@ -115,8 +114,7 @@ void Group::add(CanvasItem *item)
   ItemInfo info;
   
   info.connection= 
-    item->signal_focus_change().connect(sigc::bind<CanvasItem*>(sigc::mem_fun(this, &Group::focus_changed),
-                                                                item));
+    *scoped_connect(item->signal_focus_change(),boost::bind(&Group::focus_changed, this, _1, item)).get();
   _content_info[item]= info;
 }
 
@@ -217,7 +215,7 @@ void Group::update_bounds()
 }
 
 
-void Group::foreach(const sigc::slot<void, CanvasItem*> &slot)
+void Group::foreach(const boost::function<void (CanvasItem*)> &slot)
 {
   for (std::list<CanvasItem*>::const_iterator it= _contents.begin(); it != _contents.end(); )
   {
