@@ -189,7 +189,7 @@ ConnectionWrapper DriverManager::getConnection(const db_mgmt_ConnectionRef &conn
   //std::map<std::string, ConnectPropertyVal> properties;
   ConnectOptionsMap properties;
   grt::DictRef parameter_values= connectionProperties->parameterValues();
-  parameter_values.foreach(sigc::bind(&conv_to_dbc_value, sigc::ref(properties), sigc::ref(param_types)));
+  parameter_values.foreach(boost::bind(&conv_to_dbc_value, _1, _2, boost::ref(properties), param_types));
 
   {
     ConnectPropertyVal tmp;
@@ -286,7 +286,8 @@ retry:
   {
     std::auto_ptr<Connection> conn(driver->connect(properties));
 
-    connection_init_slot(conn.get(), connectionProperties);
+    if (connection_init_slot)
+        connection_init_slot(conn.get(), connectionProperties);
     
     std::string def_schema= parameter_values.get_string("schema", "");
     if (!def_schema.empty())
