@@ -53,7 +53,7 @@ public:
   void set_driver_dir(const std::string &path);
 
   // Callback to initialize connection with DBMS specific startup script
-  typedef sigc::slot<void, Connection*, const db_mgmt_ConnectionRef&> ConnectionInitSlot;
+  typedef boost::function<void (Connection*, const db_mgmt_ConnectionRef&)> ConnectionInitSlot;
 
   // Returns a Connection object for the give connection params
   ConnectionWrapper getConnection(const db_mgmt_ConnectionRef &connectionProperties, ConnectionInitSlot connection_init_slot= ConnectionInitSlot());
@@ -64,9 +64,9 @@ public:
   std::list<Driver *> getDrivers();
   
 public:
-  typedef sigc::slot<TunnelConnection*, const db_mgmt_ConnectionRef &> TunnelFactoryFunction;
-  typedef sigc::slot<bool, const db_mgmt_ConnectionRef &, std::string &> PasswordFindFunction;
-  typedef sigc::slot<std::string, const db_mgmt_ConnectionRef &, bool> PasswordRequestFunction;
+  typedef boost::function<TunnelConnection* (const db_mgmt_ConnectionRef &)> TunnelFactoryFunction;
+  typedef boost::function<bool (const db_mgmt_ConnectionRef &, std::string &)> PasswordFindFunction;
+  typedef boost::function<std::string (const db_mgmt_ConnectionRef &, bool)> PasswordRequestFunction;
 
   void setTunnelFactoryFunction(TunnelFactoryFunction function);
   void setPasswordFindFunction(PasswordFindFunction function);
