@@ -60,5 +60,5 @@ void Button::enable_internal_padding(bool flag)
 void Button::callback()
 {
   if (!_updating)
-    _clicked.emit();
+    _clicked();
 }
