@@ -22,6 +22,11 @@
 #import "MFView.h"
 #include "mforms/mforms.h"
 
+@interface NSObject(UndocumentedAPI)
+- (void)setShowsHiddenFiles:(BOOL)flag;
+- (NSView*)_navView;
+@end
+
 @implementation MFFileChooserImpl
 
 
