@@ -24,13 +24,13 @@
 
 @interface MFMenuItem : NSMenuItem
 {
-  sigc::slot<void> slot;
+  boost::function<void ()> slot;
 @public
   mforms::MenuItem *item;
 }
 
 - (id)initWithTitle:(NSString*)title
-               slot:(sigc::slot<void>)aslot;
+               slot:(boost::function<void ()>)aslot;
 
 @end
 
@@ -40,7 +40,7 @@ static NSMenuItem *defaultEditMenu = nil;
 @implementation  MFMenuItem
 
 - (id)initWithTitle:(NSString*)title
-               slot:(sigc::slot<void>)aslot
+               slot:(boost::function<void ()>)aslot
 {
   self = [super initWithTitle: title action: @selector(callSlot:) keyEquivalent:@""];
   if (self)
@@ -53,7 +53,8 @@ static NSMenuItem *defaultEditMenu = nil;
 
 - (void)callSlot:(id)sender
 {
-  slot();
+  if (slot)
+    slot();
 }
 
 
@@ -85,7 +86,7 @@ static bool create_menu_item(MenuItem *aitem, const std::string &title, MenuItem
   }
   else
   {
-    MFMenuItem *item = [[[MFMenuItem alloc] initWithTitle: wrap_nsstring(title) slot: sigc::mem_fun(aitem, &MenuItem::callback)] autorelease];
+    MFMenuItem *item = [[[MFMenuItem alloc] initWithTitle: wrap_nsstring(title) slot: boost::bind(&MenuItem::callback, aitem)] autorelease];
     item->item = aitem;
     aitem->set_data(item);
   }
