@@ -36,7 +36,7 @@ static NSImage *descendingSortIndicator=nil;
   mforms::Menu *menu = mOwner->get_context_menu();
   if (menu)
   {
-    menu->signal_will_show().emit();
+    (*menu->signal_will_show())();
     return menu->get_data();
   }
   return nil;
