@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -37,6 +37,8 @@
     [self addSubview: mBrowser];
     [mBrowser setFrameLoadDelegate: self];
     [mBrowser setUIDelegate: self];
+    [mBrowser setPolicyDelegate: self];
+    [mBrowser setResourceLoadDelegate: self];
     [mBrowser setShouldCloseWithWindow: YES];
   }
   return self;
@@ -64,6 +66,37 @@
     [resultListener cancel];
 }
 
+- (NSURLRequest *)webView:(WebView *)sender
+                 resource:(id)identifier
+          willSendRequest:(NSURLRequest *)request 
+         redirectResponse:(NSURLResponse *)redirectResponse 
+           fromDataSource:(WebDataSource *)dataSource
+{  
+  // disable caching
+  NSMutableURLRequest *req = [request mutableCopy];
+  [req setCachePolicy: NSURLRequestReloadIgnoringLocalCacheData];
+  return req;
+}
+
+//--------------------------------------------------------------------------------------------------
+
+- (void)webView:(WebView *)webView decidePolicyForNavigationAction:(NSDictionary *)actionInformation 
+        request:(NSURLRequest *)request
+          frame:(WebFrame *)frame
+decisionListener:(id < WebPolicyDecisionListener >)listener
+{
+  if ([[actionInformation objectForKey: WebActionNavigationTypeKey] integerValue] == WebNavigationTypeLinkClicked)
+  {
+    NSURL *url = [[actionInformation objectForKey: WebActionElementKey] objectForKey: WebElementLinkURLKey];
+    if (url && mOwner->on_link_clicked([[url description] UTF8String]))
+    {
+      [listener ignore];
+      return;
+    }
+  }
+  [listener use];
+}
+
 //--------------------------------------------------------------------------------------------------
 
 - (NSString*) description
@@ -105,7 +138,10 @@
 - (void) navigate: (NSString*) target
 {
   NSURL* url = [NSURL URLWithString: target];
-  [[mBrowser mainFrame] loadRequest:[NSURLRequest requestWithURL: url]];
+  
+  [[mBrowser mainFrame] loadRequest: [NSURLRequest requestWithURL: url 
+                                                      cachePolicy: NSURLRequestReloadIgnoringCacheData
+                                                  timeoutInterval: 60.0]];
 }
 
 //--------------------------------------------------------------------------------------------------
