@@ -77,19 +77,19 @@ SearchReplace::SearchReplace()
 
   _replace_all_button.set_text(_("Replace All"));
   _replace_all_button.enable_internal_padding(true);
-  _replace_all_button.signal_clicked().connect(sigc::bind(sigc::mem_fun(this, &SearchReplace::button_pressed), &_replace_all_button));
+  scoped_connect(_replace_all_button.signal_clicked(),boost::bind(&SearchReplace::button_pressed, this, &_replace_all_button));
 
   _replace_button.set_text(_("Replace"));
   _replace_button.enable_internal_padding(true);
-  _replace_button.signal_clicked().connect(sigc::bind(sigc::mem_fun(this, &SearchReplace::button_pressed), &_replace_button));
+  scoped_connect(_replace_button.signal_clicked(),boost::bind(&SearchReplace::button_pressed, this, &_replace_button));
   
   _find_previous_button.set_text(_("Find Previous"));
   _find_previous_button.enable_internal_padding(true);
-  _find_previous_button.signal_clicked().connect(sigc::bind(sigc::mem_fun(this, &SearchReplace::button_pressed), &_find_previous_button));
+  scoped_connect(_find_previous_button.signal_clicked(),boost::bind(&SearchReplace::button_pressed, this, &_find_previous_button));
 
   _find_next_button.set_text(_("Find Next"));
   _find_next_button.enable_internal_padding(true);
-  _find_next_button.signal_clicked().connect(sigc::bind(sigc::mem_fun(this, &SearchReplace::button_pressed), &_find_next_button));
+  scoped_connect(_find_next_button.signal_clicked(),boost::bind(&SearchReplace::button_pressed, this, &_find_next_button));
 
   _button_box.set_spacing(12);
   _button_box.add(&_replace_all_button, false, true);
@@ -104,7 +104,7 @@ SearchReplace::SearchReplace()
   set_content(&_top_box);
 
   // The cancel button is not visible. It just serves as communicator to allow ESC to close the dialog.
-  _cancel_button.signal_clicked().connect(sigc::mem_fun(this, &SearchReplace::cancel_pressed));
+  scoped_connect(_cancel_button.signal_clicked(),boost::bind(&SearchReplace::cancel_pressed, this));
 }
 
 //--------------------------------------------------------------------------------------------------
