@@ -49,7 +49,7 @@ class TabViewImpl : public ViewImpl
   {
     TabView* tv = dynamic_cast< TabView* >(owner);
     if (tv)
-      tv->signal_tab_changed().emit();
+      (*tv->signal_tab_changed())();
   }
 
   static bool create(::mforms::TabView *self, mforms::TabViewType tabtype)
