@@ -60,6 +60,7 @@ private:
     int add_string(Gtk::TreeView *tree, const std::string &title, bool editable);
     int add_integer(Gtk::TreeView *tree, const std::string &title, bool editable);
     int add_check(Gtk::TreeView *tree, const std::string &title, bool editable);
+    int add_pixbuf(Gtk::TreeView *tree, const std::string &title);
   };
 
   ColumnRecord _columns;
@@ -68,10 +69,11 @@ private:
   Gtk::ScrolledWindow *_swin;
   Gtk::TreeView *_tree;
   sigc::connection _conn;
+  int _row_height;
 
   Glib::RefPtr<Gtk::ListStore> _list_store;
   Glib::RefPtr<Gtk::TreeModelSort> _sort_model;
-
+  std::map<std::string, Glib::RefPtr<Gdk::Pixbuf> > _pixbufs;
 
   virtual Gtk::Widget *get_outer() const { return _swin; }
   virtual Gtk::Widget *get_inner() const { return _tree; }
@@ -101,6 +103,7 @@ private:
   static bool get_check(TreeView *self, int row, int column);
   static std::string get_row_tag(TreeView *self, int row);
   static void set_row_tag(TreeView *self, int row, const std::string &value);
+  static void set_row_height(TreeView *self, int height);
 
   static void set_allow_sorting(TreeView* self, bool flag);
   static void freeze_refresh(TreeView* self, bool flag);
