@@ -20,6 +20,8 @@
 #define _LF_UTILITIES_H_
 
 #include <mforms/mforms.h>
+#include <sigc++/sigc++.h>
+
 #include "gtk_helpers.h"
 
 #include "lf_mforms.h"
@@ -47,14 +49,14 @@ class UtilitiesImpl
   static void show_wait_message(const std::string &title, const std::string &text);
   static bool hide_wait_message();
   static bool run_cancelable_wait_message(const std::string &title, const std::string &text,
-                                          const sigc::slot<void> &start_task, const sigc::slot<bool> &cancel_task);
+                                          const boost::function<void ()> &start_task, const boost::function<bool ()> &cancel_task);
   static void stop_cancelable_wait_message();
 
   static void set_clipboard_text(const std::string &text);
   static std::string get_clipboard_text();
   static void open_url(const std::string &url);
   static std::string get_special_folder(mforms::FolderType type);
-  static void add_timeout(float interval, const sigc::slot<bool> &slot);
+  static void add_timeout(float interval, const boost::function<bool ()> &slot);
 
   static void store_password(const std::string &service, const std::string &account, const std::string &password);
   static bool find_password(const std::string &service, const std::string &account, std::string &password);
@@ -72,7 +74,7 @@ class MainThreadRequestQueue
 {
   struct Request
   {
-    sigc::slot<void*> slot;
+    boost::function<void* ()> slot;
     void *result;
     Glib::Mutex mutex;
     Glib::Cond cond;
@@ -87,7 +89,7 @@ class MainThreadRequestQueue
 public:
   MainThreadRequestQueue();
   static MainThreadRequestQueue *get();
-  static void *perform(const sigc::slot<void*> &slot);
+  static void *perform(const boost::function<void* ()> &slot);
 };
 
 };
