@@ -54,6 +54,7 @@ protected:
   static void set_position(::mforms::View *self, int x, int y);
   static void client_to_screen(::mforms::View *self, MySQL::Geometry::Point& point);
   static void set_enabled(::mforms::View *self, bool flag);
+  static bool is_enabled(::mforms::View *self);
   static void set_name(::mforms::View *view, const std::string &name);
   static void relayout(::mforms::View *view);
   static void set_needs_repaint(::mforms::View *view);
@@ -64,6 +65,8 @@ protected:
   virtual void suspend_layout(bool flag) {}
   static void set_front_color(::mforms::View *self, const std::string &color);
   static void set_back_color(::mforms::View *self, const std::string &color);
+  static std::string get_front_color(::mforms::View *self);
+  static std::string get_back_color(::mforms::View *self);
   virtual void set_back_color(const std::string &color) {};
   static void set_back_image(::mforms::View *self, const std::string &path, mforms::ImageLayout layout);
   static void flush_events(::mforms::View *self);
