@@ -53,13 +53,13 @@ int str_color_to_int(const std::string& v)
 }
 
 //==============================================================================
-void scope_fclose(FILE* fp)
-{
-  if (fp)
-    fclose(fp);
-}
+//void scope_fclose(FILE* fp)
+//{
+//  if (fp)
+//    fclose(fp);
+//}
 
-typedef base::scope_ptr<FILE, &scope_fclose> FILE_auto_ptr;
+//typedef base::scope_ptr<FILE, &scope_fclose> FILE_auto_ptr;
 
 //==============================================================================
 //
@@ -104,7 +104,7 @@ Gtk::Widget *mforms::gtk::CodeEditorImpl::get_outer() const
  */
 static void load_style_names(const std::string path, mforms::gtk::StyleNameMap *map)
 {
-  FILE_auto_ptr fp = fopen(path.c_str(), "r");
+  base::FILE_scope_ptr fp = fopen(path.c_str(), "r");
 
   if (fp)
   {
@@ -367,9 +367,9 @@ void mforms::gtk::CodeEditorImpl::language_setup(const std::string& language)
 //------------------------------------------------------------------------------
 void mforms::gtk::CodeEditorImpl::setup_marker(const int marker_id, const char* icon_path, int background)
 {
-  const std::string full_path = mforms::App::get()->get_resource_path(icon_path);
-  FILE_auto_ptr fp = fopen(full_path.c_str(), "r");
-  std::auto_ptr<char> xpm(0);
+  const std::string     full_path = mforms::App::get()->get_resource_path(icon_path);
+  base::FILE_scope_ptr  fp        = fopen(full_path.c_str(), "r");
+  base::AutoCharArray   xpm(0);
 
   if (fp)
   {
@@ -378,11 +378,11 @@ void mforms::gtk::CodeEditorImpl::setup_marker(const int marker_id, const char*
     fseek(fp,0,SEEK_SET);
     if (size > 0)
     {
-      xpm.reset(new char[size]);
+      xpm = base::AutoCharArray(new char[size]);
       long items_read = fread(xpm.get(), 1, size, fp);
       // TODO: Check for EINTR and ENOMEM
       if (items_read != size)
-        xpm.reset(0);
+        xpm = base::AutoCharArray();
     }
   }
 
