@@ -102,9 +102,9 @@ void FormImpl::show_modal(::mforms::Form *self, ::mforms::Button *accept, ::mfor
     bool status = false;
 
     if (accept)
-      form->accept_c= accept->signal_clicked().connect(sigc::bind(sigc::mem_fun(form, &FormImpl::accept_clicked), &status, false));
+      form->accept_c= *form->scoped_connect(accept->signal_clicked(),sigc::bind(sigc::mem_fun(form, &FormImpl::accept_clicked), &status, false)).get();
     if (cancel)
-      form->cancel_c= cancel->signal_clicked().connect(sigc::bind(sigc::mem_fun(form, &FormImpl::cancel_clicked), &status, false));
+      form->cancel_c= *form->scoped_connect(cancel->signal_clicked(),sigc::bind(sigc::mem_fun(form, &FormImpl::cancel_clicked), &status, false)).get();
 
     form->_window->signal_key_release_event().connect(sigc::bind(sigc::mem_fun(form, &FormImpl::on_key_release), &status, false, accept, cancel));
 
@@ -148,9 +148,9 @@ bool FormImpl::run_modal(::mforms::Form *self, ::mforms::Button *accept, ::mform
 
     form->_result= false;
     if (accept)
-      form->accept_c= accept->signal_clicked().connect(sigc::bind(sigc::mem_fun(form, &FormImpl::accept_clicked), &form->_result, true));
+      form->accept_c= *form->scoped_connect(accept->signal_clicked(),sigc::bind(sigc::mem_fun(form, &FormImpl::accept_clicked), &form->_result, true)).get();
     if (cancel)
-      form->cancel_c= cancel->signal_clicked().connect(sigc::bind(sigc::mem_fun(form, &FormImpl::cancel_clicked), &form->_result, true));
+      form->cancel_c= *form->scoped_connect(cancel->signal_clicked(),sigc::bind(sigc::mem_fun(form, &FormImpl::cancel_clicked), &form->_result, true)).get();
 
     form->_window->signal_key_release_event().connect(sigc::bind(sigc::mem_fun(form, &FormImpl::on_key_release), &form->_result, true, accept, cancel));
 
@@ -212,7 +212,15 @@ FormImpl::FormImpl(::mforms::Form *form, ::mforms::Form *owner, mforms::FormFlag
   _window = new Gtk::Window(Gtk::WINDOW_TOPLEVEL);
 
   if (owner)
-    _window->set_transient_for(*static_cast<Gtk::Window*>(owner->get_data<FormImpl>()->get_outer()));
+  {
+    FormImpl* impl = owner->get_data<FormImpl>();
+    if (impl)
+    {
+      Gtk::Window *w = impl->get_window();
+      if (w)
+        _window->set_transient_for(*w);
+    }
+  }
 
   _window->set_position(Gtk::WIN_POS_CENTER);
 
@@ -239,6 +247,16 @@ void FormImpl::set_size(int width, int height)
   _window->set_size_request(width, height);
 }
 
+void FormImpl::init_main_form(Gtk::Window* main)
+{
+  mforms::Form* the_main_form = mforms::Form::main_form();
+  if (the_main_form)
+  {
+    static FormImpl* form = new FormImpl(the_main_form, (mforms::Form*)0, mforms::FormNone);
+    form->_window = main;
+  }
+}
+
 void FormImpl::init()
 {
   ::mforms::ControlFactory *f = ::mforms::ControlFactory::get_instance();
