@@ -35,7 +35,7 @@ mforms::gtk::ListBoxImpl::ListBoxImpl(::mforms::ListBox *self, bool multi_select
   _swin->set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
   _swin->set_shadow_type(Gtk::SHADOW_IN);
   _swin->add(*_lbox);
-  _lbox->show();
+  _lbox->show_all();
 
   _lbox->append_column("Item", _ccol._item);
   _lbox->set_headers_visible(false);
