@@ -308,7 +308,7 @@ class GridView : public mforms::gtk::ViewImpl
 
     void content_edited(const Path& p, const int col)
     {
-      _mgrid->signal_content_edited().emit(p, col);
+      (*_mgrid->signal_content_edited())(p, col);
     }
   private:
     //bool find_all_process_iter(const Gtk::TreeIter& it);
@@ -1733,7 +1733,7 @@ bool GridView::button_release_slot(GdkEventButton* ev)
                   if (cell->is_editable())
                     cr->activate(path);
                   else
-                    _mgrid->signal_ro_content_clicked().emit(cast_path(path), cr->column());
+                    (*_mgrid->signal_ro_content_clicked())(cast_path(path), cr->column());
                 }
                 break;
               }
@@ -1741,7 +1741,7 @@ bool GridView::button_release_slot(GdkEventButton* ev)
               case mforms::CellText:
               {
                 if (hits && !cell->is_editable())
-                  _mgrid->signal_ro_content_clicked().emit(cast_path(path), cr->column());
+                  (*_mgrid->signal_ro_content_clicked())(cast_path(path), cr->column());
                 break;
               }
               case mforms::CellInvalid:
