@@ -355,9 +355,17 @@ std::string UtilitiesImpl::get_special_folder(mforms::FolderType type)
   return path.empty() ? "~" : path;
 }
 
-void UtilitiesImpl::add_timeout(float interval, const sigc::slot<bool> &slot)
+//------------------------------------------------------------------------------
+inline bool run_slot(const boost::function<bool ()> slot)
 {
-  Glib::signal_timeout().connect(slot, interval*1000);
+  return slot();
+}
+
+//------------------------------------------------------------------------------
+void UtilitiesImpl::add_timeout(float interval, const boost::function<bool ()> &slot)
+{
+  if (slot)
+    Glib::signal_timeout().connect(sigc::bind(sigc::ptr_fun(run_slot), slot), interval*1000);
 }
 
 
@@ -838,13 +846,13 @@ bool UtilitiesImpl::move_to_trash(const std::string &path)
 
 
 bool UtilitiesImpl::run_cancelable_wait_message(const std::string &title, const std::string &text,
-                                                 const sigc::slot<void> &start_task, const sigc::slot<bool> &cancel_task)
+                                                 const boost::function<void ()> &start_task, const boost::function<bool ()> &cancel_task)
 {
   if (!tmc)
     tmc = new TransparentMessage();
   if (tmc)
   {
-    tmc->show_message(title, text, cancel_task);
+    tmc->show_message(title, text, sigc::mem_fun(&cancel_task,&boost::function<bool ()>::operator()));
     tmc->running_modal = true;
 
     Glib::signal_idle().connect(sigc::bind_return(start_task, false));
@@ -933,7 +941,7 @@ MainThreadRequestQueue *MainThreadRequestQueue::get()
   return q;
 }
 
-void *MainThreadRequestQueue::perform(const sigc::slot<void*> &slot)
+void *MainThreadRequestQueue::perform(const boost::function<void* ()> &slot)
 {
   MainThreadRequestQueue *self = MainThreadRequestQueue::get();
 
