@@ -87,5 +87,5 @@ std::vector<int> ListBox::get_selected_indices()
 void ListBox::selection_changed()
 {
   if (!_updating)
-    _signal_changed.emit();
+    _signal_changed();
 }
