@@ -105,7 +105,7 @@ void Menu::set_item_enabled(int i, bool flag)
 }
 
 
-void Menu::set_handler(const sigc::slot<void, const std::string&> &action_handler)
+void Menu::set_handler(const boost::function<void (const std::string&)> &action_handler)
 {
   _action_handler = action_handler;
 }
@@ -114,7 +114,7 @@ void Menu::set_handler(const sigc::slot<void, const std::string&> &action_handle
 void Menu::popup_at(Object *control, int x, int y)
 {
 #ifndef _WIN32
-  _on_will_show.emit(); // Popping up the menu will trigger the on_show event on Win.
+  _on_will_show(); // Popping up the menu will trigger the on_show event on Win.
 #endif
   
   _menu_impl->popup_at(this, control, x, y);
@@ -124,7 +124,7 @@ void Menu::popup_at(Object *control, int x, int y)
 void Menu::popup()
 {
 #ifndef _WIN32
-  _on_will_show.emit(); // Popping up the menu will trigger the on_show event on Win.
+  _on_will_show(); // Popping up the menu will trigger the on_show event on Win.
 #endif
   
   _menu_impl->popup_at(this, 0, 0, 0);  
