@@ -21,6 +21,7 @@
 
 #include <mforms/view.h>
 #include <map>
+#include "base/trackable.h"
 
 namespace mforms {
   
@@ -48,7 +49,7 @@ namespace mforms {
    so that their minimal sizes are respected. If there is leftover space in the Box,
    it will be evenly distributed among child views that are marked to expand.
    */
-  class MFORMS_EXPORT Box : public View
+  class MFORMS_EXPORT Box : public View, public base::trackable
   {
   public:
     /** Constructor.
