@@ -128,7 +128,7 @@ namespace mforms {
      *    The line in which the change happended (the start line if it spans more than one line).
      *    The number of lines which have been added (if positive) or removed (if negative).
      */
-    sigc::signal<void, int, int> signal_changed() { return _signal_changed; }
+    boost::signals2::signal<void (int, int)>* signal_changed() { return &_signal_changed; }
 
     /** Signal emitted when the user clicks on the gutter.
      *  Parameters are:
@@ -136,7 +136,7 @@ namespace mforms {
      *    The line in which this happened.
      *    The modifier keys that were pressed.
      */
-    sigc::signal<void, int, int, mforms::ModifierKey> signal_gutter_clicked() { return _signal_gutter_clicked; }
+    boost::signals2::signal<void (int, int, mforms::ModifierKey)>* signal_gutter_clicked() { return &_signal_gutter_clicked; }
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
     void text_changed(int line, int linesAdded);
@@ -147,8 +147,8 @@ namespace mforms {
     CodeEditorImplPtrs* _code_editor_impl;
     bool _updating;
 
-    sigc::signal<void, int, int> _signal_changed;
-    sigc::signal<void, int, int, mforms::ModifierKey> _signal_gutter_clicked;
+    boost::signals2::signal<void (int, int)> _signal_changed;
+    boost::signals2::signal<void (int, int, mforms::ModifierKey)> _signal_gutter_clicked;
   };
 };
 
