@@ -30,6 +30,7 @@
 #include "mforms/button.h"
 #include "mforms/textentry.h"
 #include "mforms/filechooser.h"
+#include "base/trackable.h"
 
 namespace mforms {
 
@@ -41,8 +42,8 @@ namespace mforms {
     FileChooserType _type;
     std::string _extensions;
     std::string _default_extension;
-    sigc::slot<void> _on_validate;
-    sigc::connection _browse_connection; // The connection created when connecting the browse callback.
+    boost::function<void ()> _on_validate;
+    boost::signals2::connection _browse_connection; // The connection created when connecting the browse callback.
     bool _show_hidden;
   protected:
     void enable_file_browsing();
@@ -56,11 +57,11 @@ namespace mforms {
     
     void initialize(const std::string& initial_path, FileChooserType type, const std::string& extensions,
                     const std::string& button_text= "...", bool show_hidden = false,
-                    sigc::slot<void> on_validate= sigc::slot<void>());
+                    boost::function<void ()> on_validate= boost::function<void ()>());
     void set_filename(const std::string &path);
     std::string get_filename();
     void set_enabled(bool value);
-    void set_browse_callback(sigc::slot<void> browse_callback);
+    void set_browse_callback(boost::function<void ()> browse_callback);
 
     TextEntry *get_entry() const { return _edit; }
     
@@ -69,7 +70,7 @@ namespace mforms {
     virtual bool get_bool_value();
 
 #ifndef SWIG
-    sigc::signal<void>& signal_changed() { return _edit->signal_changed(); }
+    boost::signals2::signal<void ()>* signal_changed() { return _edit->signal_changed(); }
 #endif
     
     static void clear_stored_filenames();
