@@ -100,8 +100,8 @@ namespace mforms {
     Menu *get_context_menu() { return _context_menu; }
     
 #ifndef SWIG
-    sigc::signal<void, bec::NodeId, int> signal_row_activate() { return _activate_signal; }
-    sigc::signal<void>  signal_changed() {return _changed_signal;}
+    boost::signals2::signal<void (const bec::NodeId&, int)>* signal_row_activate() { return &_activate_signal; }
+    boost::signals2::signal<void ()>* signal_changed() {return &_changed_signal;}
 
   public:
     void row_activate_callback(const bec::NodeId &node, int column);
@@ -110,8 +110,8 @@ namespace mforms {
 #endif
   protected:
     GRTTreeViewImplPtrs *_grttreeview_impl;
-    sigc::signal<void, bec::NodeId, int> _activate_signal;
-    sigc::signal<void> _changed_signal;
+    boost::signals2::signal<void (const bec::NodeId&, int)> _activate_signal;
+    boost::signals2::signal<void ()> _changed_signal;
     Menu *_context_menu;
   };
 }
