@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -90,6 +90,10 @@
 #include <mforms/webbrowser.h>
 #include <mforms/popup.h>
 #include <mforms/code_editor.h>
+#include <mforms/menubar.h>
+#include <mforms/toolbar.h>
+#include <mforms/task_sidebar.h>
+#include <mforms/simplegrid.h>
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 namespace mforms
@@ -124,6 +128,10 @@ namespace mforms
     WebBrowserImplPtrs _webbrowser_impl;
     PopupImplPtrs _popup_impl;
     CodeEditorImplPtrs _code_editor_impl;
+    MenuItemImplPtrs _menu_item_impl;
+    ToolBarImplPtrs _tool_bar_impl;
+    TaskSidebarImplPtrs _task_sidebar_impl;
+    SimpleGridImplPtrs _simple_grid_impl;
 
     AppImplPtrs _app_impl;
     AppViewImplPtrs _app_view_impl;
