@@ -20,7 +20,7 @@
 #define __MFORMS_SIMPLEGRIDVIEW_H__
 
 #include <mforms/view.h>
-#include <sigc++/sigc++.h>
+#include <boost/signals2.hpp>
 #include <string>
 #include <vector>
 #include <map>
@@ -70,12 +70,12 @@ class MFORMS_EXPORT SimpleGrid : public mforms::View
     typedef SimpleGridPath  Path;
 
     // signals to notify customers about data change
-    //typedef sigc::signal<void, const Path&, const int>     SignalCellValueChanged;// (rowid, column)
-    //typedef sigc::slot<bool, SimpleGrid*, const Path&>     ProcessRowSlot;
+    //typedef boost::signals2::signal<void, const Path&, const int>     SignalCellValueChanged;// (rowid, column)
+    //typedef boost::function<bool (SimpleGrid*, const Path&)>     ProcessRowSlot;
 
-    //typedef sigc::slot<bool, SimpleGrid*, const Value&>              ValidationSlot;
-    //typedef sigc::slot<bool, SimpleGrid*, const Value&>              FindSlot;
-    //typedef sigc::slot<bool, SimpleGrid*, const Path&, const int>    ValidationHintSlot; // (self*, rowid, col_id)
+    //typedef boost::function<bool (SimpleGrid*, const Value&)>              ValidationSlot;
+    //typedef boost::function<bool (SimpleGrid*, const Value&)>              FindSlot;
+    //typedef boost::function<bool (SimpleGrid*, const Path&, const int)>    ValidationHintSlot; // (self*, rowid, col_id)
 
     int add_column(const std::string& name);
 
@@ -111,13 +111,13 @@ class MFORMS_EXPORT SimpleGrid : public mforms::View
     void scroll_to_row(const Path& rid);
 
     #ifndef SWIG
-    sigc::signal<void, const Path&, const int>  signal_content_edited()
+    boost::signals2::signal<void (const Path&, const int)>*  signal_content_edited()
     {
-      return _signal_content_edited;
+      return &_signal_content_edited;
     }
-    sigc::signal<void, const Path&, const int>  signal_ro_content_clicked()
+    boost::signals2::signal<void (const Path&, const int)>*  signal_ro_content_clicked()
     {
-      return _signal_ro_content_clicked;
+      return &_signal_ro_content_clicked;
     }
     #endif
 
@@ -145,8 +145,8 @@ class MFORMS_EXPORT SimpleGrid : public mforms::View
     //  return _signal_cell_changed;
     //}
   private:
-    sigc::signal<void, const Path&, const int>  _signal_ro_content_clicked;
-    sigc::signal<void, const Path&, const int>  _signal_content_edited;
+    boost::signals2::signal<void (const Path&, const int)>                      _signal_ro_content_clicked;
+    boost::signals2::signal<void (const Path&, const int)>                      _signal_content_edited;
 
   #ifndef DOXYGEN_SHOULD_SKIP_THIS
   #ifndef SWIG
