@@ -59,9 +59,9 @@ namespace mforms
   {
     TabViewImplPtrs *_tabview_impl;
 
-    sigc::signal<void> _signal_tab_changed;
-    sigc::signal<bool, int> _signal_tab_closing;
-    sigc::signal<void, int> _signal_tab_closed;
+    boost::signals2::signal<void ()> _signal_tab_changed;
+    boost::signals2::signal<bool (int)> _signal_tab_closing;
+    boost::signals2::signal<void (int)> _signal_tab_closed;
 
   public:
     /** Constructor.
@@ -90,13 +90,13 @@ namespace mforms
      
      In Python use add_tab_changed_callback()
      */
-    sigc::signal<void> signal_tab_changed() { return _signal_tab_changed; }
+    boost::signals2::signal<void ()>* signal_tab_changed() { return &_signal_tab_changed; }
     
     /** Callback called when a tab is about to close. Returning false will prevent the closure. */
-    sigc::signal<bool, int> signal_tab_closing() { return _signal_tab_closing; }
+    boost::signals2::signal<bool (int)>* signal_tab_closing() { return &_signal_tab_closing; }
 
     /** Callback called when a tab has been closed. */
-    sigc::signal<void, int> signal_tab_closed() { return _signal_tab_closed; }
+    boost::signals2::signal<void (int)>* signal_tab_closed() { return &_signal_tab_closed; }
 #endif
   };
 };
