@@ -48,7 +48,7 @@ namespace mforms {
   class MFORMS_EXPORT TaskSidebar : public Box
   {
   private:
-    sigc::signal<void, const std::string&> _on_section_command;
+    boost::signals2::signal<void (const std::string&)> _on_section_command;
 
   protected:
     TaskSidebar();
@@ -79,7 +79,7 @@ namespace mforms {
     virtual int select_entry(const std::string& section, const std::string& title) = 0;
     virtual void clear_selection() = 0;
 
-    sigc::signal<void, const std::string&>& on_section_command() { return _on_section_command;};
+    boost::signals2::signal<void (const std::string&)>* on_section_command() { return &_on_section_command;};
 
   private:
   };
