@@ -21,7 +21,7 @@
 #define _MFORMS_VIEW_H_
 
 #include <mforms/base.h>
-#include <sigc++/sigc++.h>
+#include <boost/signals2.hpp>
 
 #include "base/geometry.h"
 
@@ -79,6 +79,7 @@ namespace mforms {
     void (__stdcall *set_font)(View *self, const std::string&);
     
     void (__stdcall *set_enabled)(View *self, bool);
+    bool (__stdcall *is_enabled)(View *self);
     void (__stdcall *relayout)(View *self);
     void (__stdcall *set_needs_repaint)(View *self);
 
@@ -112,7 +113,7 @@ namespace mforms {
 
     View *_parent;
 
-    sigc::signal<void> _signal_resized;
+    boost::signals2::signal<void ()> _signal_resized;
 
     void add_subview(View *sv);
     void remove_subview(View *sv);
@@ -130,7 +131,7 @@ namespace mforms {
     AutoResizeMode get_resize_mode();
     void set_resize_mode(AutoResizeMode mode);
 
-    sigc::signal<void> signal_resized() { return _signal_resized; }
+    boost::signals2::signal<void ()>* signal_resized() { return &_signal_resized; }
     
     void set_name(const std::string &name);
     void set_tooltip(const std::string &text);
@@ -154,6 +155,7 @@ namespace mforms {
     void show(bool flag= true);
     bool is_shown();
     void set_enabled(bool flag);
+    bool is_enabled();
     void set_needs_repaint();
 
     virtual void needs_resize();
