@@ -90,5 +90,5 @@ void Panel::set_padding(int pad)
 
 void Panel::check_toggled()
 {
-  _signal_toggled.emit();
+  _signal_toggled();
 }
