@@ -23,7 +23,7 @@
 using namespace mforms;
 
 
-static sigc::signal<void, int> _radio_activated;
+static boost::signals2::signal<void (int)> _radio_activated;
 static int radio_group_id = 0;
 
 int RadioButton::new_id()
@@ -39,7 +39,7 @@ RadioButton::RadioButton(int group_id)
 
   _radio_impl->create(this, group_id);
     
-  _radio_activated.connect(sigc::mem_fun(this, &RadioButton::radio_activated));
+  _radio_activated.connect(boost::bind(&RadioButton::radio_activated, this, _1));
 }
 
 
@@ -48,7 +48,7 @@ void RadioButton::set_active(bool flag)
   _updating= true;
   (*_radio_impl->set_active)(this, flag);
   if (flag)
-    _radio_activated.emit(_group_id);
+    _radio_activated(_group_id);
   _updating= false;
 }
 
@@ -71,9 +71,9 @@ void RadioButton::callback()
   if (!_updating)
   {
     _updating = true;
-    _radio_activated.emit(_group_id);
+    _radio_activated(_group_id);
     _updating = false;
-    _signal_toggled.emit();
+    _signal_toggled();
   }
 
   Button::callback();
