@@ -101,7 +101,7 @@ int Selector::get_item_count()
 void Selector::callback()
 {
   if (!_updating)
-    _signal_changed.emit();
+    _signal_changed();
 }
 
 void Selector::set_value(const std::string& value)
