@@ -65,6 +65,10 @@ void __stdcall FormImpl::center(Form *self)
 {
 }
 
+void __stdcall FormImpl::end_modal(Form *self, bool result)
+{
+}
+
 
 FormImpl::FormImpl(::mforms::Form *form, ::mforms::Form *owner, mforms::FormFlag form_flag)
   : ViewImpl(form)
@@ -87,6 +91,7 @@ void FormImpl::init()
   f->_form_impl.set_content= &FormImpl::set_content;
   f->_form_impl.flush_events= &FormImpl::flush_events;
   f->_form_impl.center      = &FormImpl::center;
+  f->_form_impl.end_modal = &FormImpl::end_modal;
 }
 
 };
