@@ -40,8 +40,12 @@
 #include "../stub_utilities.h"
 #include "../stub_drawbox.h"
 #include "../stub_menu.h"
+#include "../stub_menuitem.h"
 #include "../stub_splitter.h"
 #include "../stub_grttreeview.h"
+#include "../stub_codeeditor.h"
+#include "../stub_toolbar.h"
+#include "../stub_simplegrid.h"
 
 sigc::slot<void,std::string> mforms::stub::UtilitiesImpl::open_url_slot;
 
@@ -71,7 +75,11 @@ void ::mforms::stub::init()
   DrawBoxImpl::init();
   SplitterImpl::init();
   MenuImpl::init();
+  MenuItemImpl::init();
   GRTTreeViewImpl::init();
+  CodeEditorImpl::init();
+  ToolBarImpl::init();
+  SimpleGridImpl::init();
   puts("done setting up mforms stubs...");
 }
 
