@@ -44,6 +44,15 @@ protected:
   {
   }
 
+  static void __stdcall set_scale_contents(ImageBox *, bool)
+  {
+  }
+
+  static void __stdcall set_image_align(ImageBox *, Alignment)
+  {
+  }
+
+
  public:
   static void init()
   {
@@ -51,6 +60,8 @@ protected:
 
     f->_imagebox_impl.create         = &ImageBoxImpl::create;
     f->_imagebox_impl.set_image      = &ImageBoxImpl::set_image;
+    f->_imagebox_impl.set_scale_contents = &ImageBoxImpl::set_scale_contents;
+    f->_imagebox_impl.set_image_align    = &ImageBoxImpl::set_image_align;
   }
 };
 
