@@ -55,6 +55,9 @@ protected:
   static void __stdcall set_front_color(::mforms::View *self, const std::string &color);
   static void __stdcall set_back_color(::mforms::View *self, const std::string &color);
   static void __stdcall set_back_image(::mforms::View *self, const std::string &path, mforms::ImageLayout layout);
+  static void __stdcall destroy(View *self);
+  static void __stdcall set_padding(View *self, const MySQL::Geometry::Padding&);
+  static void __stdcall client_to_screen(View *self, MySQL::Geometry::Point&);
 public:
   static void init();
 };
