@@ -91,7 +91,3 @@ void Table::set_homogeneous(bool value)
   (*_table_impl->set_homogeneous)(this, value);
 }
 
-void Table::set_back_color(const std::string& color)
-{
-  _table_impl->set_back_color(this, color);
-}
