@@ -104,7 +104,7 @@ void TreeView::set_row_height(int height)
     _treeview_impl->set_row_height(this, height);
 }
 
-void TreeView::set_cell_edit_handler(const sigc::slot<void, int, int, std::string> &handler)
+void TreeView::set_cell_edit_handler(const boost::function<void (int, int, std::string)> &handler)
 {
   _cell_edited = handler;
 }
@@ -161,12 +161,12 @@ bool TreeView::get_check(int row, int column)
 void TreeView::changed()
 {
   if (!_updating)
-    _signal_changed.emit();
+    _signal_changed();
 }
 
 void TreeView::row_activated(int row, int column)
 {
-  _signal_activated.emit(row, column);
+  _signal_activated(row, column);
 }
 
 
