@@ -154,44 +154,48 @@ bool Utilities::hide_wait_message()
 
 struct CancellableTaskData
 {
-  sigc::slot<void*> task;
+  boost::function<void* ()> task;
   boost::shared_ptr<bool> finished_flag;
   boost::shared_ptr<void*> result_ptr;
-  GMutex *mutex;
+  boost::shared_ptr<GMutex> mutex;
 };
 
 static void* cancellable_task_thread(CancellableTaskData *data)
 {
+  std::auto_ptr<CancellableTaskData> autodel(data);
+
   void *ptr = data->task();
-
-  g_mutex_lock(data->mutex);
-
-  *data->finished_flag = true;
+  g_mutex_lock(data->mutex.get());
   *data->result_ptr = ptr;
+  *data->finished_flag = true;
   ControlFactory::get_instance()->_utilities_impl.stop_cancelable_wait_message();
-  g_mutex_unlock(data->mutex);
-  g_mutex_free(data->mutex);
-  delete data;
+  g_mutex_unlock(data->mutex.get());
   return 0;
 }
 
-static void real_mutex_unlock(GMutex *m)
+static void real_mutex_unlock(boost::shared_ptr<GMutex> m)
 {
-  g_mutex_unlock(m);
+  g_mutex_unlock(m.get());
+}
+
+static void mutex_free(GMutex *m)
+{
+  g_mutex_free(m);
 }
 
 bool Utilities::run_cancelable_task(const std::string &title, const std::string &text,
-                                    const sigc::slot<void*> &task,
-                                    const sigc::slot<bool> &cancel_task,
+                                    const boost::function<void* ()> &task,
+                                    const boost::function<bool ()> &cancel_task,
                                     void *&task_result)
 {
   GThread *thread;
   GError *error = NULL;
   CancellableTaskData *data = new CancellableTaskData(); // this is freed by the thread
   boost::shared_ptr<bool> finished(new bool(false));
-  boost::shared_ptr<void*> result(new void*(0));
+  boost::shared_ptr<void*> result(new void*((void*)-1));
+  boost::shared_ptr<GMutex> lock(g_mutex_new(), mutex_free);
   
-  data->mutex = g_mutex_new();
+  data->mutex = lock;
   data->task = task;
   data->finished_flag = finished;
   
@@ -201,31 +205,38 @@ bool Utilities::run_cancelable_task(const std::string &title, const std::string
   // cancelled task actually finishes executing, which would invalidate any ptr to task_result 
   data->result_ptr = result;
   
-  g_mutex_lock(data->mutex);
-
+  g_mutex_lock(lock.get());
   // start a thread that will run the task
   thread = g_thread_create((void*(*)(void*))cancellable_task_thread, data, 0, &error);
   if (!thread)
   {
-    g_mutex_unlock(data->mutex);
-    g_mutex_free(data->mutex);
+    g_mutex_unlock(lock.get());
     delete data;
     std::string msg("Error creating thread: ");
     msg.append(error->message);
     g_error_free(error);
     throw std::runtime_error(msg);
   }
-  
-  if (ControlFactory::get_instance()->_utilities_impl.run_cancelable_wait_message(title, text, 
-        sigc::bind(sigc::ptr_fun(real_mutex_unlock), data->mutex), cancel_task))
+
+  boost::function<void ()> signal_ready = boost::bind(&real_mutex_unlock, data->mutex);
+
+retry:
+  if (ControlFactory::get_instance()->_utilities_impl.run_cancelable_wait_message(title, text, signal_ready, cancel_task))
   {
+    signal_ready = boost::function<void ()>();
+
+    // wait for the thread to finish clean up
+    
+    // sometimes, in the mac, there's a race and/or bug that causes the event loop
+    // from the wait panel dialog to be exited when a nested modal dialog is closed.
+    // clicking OK for the nested dialog, exits the wait panel, which woudl cause it
+    // to return prematurely.. just execute the modal panel again if that's the case
+    if (!*finished)
+      goto retry;
+
     // task completed
-    if (*finished)
-    {
-      task_result = *result;
-      return true;
-    }
-    return false;
+    task_result = *result;
+    return true;
   }
   else
   {
@@ -286,7 +297,7 @@ bool Utilities::move_to_trash(const std::string &path)
 
 //--------------------------------------------------------------------------------------------------
 
-void Utilities::add_timeout(float interval, const sigc::slot<bool> &callback)
+void Utilities::add_timeout(float interval, const boost::function<bool ()> &callback)
 {
   ControlFactory::get_instance()->_utilities_impl.add_timeout(interval, callback);
 }
@@ -381,7 +392,7 @@ void Utilities::forget_password(const std::string &service, const std::string &a
 
 //-------------------------------------------------------------------------------
 
-void *Utilities::perform_from_main_thread(const sigc::slot<void*> &slot)
+void *Utilities::perform_from_main_thread(const boost::function<void* ()> &slot)
 {
   return ControlFactory::get_instance()->_utilities_impl.perform_from_main_thread(slot);
 }
@@ -505,10 +516,10 @@ static bool _ask_for_password(const std::string &title, const std::string &servi
                              bool prompt_storage, std::string &ret_password /*out*/, bool &ret_store /*out*/)
 {
   if (Utilities::in_main_thread())
-    return (bool)_ask_for_password_main(title, service, &username, prompt_storage, &ret_password, &ret_store);
+    return _ask_for_password_main(title, service, &username, prompt_storage, &ret_password, &ret_store) != NULL;
   else
-    return (bool)Utilities::perform_from_main_thread(sigc::bind(sigc::ptr_fun(_ask_for_password_main), 
-                                                     title, service, &username, prompt_storage, &ret_password, &ret_store));
+    return Utilities::perform_from_main_thread(boost::bind(&_ask_for_password_main, 
+                                               title, service, &username, prompt_storage, &ret_password, &ret_store)) != NULL;
 }
 
 //--------------------------------------------------------------------------------------------------
