@@ -126,7 +126,7 @@ void AppImpl::set_show_file_dialog(StrStrStrStrDelegate^ dt)
     gcnew StrStrStrStrWrapperDelegate(this, &AppImpl::show_file_dialog_wrapper);
   IntPtr ip = Marshal::GetFunctionPointerForDelegate(show_file_dialog_wrapper_delegate);
   STR_STR_STR_STR_CB cb = static_cast<STR_STR_STR_STR_CB>(ip.ToPointer());
-  _callbacks->show_file_dialog= sigc::ptr_fun(cb);
+  _callbacks->show_file_dialog= boost::bind(cb, _1, _2, _3);
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -138,7 +138,7 @@ void AppImpl::set_show_status_text(VoidStrDelegate^ dt)
     gcnew VoidStrWrapperDelegate(this, &AppImpl::show_status_text_wrapper);
   IntPtr ip = Marshal::GetFunctionPointerForDelegate(show_status_text_wrapper_delegate);
   VOID_STR_CB cb = static_cast<VOID_STR_CB>(ip.ToPointer());
-  _callbacks->show_status_text= sigc::ptr_fun(cb);
+  _callbacks->show_status_text= boost::bind(cb, _1);
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -150,7 +150,7 @@ void AppImpl::set_show_progress(BoolStrStrFloatDelegate^ dt)
     gcnew BoolStrStrFloatWrapperDelegate(this, &AppImpl::show_progress_wrapper);
   IntPtr ip = Marshal::GetFunctionPointerForDelegate(show_progress_wrapper_delegate);
   BOOL_STR_STR_FLOAT_CB cb = static_cast<BOOL_STR_STR_FLOAT_CB>(ip.ToPointer());
-  _callbacks->show_progress= sigc::ptr_fun(cb);
+  _callbacks->show_progress= boost::bind(cb, _1, _2, _3);
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -162,7 +162,7 @@ void AppImpl::set_request_input(BoolStrIntStrPtrDelegate^ dt)
     gcnew BoolStrIntStrPtrWrapperDelegate(this, &AppImpl::request_input_wrapper);
   IntPtr ip = Marshal::GetFunctionPointerForDelegate(request_input_wrapper_delegate);
   BOOL_STR_INT_STRPTR_CB cb = static_cast<BOOL_STR_INT_STRPTR_CB>(ip.ToPointer());
-  _callbacks->request_input= sigc::ptr_fun(cb);
+  _callbacks->request_input= boost::bind(cb, _1, _2, _3);
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -174,7 +174,7 @@ void AppImpl::set_create_diagram(CanvasViewStringStringIntPtrDelegate^ dt)
     gcnew CanvasViewDiagramWrapperDelegate(this, &AppImpl::create_diagram_wrapper);
   IntPtr ip = Marshal::GetFunctionPointerForDelegate(create_diagram_wrapper_delegate);
   CANVASVIEW_DIAGRAM_CB cb = static_cast<CANVASVIEW_DIAGRAM_CB>(ip.ToPointer());
-  _callbacks->create_diagram= sigc::ptr_fun(cb);
+  _callbacks->create_diagram= boost::bind(cb, _1);
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -186,7 +186,7 @@ void AppImpl::set_destroy_view(VoidCanvasViewDelegate^ dt)
     gcnew VoidCanvasViewWrapperDelegate(this, &AppImpl::destroy_view_wrapper);
   IntPtr ip = Marshal::GetFunctionPointerForDelegate(destroy_view_wrapper_delegate);
   VOID_CANVASVIEW_CB cb = static_cast<VOID_CANVASVIEW_CB>(ip.ToPointer());
-  _callbacks->destroy_view= sigc::ptr_fun(cb);
+  _callbacks->destroy_view= boost::bind(cb, _1);
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -198,7 +198,7 @@ void AppImpl::set_switched_view(VoidCanvasViewDelegate^ dt)
     gcnew VoidCanvasViewWrapperDelegate(this, &AppImpl::switched_view_wrapper);
   IntPtr ip = Marshal::GetFunctionPointerForDelegate(switched_view_wrapper_delegate);
   VOID_CANVASVIEW_CB cb = static_cast<VOID_CANVASVIEW_CB>(ip.ToPointer());
-  _callbacks->switched_view= sigc::ptr_fun(cb);
+  _callbacks->switched_view= boost::bind(cb, _1);
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -210,7 +210,7 @@ void AppImpl::set_tool_changed(VoidCanvasViewDelegate^ dt)
     gcnew VoidCanvasViewWrapperDelegate(this, &AppImpl::tool_changed_wrapper);
   IntPtr ip = Marshal::GetFunctionPointerForDelegate(tool_changed_wrapper_delegate);
   VOID_CANVASVIEW_CB cb = static_cast<VOID_CANVASVIEW_CB>(ip.ToPointer());
-  _callbacks->tool_changed= sigc::ptr_fun(cb);
+  _callbacks->tool_changed= boost::bind(cb, _1);
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -222,7 +222,7 @@ void AppImpl::set_open_editor(IntPtrGRTManagerModuleStrStrGrtListFlagsDelegate^
     gcnew IntGRTManagerModuleStrStrGrtListFlagsWrapperDelegate(this, &AppImpl::open_editor_wrapper);
   IntPtr ip = Marshal::GetFunctionPointerForDelegate(open_editor_wrapper_delegate);
   INT_GRTMANAGER_MODULE_STR_STR_GRTLIST_FLAGS_CB cb = static_cast<INT_GRTMANAGER_MODULE_STR_STR_GRTLIST_FLAGS_CB>(ip.ToPointer());
-  _callbacks->open_editor= sigc::ptr_fun(cb);
+  _callbacks->open_editor= boost::bind(cb, _1, _2, _3, _4, _5, _6);
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -234,7 +234,7 @@ void AppImpl::set_show_editor(VoidIntPtrDelegate^ dt)
     gcnew VoidIntPtrWrapperDelegate(this, &AppImpl::show_editor_wrapper);
   IntPtr ip = Marshal::GetFunctionPointerForDelegate(show_editor_wrapper_delegate);
   VOID_INT64_CB cb = static_cast<VOID_INT64_CB>(ip.ToPointer());
-  _callbacks->show_editor= sigc::ptr_fun(cb);
+  _callbacks->show_editor= boost::bind(cb, _1);
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -246,7 +246,7 @@ void AppImpl::set_hide_editor(VoidIntPtrDelegate^ dt)
     gcnew VoidIntPtrWrapperDelegate(this, &AppImpl::hide_editor_wrapper);
   IntPtr ip = Marshal::GetFunctionPointerForDelegate(hide_editor_wrapper_delegate);
   VOID_INT64_CB cb = static_cast<VOID_INT64_CB>(ip.ToPointer());
-  _callbacks->hide_editor= sigc::ptr_fun(cb);
+  _callbacks->hide_editor= boost::bind(cb, _1);
 }
 
 
@@ -259,7 +259,7 @@ void AppImpl::set_refresh_gui(VoidRefreshTypeStringIntPtrDelegate ^ dt)
     gcnew VoidRefreshTypeStringIntPtrWrapperDelegate(this, &AppImpl::refresh_gui_wrapper);
   IntPtr ip = Marshal::GetFunctionPointerForDelegate(refresh_gui_wrapper_delegate);
   VOID_REFRESHTYPE_STRING_INTPTR_CB cb = static_cast<VOID_REFRESHTYPE_STRING_INTPTR_CB>(ip.ToPointer());
-  _callbacks->refresh_gui= sigc::ptr_fun(cb);
+  _callbacks->refresh_gui= boost::bind(cb, _1, _2, _3);
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -271,7 +271,7 @@ void AppImpl::set_perform_command(VoidStrDelegate ^ dt)
     gcnew VoidStrWrapperDelegate(this, &AppImpl::perform_command_wrapper);
   IntPtr ip = Marshal::GetFunctionPointerForDelegate(perform_command_wrapper_delegate);
   VOID_STR_CB cb = static_cast<VOID_STR_CB>(ip.ToPointer());
-  _callbacks->perform_command = sigc::ptr_fun(cb);
+  _callbacks->perform_command = boost::bind(cb, _1);
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -283,7 +283,7 @@ void AppImpl::set_lock_gui(VoidBoolDelegate^ dt)
     gcnew VoidBoolWrapperDelegate(this, &AppImpl::lock_gui_wrapper);
   IntPtr ip = Marshal::GetFunctionPointerForDelegate(lock_gui_wrapper_delegate);
   VOID_BOOL_CB cb = static_cast<VOID_BOOL_CB>(ip.ToPointer());
-  _callbacks->lock_gui= sigc::ptr_fun(cb);
+  _callbacks->lock_gui= boost::bind(cb, _1);
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -295,7 +295,7 @@ void AppImpl::set_quit_application(VoidDelegate^ dt)
     gcnew VoidWrapperDelegate(this, &AppImpl::quit_application_wrapper);
   IntPtr ip = Marshal::GetFunctionPointerForDelegate(quit_application_wrapper_delegate);
   VOID_CB cb = static_cast<VOID_CB>(ip.ToPointer());
-  _callbacks->quit_application= sigc::ptr_fun(cb);
+  _callbacks->quit_application= boost::bind(cb);
 }
 
 //--------------------------------------------------------------------------------------------------
