@@ -519,7 +519,7 @@ void GRTTreeViewImpl::OnMouseDown(System::Object^ sender, MouseEventArgs^ e)
     if (t && t->get_context_menu())
     {
       tree->ContextMenu = MenuImpl::get(t->get_context_menu());
-      t->get_context_menu()->signal_will_show().emit();
+      (*t->get_context_menu()->signal_will_show())();
     }
     else
       tree->ContextMenu = nullptr;
