@@ -148,7 +148,7 @@ bool ToolBarImpl::create_tool_bar(mforms::ToolBar* item, mforms::ToolBarType typ
       native_toolbar->Name = "ToolBar";
       native_toolbar->BackColor = SystemColors::ButtonFace;
       native_toolbar->GripStyle = ToolStripGripStyle::Hidden;
-      native_toolbar->ImageScalingSize = Drawing::Size(24, 22);
+      native_toolbar->ImageScalingSize = System::Drawing::Size(24, 22);
       native_toolbar->LayoutStyle = ToolStripLayoutStyle::VerticalStackWithOverflow;
       native_toolbar->Padding = Padding(2, 0, 0, 0);
       native_toolbar->RenderMode = ToolStripRenderMode::ManagerRenderMode;
@@ -500,8 +500,8 @@ Bitmap^ ToolBarImpl::create_color_image(String^ color)
   Bitmap^ image = gcnew Bitmap(60, 15);
   Graphics^ g = Graphics::FromImage(image);
   brush->Color = ColorTranslator::FromHtml(color);
-  g->FillRectangle(brush, Drawing::Rectangle(1, 0, 58, 14));
-  g->DrawRectangle(pen, Drawing::Rectangle(1, 0, 58, 14));
+  g->FillRectangle(brush, System::Drawing::Rectangle(1, 0, 58, 14));
+  g->DrawRectangle(pen, System::Drawing::Rectangle(1, 0, 58, 14));
 
   return image;
 }
