@@ -449,7 +449,7 @@ void TreeViewImpl::OnMouseDown(System::Object^ sender, MouseEventArgs^ e)
       if (menu != tree->ContextMenu)
       {
         tree->ContextMenu = menu;
-        t->get_context_menu()->signal_will_show().emit();
+        (*t->get_context_menu()->signal_will_show())();
       }
     }
     else
