@@ -587,7 +587,7 @@ Windows::Forms::DialogResult CustomMessageBox::Show(MessageType type, String^ ti
 
 delegate InvokationResult^ RunSlotDelegate();
 
-void* DispatchControl::RunOnMainThread(const sigc::slot<void*>& slot)
+void* DispatchControl::RunOnMainThread(const boost::function<void* ()>& slot)
 {
   if (InvokeRequired)
   {
@@ -685,8 +685,8 @@ bool UtilitiesImpl::hide_wait_message()
 ref class CallSlotDelegate
 {
 public:
-  CallSlotDelegate(const sigc::slot<bool> *s) : slot(s) {}
-  const sigc::slot<bool> *slot;
+  CallSlotDelegate(const boost::function<bool ()> *s) : slot(s) {}
+  const boost::function<bool ()> *slot;
   bool call_slot()
   {
     return (*slot)();
@@ -696,7 +696,7 @@ public:
 //-------------------------------------------------------------------------------------------------
 
 bool UtilitiesImpl::run_cancelable_wait_message(const string &title, const string &text, 
-                                                const sigc::slot<void> &start_task, const sigc::slot<bool> &cancel_slot)
+                                                const boost::function<void ()> &start_task, const boost::function<bool ()> &cancel_slot)
 {
   CallSlotDelegate ^caller = gcnew CallSlotDelegate(&cancel_slot);
 
@@ -1017,7 +1017,7 @@ void UtilitiesImpl::forget_password(const std::string &service, const std::strin
 
 //--------------------------------------------------------------------------------------------------
 
-void* UtilitiesImpl::perform_from_main_thread(const sigc::slot<void*>& slot)
+void* UtilitiesImpl::perform_from_main_thread(const boost::function<void* ()>& slot)
 {
   return _dispatcher->RunOnMainThread(slot);
 }
@@ -1027,11 +1027,11 @@ void* UtilitiesImpl::perform_from_main_thread(const sigc::slot<void*>& slot)
 public ref class TimerHandler
 {
 public:
-  TimerHandler(float interval, const sigc::slot<bool> &slot)
+  TimerHandler(float interval, const boost::function<bool ()> &slot)
   {
     _timer = gcnew System::Windows::Forms::Timer();
 
-    _slot = new sigc::slot<bool>(slot);
+    _slot = new boost::function<bool ()>(slot);
 
     _timer->Interval = (int) (interval * 1000);
     _timer->Tick += gcnew EventHandler(this, &TimerHandler::timer_tick);
@@ -1046,7 +1046,7 @@ public:
   }
 
 private:
-  sigc::slot<bool> *_slot;
+  boost::function<bool ()> *_slot;
   System::Windows::Forms::Timer ^_timer;
 
   void timer_tick(Object^ sender, System::EventArgs ^e)
@@ -1068,7 +1068,7 @@ private:
 
 //-------------------------------------------------------------------------------------------------
 
-void UtilitiesImpl::add_timeout(float interval, const sigc::slot<bool> &slot)
+void UtilitiesImpl::add_timeout(float interval, const boost::function<bool ()> &slot)
 {
   TimerHandler ^handler = gcnew TimerHandler(interval, slot);
 }
