@@ -373,6 +373,16 @@ void ViewImpl::set_enabled(::mforms::View *self, bool flag)
 
 //-------------------------------------------------------------------------------------------------
 
+bool ViewImpl::is_enabled(::mforms::View *self)
+{
+  ViewImpl^ view= (ViewImpl^)ObjectImpl::FromUnmanaged(self);
+  if (view != nullptr)
+    return view->get_control<Control>()->Enabled;
+  return false;
+}
+
+//-------------------------------------------------------------------------------------------------
+
 View *ViewImpl::find_subview(::mforms::View *self, std::string &name)
 {
   return 0;
