@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -38,25 +38,25 @@ namespace MySQL {
     public ref class GtkBoxLayout abstract : public LayoutEngine
     {
     public:
-      virtual Drawing::Size GetPreferredSize(Box^ container, Drawing::Size proposedSize) = 0;
+      virtual System:: Drawing::Size GetPreferredSize(Box^ container, System::Drawing::Size proposedSize) = 0;
     };
 
     // Implements an extended flow layout behavior which mimics the horizontal GTK.box layout.
     public ref class HorizontalGtkBoxLayout : public GtkBoxLayout
     {
     public:
-      Drawing::Size ComputeLayout(Box^ box, Drawing::Size proposedSize, bool resizeChildren);
+      System::Drawing::Size ComputeLayout(Box^ box, System::Drawing::Size proposedSize, bool resizeChildren);
       virtual bool Layout(Object^ container, LayoutEventArgs^ arguments) override;
-      virtual Drawing::Size GetPreferredSize(Box^ container, Drawing::Size proposedSize) override;
+      virtual System::Drawing::Size GetPreferredSize(Box^ container, System::Drawing::Size proposedSize) override;
     };
 
     // Implements an extended flow layout behavior which mimics the vertical GTK.box layout.
     public ref class VerticalGtkBoxLayout : public GtkBoxLayout
     {
     public:
-      Drawing::Size ComputeLayout(Box^ box, Drawing::Size proposedSize, bool resizeChildren);
+      System::Drawing::Size ComputeLayout(Box^ box, System::Drawing::Size proposedSize, bool resizeChildren);
       virtual bool Layout(Object^ container, LayoutEventArgs^ arguments) override;
-      virtual Drawing::Size GetPreferredSize(Box^ container, Drawing::Size proposedSize) override;
+      virtual System::Drawing::Size GetPreferredSize(Box^ container, System::Drawing::Size proposedSize) override;
     };
 
     // Implements a GTK.box like control.
@@ -70,14 +70,14 @@ namespace MySQL {
       bool horizontal;
       bool homogeneous;
       int spacing;
-      Drawing::Size preferredSize;
+      System::Drawing::Size preferredSize;
     public:
       Box()
       {
         horizontal= false;
         homogeneous= false;
         spacing= 0;
-        preferredSize= Drawing::Size(0, 0);
+        preferredSize= System::Drawing::Size(0, 0);
       }
 
       bool GetControlExpands(Control ^ctl)
@@ -90,7 +90,7 @@ namespace MySQL {
         return fillInfo[ctl];
       }
 
-      virtual Drawing::Size GetPreferredSize(Drawing::Size proposedSize) override;
+      virtual System::Drawing::Size GetPreferredSize(System::Drawing::Size proposedSize) override;
 
       void Add(Control ^ctl, bool expands, bool fills)
       {
