@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2011, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -40,7 +40,7 @@ namespace MySQL {
         if (cb != nullptr)
         {
           CheckBox^ box= ViewImpl::create<CheckBox>(self, cb);
-          box->ForeColor = Color::Black;
+          box->ForeColor = System::Drawing::Color::Black;
           box->Click += gcnew System::EventHandler(&CheckBoxImpl::click);
           return true;
         }
