@@ -44,6 +44,7 @@ namespace MySQL {
       static int add_submenu(mforms::Menu* self, const std::string& caption, mforms::Menu* submenu);
       static void set_item_enabled(mforms::Menu* self, int i, bool flag);
       static void popup_at(mforms::Menu* self, mforms::Object* control, int x, int y);
+      static void clear(mforms::Menu* self);
 
       void menuItemClick(Object^ sender, System::EventArgs^ e);
     public:
@@ -60,6 +61,7 @@ namespace MySQL {
         DEF_CALLBACK3(int, mforms::Menu*, const std::string&, mforms::Menu*, mgr, f->_menu_impl, MenuImpl, add_submenu);
         DEF_CALLBACK3(void, mforms::Menu*, int, bool, mgr, f->_menu_impl, MenuImpl, set_item_enabled);
         DEF_CALLBACK4(void, mforms::Menu*, mforms::Object*, int, int, mgr, f->_menu_impl, MenuImpl, popup_at);
+        DEF_CALLBACK1(void, mforms::Menu*, mgr, f->_menu_impl, MenuImpl, clear);
       }
     };
 
