@@ -36,18 +36,18 @@ namespace MySQL {
     private ref class FillLayout : public LayoutEngine
     {
     public:
-      Drawing::Size ComputeLayout(Control^ control, Drawing::Size proposedSize, bool resizeChildren);
+      System::Drawing::Size ComputeLayout(Control^ control, System::Drawing::Size proposedSize, bool resizeChildren);
       virtual bool Layout(Object^ container, LayoutEventArgs^ arguments) override;
-      Drawing::Size GetPreferredSize(Control^ control, Drawing::Size proposedSize);
+      System::Drawing::Size GetPreferredSize(Control^ control, System::Drawing::Size proposedSize);
     };
 
     private interface class ValueSetter
     {
-      virtual void ApplyContentBounds(const Drawing::Rectangle% bounds);
+      virtual void ApplyContentBounds(const System::Drawing::Rectangle% bounds);
     };
 
 
-    private delegate System::Void ApplyBoundsDelegate(const Drawing::Rectangle% bounds);
+    private delegate System::Void ApplyBoundsDelegate(const System::Drawing::Rectangle% bounds);
 
     /**
      * A group box with a fill layout.
@@ -61,7 +61,7 @@ namespace MySQL {
       {
       }
 
-      virtual Drawing::Size GetPreferredSize(Drawing::Size proposedSize) override;
+      virtual System::Drawing::Size GetPreferredSize(System::Drawing::Size proposedSize) override;
 
       virtual property Windows::Forms::Layout::LayoutEngine^ LayoutEngine
       {
@@ -74,7 +74,7 @@ namespace MySQL {
         }
       }
 
-      virtual void ApplyContentBounds(const Drawing::Rectangle% bounds)
+      virtual void ApplyContentBounds(const System::Drawing::Rectangle% bounds)
       {
         Controls[0]->Bounds = bounds;
       };
@@ -92,7 +92,7 @@ namespace MySQL {
       {
       }
 
-      virtual Drawing::Size GetPreferredSize(Drawing::Size proposedSize) override;
+      virtual System::Drawing::Size GetPreferredSize(System::Drawing::Size proposedSize) override;
 
       virtual property Windows::Forms::Layout::LayoutEngine^ LayoutEngine
       {
@@ -105,7 +105,7 @@ namespace MySQL {
         }
       }
 
-      virtual void ApplyContentBounds(const Drawing::Rectangle% bounds)
+      virtual void ApplyContentBounds(const System::Drawing::Rectangle% bounds)
       {
         Controls[0]->Bounds = bounds;
       };
@@ -123,7 +123,7 @@ namespace MySQL {
       {
       }
 
-      virtual Drawing::Size GetPreferredSize(Drawing::Size proposedSize) override;
+      virtual System::Drawing::Size GetPreferredSize(System::Drawing::Size proposedSize) override;
 
       virtual property Windows::Forms::Layout::LayoutEngine^ LayoutEngine
       {
@@ -136,7 +136,7 @@ namespace MySQL {
         }
       }
 
-      virtual void ApplyContentBounds(const Drawing::Rectangle% bounds)
+      virtual void ApplyContentBounds(const System::Drawing::Rectangle% bounds)
       {
         Controls[0]->Bounds = bounds;
       };
