@@ -57,7 +57,7 @@ namespace MySQL {
       {
         MySQL::Geometry::Rect get()
         {
-          Drawing::Rectangle content_area= ClientRectangle;
+          System::Drawing::Rectangle content_area= ClientRectangle;
           content_area.X += Padding.Left;
           content_area.Y += Padding.Top;
           content_area.Width -= Padding.Horizontal;
@@ -85,16 +85,16 @@ namespace MySQL {
     private ref class TransparentPopupControl: PopupControl
     {
     private:
-      Drawing::Bitmap^ contentBitmap;
-      Drawing::Size baseSize;
+      System::Drawing::Bitmap^ contentBitmap;
+      System::Drawing::Size baseSize;
       float borderSize;
       int shadowSize;
-      Drawing::Color shadowColor;
+      System::Drawing::Color shadowColor;
       int shadowOffset;
       int cornerSize;
       int animationSteps;
       bool animated;
-      Drawing::Point hotSpot;
+      System::Drawing::Point hotSpot;
     protected:
       void RunLoop();
 
@@ -117,10 +117,10 @@ namespace MySQL {
         MySQL::Geometry::Rect get() override
         {
           MySQL::Geometry::Rect rect(0, 0, baseSize.Width, baseSize.Height);
-          rect.left += shadowSize + shadowOffset + Padding.Left;
-          rect.top += shadowSize + shadowOffset + Padding.Top;
-          rect.width -= Padding.Horizontal;
-          rect.height -= Padding.Vertical;
+          rect.pos.x += shadowSize + shadowOffset + Padding.Left;
+          rect.pos.y += shadowSize + shadowOffset + Padding.Top;
+          rect.size.width -= Padding.Horizontal;
+          rect.size.height -= Padding.Vertical;
 
           return rect;
         }
