@@ -42,7 +42,7 @@ namespace MySQL {
           ProgressBar ^pb= ViewImpl::create<ProgressBar>(self, cb);
           pb->Maximum= 1000;
           pb->Minimum= 0;
-          pb->Size= Size(100, 20);
+          pb->Size= System::Drawing::Size(100, 20);
           return true;
         }
         return false;
