@@ -40,7 +40,7 @@ namespace MySQL {
         if (rb != nullptr)
         {
           RadioButton^ button= ViewImpl::create<RadioButton>(self, rb);
-          button->ForeColor = Color::Black;
+          button->ForeColor = System::Drawing::Color::Black;
           button->Click += gcnew System::EventHandler(&RadioButtonImpl::click);
           return true;
         }
