@@ -92,8 +92,8 @@ namespace MySQL {
         rowCount= 0;
       }
 
-      Drawing::Size ComputeLayout(Drawing::Size proposedSize, bool resizeChildren);
-      virtual Drawing::Size GetPreferredSize(Drawing::Size proposedSize) override;
+      System::Drawing::Size ComputeLayout(System::Drawing::Size proposedSize, bool resizeChildren);
+      virtual System::Drawing::Size GetPreferredSize(System::Drawing::Size proposedSize) override;
 
       void Add(Control ^control, int left, int right, int top, int bottom, int flags);
       void Remove(Control ^control);
