@@ -28,8 +28,6 @@
 using namespace std;
 using namespace mforms;
 
-using namespace Windows::Forms;
-
 namespace MySQL {
   namespace Forms {
 
@@ -102,10 +100,10 @@ namespace MySQL {
     private ref class DispatchControl : Control
     {
     private:
-      const sigc::slot<void*>* _slot;
+      const boost::function<void* ()>* _slot;
       InvokationResult^ RunSlot();
     public:
-      void* RunOnMainThread(const sigc::slot<void*>& slot);
+      void* RunOnMainThread(const boost::function<void* ()>& slot);
     };
 
     public ref class UtilitiesImpl
@@ -115,7 +113,6 @@ namespace MySQL {
 
       static void load_passwords();
       static void unload_passwords(bool store);
-
     protected:
       UtilitiesImpl();
 
@@ -130,7 +127,7 @@ namespace MySQL {
       static void show_wait_message(const string &title, const string &text);
       static bool hide_wait_message();
       static bool run_cancelable_wait_message(const string &title, const string &text, 
-        const sigc::slot<void> &start_task, const sigc::slot<bool> &cancel_slot);
+        const boost::function<void ()> &start_task, const boost::function<bool ()> &cancel_slot);
       static void stop_cancelable_wait_message();
 
       static void set_clipboard_text(const string &content);
@@ -140,13 +137,13 @@ namespace MySQL {
       static void open_url(const string &url);
       static bool move_to_trash(const string &file_name);
 
-      static void add_timeout(float interval, const sigc::slot<bool> &slot);
+      static void add_timeout(float interval, const boost::function<bool ()> &slot);
 
       static void store_password(const std::string &service, const std::string &account, const std::string &password);
       static bool find_password(const std::string &service, const std::string &account, std::string &password);
       static void forget_password(const std::string &service, const std::string &account);
 
-      static void* perform_from_main_thread(const sigc::slot<void*> &slot);
+      static void* perform_from_main_thread(const boost::function<void* ()> &slot);
     public:
       static void init(Manager ^mgr)
       {
@@ -166,18 +163,18 @@ namespace MySQL {
         DEF_CALLBACK2(void, const string&, const string&, mgr, f->_utilities_impl, UtilitiesImpl,
           show_wait_message);
         DEF_CALLBACK0(bool, mgr, f->_utilities_impl, UtilitiesImpl, hide_wait_message);
-        DEF_CALLBACK4(bool, const std::string&, const std::string&, const sigc::slot<void> &, const sigc::slot<bool>&, mgr, f->_utilities_impl, UtilitiesImpl, run_cancelable_wait_message);
+        DEF_CALLBACK4(bool, const std::string&, const std::string&, const boost::function<void ()> &, const boost::function<bool ()>&, mgr, f->_utilities_impl, UtilitiesImpl, run_cancelable_wait_message);
         DEF_CALLBACK0(void, mgr, f->_utilities_impl, UtilitiesImpl, stop_cancelable_wait_message);
         DEF_CALLBACK1(void, const string&, mgr, f->_utilities_impl, UtilitiesImpl, set_clipboard_text);
         DEF_CALLBACK0(string, mgr, f->_utilities_impl, UtilitiesImpl, get_clipboard_text);
         DEF_CALLBACK1(void, const string&, mgr, f->_utilities_impl, UtilitiesImpl, open_url);
         DEF_CALLBACK1(bool, const string&, mgr, f->_utilities_impl, UtilitiesImpl, move_to_trash);
-        DEF_CALLBACK2(void, float, const sigc::slot<bool>&, mgr, f->_utilities_impl, UtilitiesImpl, add_timeout);
+        DEF_CALLBACK2(void, float, const boost::function<bool ()>&, mgr, f->_utilities_impl, UtilitiesImpl, add_timeout);
         DEF_CALLBACK1(string, mforms::FolderType, mgr, f->_utilities_impl, UtilitiesImpl, get_special_folder);
         DEF_CALLBACK3(void, const string&, const string&, const string&, mgr, f->_utilities_impl, UtilitiesImpl, store_password);
         DEF_CALLBACK3(bool, const string&, const string&, string&, mgr, f->_utilities_impl, UtilitiesImpl, find_password);
         DEF_CALLBACK2(void, const string&, const string&, mgr, f->_utilities_impl, UtilitiesImpl, forget_password);
-        DEF_CALLBACK1(void*, const sigc::slot<void*>&, mgr, f->_utilities_impl, UtilitiesImpl, perform_from_main_thread);
+        DEF_CALLBACK1(void*, const boost::function<void* ()>&, mgr, f->_utilities_impl, UtilitiesImpl, perform_from_main_thread);
       }
     };
   };
