@@ -30,9 +30,10 @@
 #include <deque>
 #include <vector>
 #include <stdexcept>
+#include <boost/function.hpp>
 #include <libxml/xmlmemory.h>
-#include <sigc++/sigc++.h>
-
+#include <boost/signals2.hpp>
+ 		  	
 #include <glib.h>
 
 #include <string>
@@ -40,6 +41,7 @@
 #ifndef _NODLL_
 # if defined(_WIN32)
 # pragma warning (disable: 4275)
+# pragma warning(disable:4251)
 #  ifdef MYSQLGRTLIBRARY_EXPORTS
 #   define MYSQLGRT_PUBLIC __declspec(dllexport)
 #  else
@@ -59,13 +61,30 @@
 #define THROW(...) throw (__VA_ARGS__)
 #endif
 
+#ifdef _WIN32
+#include <hash_set>
+typedef stdext::hash_set<std::string> string_hash_set;
+#else
+#include <ext/hash_set>
+
+struct string_hash : public std::unary_function<std::string, size_t> 
+{
+  size_t operator() (const std::string &v) const
+  {
+    return __gnu_cxx::hash<const char*>()(v.c_str());
+  }
+};
+
+typedef __gnu_cxx::hash_set<std::string, string_hash> string_hash_set;
+#endif
+
 
 #define GRT_VERSION "4.1.0"
 
 
 
 namespace grt {
-  
+ 
   class MYSQLGRT_PUBLIC os_error : public std::runtime_error
   {
   public:
@@ -1048,13 +1067,14 @@ namespace grt {
     {
       return content().raw_rend();
     }
-  */  
-    inline bool foreach(const sigc::slot<bool, ValueRef> &slot) const
+  */
+    template<typename TPred>
+    bool foreach(TPred pred) const
     {
       for (internal::List::raw_const_iterator end= content().raw_end(), iter= content().raw_begin();
         iter != end; ++iter)
       {
-        if (!slot(*iter))
+        if (!pred(*iter))
           return false;
       }
       return true;
@@ -1228,13 +1248,14 @@ namespace grt {
       return const_reverse_iterator(content().raw_rend());
     }
     
-    inline bool foreach(const sigc::slot<bool, Ref<O> > &slot) const
+    template<typename TPred>
+    bool foreach(TPred pred) const
     {
       for (internal::List::raw_const_iterator end= content().raw_end(), iter= content().raw_begin();
         iter != end; ++iter)
       {
         Ref<O> tmp((O*)iter->valueptr());
-        if (!slot(tmp))
+        if (!pred(tmp))
           return false;
       }
       return true;
@@ -1309,12 +1330,13 @@ namespace grt {
       content().set_unchecked(index, value);
     }
 
-    inline bool foreach(const sigc::slot<bool, long> &slot) const
+    template<typename TPred>
+    bool foreach(TPred pred) const
     {
       for (internal::List::raw_const_iterator end= content().raw_end(), iter= content().raw_begin();
         iter != end; ++iter)
       {
-        if (!slot(*(internal::Integer*)iter->valueptr()))
+        if (!pred(*(internal::Integer*)iter->valueptr()))
           return false;
       }
       return true;
@@ -1393,12 +1415,13 @@ namespace grt {
       content().set_unchecked(index, value);
     }
 
-    inline bool foreach(const sigc::slot<bool, double> &slot) const
+    template<typename TPred>
+    bool foreach(TPred pred) const
     {
       for (internal::List::raw_const_iterator end= content().raw_end(), iter= content().raw_begin();
         iter != end; ++iter)
       {
-        if (!slot(*(internal::Double*)iter->valueptr()))
+        if (!pred(*(internal::Double*)iter->valueptr()))
           return false;
       }
       return true;
@@ -1506,23 +1529,13 @@ namespace grt {
       return const_reverse_iterator(content().raw_rend());
     }
     
-    inline bool foreach(const sigc::slot<bool, std::string> &slot) const
+    template<typename TPred>
+    bool foreach(TPred pred) const
     {
       for (internal::List::raw_const_iterator end= content().raw_end(), iter= content().raw_begin();
         iter != end; ++iter)
       {
-        if (!slot(*(internal::String*)iter->valueptr()))
-          return false;
-      }
-      return true;
-    }
-
-    inline bool foreach(const sigc::slot<bool, const char*> &slot) const
-    {
-      for (internal::List::raw_const_iterator end= content().raw_end(), iter= content().raw_begin();
-        iter != end; ++iter)
-      {
-        if (!slot(((internal::String*)iter->valueptr())->c_str()))
+        if (!pred(*(internal::String*)iter->valueptr()))
           return false;
       }
       return true;
@@ -1603,12 +1616,13 @@ namespace grt {
     const_iterator begin() const { return content().begin(); }
     const_iterator end() const { return content().end(); }
     
-    inline bool foreach(const sigc::slot<bool, const std::string&, ValueRef> &slot) const
+    template<typename TPred>
+    bool foreach(TPred pred) const
     {
       for (const_iterator end= content().end(), iter= content().begin();
         iter != end; ++iter)
       {
-        if (!slot(iter->first, iter->second))
+        if (!pred(iter->first, iter->second))
           return false;
       }
       return true;
@@ -1783,12 +1797,13 @@ namespace grt {
       content().set_unchecked(index, value);
     }
 
-    inline bool foreach(const sigc::slot<bool, internal::Dict> &slot) const
+    template<typename TPred>
+    bool foreach(TPred pred) const
     {
       for (internal::List::raw_const_iterator end= content().raw_end(), iter= content().raw_begin();
         iter != end; ++iter)
       {
-        if (!slot(*(internal::Dict*)iter->valueptr()))
+        if (!pred(*(internal::Dict*)iter->valueptr()))
           return false;
       }
       return true;
@@ -1881,7 +1896,8 @@ namespace grt {
   class Validator
   {
   public:
-    typedef sigc::slot<void, const ObjectRef&, const std::string&, const int> MessageSlot;
+    typedef boost::function<void (const ObjectRef&, const std::string&, const int)> MessageSlot;
+
     typedef std::string Tag;
     
     virtual ~Validator() {};
@@ -1975,42 +1991,114 @@ namespace grt {
     unsigned int crc32() const { return _crc32; }
 
     /** Calls slot iterating through all members of the metaclass.
-     * 
-     * The slot will be called for each member of the metaclass,
-     * including inherited ones. If a member is overriden,
-     * it will be called only once, for the "topmost" one.
-     * The slot must return true as long as the iteration is
-     * to be continued. Returning false will stop it.
-     * 
-     * @return true if iteration was completed and false if it
-     * was cancelled by the slot before completion.
-     */
-    bool foreach_member(const sigc::slot<bool, const Member*> &slot);
-     
+    * 
+    * The slot will be called for each member of the metaclass,
+    * including inherited ones. If a member is overriden,
+    * it will be called only once, for the "topmost" one.
+    * The slot must return true as long as the iteration is
+    * to be continued. Returning false will stop it.
+    * 
+    * @return true if iteration was completed and false if it
+    * was cancelled by the slot before completion.
+    */
+    template<typename TPred>
+    bool foreach_member(TPred pred)
+    {
+      // set of already seen members (only overriden ones)
+      string_hash_set seen;
+      MetaClass *mc= this;
+
+      do
+      {
+        for (MemberList::const_iterator mem= mc->_members.begin(); mem != mc->_members.end(); ++mem)
+        {
+          if (seen.find(mem->first) != seen.end())
+            continue;
+          seen.insert(mem->first);
+
+          if (!pred(&mem->second))
+            return false;
+        }
+        mc= mc->_parent;
+      }
+      while (mc != 0);
+
+      return true;
+    }
+
     /** Calls slot iterating through all methods of the metaclass.
-     * 
-     * The slot will be called for each method of the metaclass,
-     * including inherited ones. If a method is overriden,
-     * it will be called only once, for the "topmost" one.
-     * The slot must return true as long as the iteration is
-     * to be continued. Returning false will stop it.
-     * 
-     * @return true if iteration was completed and false if it
-     * was cancelled by the slot before completion.
-     */
-    bool foreach_method(const sigc::slot<bool, const Method*> &slot);
+    * 
+    * The slot will be called for each method of the metaclass,
+    * including inherited ones. If a method is overriden,
+    * it will be called only once, for the "topmost" one.
+    * The slot must return true as long as the iteration is
+    * to be continued. Returning false will stop it.
+    * 
+    * @return true if iteration was completed and false if it
+    * was cancelled by the slot before completion.
+    */
+
+    template<typename TPred>
+    bool foreach_method(TPred pred)
+    {
+      // set of already seen methods (only overriden ones)
+      string_hash_set seen;
+      MetaClass *mc= this;
+
+      do
+      {
+        for (MethodList::const_iterator mem= mc->_methods.begin(); mem != mc->_methods.end(); ++mem)
+        {
+          if (seen.find(mem->first) != seen.end())
+            continue;
+          seen.insert(mem->first);
+
+          if (!pred(&mem->second))
+            return false;
+        }
+        mc= mc->_parent;
+      }
+      while (mc != 0);
+
+      return true;
+    }
 
     /** Calls slot iterating through all signals of the metaclass.
-     * 
-     * The slot will be called for each signal of the metaclass,
-     * including inherited ones.
-     * The slot must return true as long as the iteration is
-     * to be continued. Returning false will stop it.
-     * 
-     * @return true if iteration was completed and false if it
-     * was cancelled by the slot before completion.
-     */
-    bool foreach_signal(const sigc::slot<bool, const Signal*> &slot);
+    * 
+    * The slot will be called for each signal of the metaclass,
+    * including inherited ones.
+    * The slot must return true as long as the iteration is
+    * to be continued. Returning false will stop it.
+    * 
+    * @return true if iteration was completed and false if it
+    * was cancelled by the slot before completion.
+    */
+    template<typename TPred>
+    bool foreach_signal(TPred pred)
+    {
+      // set of already seen methods (only overriden ones)
+      string_hash_set seen;
+      MetaClass *mc= this;
+
+      do
+      {
+        for (SignalList::const_iterator mem= mc->_signals.begin(); mem != mc->_signals.end(); ++mem)
+        {
+          if (seen.find(mem->name) != seen.end())
+            continue;
+          seen.insert(mem->name);
+
+          if (!pred(&*mem))
+            return false;
+        }
+        mc= mc->_parent;
+      }
+      while (mc != 0);
+
+      return true;
+    }
+
+
 
     /** Applies all validators to obj and tag
      *  
@@ -2154,8 +2242,10 @@ namespace grt {
    * 
    * @ingroup GRT
    */ 
+  class LuaModuleLoader;
   class MYSQLGRT_PUBLIC Module//
-  {    
+  {
+  friend class LuaModuleLoader;
   public:
     struct Function
     {
@@ -2163,7 +2253,7 @@ namespace grt {
       TypeSpec ret_type;
       ArgSpecList arg_types;
 
-      sigc::slot<ValueRef, const grt::BaseListRef&> call;
+      boost::function<ValueRef (const grt::BaseListRef&)> call;
     };
 
     bool has_function(const std::string &name) const;
@@ -2225,7 +2315,7 @@ namespace grt {
      * Ex.:
      *  doSomething:s:i count,l<i> poslist,o<db.mysql.Table> table,d args
      */
-    virtual bool add_parse_function_spec(const std::string &spec, const sigc::slot<ValueRef,BaseListRef,Module*,Module::Function> &caller);
+    virtual bool add_parse_function_spec(const std::string &spec, const boost::function<ValueRef (BaseListRef, Module*, Module::Function)> &caller);
     
     void add_function(const Function &func);
 
@@ -2297,8 +2387,8 @@ namespace grt {
     std::string format(bool withtype= false) const;
   };
 
-  typedef sigc::slot<void, const Message&, void*> MessageSlot;
-  typedef sigc::slot<bool> StatusQuerySlot;
+  typedef boost::function<void (const Message&, void*)> MessageSlot;
+  typedef boost::function<bool ()> StatusQuerySlot;
 
   //-----------------------------------------------------------------------------------------------
   
