@@ -19,13 +19,15 @@
 
 #include "stdafx.h"
 
+#include "base/string_utilities.h"
+#include "base/log.h"
+
 #include "grtpp_shell_python.h"
 #include "grtpp.h"
 #include "grtpp_util.h"
 #include "grtpp_shell.h"
 #include "grtpp_module_cpp.h"
 #include "grtpp_undo_manager.h"
-#include "base/string_utilities.h"
 
 #include <algorithm>
 
@@ -36,6 +38,8 @@
 #include "serializer.h"
 #include "unserializer.h"
 
+ENABLE_LOG("")
+
 using namespace grt;
 using namespace base;
 
@@ -784,6 +788,16 @@ int GRT::scan_modules_in(const std::string &path, const std::list<std::string> &
 }
 
 
+static bool compare_modules(Module *a, Module *b)
+{
+  return g_strcasecmp(a->name().c_str(), b->name().c_str()) < 0;
+}
+
+void GRT::end_loading_modules()
+{
+  std::sort(_modules.begin(), _modules.end(), compare_modules);
+}
+
 Module *GRT::get_module(const std::string &name)
 {
   for (std::vector<Module*>::iterator iter= _modules.begin(); iter != _modules.end(); ++iter)
@@ -1010,6 +1024,7 @@ void GRT::send_error(const std::string &message, const std::string &details, voi
   
   if (verbose())
     g_message("ERROR: %s    %s", message.c_str(), details.c_str());
+  log_error("%s    %s", message.c_str(), details.c_str());
 }
 
 
@@ -1027,6 +1042,7 @@ void GRT::send_warning(const std::string &message, const std::string &details, v
   
   if (verbose())
     g_message("WARNING: %s    %s", message.c_str(), details.c_str());
+  log_warning("%s    %s", message.c_str(), details.c_str());
 }
 
 
@@ -1041,6 +1057,8 @@ void GRT::send_info(const std::string &message, const std::string &details, void
   msg.progress= 0.0;
   _message_slot(msg, sender);
   g_static_rec_mutex_unlock(&_message_mutex);
+  
+  log_info("%s    %s", message.c_str(), details.c_str());
 }
 
 
@@ -1069,6 +1087,8 @@ void GRT::send_verbose(const std::string &message, void *sender)
   msg.progress= 0.0;
   _message_slot(msg, sender);
   g_static_rec_mutex_unlock(&_message_mutex);
+  
+  log_info("%s", message.c_str());
 }
 
 
