@@ -367,8 +367,8 @@ struct ClassImplGenerator
          iter != gstruct->get_signals_partial().end(); ++iter)
     {
       fprintf(f, "  // args: %s\n", format_signal_names(iter->arg_types).c_str());
-      fprintf(f, "  sigc::signal<void%s%s > signal_%s() { return _signal_%s; }\n",
-              iter->arg_types.empty()?"":", ", format_signal_args(iter->arg_types).c_str(),
+      fprintf(f, "  boost::signals2::signal<void (%s) > signal_%s() { return _signal_%s; }\n",
+              format_signal_args(iter->arg_types).c_str(),
               iter->name.c_str(),
               iter->name.c_str());
     }
@@ -541,8 +541,8 @@ struct ClassImplGenerator
     for (MetaClass::SignalList::const_iterator iter= gstruct->get_signals_partial().begin();
          iter != gstruct->get_signals_partial().end(); ++iter)
     {
-      fprintf(f, "  sigc::signal<void%s%s > _signal_%s;\n",
-              iter->arg_types.empty()?"":", ", format_signal_args(iter->arg_types).c_str(),
+      fprintf(f, "  boost::signals2::signal<void (%s) > _signal_%s;\n",
+              format_signal_args(iter->arg_types).c_str(),
               iter->name.c_str());
     }
     
