@@ -139,7 +139,7 @@ void CPPModule::register_functions(ModuleFunctorBase *first, ...)
       f.name= func->get_name();
       f.ret_type= func->get_return_type();
       f.arg_types= func->get_signature();
-      f.call= sigc::mem_fun(*func, &ModuleFunctorBase::perform_call);
+      f.call= boost::bind(&ModuleFunctorBase::perform_call, func, _1);
       
       add_function(f);
     }
