@@ -1,25 +1,27 @@
 /* 
- * © 2007-2008 MySQL AB, 2008-2009 Sun Microsystems, Inc.
+ * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; version 2 of the
+ * License.
+ * 
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301  USA
  */
 
 #ifndef _GRTPP_MODULE_CPP_H_
 #define _GRTPP_MODULE_CPP_H_
 
+//TODO: sigc fix this
+#include "../../library/base/base/trackable.h"
 #include <cstring>
 #include <grtpp.h>
 #include <typeinfo>
@@ -174,7 +176,7 @@ namespace grt {
   
 
 
-  class MYSQLGRT_PUBLIC CPPModule : virtual public InterfaceData, public Module, public sigc::trackable
+  class MYSQLGRT_PUBLIC CPPModule : virtual public InterfaceData, public Module, public base::trackable
   {
     friend class CPPModuleLoader;
   public:
