@@ -217,7 +217,7 @@ namespace grt
   
   MYSQLGRT_PUBLIC bool compare_list_contents(const ObjectListRef &list1, const ObjectListRef &list2);
   
-  MYSQLGRT_PUBLIC void remove_list_items_matching(ObjectListRef list, const sigc::slot<bool,grt::ObjectRef> &matcher);
+  MYSQLGRT_PUBLIC void remove_list_items_matching(ObjectListRef list, const boost::function<bool (grt::ObjectRef)> &matcher);
   
   MYSQLGRT_PUBLIC ObjectRef copy_object(GRT *grt, ObjectRef object, std::set<std::string> skip_members= std::set<std::string>());
 
