@@ -508,8 +508,7 @@ static PyObject *grt_push_output_handler(PyObject *self, PyObject *args)
   if (!PyCallable_Check(o))
     return NULL;
 
-  ctx->push_output_handler(sigc::bind(sigc::ptr_fun(call_handle_output), AutoPyObject(o)));
-  
+  ctx->push_output_handler(boost::bind(&call_handle_output,_1, AutoPyObject(o)));
   Py_INCREF(Py_None);
   return Py_None;
 }
@@ -1115,7 +1114,7 @@ ValueRef PythonContext::from_pyobject(PyObject *object, const grt::TypeSpec &exp
 
 int PythonContext::run_file(const std::string &file, bool interactive)
 {
-  PyObject *f = PyFile_FromString((char*)base::string_to_path(file).c_str(), (char*)"r");
+  PyObject *f = PyFile_FromString((char*)base::string_to_path_for_open(file).c_str(), (char*)"r");
   if (!f)
   {
     log_error("Could not open file %s", file.c_str());
