@@ -390,7 +390,17 @@ ValueRef internal::Unserializer::traverse_xml_recreating_tree(xmlNodePtr node)
           sub_value= traverse_xml_recreating_tree(child);
   
           if (sub_value.is_valid())
-            list.ginsert(sub_value);
+          {
+            try
+            {
+              list.ginsert(sub_value);
+            }
+            catch (const std::exception &exc)
+            {
+              g_warning("Error inserting %s to list: %s", sub_value.repr().c_str(), exc.what());
+              throw;
+            }
+          }
           else
           {
             //error!
@@ -498,7 +508,8 @@ void internal::Unserializer::unserialize_object_contents(const ObjectRef &object
       {
         if (!object->has_member(key))
         {
-          g_warning("%s", std::string("unserialized XML contains invalid member "+object.class_name()+"::"+key).c_str());
+          g_warning("in %s: %s", object.id().c_str(),
+                    std::string("unserialized XML contains invalid member "+object.class_name()+"::"+key).c_str());
           //throw std::runtime_error("unserialized XML contains invalid member "+object.class_name()+"::"+key);
         }
         else
@@ -524,7 +535,18 @@ void internal::Unserializer::unserialize_object_contents(const ObjectRef &object
             throw;
           }
           if (sub_value.is_valid())
-            mc->set_member_internal((internal::Object*)object.valueptr(), key, sub_value, true);
+          {
+            try 
+            {
+              mc->set_member_internal((internal::Object*)object.valueptr(), key, sub_value, true);
+            }
+            catch (const std::exception &exc) 
+            {
+              g_warning("exception setting %s<%s>:%s to %s", object.id().c_str(), object.class_name().c_str(), key.c_str(), 
+                        sub_value.repr().c_str());
+              throw;
+            }
+          }
         }
       }
     }
