@@ -486,6 +486,23 @@ int myx_process_sql_statements_from_file(const char *filename, CHARSET_INFO *cs,
   is.open(filename, std::ios::in | std::ios::binary);
 #endif
 
+  // Find out size of the file and return if it doesn't contain anything.
+  is.seekg (0, std::ios::end);
+  std::streamoff length = is.tellg();
+  is.seekg (0, std::ios::beg);
+  if (length < 3) // 3 bytes to allow checking for a UTF-8 BOM.
+    return 0;
+
+  // Check if the file contains a BOM (byte-order-mark). 3 characters for the UTF-8 encoded BOM
+  // +1 for the terminating 0 added by get().
+  char buffer[4];
+  is.get(buffer, 4);
+  if (((unsigned char)buffer[0] != 0xEF) || ((unsigned char)buffer[1] != 0xBB) || ((unsigned char)buffer[2] != 0xBF))
+  {
+    // Not a BOM, so reset the input pointer.
+    is.seekg (0, std::ios::beg);
+  }
+
   MyxStatementParser p(cs);
   p.process(is, cb, user_data, mode);
   return 0;
