@@ -1,20 +1,20 @@
 /* 
  * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; version 2 of the
+ * License.
+ * 
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301  USA
  */
 
 
@@ -33,6 +33,7 @@
 #include "mysql_sql_statement_decomposer.h"
 #include "mysql_sql_schema_rename.h"
 
+#include "myx_statement_parser.h"
 #include "mysql_sql_parser_fe.h"
 #include "myx_sql_tree_item.h"
 
@@ -210,7 +211,7 @@ grt::StringListRef MysqlSqlFacadeImpl::splitSqlStatements(const std::string &sql
 }
 
 
-static grt::BaseListRef process_ast_node(grt::GRT *grt, const SqlAstNode& item)
+static grt::BaseListRef process_ast_node(grt::GRT *grt, int base_offset, const SqlAstNode& item)
 {
   grt::BaseListRef tuple(grt);
 
@@ -218,7 +219,7 @@ static grt::BaseListRef process_ast_node(grt::GRT *grt, const SqlAstNode& item)
   tuple.ginsert(grt::StringRef(item_name ? sql::symbol_names[item_name] : ""));
   
   bool has_value = false;
-  if (item.value()[0] != '\0')
+  if (!item.value().empty())
   {
     tuple.ginsert(grt::StringRef(item.value()));
     has_value = true;
@@ -232,14 +233,14 @@ static grt::BaseListRef process_ast_node(grt::GRT *grt, const SqlAstNode& item)
     if (subitems)
     {
       for (SqlAstNode::SubItemList::const_iterator i= subitems->begin(), i_end= subitems->end(); i != i_end; ++i)
-        children.ginsert(process_ast_node(grt, **i));
+        children.ginsert(process_ast_node(grt, base_offset, **i));
     }
     tuple.ginsert(children);
   }
   
   if (has_value)
   {
-    tuple.ginsert(grt::IntegerRef(item.stmt_lineno()));
+    tuple.ginsert(grt::IntegerRef(base_offset));
     tuple.ginsert(grt::IntegerRef(item.stmt_boffset()));
     tuple.ginsert(grt::IntegerRef(item.stmt_eoffset()));
   }
@@ -262,7 +263,7 @@ static int parse_callback(void* user_data, const MyxStatementParser *splitter, c
   grt::BaseListRef result = *(grt::BaseListRef*)user_data;
 
   if (err_msg.empty())
-    result.ginsert(process_ast_node(result.get_grt(), *tree));
+    result.ginsert(process_ast_node(result.get_grt(), splitter->statement_boffset(), *tree));
   else
     result.ginsert(grt::StringRef(err_msg));
 
