@@ -27,7 +27,7 @@
 #include "base/string_utilities.h"
 #include <sstream>
 #include <iterator>
-
+#include <boost/lambda/lambda.hpp>
 
 using namespace grt;
 using namespace base;
@@ -70,7 +70,9 @@ static TableStorageEngines __table_storage_engines;
 Mysql_sql_parser::Null_state_keeper::~Null_state_keeper()
 {
   _sql_parser->_fk_refs.clear();
-  _sql_parser->_process_specific_create_statement.disconnect();
+  static const Parse_result pr = pr_irrelevant;
+  boost::function<Parse_result ()> f = boost::lambda::var(pr);
+  _sql_parser->_process_specific_create_statement.clear();
   _sql_parser->_datatype_cache= grt::DictRef();
   _sql_parser->_created_objects= grt::ListRef<GrtObject>();
   _sql_parser->_processing_create_statements= true;
@@ -86,15 +88,15 @@ Mysql_sql_parser::Null_state_keeper::~Null_state_keeper()
   _sql_parser->_sql_script_codeset= StringRef("");
   _sql_parser->_triggers_owner_table= db_mysql_TableRef();
 
-  _sql_parser->_shape_schema.disconnect();
-  _sql_parser->_shape_table.disconnect();
-  _sql_parser->_shape_view.disconnect();
-  _sql_parser->_shape_routine.disconnect();
-  _sql_parser->_shape_trigger.disconnect();
-  _sql_parser->_shape_index.disconnect();
-  _sql_parser->_shape_logfile_group.disconnect();
-  _sql_parser->_shape_tablespace.disconnect();
-  _sql_parser->_shape_serverlink.disconnect();
+  _sql_parser->_shape_schema = boost::bind(f);
+  _sql_parser->_shape_table = boost::bind(f);
+  _sql_parser->_shape_view = boost::bind(f);
+  _sql_parser->_shape_routine = boost::bind(f);
+  _sql_parser->_shape_trigger = boost::bind(f);
+  _sql_parser->_shape_index = boost::bind(f);
+  _sql_parser->_shape_logfile_group = boost::bind(f);
+  _sql_parser->_shape_tablespace = boost::bind(f);
+  _sql_parser->_shape_serverlink = boost::bind(f);
 
   static struct TableStorageEnginesInitializer
   {
@@ -189,7 +191,7 @@ int Mysql_sql_parser::parse_sql_script(db_CatalogRef &catalog, const std::string
     set_active_schema(*default_schema->name());
   }
 
-  _process_sql_statement= sigc::mem_fun(this, &Mysql_sql_parser::process_sql_statement);
+  _process_sql_statement= boost::bind(&Mysql_sql_parser::process_sql_statement, this, _1);
 
   int res;
   Mysql_sql_parser_fe sql_parser_fe(_grtm->get_grt());
@@ -624,8 +626,8 @@ db_mysql_SchemaRef Mysql_sql_parser::ensure_schema_created(const std::string &sc
       schema_cs_collation_setter.charset_name(_catalog->defaultCharacterSetName());
       schema_cs_collation_setter.collation_name(_catalog->defaultCollationName());
     }
-
-    _shape_schema(schema);
+    if(_shape_schema)
+      _shape_schema(schema);
     do_transactable_list_insert(_catalog->schemata(), schema);
     log_db_obj_created(schema);
   }
@@ -1722,7 +1724,8 @@ Mysql_sql_parser::process_create_table_statement(const SqlAstNode *tree)
     }
   }
 
-  _shape_table(obj);
+  if(_shape_table)
+    _shape_table(obj);
   do_transactable_list_insert(schema->tables(), obj);
   if (!obj->isStub())
     log_db_obj_created(schema, obj);
