@@ -46,17 +46,17 @@ private:
   size_t *_limit_ins_pos;
   bool _statement_valid;
 public:
-  bool get_limit_clause_params(const std::string &sql, int &row_count, int &row_row_offset, bool &contains_limit_clause, size_t &limit_ins_pos)
+  bool get_limit_clause_params(const std::string &sql, int *row_count, int *row_row_offset, bool *contains_limit_clause, size_t *limit_ins_pos)
   {
     NULL_STATE_KEEPER
 
-    _row_count= &row_count;
-    _row_offset= &row_row_offset;
-    _contains_limit_clause= &contains_limit_clause;
-    _limit_ins_pos= &limit_ins_pos;
+    _row_count= row_count;
+    _row_offset= row_row_offset;
+    _contains_limit_clause= contains_limit_clause;
+    _limit_ins_pos= limit_ins_pos;
     _statement_valid= false;
 
-    _process_sql_statement= sigc::mem_fun(this, &Mysql_sql_statement_info::process_sql_statement);
+    _process_sql_statement= boost::bind(&Mysql_sql_statement_info::process_sql_statement, this, _1);
 
     Mysql_sql_parser_fe sql_parser_fe(_grtm->get_grt());
     sql_parser_fe.ignore_dml= false;
@@ -153,16 +153,17 @@ Sql_specifics(grt)
 }
 
 
-std::string Mysql_sql_specifics::limit_select_query(const std::string &sql, int &row_count, int &row_row_offset)
+std::string Mysql_sql_specifics::limit_select_query(const std::string &sql, int *row_count, int *row_row_offset)
 {
   Mysql_sql_statement_info statement_info(_grt);
-  bool contains_limit_clause;
-  size_t limit_ins_pos;
-  if (statement_info.get_limit_clause_params(sql, row_count, row_row_offset, contains_limit_clause, limit_ins_pos))
+  bool contains_limit_clause = false;
+  size_t limit_ins_pos = sql.length();
+
+  if (statement_info.get_limit_clause_params(sql, row_count, row_row_offset, &contains_limit_clause, &limit_ins_pos))
   {
     if (!contains_limit_clause)
     {
-      std::string limit_clause= strfmt("\nLIMIT %i, %i\n", row_row_offset, row_count);
+      std::string limit_clause= strfmt("\nLIMIT %i, %i\n", *row_row_offset, *row_count);
       std::string res;
       res.reserve(sql.size() + limit_clause.size());
       res= sql;
@@ -189,13 +190,21 @@ std::string Mysql_sql_specifics::query_connection_id()
 
 std::string Mysql_sql_specifics::query_kill_connection(boost::int64_t connection_id)
 {
+#ifdef __GNUC__
+  return strfmt("KILL CONNECTION %lli", connection_id);
+#else
   return strfmt("KILL CONNECTION %i", connection_id);
+#endif
 }
 
 
 std::string Mysql_sql_specifics::query_kill_query(boost::int64_t connection_id)
 {
+#ifdef __GNUC__
+  return strfmt("KILL QUERY %lli", connection_id);
+#else
   return strfmt("KILL QUERY %i", connection_id);
+#endif
 }
 
 std::string Mysql_sql_specifics::query_variable(const std::string &name)
@@ -247,7 +256,7 @@ std::string blob_to_string_(const unsigned char *data, size_t size)
 sqlide::QuoteVar::Blob_to_string Mysql_sql_specifics::blob_to_string()
 {
   static Mysql_sql_parser_fe sql_parser_fe(_grt);
-  return sigc::ptr_fun(&blob_to_string_);
+  return std::ptr_fun(&blob_to_string_);
 }
 
 
