@@ -2267,6 +2267,39 @@ int DbMySQLImpl::makeSQLSyncScript(const grt::DictRef& options,
   return 0;
 }
 
+std::string DbMySQLImpl::makeAlterScript(GrtNamedObjectRef source, GrtNamedObjectRef target)
+{
+  grt::DbObjectMatchAlterOmf omf;
+  omf.dontdiff_mask = 3;
+
+  std::auto_ptr<DiffChange> diff(diff_make(source, target, &omf, grt::NormalizedComparer(get_grt())));
+  if (!diff.get())
+      return "";
+
+  grt::DictRef options(get_grt());
+  grt::StringListRef alter_list(get_grt());
+  options.set("OutputContainer", alter_list);
+  options.set("UseFilteredLists", grt::IntegerRef(0));
+  options.set("KeepOrder", grt::IntegerRef(1));
+  grt::ListRef<GrtNamedObject> alter_object_list(get_grt());
+  options.set("OutputObjectContainer", alter_object_list);
+
+
+  char buf1[128];
+  sprintf(buf1, "%p", diff.get());
+
+  generateSQL(source, options, std::string(buf1));
+
+  int res= makeSQLSyncScript(options, alter_list, alter_object_list);
+  if (res)
+    return "";
+
+  grt::StringRef script= grt::StringRef::cast_from(options.get("OutputScript"));
+  if (!script.is_valid())
+      return "";
+
+  return script;
+}
 
 std::string DbMySQLImpl::makeAlterScriptForObject(GrtNamedObjectRef source, GrtNamedObjectRef target, GrtNamedObjectRef obj)
 {
