@@ -1,27 +1,27 @@
 /* 
  * Copyright (c) 2009, 2010, Oracle and/or its affiliates. All rights reserved.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; version 2 of the
+ * License.
+ * 
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, 
- * Boston, MA 02110-1301  USA
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301  USA
  */
 
 #include "wb_config.h"
 
 #include <glib/gstdio.h>
 
-#include "util_functions.h"
+#include "base/util_functions.h"
 #include "wb_model.h"
 #include "reporting.h"
 
@@ -29,7 +29,7 @@
 #include "grts/structs.workbench.h"
 
 #include "reporting_template_variables.h"
-#include "string_utilities.h"
+#include "base/string_utilities.h"
 
 // Support for syntax highlighting in SQL output.
 #ifdef _WIN32
@@ -355,7 +355,7 @@ workbench_model_reporting_TemplateStyleInfoRef WbModelImpl::get_template_style_f
 
 //--------------------------------------------------------------------------------------------------
 
-void assign_dict_field_if_exist(bool& var, const char* field, const grt::DictRef& dict)
+void read_option(bool& var, const char* field, const grt::DictRef& dict)
 {
   if (dict.has_key(field))
     var= dict.get_int(field) != 0;
@@ -363,7 +363,7 @@ void assign_dict_field_if_exist(bool& var, const char* field, const grt::DictRef
 
 //--------------------------------------------------------------------------------------------------
 
-void assign_dict_field_if_exist(string& var, const char* field, const grt::DictRef& dict)
+void read_option(string& var, const char* field, const grt::DictRef& dict)
 {
   if (dict.has_key(field))
     var= dict.get_string(field);
@@ -372,7 +372,7 @@ void assign_dict_field_if_exist(string& var, const char* field, const grt::DictR
 //--------------------------------------------------------------------------------------------------
 
 /**
- * Assignes the given value to the dictionary if it is not empty. Otherwise the text "n/a" is added.
+ * Assigns the given value to the dictionary if it is not empty. Otherwise the text "n/a" is added.
  **/
 void assignValueOrNA(TemplateDictionary* dict, const char* key, const string& value)
 {
@@ -622,7 +622,7 @@ void fillRoutineDict(const db_mysql_RoutineRef& routine, TemplateDictionary *rou
 
 //--------------------------------------------------------------------------------------------------
 
-static Scintilla::WordList* keywordLists[KEYWORDSET_MAX + 1];
+static Scintilla::WordList* keywordLists[KEYWORDSET_MAX + 2];
 
 /**
  * Initialization of the syntax highlighter classes that are used to colorize SQL code in HTML reports.
@@ -864,16 +864,16 @@ int WbModelImpl::generateReport(workbench_physical_ModelRef model, const grt::Di
   
   if (options.is_valid())
   {
-    assign_dict_field_if_exist(template_name, "template_name", options);
-    assign_dict_field_if_exist(template_style_name, "template_style_name", options);
-    assign_dict_field_if_exist(title, "title", options);
-    assign_dict_field_if_exist(output_path, "output_path", options);
-    assign_dict_field_if_exist(columns_show, "columns_show", options);
-    assign_dict_field_if_exist(indices_show, "indices_show", options);
-    assign_dict_field_if_exist(fks_show, "fks_show", options);
-    assign_dict_field_if_exist(fks_show_referred_fks, "fks_show_referred_fks", options);
-    assign_dict_field_if_exist(show_ddl, "show_ddl", options);
-    assign_dict_field_if_exist(use_highlighting, "use_highlighting", options);
+    read_option(template_name, "template_name", options);
+    read_option(template_style_name, "template_style_name", options);
+    read_option(title, "title", options);
+    read_option(output_path, "output_path", options);
+    read_option(columns_show, "columns_show", options);
+    read_option(indices_show, "indices_show", options);
+    read_option(fks_show, "fks_show", options);
+    read_option(fks_show_referred_fks, "fks_show_referred_fks", options);
+    read_option(show_ddl, "show_ddl", options);
+    read_option(use_highlighting, "use_highlighting", options);
   }
   
   bool single_file_report = count_template_files(getTemplateDirFromName(template_name)) == 1;
@@ -882,26 +882,17 @@ int WbModelImpl::generateReport(workbench_physical_ModelRef model, const grt::Di
   if (use_highlighting)
     lexer= setup_syntax_highlighter(model->rdbms());
   
-  // ensure the output dir exists
+  // Ensure the output dir exists.
   {
     int r;
-    string outputdir;
-    if (single_file_report)
-    {
-      char *dirname = g_path_get_dirname(output_path.c_str());
-      outputdir= dirname;
-      g_free(dirname);
-    }
-    else
-      outputdir= output_path;
 
-    if (!g_file_test(outputdir.c_str(), G_FILE_TEST_EXISTS))
+    if (!g_file_test(output_path.c_str(), G_FILE_TEST_EXISTS))
     {
-      r = g_mkdir_with_parents(outputdir.c_str(), 0700);
+      r = g_mkdir_with_parents(output_path.c_str(), 0700);
       if (r < 0)
       {
-        grt->send_error(strfmt("Could not create report directory %s: %s",
-                               outputdir.c_str(), g_strerror(errno)));
+        grt->send_error(strfmt("Could not create report directory %s: %s", output_path.c_str(),
+          g_strerror(errno)));
         grt->make_output_visible();
         return 0;
       }
@@ -1250,13 +1241,17 @@ int WbModelImpl::generateReport(workbench_physical_ModelRef model, const grt::Di
           
           if (single_file_report)
           {
+            // For single file reports the target file name is constructed from the report title.
+            output_filename = bec::make_path(output_path, title);
             string template_filename(entry);
+
+            // Remove the .tpl suffix.
             string name = template_filename.substr(0, template_filename.size() - 4);
+
+            // Find the file's target suffix. If there is one use this for the target file too.
             string::size_type p = name.rfind('.');
             if (p != string::npos)
-              output_filename= output_path+name.substr(p);
-            else
-              output_filename= output_path;
+              output_filename += name.substr(p);
           }
           else
           {
@@ -1290,7 +1285,7 @@ int WbModelImpl::generateReport(workbench_physical_ModelRef model, const grt::Di
   if (use_highlighting)
     cleanup_syntax_highlighter();
   
-  grt->send_info(strfmt("Schema report written to %s %s", single_file_report?"file":"folder", output_path.c_str()));
+  grt->send_info(strfmt("Schema report written to %s %s", single_file_report ? "file" : "folder", output_path.c_str()));
 
   return 1;
 }
