@@ -144,7 +144,7 @@ bool MySQLTableColumnsListBE::set_field(const ::bec::NodeId &node, int column, i
             }
           }
           _owner->update_change_date();
-          _owner->get_table()->signal_refreshDisplay().emit("column");
+          (*_owner->get_table()->signal_refreshDisplay())("column");
           undo.end(value ? 
             strfmt(_("Set Auto Increment '%s.%s'"), _owner->get_name().c_str(), col->name().c_str()) : 
             strfmt(_("Unset Auto Increment '%s.%s'"), _owner->get_name().c_str(), col->name().c_str()));
@@ -484,13 +484,12 @@ void MySQLTableEditorBE::set_table_option_by_name(const std::string& name, const
       parse_charset_collation(value, charset, collation);
       if (charset != *_table->defaultCharacterSetName() || collation != *_table->defaultCollationName())
       {
-        block_auto_refresh();
+        RefreshUI::Blocker blocker(*this);
         AutoUndoEdit undo(this);
         set_table_option_by_name("CHARACTER SET", charset);
         set_table_option_by_name("COLLATE", collation);
         update_change_date();
         undo.end(strfmt(_("Change Charset/Collation for '%s'"), _table->name().c_str()));
-        unblock_auto_refresh();
       }
     }
   }
