@@ -41,7 +41,7 @@ class DbMySQLRelationshipEditor : public PluginEditorBase//, public WidgetsAutoC
   void identifying_toggled()
   {
     Gtk::CheckButton *cbtn = 0;
-    xml()->get("identifying_cbox", &cbtn);
+    xml()->get_widget("identifying_cbox", cbtn);
 
     _be->set_is_identifying(cbtn->get_active());
   }
@@ -61,7 +61,7 @@ DbMySQLRelationshipEditor::DbMySQLRelationshipEditor(grt::Module *m, bec::GRTMan
     , _refreshing(false)
 {
   Gtk::Notebook *editor_window(0);
-  xml()->get("mysql_relationship_editor", &editor_window);
+  xml()->get_widget("mysql_relationship_editor", editor_window);
 
   _be->set_refresh_ui_slot(sigc::mem_fun(this, &DbMySQLRelationshipEditor::refresh_form_data));
 
@@ -75,37 +75,37 @@ DbMySQLRelationshipEditor::DbMySQLRelationshipEditor(grt::Module *m, bec::GRTMan
   show_all();
 
   Gtk::RadioButton* rbtn(0);
-  xml()->get("fully_visible_rbtn", &rbtn);
+  xml()->get_widget("fully_visible_rbtn", rbtn);
   rbtn->signal_toggled().connect(sigc::bind(sigc::mem_fun(this, &DbMySQLRelationshipEditor::visibility_toggled)
                                            , RelationshipEditorBE::Visible));
 
-  xml()->get("draw_split_rbtn", &rbtn);
+  xml()->get_widget("draw_split_rbtn", rbtn);
   rbtn->signal_toggled().connect(sigc::bind(sigc::mem_fun(this, &DbMySQLRelationshipEditor::visibility_toggled)
                                            , RelationshipEditorBE::Splitted));
-  xml()->get("hide_rbtn", &rbtn);
+  xml()->get_widget("hide_rbtn", rbtn);
   rbtn->signal_toggled().connect(sigc::bind(sigc::mem_fun(this, &DbMySQLRelationshipEditor::visibility_toggled)
                                            , RelationshipEditorBE::Hidden));
   
-  xml()->get("one_to_many_rbtn", &rbtn);
+  xml()->get_widget("one_to_many_rbtn", rbtn);
   rbtn->signal_toggled().connect(sigc::bind(sigc::mem_fun(this, &DbMySQLRelationshipEditor::set_to_many), true));
 
-  xml()->get("one_to_one_rbtn", &rbtn);
+  xml()->get_widget("one_to_one_rbtn", rbtn);
   rbtn->signal_toggled().connect(sigc::bind(sigc::mem_fun(this, &DbMySQLRelationshipEditor::set_to_many), false));
   
   Gtk::CheckButton *cbtn;
-  xml()->get("table1_mandatory_cbox", &cbtn);
+  xml()->get_widget("table1_mandatory_cbox", cbtn);
   cbtn->signal_toggled().connect(sigc::bind(sigc::mem_fun(this, &DbMySQLRelationshipEditor::mandatory_toggled), true));
   
-  xml()->get("table2_mandatory_cbox", &cbtn);
+  xml()->get_widget("table2_mandatory_cbox", cbtn);
   cbtn->signal_toggled().connect(sigc::bind(sigc::mem_fun(this, &DbMySQLRelationshipEditor::mandatory_toggled), false));
 
-  xml()->get("identifying_cbox", &cbtn);
+  xml()->get_widget("identifying_cbox", cbtn);
   cbtn->signal_toggled().connect(sigc::mem_fun(this, &DbMySQLRelationshipEditor::identifying_toggled));
 
   Gtk::Button* btn(0);
-  xml()->get("edit_table1_btn", &btn);
+  xml()->get_widget("edit_table1_btn", btn);
   btn->signal_clicked().connect(sigc::bind(sigc::mem_fun(this, &DbMySQLRelationshipEditor::open_editor), true));
-  xml()->get("edit_table2_btn", &btn);
+  xml()->get_widget("edit_table2_btn", btn);
   btn->signal_clicked().connect(sigc::bind(sigc::mem_fun(this, &DbMySQLRelationshipEditor::open_editor), false));
 
   try
@@ -160,7 +160,7 @@ void DbMySQLRelationshipEditor::mandatory_toggled(const bool is_left)
   if (!_refreshing)
   {
      Gtk::CheckButton *cbtn(0);
-     xml()->get(is_left ? "table1_mandatory_cbox" : "table2_mandatory_cbox", &cbtn);
+     xml()->get_widget(is_left ? "table1_mandatory_cbox" : "table2_mandatory_cbox", cbtn);
      const bool is_active = cbtn->get_active();
 
      if (is_left)
@@ -191,21 +191,21 @@ void DbMySQLRelationshipEditor::do_refresh_form_data()
 {
   _refreshing = true;
   Gtk::Entry *entry;
-  xml()->get("conn_name", &entry);
+  xml()->get_widget("conn_name", entry);
   entry->set_text(_be->get_caption());
 
-  xml()->get("conn_extra_name", &entry);
+  xml()->get_widget("conn_extra_name", entry);
   entry->set_text(_be->get_extra_caption());
   
   Gtk::TextView* text;
-  xml()->get("conn_comments", &text);
+  xml()->get_widget("conn_comments", text);
   text->get_buffer()->set_text(_be->get_comment());
 
   Gtk::Label *label;
-  xml()->get("long_caption", &label);
+  xml()->get_widget("long_caption", label);
   label->set_text(_be->get_caption_long());
 
-  xml()->get("long_caption2", &label);
+  xml()->get_widget("long_caption2", label);
   label->set_text(_be->get_extra_caption_long());
 
   const RelationshipEditorBE::VisibilityType visibility = _be->get_visibility();
@@ -213,45 +213,46 @@ void DbMySQLRelationshipEditor::do_refresh_form_data()
   switch (visibility)
   {
     case RelationshipEditorBE::Visible:
-      xml()->get("fully_visible_rbtn", &rbtn);
+      xml()->get_widget("fully_visible_rbtn", rbtn);
       break;
     case RelationshipEditorBE::Splitted:
-      xml()->get("draw_split_rbtn", &rbtn);
+      xml()->get_widget("draw_split_rbtn", rbtn);
       break;
     case RelationshipEditorBE::Hidden:
-      xml()->get("hide_rbtn", &rbtn);
+      xml()->get_widget("hide_rbtn", rbtn);
       break;
   }
   if (rbtn)
     rbtn->set_active(true);
   
   //refresh fk tab
-  xml()->get("table1_name", &label);
+  xml()->get_widget("table1_name", label);
   label->set_markup("<b>" + _be->get_left_table_name() + "</b>");
-  xml()->get("table1_fktext", &label);
+  xml()->get_widget("table1_fktext", label);
   label->set_text(_be->get_left_table_fk());
-  xml()->get("table1_columntext", &label);
+  xml()->get_widget("table1_columntext", label);
   label->set_text(_be->get_left_table_info());
 
-  xml()->get("table2_name", &label);
+  xml()->get_widget("table2_name", label);
   label->set_markup("<b>" + _be->get_right_table_name() + "</b>");
-  xml()->get("table2_columntext", &label);
+  xml()->get_widget("table2_columntext", label);
   label->set_text(_be->get_right_table_info());
 
   Gtk::CheckButton *cbtn;
-  xml()->get("table1_mandatory_cbox", &cbtn);
+  xml()->get_widget("table1_mandatory_cbox", cbtn);
   cbtn->set_active(_be->get_left_mandatory());
   
-  xml()->get("table2_mandatory_cbox", &cbtn);
+  xml()->get_widget("table2_mandatory_cbox", cbtn);
   cbtn->set_active(_be->get_right_mandatory());
 
-  xml()->get("identifying_cbox", &cbtn);
+  xml()->get_widget("identifying_cbox", cbtn);
   cbtn->set_active(_be->get_is_identifying());
 
   if (_be->get_to_many())
-    xml()->get("one_to_many_rbtn", &rbtn)->set_active(true);
+    xml()->get_widget("one_to_many_rbtn", rbtn);
   else
-    xml()->get("one_to_one_rbtn", &rbtn)->set_active(true);
+    xml()->get_widget("one_to_one_rbtn", rbtn);
+  rbtn->set_active(true);
 
   _refreshing = false;
 }
