@@ -4,9 +4,9 @@
 #include "grt/tree_model.h"
 #include "sql_editor_fe.h"
 #include "errors_list.h"
+#include <gtkmm/builder.h>
 
 class MySQLTableEditorBE;
-class MGGladeXML;
 class ListModelWrapper;
 class DbMySQLTableEditor;
 
@@ -16,7 +16,7 @@ class DbMySQLTableEditor;
 class DbMySQLTableEditorTriggerPage
 {
   public:
-    DbMySQLTableEditorTriggerPage(DbMySQLTableEditor *owner, MySQLTableEditorBE* be, MGGladeXML* xml);
+    DbMySQLTableEditorTriggerPage(DbMySQLTableEditor *owner, MySQLTableEditorBE* be, Glib::RefPtr<Gtk::Builder> xml);
     ~DbMySQLTableEditorTriggerPage();
 
     void refresh();
@@ -28,7 +28,7 @@ class DbMySQLTableEditorTriggerPage
 
     DbMySQLTableEditor                       *_owner;
     MySQLTableEditorBE                       *_be;
-    MGGladeXML                               *_xml;
+    Glib::RefPtr<Gtk::Builder>                               _xml;
 
     SqlEditorFE                               _trigger_code;
 };
