@@ -1583,7 +1583,7 @@ objectValueForItemAtIndex: (NSInteger) index;
   }
   // Register a callback that will call [self refresh] when the edited object is
   // changed from somewhere else in the application.
-  mBackEnd->set_refresh_ui_slot(sigc::bind(sigc::ptr_fun(call_refresh), self));    
+  mBackEnd->set_refresh_ui_slot(boost::bind(call_refresh, self));    
   
   [self setupEditor];
   
@@ -1717,7 +1717,7 @@ static int process_syntax_error(const int line, const int err_tok_line_pos, cons
   [mEditorTriggers setString: str];
   
   // Connect the parser with our callback to get notifications about syntax errors.
-  mBackEnd->get_sql_editor()->sql_parser_err_cb(sigc::bind(sigc::ptr_fun(process_syntax_error), self));
+  mBackEnd->get_sql_editor()->sql_parser_err_cb(boost::bind(process_syntax_error, _1, _2, _3, _4, self));
 }
 
 //--------------------------------------------------------------------------------------------------
