@@ -68,7 +68,7 @@ static void call_refresh(DbMysqlViewEditor *self)
   // register a callback that will make [self refresh] get called
   // whenever the backend thinks its needed to refresh the UI from the backend data (ie, the
   // edited object was changed from somewhere else in the application)
-  mBackEnd->set_refresh_ui_slot(sigc::bind(sigc::ptr_fun(call_refresh), self));
+  mBackEnd->set_refresh_ui_slot(boost::bind(call_refresh, self));
   
   NSUInteger index= [tabView indexOfTabViewItemWithIdentifier: @"privileges"];
   if (index != NSNotFound)
@@ -240,8 +240,8 @@ static void process_syntax_done(DbMysqlViewEditor *self)
   [codeText setStatusText: @""/*"No errors found"*/];
   
   // Connect the parser with our callback to get notifications about syntax errors.
-  mBackEnd->get_sql_editor()->sql_parser_err_cb(sigc::bind(sigc::ptr_fun(process_syntax_error), self));
-  mBackEnd->get_sql_editor()->sql_check_finish_signal.connect(sigc::bind(sigc::ptr_fun(process_syntax_done), self));
+  mBackEnd->get_sql_editor()->sql_parser_err_cb(boost::bind(process_syntax_error, _1, _2, _3, _4, self));
+  mBackEnd->get_sql_editor()->sql_check_finish_signal.connect(boost::bind(process_syntax_done, self));
 }
 
 //--------------------------------------------------------------------------------------------------
