@@ -207,9 +207,9 @@ void DbMySQLSQLExport::start_export(bool wait_finish)
 {
   bec::GRTTask *task= new bec::GRTTask("SQL export", 
     _manager->get_dispatcher(), 
-    sigc::bind<grt::StringRef>(sigc::mem_fun(this, &DbMySQLSQLExport::export_task), grt::StringRef()));
+    boost::bind(&DbMySQLSQLExport::export_task, this, _1, grt::StringRef()));
 
-  task->signal_finished().connect(sigc::mem_fun(this, &DbMySQLSQLExport::export_finished));
+  scoped_connect(task->signal_finished(),boost::bind(&DbMySQLSQLExport::export_finished, this, _1));
   
   if (wait_finish)
     _manager->get_dispatcher()->add_task_and_wait(task);
@@ -222,7 +222,8 @@ void DbMySQLSQLExport::export_finished(grt::ValueRef res)
   CatalogMap cmap;
   update_all_old_names(get_model_catalog(), false, cmap);
   _manager->get_grt()->send_output(grt::StringRef::cast_from(res).c_str());
-  _task_finish_cb();
+  if (_task_finish_cb)
+    _task_finish_cb();
 }
 
 ValueRef DbMySQLSQLExport::export_task(grt::GRT* grt, grt::StringRef)
@@ -240,7 +241,7 @@ ValueRef DbMySQLSQLExport::export_task(grt::GRT* grt, grt::StringRef)
 
     grt::ValueRef e(NULL);
 
-//  return diff_make(cat, org_cat, &omf, sigc::mem_fun(cmp, &NormalizedComparer<grt::GRT*>::normalizedComparison));
+//  return diff_make(cat, org_cat, &omf, boost::bind(&NormalizedComparer<grt::GRT*>::normalizedComparison, cmp));
 
     DiffChange* create_change= diff_make(e, _catalog, NULL, grt::NormalizedComparer(grt));
     DiffChange* drop_change= diff_make(_catalog, e, NULL, grt::NormalizedComparer(grt));
@@ -439,7 +440,7 @@ void DbMySQLSQLExport::setup_grt_string_list_models_from_catalog(bec::GrtStringL
 //      GrtObjectRef::cast_from(_manager->get_grt()->get("/wb/doc/physicalModels/0/catalog")));
 //
 //    _manager->get_dispatcher()->call_from_main_thread<int>(
-//      sigc::bind(_validation_step_finished_cb, validation_res), true);
+//      boost::bind(_validation_step_finished_cb, validation_res), true);
 //
 //    WbValidationMySQLInterfaceModule *mysql_validation_module=
 //      static_cast<WbValidationMySQLInterfaceModule *>(
@@ -454,7 +455,7 @@ void DbMySQLSQLExport::setup_grt_string_list_models_from_catalog(bec::GrtStringL
 //      GrtObjectRef::cast_from(_manager->get_grt()->get("/wb/doc/physicalModels/0/catalog")));
 //
 //    _manager->get_dispatcher()->call_from_main_thread<int>(
-//      sigc::bind(_validation_step_finished_cb, validation_res), true);
+//      boost::bind(_validation_step_finished_cb, validation_res), true);
 //  }
 //  catch(std::exception& ex)
 //  {
