@@ -115,7 +115,7 @@ static bool remove_model_only_objects(db_TableRef table)
 static bool remove_model_only_objects(db_SchemaRef schema)
 {
   remove_model_only_objects(schema->tables());
-  schema->tables().foreach(sigc::ptr_fun((bool(*)(db_TableRef))&remove_model_only_objects));
+  schema->tables().foreach(std::ptr_fun<db_TableRef, bool>(remove_model_only_objects));
   remove_model_only_objects(schema->views());
   remove_model_only_objects(schema->routines());
   return true;
@@ -124,7 +124,7 @@ static bool remove_model_only_objects(db_SchemaRef schema)
 static bool remove_model_only_objects(db_CatalogRef catalog)
 {
   remove_model_only_objects(catalog->schemata());
-  catalog->schemata().foreach(sigc::ptr_fun((bool(*)(db_SchemaRef))&remove_model_only_objects));
+  catalog->schemata().foreach(std::ptr_fun<db_SchemaRef, bool>(&remove_model_only_objects));
   return true;
 }
 
@@ -266,9 +266,9 @@ void DbMySQLScriptSync::start_sync()
 {
   bec::GRTTask *task= new bec::GRTTask("SQL sync", 
     _manager->get_dispatcher(), 
-    sigc::bind<grt::StringRef>(sigc::mem_fun(this, &DbMySQLScriptSync::sync_task), grt::StringRef()));
+    boost::bind(&DbMySQLScriptSync::sync_task, this, _1, grt::StringRef()));
 
-  task->signal_finished().connect(sigc::mem_fun(this, &DbMySQLScriptSync::sync_finished));
+  scoped_connect(task->signal_finished(),boost::bind(&DbMySQLScriptSync::sync_finished, this, _1));
   _manager->get_dispatcher()->add_task(task);
 }
 
