@@ -137,7 +137,7 @@ std::string tut::Test_object_base<db_mysql_plugin_test>::run_sync_plugin_generat
 {
   sync_plugin.reset(new DbMySQLScriptSyncTest(tester.wb->get_grt_manager()));
   static_cast<DbMySQLScriptSyncTest *>(sync_plugin.get())->set_model_catalog(mod_cat);
-  sync_plugin->init_diff_tree(schemata, org_cat, mod_cat);
+  sync_plugin->init_diff_tree(org_cat, mod_cat);
   return sync_plugin->generate_diff_tree_script();
 }
 
@@ -148,7 +148,7 @@ void tut::Test_object_base<db_mysql_plugin_test>::run_sync_plugin_apply_to_model
 {
   sync_plugin.reset(new DbMySQLScriptSyncTest(tester.wb->get_grt_manager()));
   static_cast<DbMySQLScriptSyncTest *>(sync_plugin.get())->set_model_catalog(mod_cat);
-  sync_plugin->init_diff_tree(schemata, org_cat, ValueRef());
+  sync_plugin->init_diff_tree(org_cat, ValueRef());
   sync_plugin->apply_changes_to_model();
 }
 
@@ -662,7 +662,7 @@ TEST_FUNCTION(12)
 
   DbMySQLScriptSyncTest p(wb.wb->get_grt_manager());
   p.set_model_catalog(mod_cat);
-  DiffTreeBE *tree= p.init_diff_tree(schemata, org_cat, ValueRef());
+  DiffTreeBE *tree= p.init_diff_tree(org_cat, ValueRef());
   
   // change apply direction for table table1
   bec::NodeId mydb_node= tree->get_child(NodeId(), 0);
