@@ -41,6 +41,8 @@ using namespace base;
 #include "fetch_schema_contents_page.h"
 #include "synchronize_differences_page.h"
 
+#include <boost/lambda/bind.hpp>
+
 class DescriptionPage : public WizardPage
 {
 private:
@@ -94,12 +96,12 @@ public:
   }
 
   FileImportPage(WizardForm *form,const std::string description,const std::string file_value_name,DbMySQLDiffAlter *be):
-  WizardProgressPage(form,description),_file_value_name(file_value_name),_be(be)
+  WizardProgressPage(form,description), _be(be), _file_value_name(file_value_name)
   {
     set_title(_("Parse and Load Schemata From File"));
     set_short_title(_("Parse Script File"));
     add_task(_("Retrieve database objects from file"),
-      sigc::mem_fun(this, &FileImportPage::perform_fetch),
+      boost::bind(&FileImportPage::perform_fetch, this),
       _("Retrieving object lists from selected file..."));
 
     end_adding_tasks(false,
@@ -199,8 +201,8 @@ public:
 
     _left.panel.set_title(_("Source – Database To Take Updates From"));
 
-    _left.set_change_slot(sigc::mem_fun(this,&AlterSourceSelectPage::left_changed));
-    _right.set_change_slot(sigc::mem_fun(this,&AlterSourceSelectPage::right_changed));
+    _left.set_change_slot(boost::bind(&AlterSourceSelectPage::left_changed, this));
+    _right.set_change_slot(boost::bind(&AlterSourceSelectPage::right_changed, this));
 
     _left.model_radio->set_active(true);
     _right.model_radio->set_enabled(false);
@@ -234,7 +236,7 @@ public:
 
   }
 
-  void set_generate_text_slot(const sigc::slot<std::string> &slot)
+  void set_generate_text_slot(const boost::function<std::string()> &slot)
   {
     _generate= slot;
   }
@@ -264,7 +266,7 @@ public:
   virtual bool next_closes_wizard() { return values().get_int("result") != DataSourceSelector::ServerSource; }
 
 protected:  
-  sigc::slot<std::string> _generate;
+  boost::function<std::string()> _generate;
 };
 
 
@@ -282,13 +284,13 @@ public:
     set_short_title(_("Alter Progress"));
 
     add_async_task(_("Connect to DBMS"),
-      sigc::mem_fun(this, &AlterApplyProgressPage::do_connect),
+      boost::bind(&AlterApplyProgressPage::do_connect, this),
       _("Connecting to DBMS..."));
 
     TaskRow *task= add_async_task(_("Execute Alter Script"),
-      sigc::mem_fun(this, &AlterApplyProgressPage::do_export),
+      boost::bind(&AlterApplyProgressPage::do_export, this),
       _("Applying Alter engineered SQL script in DBMS..."));
-    task->process_finish= sigc::mem_fun(this, &AlterApplyProgressPage::export_finished);
+    task->process_finish= boost::bind(&AlterApplyProgressPage::export_finished, this, _1);
 
     end_adding_tasks(false,
       _("Applying Alter Finished Successfully"));
@@ -321,15 +323,16 @@ public:
 
   bool do_connect()
   {
-    execute_grt_task(sigc::bind_return(sigc::hide<0>(sigc::mem_fun(_dbplugin->db_conn(), &DbConnection::test_connection)), grt::ValueRef()),false);
-
+    static const grt::ValueRef vref;
+    boost::function<grt::ValueRef (bool)> task = boost::lambda::var(vref);
+    execute_grt_task(boost::bind(task,boost::bind(&DbConnection::test_connection,_dbplugin->db_conn())), false);
     return true;
   }  
 
   bool do_export()
   {
     _dbplugin->sql_script(values().get_string("script"));
-    execute_grt_task(sigc::mem_fun(_dbplugin,&Db_plugin::apply_script_to_db), false);
+    execute_grt_task(boost::bind(&Db_plugin::apply_script_to_db, _dbplugin, _1), false);
 
     return true;
   }
@@ -406,7 +409,7 @@ public:
       FetchSchemaNamesProgressPage *fetch_names_page;
       add_page(mforms::manage(fetch_names_page= new FetchSchemaNamesProgressPage(this, strfmt("fetchNames%i",i).c_str())));
       fetch_names_page->set_db_connection(dbplugin[i]->db_conn());
-      fetch_names_page->set_load_schemata_slot(sigc::bind(sigc::mem_fun(this, &WbPluginDiffAlter::load_schemata), dbplugin[i]));
+      fetch_names_page->set_load_schemata_slot(boost::bind(&WbPluginDiffAlter::load_schemata, this, dbplugin[i]));
       fetch_names_page->set_title(std::string(title_prefix[i]).append(fetch_names_page->get_title()));
 
       SchemaSelectionPage *schema_page;
@@ -430,7 +433,7 @@ public:
 
     ViewResultPage *page;
     add_page(mforms::manage(page= new ViewResultPage(this)));
-    page->set_generate_text_slot(sigc::mem_fun(this, &WbPluginDiffAlter::generate_alter));
+    page->set_generate_text_slot(boost::bind(&WbPluginDiffAlter::generate_alter, this));
     add_page(mforms::manage(_apply_page = new AlterApplyProgressPage(this)));
     _apply_page->set_db_plugin(dbplugin[1]);
 
@@ -503,8 +506,8 @@ public:
       else if (_source_page->get_right_source() == DataSourceSelector::FileSource)
         right_catalog = _import_destination_file->get_catalog();
 
-      _diffs_page->set_src(left_catalog);
-      _diffs_page->set_dst(right_catalog);
+      _diffs_page->set_src(right_catalog);
+      _diffs_page->set_dst(left_catalog);
     }
     return get_page_with_id(nextid);
   }
