@@ -11,6 +11,8 @@
 
 #include "catalog_validation_page.h"
 
+#include <boost/lambda/bind.hpp>
+
 using namespace grtui;
 using namespace mforms;
 
@@ -66,12 +68,12 @@ public:
     _options_box.add(&_generate_drop_schema_check, false, false);
     _skip_foreign_keys_check.set_text(_("Skip creation of FOREIGN KEYS"));
     _options_box.add(&_skip_foreign_keys_check, false, false);
-    _skip_foreign_keys_check.signal_clicked().connect(sigc::mem_fun(this, &ExportInputPage::SkipFKToggled));
+    scoped_connect(_skip_foreign_keys_check.signal_clicked(),boost::bind(&ExportInputPage::SkipFKToggled, this));
     _skip_FK_indexes_check.set_text(_("Skip creation of FK Indexes as well"));
     _options_box.add(&_skip_FK_indexes_check, false, false);
     _omit_schema_qualifier_check.set_text(_("Omit Schema Qualifier in Object Names"));
     _options_box.add(&_omit_schema_qualifier_check, false, false);
-    _omit_schema_qualifier_check.signal_clicked().connect(sigc::mem_fun(this, &ExportInputPage::OmitSchemaToggled));
+    scoped_connect(_omit_schema_qualifier_check.signal_clicked(),boost::bind(&ExportInputPage::OmitSchemaToggled, this));
     _generate_use_check.set_text(_("Generate USE statements"));
     _options_box.add(&_generate_use_check, false, false);
     _generate_create_index_check.set_text(_("Generate Separate CREATE INDEX Statements"));
@@ -85,7 +87,7 @@ public:
 
     add(&_options, false, false);
     
-    signal_leave().connect(sigc::mem_fun(this, &ExportInputPage::gather_options));
+    scoped_connect(signal_leave(),boost::bind(&ExportInputPage::gather_options, this, _1));
     
     grt::Module *module= ((WizardPlugin*)_form)->module();
     _generate_drop_check.set_active(module->document_int_data("GenerateDrops", 0));
@@ -284,7 +286,7 @@ public:
       _form->update_buttons();
       Db_frw_eng *backend= ((WbPluginDbExport*)_form)->be();
       
-      backend->export_task_finish_cb(sigc::mem_fun(this, &PreviewScriptPage::export_task_finished));
+      backend->export_task_finish_cb(boost::bind(&PreviewScriptPage::export_task_finished, this));
       backend->start_export();
     }
   }
@@ -345,13 +347,13 @@ public:
     set_short_title(_("Commit Progress"));
 
     add_async_task(_("Connect to DBMS"),
-             sigc::mem_fun(this, &ExportProgressPage::do_connect),
+             boost::bind(&ExportProgressPage::do_connect, this),
              _("Connecting to DBMS..."));
 
     TaskRow *task= add_async_task(_("Execute Forward Engineered Script"),
-                   sigc::mem_fun(this, &ExportProgressPage::do_export),
+                   boost::bind(&ExportProgressPage::do_export, this),
                    _("Executing forward engineered SQL script in DBMS..."));
-    task->process_finish= sigc::mem_fun(this, &ExportProgressPage::export_finished);
+    task->process_finish= boost::bind(&ExportProgressPage::export_finished, this, _1);
 
     end_adding_tasks(false,
                      _("Forward Engineer Finished Successfully"));
@@ -384,16 +386,15 @@ public:
 
   bool do_connect()
   {
-    execute_grt_task(sigc::bind_return(sigc::hide<0>(sigc::mem_fun(((WbPluginDbExport*)_form)->be()->db_conn(), &DbConnection::test_connection)), grt::ValueRef()),
-                     false);
-
+    static const grt::ValueRef vref;
+    boost::function<grt::ValueRef (bool)> task = boost::lambda::var(vref);
+    execute_grt_task(boost::bind(task,boost::bind(&DbConnection::test_connection, ((WbPluginDbExport*)_form)->be()->db_conn())), false);
     return true;
   }  
   
   bool do_export()
   {
-    execute_grt_task(sigc::mem_fun(((WbPluginDbExport*)_form)->be(), 
-                                   &Db_plugin::apply_script_to_db), false);
+    execute_grt_task(boost::bind(&Db_plugin::apply_script_to_db, ((WbPluginDbExport*)_form)->be(), _1), false);
 
     return true;
   }
