@@ -59,8 +59,8 @@ public:
     _file_selector= mforms::manage(new FsObjectSelector(&_browse_button, &_filename));
     std::string initial_value= form->module()->document_string_data("output_filename", "");
     _file_selector->initialize(initial_value, mforms::SaveFile, "SQL Files (*.sql)|*.sql", _("Browse..."),
-      false, sigc::mem_fun(this, &WizardPage::validate));
-    _file_selector->signal_changed().connect(sigc::mem_fun(this, &ExportInputPage::file_changed));
+      false, boost::bind(&WizardPage::validate, this));
+    scoped_connect(_file_selector->signal_changed(),boost::bind(&ExportInputPage::file_changed, this));
     
     _caption.set_text(_("Output SQL Script File:"));
 
@@ -79,12 +79,12 @@ public:
     _options_box.add(&_generate_drop_schema_check, false, false);
     _skip_foreign_keys_check.set_text(_("Skip Creation of FOREIGN KEYS"));
     _options_box.add(&_skip_foreign_keys_check, false, false);
-    _skip_foreign_keys_check.signal_clicked().connect(sigc::mem_fun(this, &ExportInputPage::SkipFKToggled));
+    scoped_connect(_skip_foreign_keys_check.signal_clicked(),boost::bind(&ExportInputPage::SkipFKToggled, this));
     _skip_FK_indexes_check.set_text(_("Skip creation of FK Indexes as well"));
     _options_box.add(&_skip_FK_indexes_check, false, false);
     _omit_schema_qualifier_check.set_text(_("Omit Schema Qualifier in Object Names"));
     _options_box.add(&_omit_schema_qualifier_check, false, false);
-    _omit_schema_qualifier_check.signal_clicked().connect(sigc::mem_fun(this, &ExportInputPage::OmitSchemaToggled));
+    scoped_connect(_omit_schema_qualifier_check.signal_clicked(),boost::bind(&ExportInputPage::OmitSchemaToggled, this));
     _generate_use_check.set_text(_("Generate USE statements"));
     _options_box.add(&_generate_use_check, false, false);
     _generate_create_index_check.set_text(_("Generate Separate CREATE INDEX Statements"));
