@@ -262,7 +262,7 @@ WbPluginDbImport::WbPluginDbImport(grt::Module *module)
 
   _fetch_progress_page= new FetchSchemaNamesProgressPage(this);
   _fetch_progress_page->set_db_connection(db_plugin()->db_conn());
-  _fetch_progress_page->set_load_schemata_slot(sigc::mem_fun(this, &WbPluginDbImport::load_schemata));
+  _fetch_progress_page->set_load_schemata_slot(boost::bind(&WbPluginDbImport::load_schemata, this));
 
   _schema_selection_page= new SchemaSelectionPage(this);
   _schema_selection_page->set_db_plugin(db_plugin());
@@ -407,11 +407,11 @@ WbPluginDbImport::WbPluginDbImport(grt::Module *module)
     set_short_title(_("Reverse Engineer"));
 
     add_async_task(_("Reverse Engineer Selected Objects"),
-                   sigc::mem_fun(this, &DBImportProgressPage::perform_import),
+                   boost::bind(&DBImportProgressPage::perform_import, this),
                    _("Reverse engineering DDL from selected objects..."));
 
     _place_task= add_async_task(_("Place Objects on Diagram"), 
-             sigc::mem_fun(this, &DBImportProgressPage::perform_place),
+             boost::bind(&DBImportProgressPage::perform_place, this),
              _("Placing objects..."));
 
     end_adding_tasks(true,
