@@ -52,8 +52,8 @@ ImportInputPage::ImportInputPage(WizardPlugin *form)
 
   std::string initial_filename= form->module()->document_string_data("input_filename", "");
   _file_selector.initialize(initial_filename, mforms::OpenFile, "SQL Files (*.sql)|*.sql", _("Browse..."),
-    false, sigc::mem_fun(this, &WizardPage::validate));
-  _file_selector.signal_changed().connect(sigc::mem_fun(this, &ImportInputPage::file_changed));
+    false, boost::bind(&WizardPage::validate, this));
+  scoped_connect(_file_selector.signal_changed(),boost::bind(&ImportInputPage::file_changed, this));
 
   _file_codeset_caption.set_text(_("File encoding:"));
   _file_codeset_caption.set_text_align(mforms::WizardLabelAlignment);
@@ -68,7 +68,7 @@ ImportInputPage::ImportInputPage(WizardPlugin *form)
   _autoplace_check.set_text(_("Place imported objects on a diagram"));
   _autoplace_check.set_active(true);
 
-  signal_leave().connect(sigc::mem_fun(this, &ImportInputPage::gather_options));
+  scoped_connect(signal_leave(),boost::bind(&ImportInputPage::gather_options, this, _1));
 
   _autoplace_check.set_active(form->module()->document_int_data("place_figures", 0));
 }
@@ -151,7 +151,7 @@ void ImportInputPage::gather_options(bool advancing)
 
 //--------------------------------------------------------------------------------------------------
 
-ImportProgressPage::ImportProgressPage(WizardForm *form, const sigc::slot<void,bool,std::string> &finished_cb)
+ImportProgressPage::ImportProgressPage(WizardForm *form, const boost::function<void (bool,std::string)> &finished_cb)
   : WizardProgressPage(form, "progress")
 {
   set_title(_("Reverse Engineering Progress"));
@@ -169,17 +169,17 @@ ImportProgressPage::ImportProgressPage(WizardForm *form, const sigc::slot<void,b
 
   TaskRow *task=
     add_async_task(_("Reverse Engineer SQL Script"), 
-                   sigc::mem_fun(this, &ImportProgressPage::import_objects),
+                   boost::bind(&ImportProgressPage::import_objects, this),
                    _("Reverse engineering and importing objects from script..."));
-  task->process_finish= sigc::mem_fun(this, &ImportProgressPage::import_objects_finished);
+  task->process_finish= boost::bind(&ImportProgressPage::import_objects_finished, this, _1);
 
   add_task(_("Verify Results"), 
-           sigc::mem_fun(this, &ImportProgressPage::verify_results),
+           boost::bind(&ImportProgressPage::verify_results, this),
            _("Verifying imported objects..."));
 
   _auto_place_task= 
     add_async_task(_("Place Objects on Diagram"), 
-                   sigc::mem_fun(this, &ImportProgressPage::place_objects),
+                   boost::bind(&ImportProgressPage::place_objects, this),
                    _("Placing imported objects on a new diagram..."));
 
   end_adding_tasks(true,
@@ -291,7 +291,8 @@ std::string ImportProgressPage::get_summary()
 
 void ImportProgressPage::tasks_finished(bool success)
 {
-  _finished_cb(success, get_summary());
+  if (_finished_cb)
+    _finished_cb(success, get_summary());
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -300,7 +301,7 @@ WbPluginSQLImport::WbPluginSQLImport(grt::Module *module)
   : WizardPlugin(module)
 {
   _input_page= new ImportInputPage(this);
-  _progress_page= new ImportProgressPage(this, sigc::mem_fun(this, &WbPluginSQLImport::update_summary));
+  _progress_page= new ImportProgressPage(this, boost::bind(&WbPluginSQLImport::update_summary, this, _1, _2));
   
   _finish_page= new WizardFinishedPage(this, _("SQL Import Finished"));
 
