@@ -65,12 +65,12 @@ class ImportProgressPage : public WizardProgressPage
 private:
   Sql_import _import_be;
   TaskRow *_auto_place_task;
-  sigc::slot<void,bool,std::string> _finished_cb;
+  boost::function<void (bool,std::string)> _finished_cb;
   bool _auto_place;
   bool _done;
   
 public:
-  ImportProgressPage(WizardForm *form, const sigc::slot<void,bool,std::string> &finished_cb);
+  ImportProgressPage(WizardForm *form, const boost::function<void (bool,std::string)> &finished_cb);
   void import_objects_finished(grt::ValueRef value);
   bool import_objects();
   bool verify_results();
