@@ -92,7 +92,7 @@ public:
     _model_only.set_text("Skip DB changes and update model only");
     _button_box.add(&_model_only, true, true);
     
-    signal_leave().connect(sigc::mem_fun(this, &PreviewScriptPage::apply_changes));
+    scoped_connect(signal_leave(),boost::bind(&PreviewScriptPage::apply_changes, this, _1));
   }
 
 
@@ -135,11 +135,11 @@ public:
     set_short_title(_("Synchronize Progress"));
 
     db_task = add_async_task(_("Apply Changes to Database"),
-                   sigc::mem_fun(this, &DBSynchronizeProgressPage::perform_sync_db),
+                   boost::bind(&DBSynchronizeProgressPage::perform_sync_db, this),
                    _("Applying selected changes from model to the database..."));
 
     add_task(_("Apply Changes to Model"),
-             sigc::mem_fun(this, &DBSynchronizeProgressPage::perform_sync_model),
+             boost::bind(&DBSynchronizeProgressPage::perform_sync_model, this),
              _("Applying selected changes from database to the model..."));
 
     end_adding_tasks(true,
@@ -163,8 +163,7 @@ public:
   {
     _form->grtm()->get_grt()->send_info("Applying synchronization scripts to server...");
     
-    execute_grt_task(sigc::mem_fun(((WbPluginDbSynchronize*)_form)->get_db_be(), 
-                                   &Db_plugin::apply_script_to_db), false);
+    execute_grt_task(boost::bind(&Db_plugin::apply_script_to_db, ((WbPluginDbSynchronize*)_form)->get_db_be(), _1), false);
     
     return true;
   }
@@ -204,7 +203,7 @@ WbPluginDbSynchronize::WbPluginDbSynchronize(grt::Module *module)
 
   FetchSchemaNamesProgressPage *fetch_progress_page= new FetchSchemaNamesProgressPage(this);
   fetch_progress_page->set_db_connection(_db_be.db_conn());
-  fetch_progress_page->set_load_schemata_slot(sigc::mem_fun(this, &WbPluginDbSynchronize::load_schemata));
+  fetch_progress_page->set_load_schemata_slot(boost::bind(&WbPluginDbSynchronize::load_schemata, this));
   add_page(mforms::manage(fetch_progress_page));
 
   SchemaSelectionPage *schema_selection_page= new SchemaSelectionPage(this,"pickSchemata",true);
@@ -218,7 +217,7 @@ WbPluginDbSynchronize::WbPluginDbSynchronize(grt::Module *module)
 
   SynchronizeDifferencesPage *diffs_page= new SynchronizeDifferencesPage(this, &_be);
   diffs_page->set_title(_("Model and Database Differences"));
-  diffs_page->set_source_catalog_slot(sigc::mem_fun(&_db_be, &Db_plugin::db_catalog));
+  diffs_page->set_source_catalog_slot(boost::bind(&Db_plugin::db_catalog, &_db_be));
   add_page(mforms::manage(diffs_page));
   
   add_page(mforms::manage(new PreviewScriptPage(this)));
