@@ -328,7 +328,7 @@ class WbAdminControl:
     
     raw_version = "unknown"
     server_version = "unknown"
-
+    
     def __init__(self, server_profile,
                             connect_sql=True):
 
@@ -345,6 +345,8 @@ class WbAdminControl:
         self.sql_enabled = connect_sql
         self.password_handler = PasswordHandler(server_profile)
         
+        self.server_active_plugins = set()
+        
         self.running = True
 
         self.add_me_for_event("server_started", self)
@@ -574,12 +576,25 @@ class WbAdminControl:
             self.sql = SQLQueryExecutor(connection)
 
         if self.sql and self.sql.is_connected():
+            # perform some server capabilities checking
+            
+            # check version
             result = self.exec_query("select version() as version")
             if result and result.nextRow():
                 self.server_version= result.stringByName("version")
                 self.raw_version = self.server_version
                 dprint_ex(1, "Got MySQL version -", self.server_version)
-            dprint_ex(1,"Created SQL connection to MySQL server. Server version is", self.server_version, ", conn status = ", self.is_sql_connected())
+            
+            result = self.exec_query("show plugins")
+            # check whether Windows authentication plugin is available
+            while result and result.nextRow():
+                name = result.stringByName("Name")
+                status = result.stringByName("Status")
+                plugin_type = result.stringByName("Type")
+                if status == "ACTIVE":
+                    self.server_active_plugins.add((name, plugin_type))
+
+            dprint_ex(1,"Created SQL connection to MySQL server. Server version is", self.server_version, ", conn status = ", self.is_sql_connected(), ", active plugins = ", str(self.server_active_plugins))
         else:
             print "Failed to connect to MySQL server"
 
