@@ -1,4 +1,4 @@
-# Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -44,6 +44,7 @@ GET_ACCOUNT_MYSQL_TABLE_PRIVS_QUERY = "SELECT * FROM mysql.tables_priv WHERE Hos
 
 UPDATE_ACCOUNT_QUERY = "UPDATE mysql.user SET %(assignments)s WHERE User='%(old_user)s' AND Host='%(old_host)s'"
 CREATE_USER_QUERY = "CREATE USER '%(user)s'@'%(host)s' identified by password '%(password)s'"
+CREATE_USER_QUERY_PLUGIN = "CREATE USER '%(user)s' IDENTIFIED WITH '%(auth_plugin)s' AS '%(auth_string)s'"
 #INSERT_ACCOUNT_QUERY = "INSERT INTO mysql.user (User, Host, Password, %(field_names)s) VALUES ('%(user)s', '%(host)s', PASSWORD('%(password)s'), %(field_values)s)"
 #INSERT_ACCOUNT_QUERY_NO_PASSWORD = "INSERT INTO mysql.user (User, Host, Password, %(field_names)s) VALUES ('%(user)s', '%(host)s', '', %(field_values)s)"
 
@@ -204,6 +205,8 @@ class AdminSecurity:
         self._account_info_cache = {}
         self._schema_privileges_cache = {}
 
+        self.has_plugin = False
+        self.has_authentication_string = False
         self.has_max_user_connections = False
         self.schema_privilege_names = []
         self.global_privilege_names = []
@@ -253,7 +256,10 @@ class AdminSecurity:
                   self.global_privilege_names.append(field)
                 if field == "max_user_connections":
                   self.has_max_user_connections = True
-
+                if field == "plugin":
+                  self.has_plugin = True
+                if field == "authentication_string":
+                  self.has_authentication_string = True
 
         # get list of schema names
         schema_names = []
@@ -311,7 +317,7 @@ class AdminSecurity:
 
     def delete_account(self, acct):
         if acct.is_commited:
-            query = REMOVE_USER % {"user":acct.username, "host":acct.host}
+            query = REMOVE_USER % {"user":escape_sql_string(acct.username), "host":escape_sql_string(acct.host)}
             self.ctrl_be.exec_sql(query)
 
             self.ctrl_be.exec_sql(FLUSH_PRIVILEGES)
@@ -493,6 +499,7 @@ class AdminAccount:
     _orig_username = None
     _orig_host = None
     _orig_password = None
+    _orig_auth_string = None
     username = None
     password = None
     confirm_password = None
@@ -502,6 +509,8 @@ class AdminAccount:
     max_updates = 0
     max_connections = 0
     max_user_connections = 0
+    auth_plugin = None
+    auth_string = None
     
     _global_privs = set()
     _orig_global_privs = set()
@@ -511,6 +520,11 @@ class AdminAccount:
     def __init__(self, owner):
         self._owner = owner
 
+    def formatted_name(self):
+        if self.host is not None:
+            return "%s@%s" % (self.username, self.host)
+        else:
+            return self.username
 
     def copy(self):
         copy = AdminAccount(self._owner)
@@ -522,6 +536,8 @@ class AdminAccount:
         copy.max_updates = self.max_updates
         copy.max_connections = self.max_connections
         copy.max_user_connections = self.max_user_connections
+        copy.auth_plugin = self.auth_plugin
+        copy.auth_string = self.auth_string
         copy.is_commited = self.is_commited
         copy._global_privs = self._global_privs.copy()
         return copy
@@ -530,6 +546,7 @@ class AdminAccount:
         copy = self.copy()
         copy._orig_username = self._orig_username
         copy._orig_password = self._orig_password
+        copy._orig_auth_string = self._orig_auth_string
         copy._orig_host = self._orig_host
         return copy
 
@@ -587,10 +604,10 @@ class AdminAccount:
         # check if username + host is duplicated
         if self.is_commited and (self.username != self._orig_username or self.host != self._orig_host):
             if (self.username, self.host) in self._owner.account_names:
-                raise WBSecurityValidationError("The '%s'@'%s' account already exists and cannot be saved." % (self.username, self.host))
+                raise WBSecurityValidationError("The '%s' account already exists and cannot be saved." % (self.formatted_name()))
         elif not self.is_commited:
             if self._owner.account_names.count((self.username, self.host)) > 1:
-                raise WBSecurityValidationError("The '%s'@'%s' account already exists and cannot be saved." % (self.username, self.host))
+                raise WBSecurityValidationError("The '%s' account already exists and cannot be saved." % (self.formatted_name()))
 
         fields = {
             "old_user" : escape_sql_string(self._orig_username) if self._orig_username else self._orig_username,
@@ -598,6 +615,8 @@ class AdminAccount:
             "user" : escape_sql_string(self.username) or "NULL",
             "host" : escape_sql_string(self.host) or "",
             "password" : escape_sql_string(self.password or self._orig_password or ""),
+            "auth_plugin" : escape_sql_string(self.auth_plugin) if self.auth_plugin else None,
+            "auth_string" : escape_sql_string(self.auth_string) if self.auth_string else None
         }
 
         if self.is_commited:
@@ -614,10 +633,14 @@ class AdminAccount:
 
             if self._orig_username != self.username:
                 assignments.append("User='%s'"%escape_sql_string(self.username))
-            if self._orig_host != self.host:
-                assignments.append("Host='%s'"%escape_sql_string(self.host))
-            if self.password:
-                assignments.append("Password=password('%s')"%escape_sql_string(self.password))
+            if self.auth_plugin:
+                if self._orig_auth_string != self.auth_string:
+                    assignments.append("authentication_string='%s'" % escape_sql_string(self.auth_string))
+            else:
+                if self._orig_host != self.host:
+                    assignments.append("Host='%s'"%escape_sql_string(self.host))
+                if self.password:
+                    assignments.append("Password=password('%s')"%escape_sql_string(self.password))
 
             fields["assignments"] = ", ".join(assignments)
 
@@ -651,7 +674,10 @@ class AdminAccount:
 
             raw_pwd = fields['password']
             fields['password'] = make_scrambled_password(raw_pwd)
-            create_query = CREATE_USER_QUERY % fields
+            if self.auth_plugin:
+                create_query = CREATE_USER_QUERY_PLUGIN % fields
+            else:
+                create_query = CREATE_USER_QUERY % fields
             run_query(create_query)
 
             fields['password'] = raw_pwd
@@ -725,7 +751,7 @@ class AdminAccount:
     def load(self, username, hostname):
         self.is_commited = True
         # Basic stuff from User table
-        query = GET_ACCOUNT_QUERY % {"user":escape_sql_string(username),"host":hostname}
+        query = GET_ACCOUNT_QUERY % {"user":escape_sql_string(username),"host":escape_sql_string(hostname)}
         try:
             result = self._owner.ctrl_be.exec_query(query)
         except Exception, e:
@@ -736,15 +762,21 @@ class AdminAccount:
 
         self.username = result.stringByName("User")
         self.host = result.stringByName("Host")
+        
         self._orig_password = result.stringByName("Password")
         self._orig_username = self.username
         self._orig_host = self.host
+        self._orig_auth_string = self.auth_string
         
         self.max_questions = result.intByName("max_questions")
         self.max_updates = result.intByName("max_updates")
         self.max_connections = result.intByName("max_connections")
         if self._owner.has_max_user_connections:
             self.max_user_connections = result.intByName("max_user_connections")
+        if self._owner.has_plugin:
+            self.auth_plugin = result.stringByName("plugin")
+        if self._owner.has_authentication_string:
+            self.auth_string = result.stringByName("authentication_string")
         
         self._global_privs = set()
         for priv in self._owner.global_privilege_names:
@@ -770,7 +802,7 @@ class AdminAccount:
         """
 
         # privs from mysql tables
-        query = GET_ACCOUNT_MYSQL_TABLE_PRIVS_QUERY % {"user":escape_sql_string(username),"host":hostname}
+        query = GET_ACCOUNT_MYSQL_TABLE_PRIVS_QUERY % {"user":escape_sql_string(username),"host":escape_sql_string(hostname)}
         try:
             result = self._owner.ctrl_be.exec_query(query)
         except Exception, e:
