@@ -37,7 +37,7 @@ class WbAdminConnections(mforms.Box):
         self.add(self.warning, False, True)
     
         self.connection_list = newTreeView(mforms.TreeDefault)
-        self.connection_list.add_column(mforms.IntegerColumnType, "Id", 50, False)
+        self.connection_list.add_column(mforms.StringColumnType, "Id", 50, False)
         self.connection_list.add_column(mforms.StringColumnType, "User", 80, False)
         self.connection_list.add_column(mforms.StringColumnType, "Host", 120, False)
         self.connection_list.add_column(mforms.StringColumnType, "DB", 100, False)
@@ -149,7 +149,7 @@ class WbAdminConnections(mforms.Box):
 
         i = self.connection_list.get_selected()
         if i >= 0:
-          old_selected = self.connection_list.get_int(i, 0)
+          old_selected = self.connection_list.get_string(i, 0)
         else:
           old_selected = None
 
@@ -159,23 +159,34 @@ class WbAdminConnections(mforms.Box):
         if query_result is not None:
           self.connection_list.freeze_refresh()
           self.connection_list.clear_rows()
+          id_width = 0
           try:
             for row in query_result:
               r = self.connection_list.add_row()
               for c, field in enumerate(row):
-                if c == 0 or c == 5:
+                if c == 5:
                   try:
                     field= int(field)
                   except:
                     field= 0
                   self.connection_list.set_int(r, c, field)
                 else:
-                  self.connection_list.set_string(r, c, str(field))
+                  field = str(field)
+                  if c == 0:
+                      id_width = max(id_width, len(field))
+                  self.connection_list.set_string(r, c, field)
+
                 if c == 0 and field == old_selected:
                   self.connection_list.set_selected(r)
           finally:
             self.connection_list.thaw_refresh()
 
+          if id_width > 0:
+              cnt = self.connection_list.count()
+              for row in range(0, cnt):
+                  cid = self.connection_list.get_string(row, 0)
+                  self.connection_list.set_string(row, 0, cid.rjust(id_width, ' '))
+
           self.connection_selected()
 
     def kill_connection(self):
@@ -186,7 +197,7 @@ class WbAdminConnections(mforms.Box):
       if sel < 0:
         return
 
-      connid = self.connection_list.get_int(sel, 0)
+      connid = self.connection_list.get_string(sel, 0)
 
       try:
         self.ctrl_be.exec_sql("KILL CONNECTION %s"%connid)
@@ -204,7 +215,7 @@ class WbAdminConnections(mforms.Box):
       if sel < 0:
         return
 
-      connid = self.connection_list.get_int(sel, 0)
+      connid = self.connection_list.get_string(sel, 0)
 
       try:
         self.ctrl_be.exec_sql("KILL QUERY %s"%connid)
