@@ -1,10 +1,19 @@
+# Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
 #
-#  wb_admin_export.py
-#  MySQLWorkbench
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License as
+# published by the Free Software Foundation; version 2 of the
+# License.
 #
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
 #
-#  Copyright (c) 2009-2010 Oracle and/or its affiliates. All rights reserved. 
-#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+# 02110-1301  USA
 
 import os
 import re
@@ -18,6 +27,11 @@ import wb_admin_export_options
 import tempfile
 import platform
 
+try:
+ import _subprocess
+except ImportError:
+ pass
+
 from wb_server_management import local_run_cmd
 
 from db_utils import MySQLConnection, MySQLError, ConnectionTunnel, escape_sql_string, escape_sql_identifier
@@ -81,14 +95,15 @@ class DumpThread(threading.Thread):
                 params.append(quote_shell_token(arg))
             
             strcmd = " ".join(params)
+                                                     
             logstr = strcmd.partition("--password=")[0]
     
             if platform.system() == 'Windows':
-                pwdfile = tempfile.NamedTemporaryFile(delete=False)
+                pwdfile = tempfile.NamedTemporaryFile(delete=False, suffix=".cnf")
                 pwdfilename = pwdfile.name
             else:
                 tmpdir = tempfile.mkdtemp()
-                pwdfilename = os.path.join(tmpdir, 'extraparams')
+                pwdfilename = os.path.join(tmpdir, 'extraparams.cnf')
                 os.mkfifo(pwdfilename)
    
             logstr += "--defaults-extra-file=\"" + pwdfilename + "\" "
@@ -114,8 +129,8 @@ class DumpThread(threading.Thread):
             if platform.system() == 'Windows':
                 try:
                     info = subprocess.STARTUPINFO()
-                    info.dwFlags |= subprocess.STARTF_USESHOWWINDOW
-                    info.wShowWindow = subprocess.SW_HIDE
+                    info.dwFlags |= _subprocess.STARTF_USESHOWWINDOW
+                    info.wShowWindow = _subprocess.SW_HIDE
                     p1 = subprocess.Popen(logstr,stdout=respipe or subprocess.PIPE,stdin=subprocess.PIPE, stderr=subprocess.PIPE,startupinfo=info,shell=logstr[0] != '"')
                 except OSError, exc:
                     import traceback
@@ -290,7 +305,7 @@ class WbAdminSchemaListTab(mforms.Box):
         if self.savefile_path is None:
             self.savefile_path = os.path.join(self.savefolder_path, "export.sql")
 
-        self.schema_list = newTreeView(mforms.TreeShowHeader)
+        self.schema_list = newTreeView(mforms.TreeDefault)
         self.schema_list.add_column(mforms.CheckColumnType, is_importing and "Import" or "Export", 50, True)
         self.schema_list.add_column(mforms.StringColumnType, "Schema", 300, False)
 
@@ -298,7 +313,7 @@ class WbAdminSchemaListTab(mforms.Box):
         self.schema_list.end_columns()
         self.schema_list.set_allow_sorting(True)
 
-        self.table_list = newTreeView(mforms.TreeShowHeader)
+        self.table_list = newTreeView(mforms.TreeDefault)
         self.table_list.add_column(mforms.CheckColumnType, is_importing and "Import" or "Export", 50, True)
         self.table_list.add_column(mforms.StringColumnType, "Tables in Schema", 300, False)
         self.table_list.end_columns()
@@ -361,7 +376,7 @@ class WbAdminSchemaListTab(mforms.Box):
         self.file_te.set_value(self.savefile_path)
         file_path.add(labelfile, False, False)
         file_path.add(self.file_te, True, True)
-        file_path.add(self.file_btn, False, False)
+        file_path.add(self.file_btn, False, True)
 
         self.folderradio.add_clicked_callback(self.set_save_option)
         self.folderradio.set_active(True)
@@ -378,7 +393,7 @@ class WbAdminSchemaListTab(mforms.Box):
         self.folder_btn.add_clicked_callback(self.open_folder_chooser)
         folder_path.add(labelfolder, False, False)
         folder_path.add(self.folder_te, True, True)
-        folder_path.add(self.folder_btn, False, False)
+        folder_path.add(self.folder_btn, False, True)
 
         optionsbox.add(self.folderradio, False, True)
         optionsbox.add(self.folderlabel, False, True)
@@ -900,8 +915,11 @@ class WbAdminImportTab(WbAdminSchemaListTab):
 
 
         if connection_params.driver.name == "MysqlNativeSocket":
-            host_option = "--protocol=pipe"
-            port_option = "--socket=" + [conn["socket"]][0]
+            host_option = "--protocol="+("pipe" if sys.platform == "win32" else "socket")
+            if conn["socket"]:
+                port_option = "--socket=" + [conn["socket"]][0]
+            else:
+                port_option = ""
         else:
             if tunnel.port or conn["port"]:
                 port_option = "--port=" + str(tunnel.port or conn["port"])
@@ -920,6 +938,7 @@ class WbAdminImportTab(WbAdminSchemaListTab):
         "--comments",
         "<" # the rest of the params will be redirected from stdin
         ]
+        params = [item for item in params if item]
         if connection_params.driver.name != "MysqlNativeSocket":
             if tunnel.port:
                  params.insert(1, "--protocol=tcp")
@@ -929,7 +948,8 @@ class WbAdminImportTab(WbAdminSchemaListTab):
             return
 #        if cmd[0] != '"':
 #            cmd = '"' + cmd + '"'
-        cmd += " " + (" ".join(params))
+        #cmd += " " + (" ".join(params))
+        cmd = subprocess.list2cmdline([cmd] + params)
 
         password = self.get_mysql_password()
         if password is None:
@@ -1343,6 +1363,17 @@ class WbAdminExportTab(WbAdminSchemaListTab):
 
     def validate_single_transaction(self, starting):
         schemas_to_dump = self.table_list_model.get_objects_to_dump()
+        if self.single_transaction_check.get_active() and self.owner.get_lock_tables() == {'lock-tables': 'TRUE'}:
+            r = mforms.Utilities.show_warning("Export to Disk", 
+                              "Single transaction with --lock-tables is not supported.\n"
+                              "Disable --lock-tables?",
+                              "Disable", "Cancel", "")
+            if r == mforms.ResultOk:
+                self.owner.set_lock_tables(False)
+                return True
+            else:
+                return False
+
         # check if there are >1 schemas selected and if so, that all tables are selected in each
         if len(schemas_to_dump) > 1 and self.single_transaction_check.get_active():
             if not self.table_list_model.validate_single_transaction(schemas_to_dump):
@@ -1437,7 +1468,7 @@ class WbAdminExportTab(WbAdminSchemaListTab):
         operations = []
         if save_to_folder:
             if not os.path.exists(self.path):
-                os.makedirs(self.path)
+                os.makedirs(self.path, mode=0700)
             for schema, tables in schemas_to_dump:
                 for table in tables:
                     title = "Dumping " + schema
@@ -1456,7 +1487,7 @@ class WbAdminExportTab(WbAdminSchemaListTab):
                 os.makedirs(os.path.dirname(self.path))
 
             # if there is a single schema to dump or single-transaction is off we allow selecting the tables
-            if len(schemas_to_dump) == 1 or not single_transaction:
+            if (len(schemas_to_dump) != 1 and not single_transaction) or (len(schemas_to_dump) == 1 and not self.table_list_model.validate_single_transaction(schemas_to_dump)):
                 for schema, tables in schemas_to_dump:
                     if dump_views:
                         tables += self.table_list_model.get_views_by_schema(schema)
@@ -1497,11 +1528,13 @@ class WbAdminExportTab(WbAdminSchemaListTab):
 
         if connection_params.driver.name == "MysqlNativeSocket":
             params = {
-            "protocol":"pipe",
+            "protocol":"pipe" if sys.platform == "win32" else "socket",
             "socket":([conn["socket"]])[0],
             "default-character-set":"utf8",
             "user":conn["userName"]
-            }            
+            }
+            if not params["socket"]:
+                del params["socket"]
         else:
             params = {
             "host":(tunnel.port and ["localhost"] or [conn["hostName"]])[0],
@@ -1520,11 +1553,13 @@ class WbAdminExportTab(WbAdminSchemaListTab):
         if cmd == None:
             self.failed("mysqldump command was not found, please install it or configure it in Edit -> Preferences -> MySQL")
             return
-        if cmd[0] != '"':
-            cmd = '"' + cmd + '"'
-        cmd += " --password="
+        #if cmd[0] != '"':
+        #    cmd = '"' + cmd + '"'
+        #cmd += " --password="
+        args = [cmd, "--password="]
         for paramname, paramvalue in params.items():
-            cmd += " --"+paramname+((paramvalue != None and ["="+str(paramvalue)] or [""])[0])
+            args.append("--"+paramname+((paramvalue != None and ["="+str(paramvalue)] or [""])[0]))
+        cmd = subprocess.list2cmdline(args)
         password = self.get_mysql_password()
         if password is None:
             self.cancelled("Password Input Cancelled")
@@ -1704,7 +1739,7 @@ class WbAdminExportTab(WbAdminSchemaListTab):
 ####################################################################################################
 
 class WbAdminExportOptionsTab(mforms.Box):
-    class check_option_getter:
+    class check_option_model:
         def __init__(self,optname,checkbox,default):
             self.optname = optname
             self.checkbox = checkbox
@@ -1716,6 +1751,9 @@ class WbAdminExportOptionsTab(mforms.Box):
             else:
                 return {self.optname:(self.checkbox.get_active() and ["TRUE"] or ["FALSE"])[0]}
 
+        def set_option(self, value):
+            self.checkbox.set_active(value)
+
 
     def __init__(self):
         mforms.Box.__init__(self, False)
@@ -1737,7 +1775,7 @@ class WbAdminExportOptionsTab(mforms.Box):
                 checkbox.set_text("%s - %s"% (optname, option[0]))
                 checkbox.set_active(option[1] == "TRUE")
                 box.add(checkbox, False, True)
-                self.options[optname] = self.check_option_getter(optname,checkbox,option[1])
+                self.options[optname] = self.check_option_model(optname,checkbox,option[1])
             if groupname == "Other":
                 max_allowed_packet_box = newBox(True)
                 self.max_allowed_packet_te = newTextEntry()
@@ -1756,6 +1794,12 @@ class WbAdminExportOptionsTab(mforms.Box):
         scrollpan.add(outerbox)
         self.add(scrollpan, True, True)
 
+    def get_lock_tables(self):
+        return self.options["lock-tables"].get_option()
+
+    def set_lock_tables(self, value):
+        return self.options["lock-tables"].set_option(value)
+
     def get_options(self):
         options = {}
         for optname, getter in self.options.items():
@@ -1770,15 +1814,19 @@ class WbAdminExportOptionsTab(mforms.Box):
 class WbAdminExport(mforms.Box):
     ui_created = False
 
-    def __init__(self, instance_info, ctrl_be):
+    def __init__(self, instance_info, ctrl_be, main_view):
         mforms.Box.__init__(self, False)
+        main_view.ui_profile.apply_style(self, 'page')
         self.ctrl_be = ctrl_be
         self.set_managed()
         self.secman = None
         self.instance_info = instance_info
+        self.main_view = main_view
+        self.main_view.add_content_page(self, "DATA EXPORT / RESTORE", "Data Export and Restore", "admin_manage_exported_win")
 
 
     def page_activated(self):
+        self.main_view.set_content_label(" Data Export and Restore")
         if not self.ui_created:
             self.suspend_layout()
             self.create_ui()
@@ -1820,6 +1868,12 @@ class WbAdminExport(mforms.Box):
     def shutdown(self): # called when admin tab is closed
         if self.ui_created:
             self.export_tab.close()
+
+    def get_lock_tables(self):
+        return self.options_tab.get_lock_tables()
+
+    def set_lock_tables(self, value):
+        return self.options_tab.set_lock_tables(value)
  
  
     def get_export_options(self):
