@@ -1,4 +1,4 @@
-# Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -17,6 +17,8 @@
 
 from mforms import newBox, newLabel, newButton, newTextEntry, newTreeView, newTable, newRadioButton, newListBox, newSelector, newPanel, newTabView, Utilities, newCheckBox, newImageBox, App
 import mforms
+import re
+import getpass
 
 from wb_admin_utils import not_running_warning_label
 from wb_admin_security_be import AdminSecurity, PrivilegeInfo, SecurityAdminRoles, WBSecurityValidationError
@@ -51,6 +53,28 @@ SCHEMA_OTHER_RIGHTS = [
 ]
 
 
+AUTHENTICATION_PLUGIN_TYPES = {
+None : {"name" : "Standard", 
+        "auth_string_label": "",
+        "enable_host": True,
+        "enable_password" : True,
+        },
+"authentication_windows" : { "name": "Windows Native",
+        "auth_string_label": "Supply the Windows username and/or group names that are allowed to use this account, separated by a comma (,)\nThis account will be usable by these users whenever they are logged into Windows, without additional passwords.\nExample: Administrator, %s" % (getpass.getuser() or "joe"),
+        "enable_host": False,
+        "enable_password" : False
+        },
+"authentication_pam" : {"name": "PAM",
+        "auth_string_label": "Syntax: <pam_service_name>[,<group_name1>=<sql_user_name1>  [,<group_name2>=<sql_user_name2> ...]]\nSee documentation for details.",
+        "enable_host": False,
+        "enable_password" : False
+        },
+"*" : {"name": None,
+        "auth_string_label": "See the plugin documentation for valid values and details.",
+        "enable_host": True,
+        "enable_password" : True
+        }
+}
 
 def rLabel(text):
     l = newLabel(text)
@@ -211,6 +235,7 @@ class SecurityAccount(mforms.Box):
 
         self._selected_user = None
         self._selected_user_original = None
+        self.valid = False
 
         self.suspend_layout()
         self.set_padding(8)
@@ -285,7 +310,7 @@ class SecurityAccount(mforms.Box):
         abox.set_spacing(8)
         top_box.add(abox, True, True)
     
-        self.account_label = newLabel("Select an Account to Edit")
+        self.account_label = newLabel("Select an account to edit or click Add Account to create a new one")
         self.account_label.set_style(mforms.BoldStyle)
         
         abox.add(self.account_label, False, True)
@@ -295,11 +320,15 @@ class SecurityAccount(mforms.Box):
         abox.add(tabView, True, True)
         
         ##
+        vbox = newBox(False)
+        vbox.set_spacing(12)
+        vbox.set_padding(12)
+        tabView.add_page(vbox, "Login")
+
         table = newTable()
-        tabView.add_page(table, "Login")
-        
-        table.set_padding(12)
-        table.set_row_count(4)
+        vbox.add(table, False, True)
+                        
+        table.set_row_count(7)
         table.set_column_count(3)
         table.set_row_spacing(8)
         table.set_column_spacing(8)
@@ -315,37 +344,66 @@ class SecurityAccount(mforms.Box):
         self.confirm.set_size(150, -1)
         self.confirm.add_changed_callback(self.set_dirty)
         
-        #radiobox = newBox(False)
-        #radiobox.set_spacing(4)
-        #self.hostany = RadioButton()
-        #self.hostany.set_text("Allow connections from any host (%)")
-        #self.hostany.add_clicked_callback(self.host_limit_clicked)
-#        radiobox.add(self.hostany, False, True)
-        #rbox = newBox(True)
-        #rbox.set_spacing(12)
-#        self.hostlimit = RadioButton()
-        #self.hostlimit.set_text("Limit to host:")
-        #self.hostlimit.add_clicked_callback(self.host_limit_clicked)
-        #rbox.add(self.hostlimit, False, True)
         self.hostlimithost = newTextEntry()
-        self.hostlimithost.add_changed_callback(self.set_dirty)
-        #rbox.add(self.hostlimithost, True, True)
-        #self.hostlimithost.set_size(200, -1)
-        #rbox.add(dLabel("% and _ wildcards may be used"), False, True)
-        #radiobox.add(rbox, False, True)
-
+        self.hostlimithost.add_changed_callback(self.validate_hostlimithost)
+        
         table.add(rLabel("Login Name:"), 0, 1, 0, 1, mforms.HFillFlag)
         table.add(self.username, 1, 2, 0, 1, mforms.HFillFlag)
         table.add(dLabel("You may create multiple accounts with the same name\nto connect from different hosts."), 2, 3, 0, 1, mforms.HFillFlag|mforms.HExpandFlag)
-        table.add(rLabel("Password:"), 0, 1, 1, 2, mforms.HFillFlag)
-        table.add(self.password, 1, 2, 1, 2, mforms.HFillFlag)
-        table.add(dLabel("Type a password to reset it."), 2, 3, 1, 2, mforms.HFillFlag|mforms.HExpandFlag)
-        table.add(rLabel("Confirm Password:"), 0, 1, 2, 3, mforms.HFillFlag)
-        table.add(self.confirm, 1, 2, 2, 3, mforms.HFillFlag)
-        table.add(dLabel("Enter password again to confirm."), 2, 3, 2, 3, mforms.HFillFlag|mforms.HExpandFlag)
-        table.add(rLabel("Limit Connectivity to Hosts Matching:"), 0, 1, 3, 4, mforms.HFillFlag)
-        table.add(self.hostlimithost, 1, 2, 3, 4, mforms.HFillFlag)
-        table.add(dLabel("% and _ wildcards may be used"), 2, 3, 3, 4, mforms.HFillFlag|mforms.HExpandFlag)
+
+        self.has_extra_plugins = len([p for p in self.active_plugins if p not in ("mysql_native_password", "mysql_old_password")]) > 0
+
+        if self.has_extra_plugins:
+            self.auth_type_label = rLabel("Authentication Type:")
+            table.add(self.auth_type_label, 0, 1, 1, 2, mforms.HFillFlag)
+            self.auth_type_sel = newSelector()
+            table.add(self.auth_type_sel, 1, 2, 1, 2, mforms.HFillFlag|mforms.HExpandFlag)
+            table.add(dLabel("\nFor the standard password and/or host based authentication,\nselect 'Standard'.\n"), 2, 3, 1, 2, mforms.HFillFlag)
+            self.auth_type_sel.add_changed_callback(self.auth_type_changed)
+            self.auth_type_list = []
+            for plugin in [None] + self.active_plugins:
+                if plugin in ("mysql_native_password", "mysql_old_password"):
+                    continue
+                if AUTHENTICATION_PLUGIN_TYPES.has_key(plugin):
+                    self.auth_type_sel.add_item(AUTHENTICATION_PLUGIN_TYPES[plugin]["name"])
+                else:
+                    self.auth_type_sel.add_item(plugin)
+                self.auth_type_list.append(plugin)
+        else:
+            self.auth_type_list = None
+            self.auth_string_param = None
+
+        self.auth_type_password_labels = []
+        def add(label, l = self.auth_type_password_labels):
+            l.append(label)
+            return label
+
+        table.add(add(rLabel("Limit Connectivity to Hosts Matching:")), 0, 1, 2, 3, mforms.HFillFlag)
+        table.add(self.hostlimithost, 1, 2, 2, 3, mforms.HFillFlag)
+        self.hostlimit_box = newBox(True)
+        self.hostlimithost_valid_icon = newImageBox()
+        self.hostlimit_box.add(self.hostlimithost_valid_icon, False, False)
+        self.hostlimit_box.add(add(dLabel("% and _ wildcards may be used")), True, True)
+        table.add(self.hostlimit_box, 2, 3, 2, 3, mforms.HFillFlag|mforms.HExpandFlag)
+        
+        table.add(add(rLabel("Password:")), 0, 1, 3, 4, mforms.HFillFlag)
+        table.add(self.password, 1, 2, 3, 4, mforms.HFillFlag)
+        table.add(add(dLabel("Type a password to reset it.")), 2, 3, 3, 4, mforms.HFillFlag|mforms.HExpandFlag)
+        table.add(add(rLabel("Confirm Password:")), 0, 1, 4, 5, mforms.HFillFlag)
+        table.add(self.confirm, 1, 2, 4, 5, mforms.HFillFlag)
+        table.add(add(dLabel("Enter password again to confirm.")), 2, 3, 4, 5, mforms.HFillFlag|mforms.HExpandFlag)
+
+        table.add(newLabel(""), 1, 2, 5, 6, mforms.HFillFlag)
+
+        if self.has_extra_plugins:
+            self.auth_string_param = newTextEntry()
+            self.auth_string_param.add_changed_callback(self.set_dirty)
+            self.auth_string_label = rLabel("Authentication String:")
+            table.add(self.auth_string_label, 0, 1, 6, 7, mforms.HFillFlag)
+            table.add(self.auth_string_param, 1, 2, 6, 7, mforms.HFillFlag|mforms.HExpandFlag)
+            table.add(dLabel("Authentication plugin specific parameters."), 2, 3, 6, 7, mforms.HFillFlag)
+            self.auth_string_help = newLabel("")
+            vbox.add(self.auth_string_help, False, True)
 
         ####
         
@@ -418,9 +476,72 @@ class SecurityAccount(mforms.Box):
         table.add(dLabel("The number of simultaneous connections to the server the account can have."), 2, 3, 3, 4, mforms.HFillFlag|mforms.HExpandFlag)
 
         self.resume_layout()
-      
+
         self.user_selected()
 
+    @property
+    def active_plugins(self):
+        return [name for name, ptype in self.owner.ctrl_be.server_active_plugins if ptype == "AUTHENTICATION"]
+
+    def selected_plugin_type(self):
+        if self.auth_type_list:
+            return self.auth_type_list[max(self.auth_type_sel.get_selected_index(), 0)]
+        return None
+
+    def update_enable_state_for_auth_type(self, auth_type):
+        info = AUTHENTICATION_PLUGIN_TYPES.get(auth_type)
+        if not info:
+            info = AUTHENTICATION_PLUGIN_TYPES["*"]
+
+        if info:
+            self.password.set_enabled(info["enable_password"])
+            self.confirm.set_enabled(info["enable_password"])
+            self.hostlimithost.set_enabled(info["enable_host"])
+
+            if self.auth_string_param:
+                self.auth_string_help.set_text(info["auth_string_label"])
+
+                if auth_type is None:
+                    self.auth_string_label.set_enabled(False)
+                    self.auth_string_param.set_enabled(False)
+                    for label in self.auth_type_password_labels:
+                        label.set_enabled(True)
+                else:
+                    self.auth_string_label.set_enabled(True)
+                    self.auth_string_param.set_enabled(True)
+                    for label in self.auth_type_password_labels:
+                        label.set_enabled(False)
+
+
+    def set_hostlimithost(self, value):
+        self.hostlimithost.set_value(value)
+        self.validate_hostlimithost()
+
+
+    def auth_type_changed(self):
+        if not self.has_extra_plugins:
+            return
+
+        auth_type = self.selected_plugin_type()
+        self.update_enable_state_for_auth_type(auth_type)
+
+        info = AUTHENTICATION_PLUGIN_TYPES.get(auth_type)
+        if not info:
+            info = AUTHENTICATION_PLUGIN_TYPES["*"]
+
+        if info:
+            if not info["enable_password"]:
+                self.password.set_value("")
+                self.confirm.set_value("")
+
+            if not info["enable_host"]:
+                self.set_hostlimithost("%")
+
+            if auth_type is None and self.auth_string_param:
+                self.auth_string_param.set_value("")
+
+        self.set_dirty()
+
 
     def role_list_toggled(self, row, col, value):
         if self._selected_user:
@@ -457,11 +578,11 @@ class SecurityAccount(mforms.Box):
 
         if sel >= 0:
             user, host = eval(self.user_list.get_row_tag(sel))
-            self.account_label.set_text("Details for Account %s@%s" % (user, host))
+            self.account_label.set_text("Details for account %s@%s" % (user, host))
 
             user_info = self.owner.secman.async_get_account(self.show_user, user, host)
         else:
-            self.account_label.set_text("Select an Account to Edit")
+            self.account_label.set_text("Select an account to edit or click Add Account to create a new one")
 
 
     def show_user(self, user):
@@ -486,16 +607,22 @@ class SecurityAccount(mforms.Box):
             self.password.set_value("")
             self.confirm.set_value("")
 
-            #if user.host == "%":
-            #    self.hostany.set_active(True)
-            #    self.hostlimit.set_active(False)
-            #    self.hostlimithost.set_enabled(False)
-            #else:
-            #    self.hostany.set_active(False)
-            #    self.hostlimit.set_active(True)
-            #    self.hostlimithost.set_enabled(True)
-            #    self.hostlimithost.set_value(user.host)
-            self.hostlimithost.set_value(user.host)
+            self.set_hostlimithost(user.host)
+            
+            if self.auth_type_list:
+                try:
+                    index = self.auth_type_list.index(user.auth_plugin or None)
+                except ValueError, x:
+                    mforms.Utilities.show_warning("Invalid Authentication Plugin", 
+                              "User %s has plugin type %s, which is not listed as a known authentication plugin by the server." % (user.formatted_name(), user.auth_plugin), 
+                              "OK", "", "")
+                    return
+
+                self.auth_type_sel.set_selected(index)
+                # changing auth type not supported atm
+                self.auth_type_sel.set_enabled(not user.is_commited)
+                self.auth_string_param.set_value(user.auth_string or "")
+                self.update_enable_state_for_auth_type(user.auth_plugin or None)
 
             self.max_questions.set_value(str(user.max_questions))
             self.max_updates.set_value(str(user.max_updates))
@@ -512,7 +639,10 @@ class SecurityAccount(mforms.Box):
             self.password.set_value("")
             self.confirm.set_value("")
             
-            self.hostlimithost.set_value("")
+            self.set_hostlimithost("")
+
+            if self.auth_string_param:
+                self.auth_string_param.set_value("")
 
             self.max_questions.set_value("")
             self.max_updates.set_value("")
@@ -541,14 +671,16 @@ class SecurityAccount(mforms.Box):
 
     def del_account(self):
         if self._selected_user:
-            if Utilities.show_message("Remove Account",
-                  "The account '%s@%s' will be permanently removed. Please confirm."%(self._selected_user.username, self._selected_user.host),
+            if not self._selected_user.is_commited or Utilities.show_message("Remove Account",
+                  "The account '%s' will be permanently removed. Please confirm."%(self._selected_user.formatted_name()),
                   "Remove", "Cancel", "") == mforms.ResultOk:
+                the_name = self._selected_user.formatted_name()
                 self.owner.secman.delete_account(self._selected_user)
                 self._selected_user = None
                 self._selected_user_original = None
                 self.refresh()
                 self.user_selected()
+                mforms.App.get().set_status_text("Account '%s' was deleted" % the_name)
 
 
     def refresh(self):
@@ -584,6 +716,24 @@ class SecurityAccount(mforms.Box):
                 self.role_priv_list.set_string(row, 0, priv)
         self.role_priv_list.thaw_refresh()
 
+    def validate_hostlimithost(self):
+        host = self.hostlimithost.get_string_value()
+        self.valid_name = False
+        if len(host) <= 255:
+            if host[-1:] == ".":
+                host = host[:-1]
+            allowed = re.compile("(?!-)[_%A-Z\d-]{1,63}(?<!-)$", re.IGNORECASE)
+            self.valid_name = all(allowed.match(x) for x in host.split("."))
+
+        if self.valid_name:
+            #self.set_dirty()
+            self.hostlimithost_valid_icon.show(False)
+        else:
+            #self.unset_dirty()
+            self.hostlimithost_valid_icon.set_image("mini_error.png")
+            self.hostlimithost_valid_icon.show()
+            self.hostlimithost_valid_icon.set_tooltip("Host name contains incorrect characters")
+
     def set_dirty(self):
         self.save_button.set_enabled(True)
         self.revert_button.set_enabled(True)
@@ -618,8 +768,13 @@ class SecurityAccount(mforms.Box):
         if self._selected_user:
             username = self.username.get_string_value()
             host = self.hostlimithost.get_string_value()
-
-            if not self._selected_user.is_commited and not self.password.get_string_value():
+            
+            is_new_user = not self._selected_user.is_commited
+            
+            password_unneeded = False
+            if self.has_extra_plugins and not AUTHENTICATION_PLUGIN_TYPES[self.selected_plugin_type()]["enable_password"]:
+                password_unneeded = True
+            if is_new_user and not self.password.get_string_value() and not password_unneeded:
                 if Utilities.show_warning("Save Account Changes",
                         "It is a security hazard to create an account with no password.\nPlease confirm creation of '%s'@'%s' with no password."%(username, host),
                         "Create", "Cancel", "") != mforms.ResultOk:
@@ -638,6 +793,12 @@ class SecurityAccount(mforms.Box):
             self._selected_user.max_connections = int(self.max_connections.get_string_value())
             self._selected_user.max_user_connections = int(self.max_uconnections.get_string_value())
 
+            if is_new_user and self.has_extra_plugins:
+                self._selected_user.auth_plugin = self.selected_plugin_type()
+
+            if self._selected_user.auth_plugin:
+                self._selected_user.auth_string = self.auth_string_param.get_string_value()
+
             try:
                 self._selected_user.save()
             except WBSecurityValidationError, exc:
@@ -649,9 +810,15 @@ class SecurityAccount(mforms.Box):
                       str(exc), "OK", "", "")
                 return
             
+            the_name = self._selected_user.formatted_name()
+            
             self._selected_user.load(self._selected_user.username, self._selected_user.host)
             self.owner.refresh()
-
+            
+            if is_new_user:
+                mforms.App.get().set_status_text("Created account '%s'" % the_name)
+            else:
+                mforms.App.get().set_status_text("Updated account '%s'" % the_name)
 
 #############################
 
