@@ -22,7 +22,7 @@
 
 #include "wb_editor_storednote.h"
 #include "GrtTemplates.h"
-#include "string_utilities.h"
+#include "base/string_utilities.h"
 
 #pragma make_public(::StoredNoteEditorBE)
 
